Form 10-K for the Fiscal Year Ended June 30, 2004

-----BEGIN PRIVACY-ENHANCED MESSAGE----- Proc-Type: 2001,MIC-CLEAR Originator-Name: webmaster@www.sec.gov Originator-Key-Asymmetric: MFgwCgYEVQgBAQICAf8DSgAwRwJAW2sNKK9AVtBzYZmr6aGjlWyK3XmZv3dTINen TWSM7vrzLADbmYQaionwg5sDW3P6oaM5D3tdezXMm7z1T+B+twIDAQAB MIC-Info: RSA-MD5,RSA, ROV6G/Q/ww7Zeo3hSd0CDooGkzJ/DeMRq19D3wsu7+e0V6RYCT5Y8tgOOafcR4TW NqhXnOpUoL624uC6dLqJFA== 0001193125-04-150689.txt : 20040901 0001193125-04-150689.hdr.sgml : 20040901 20040901170300 ACCESSION NUMBER: 0001193125-04-150689 CONFORMED SUBMISSION TYPE: 10-K PUBLIC DOCUMENT COUNT: 16 CONFORMED PERIOD OF REPORT: 20040630 FILED AS OF DATE: 20040901 DATE AS OF CHANGE: 20040901 FILER: COMPANY DATA: COMPANY CONFORMED NAME: MICROSOFT CORP CENTRAL INDEX KEY: 0000789019 STANDARD INDUSTRIAL CLASSIFICATION: SERVICES-PREPACKAGED SOFTWARE [7372] IRS NUMBER: 911144442 STATE OF INCORPORATION: WA FISCAL YEAR END: 0630 FILING VALUES: FORM TYPE: 10-K SEC ACT: 1934 Act SEC FILE NUMBER: 000-14278 FILM NUMBER: 041011640 BUSINESS ADDRESS: STREET 1: ONE MICROSOFT WAY #BLDG 8 STREET 2: NORTH OFFICE 2211 CITY: REDMOND STATE: WA ZIP: 98052 BUSINESS PHONE: 4258828080 MAIL ADDRESS: STREET 1: ONE MICROSOFT WAY - BLDG 8 STREET 2: NORTH OFFICE 2211 CITY: REDMOND STATE: WA ZIP: 98052-6399 10-K 1 d10k.htm FORM 10-K FOR THE FISCAL YEAR ENDED JUNE 30, 2004

##### Table of Contents

United States Securities and Exchange Commission

Washington, D.C. 20549

FORM 10-K

x ANNUAL REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF 1934

FOR THE FISCAL YEAR ENDED JUNE 30, 2004

OR

¨ TRANSITION REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF 1934

FOR THE TRANSITION PERIOD FROM TO

COMMISSION FILE NUMBER 0-14278

MICROSOFT CORPORATION

WASHINGTON |  | 91-1144442
(STATE OF INCORPORATION) |  | (I.R.S. ID)

ONE MICROSOFT WAY, REDMOND, WASHINGTON 98052-6399

(425) 882-8080

Securities registered pursuant to Section 12(b) of the Act:

NONE

Securities registered pursuant to Section 12(g) of the Act:

COMMON STOCK

Indicate by check mark whether the registrant (1) has filed all reports required to be filed by Section 13 or 15(d) of the Securities Exchange Act of 1934 during the preceding 12 months (or for such shorter period that the registrant was required to file such reports), and (2) has been subject to such filing requirements for the past 90 days. Yes x No ¨

Indicate by check mark if disclosure of delinquent filers pursuant to Item 405 of Regulation S-K is not contained herein, and will not be contained, to the best of registrant’s knowledge, in definitive proxy or information statements incorporated by reference in Part III of this Form 10-K or any amendment to this Form 10-K. ¨

Indicate by check mark whether the registrant is an accelerated filer (as defined in Rule 12b-2 of the Exchange Act). Yes x No ¨

The aggregate market value of common stock held by non-affiliates of the registrant as of December 31, 2003 was $252,132,492,030.

The number of shares outstanding of the registrant’s common stock as of August 15, 2004 was 10,872,704,667.

DOCUMENTS INCORPORATED BY REFERENCE

Portions of the definitive Proxy Statement to be delivered to shareholders in connection with the Annual Meeting of Shareholders to be held November 9, 2004 are incorporated by reference into Part III.

##### Table of Contents

Microsoft Corporation

FORM 10-K

For The Fiscal Year Ended June 30, 2004

INDEX

PART I |  |  |  |
Item 1. |  | Business |  | 1
Item 2. |  | Properties |  | 10
Item 3. |  | Legal Proceedings |  | 11
Item 4. |  | Submission of Matters to a Vote of Security Holders |  | 11
|  | Executive Officers of the Registrant |  | 11
PART II |  |  |  |
Item 5. |  | Market for Registrant’s Common Equity, Related Stockholder Matters and Issuer Purchases of Equity Securities |  | 13
Item 6. |  | Selected Financial Data |  | 14
Item 7. |  | Management’s Discussion and Analysis of Financial Condition and Results of Operations |  | 15
Item 7A. |  | Quantitative and Qualitative Disclosures about Market Risk |  | 33
Item 8. |  | Financial Statements and Supplementary Data |  | 35
Item 9. |  | Changes in and Disagreements with Accountants on Accounting and Financial Disclosure |  | 65
Item 9A. |  | Controls and Procedures |  | 65
Item 9B. |  | Other Information |  | 65
PART III |  |  |  |
Item 10. |  | Directors and Executive Officers of the Registrant |  | 66
Item 11. |  | Executive Compensation |  | 66
Item 12. |  | Security Ownership of Certain Beneficial Owners and Management |  | 66
Item 13. |  | Certain Relationships and Related Transactions |  | 66
Item 14. |  | Principal Accountant Fees and Services |  | 66
PART IV |  |  |  |
Item 15. |  | Exhibits and Financial Statement Schedules |  | 66
|  | Signatures |  | 68

##### Table of Contents

Part I

Item 1

PART I

ITEM 1. BUSINESS

GENERAL

Over the last three decades, technology has transformed the way people work, play, and communicate. Today, people access information and communicate with individuals from around the world in an instant. Groundbreaking technologies have opened the door to innovations in every field of human endeavor, delivering new opportunity, convenience, and value to people’s lives. Since our founding in 1975, we have been a leader in this transformation. As a reflection of that role, and to help us focus on the opportunities that lie ahead we have established a new corporate mission: To enable people and businesses throughout the world to realize their full potential.

PRODUCT SEGMENTS

Our product segments provide management with a comprehensive financial view of our key businesses. The segments provide a framework for the alignment of strategies and objectives across the development, sales, marketing, and services organizations, and for the timely and rational allocation of development, sales, marketing, and services resources within businesses. The segments also help focus strategic planning efforts on key objectives and initiatives across our broad businesses.

The product segments are designed to allocate resources internally and provide a framework to determine management responsibility. Due to our integrated business structure, operating costs included in one segment may benefit other segments. Therefore, these segments are not designed to measure operating income or loss that is directly related to the products included in each segment. Inter-segment cost commissions are estimated by management and used to compensate or charge each segment for such shared costs and to incent shared effort. Due to our integrated business structure, segments should not be viewed as discrete or easily separable businesses.

Our seven product segments are: Client; Server and Tools; Information Worker; Microsoft Business Solutions; MSN; Mobile and Embedded Devices; and Home and Entertainment. See Note 18 – Segment Information of the Notes to Financial Statements for financial information regarding segment reporting.

Client. The Client segment has overall responsibility for product delivery, engineering, and technical architecture for the Microsoft Windows operating system and new media technology, as well as our relationships with manufacturers of personal computers, including multinational and regional original equipment manufacturer (OEM) accounts. The segment includes sales and marketing expenses for the Windows Client operating system and product development efforts for the Windows platform.

The Client segment includes Windows XP and other standard Windows operating systems. Windows XP extends the personal computing experience by uniting PCs, devices, and services, while enhancing reliability, security, and performance. With emerging form factors such as the Tablet PC and Media Center, and with investments in technology such as Windows Media, we believe the “Windows PC” continues to evolve with innovations that enable people to use computers in more ways, in more places, and more often than ever before.

Windows XP Home Edition is designed for individuals or families and includes capabilities for digital photo, music, video, home networking, and communications. Windows XP Professional, designed for business users and people who demand the most from their computing experience, includes all the features of Home Edition, along with advanced security, performance, manageability, and multilingual features to help customers improve their productivity and connectivity. Windows XP 64-Bit Edition meets the demands of specialized technical workstation users.

The next generation of the Windows operating system, code-named Longhorn, is currently under development. This development phase represents a significant investment for the Client business and is expected to result in a product that is more manageable and deployable for both our business and consumer markets. While all features and functions have not been finalized, Longhorn will include significant advances in security, digital media, user interfaces, and other areas that are expected to enhance the user and developer experience. We are targeting broad availability of this operating system in calendar year 2006. We are also developing a Windows storage subsystem, which will provide advanced data organization and management capabilities, that we plan to deliver subsequent to the Longhorn operating system introduction.

PAGE |  | 1

##### Table of Contents

Part I

Item 1

Server and Tools. The Server and Tools segment has overall responsibility for integrated product development and marketing of Windows Server System products, including building and marketing Windows Server operating systems. Windows Server System is integrated server infrastructure software that is designed to support end-to-end solutions built on the Windows Server 2003 operating system. In addition, the segment provides information about the extended Microsoft platform through a variety of content offerings, such as Web-based training for developers and IT professionals. Through this segment, we offer a broad range of consulting services for advanced technology requirements, including custom solution services, enterprise application planning, architecture and design services, and proof-of-concept services. We also provide product support services to corporations and other large customers. The Server and Tools segment also includes: developer tools, training, and certification; Microsoft Press; the Enterprise and Partner Group, which is responsible for sales, partner management and partner programs for the enterprise business; and the Public Sector sales and marketing organization.

Products in Server and Tools provide a wide range of capabilities that include messaging and collaboration, database management, e-commerce, and mobile information access. These products are designed to work seamlessly with one another and with advancements in applications and development tools. This architecture is designed to help simplify the design, development, deployment, and management of solutions so that customers can focus less on integrating systems and training users, and more on adding strategic value to their businesses. Windows Server System also readily integrates with customers’ existing non-Microsoft systems, through support for open standards such as HTTP and XML, and through native support for XML-based Web services.

Windows Server delivers a platform for powering connected applications, networks, and Web services from the work group to the data center. SQL Server is a database-and-analysis offering for rapidly delivering the next generation of scalable e-commerce, line-of-business, and data-warehousing solutions. Exchange Server, a business tool for e-mail collaboration, enables information workers to gain access to critical business communications. Systems Management Server (SMS) provides a comprehensive solution for change and configuration management of information systems, which we believe enables organizations to provide relevant software and updates to users quickly and cost-effectively. Small Business Server helps small businesses do more with a business server solution that includes messaging and collaboration, security-enhanced Internet access, protected data storage, reliable printing, the ability to run line-of-business applications, and faxing. BizTalk Server is designed to help customers efficiently and effectively integrate systems, employees, and trading partners through manageable business processes, enabling them to automate and orchestrate interactions in a flexible and highly automated manner. Developer tools focus on coordinating the overall programming model for the client and server, creating tools for developing Microsoft .NET-connected applications and services, and fostering synergies between Windows and the Windows Server System offerings.

Information Worker. The Information Worker segment is responsible for developing and delivering technologies that transform information into impact for people and organizations that create, analyze, communicate, and use information every day. The products in this segment help people to be more productive, with more control over their time and more opportunity to realize their potential. These applications are a critical part of the application architecture for many enterprises, enabling businesses to liberate information from individual silos, become more agile and flexible, and respond more readily to new opportunities.

The segment consists of the Microsoft Office System of programs, servers, services, and solutions. Microsoft Office System 2003, the successor to Microsoft Office XP, was released to market in the first half of fiscal 2004 and has evolved from a suite of personal productivity products to a more comprehensive and integrated system of products designed to increase personal, team, and organization productivity. The Microsoft Office System features integration with Microsoft intranet collaboration technologies, Information Rights Management, and support for industry standard XML. The Microsoft Office System includes the Microsoft Office 2003 Editions, which include (depending upon the edition): Microsoft Office Outlook 2003; Microsoft Office Excel 2003; Microsoft Office PowerPoint 2003; Microsoft Office Word 2003; and Microsoft Office Access 2003. Other products in the Microsoft Office System include: Microsoft Office Visio 2003; Microsoft Office Project 2003; Microsoft Office Project Server 2003; Microsoft Office InfoPath 2003; Microsoft Office OneNote 2003; Microsoft Office Publisher 2003; Microsoft Office FrontPage 2003; and Microsoft Office SharePoint Portal Server 2003. In addition, the Information Worker segment includes Microsoft Office Live Meeting Web conferencing service and professional product support.

Historically, approximately 40 percent of Information Worker billed revenue comes from multi-year license agreements with large enterprises. Revenues from these licenses generally depend upon the number of information workers in a licensed enterprise. Therefore, our revenue from this category of agreements is relatively independent of the number of PCs sold in a given year, but rather depends on the number of employees in a given enterprise.

PAGE |  | 2

##### Table of Contents

Part I

Item 1

Consequently, general employment levels, particularly in North America and EMEA, significantly affect Information Worker revenue. Approximately 40 percent of Information Worker revenue comes from new licenses acquired through fully packaged product and transactional volume licensing programs to individual consumers and enterprises of all sizes. Most of this revenue is sensitive to information technology budgets, which often depend on general economic conditions. The remaining approximately 20 percent of Information Worker revenue is from licenses to OEMs for new PCs and through sales of retail packaged products and is affected by the relative level of PC shipments.

For fiscal 2004, the segment includes the Small and Mid-Market Solutions & Partners (SMS&P) organization, which is responsible for sales, partner management, partner programs, and customer segment marketing to small and mid-market businesses. During fiscal 2004, we combined the existing small and medium business sales force with the sales and marketing assets of the Microsoft Business Solutions segment to form the SMS&P organization. We announced in the fourth quarter of fiscal 2004 a reorganization which, effective July 1, 2004, will include the SMS&P organization in the Microsoft Business Solutions segment. This change is designed to optimize our focus on delivering business applications to small and mid-market segment businesses.

Microsoft Business Solutions. The Microsoft Business Solutions segment is responsible for developing and marketing integrated, end-to-end business applications and services designed to help small and mid-market businesses achieve success by becoming more connected with customers, employees, partners, and suppliers. The applications provide integrated, end-to-end automation for financial reporting, distribution, project accounting, electronic commerce, human resources and payroll, manufacturing, supply chain management, business intelligence, sales and marketing management, customer relationship management, and customer service and support.

The segment consists of the businesses generated from Enterprise Resource Planning (Microsoft Great Plains, Microsoft Navision, Microsoft Solomon and Microsoft Axapta – acquired through our purchase of Great Plains and Navision); Microsoft CRM (Customer Relationship Management); Microsoft RMS (Retail Management System); and other business applications and services. Microsoft Business Solutions products are sold, implemented, and supported through a partner network consisting of value-added resellers, systems integrators, consultants, independent software vendors (ISVs), accounting firms (national, regional, and local), application service providers (ASPs), and eBuilders. Microsoft Business Solutions partners provide distribution, marketing, training, and support in the business application customer segment. As described previously, beginning in the first quarter of fiscal 2005, the SMS&P organization, which was part of the Information Worker segment, will be included in the Microsoft Business Solutions segment.

MSN. MSN is responsible for delivering online services that seek to empower people by bringing them closer to the people and information that matter most to them. MSN provides personal communications services, such as e-mail and instant messaging, and information services such as MSN Search and the MSN portals and channels around the world. MSN manages many of its own properties, including health, autos, and shopping. MSN also creates alliances with leading third parties for many channels, including top partners like MSNBC.com, a joint venture between NBC Universal and Microsoft; Foxsports.com, a property of Fox Entertainment Group; Expedia.com and Match.com, operating units of InterActiveCorp and CareerBuilder.com. MSN provides a variety of paid services resulting in revenue for the segment, including MSN Internet Access, Premium Web Services (consisting of MSN Internet Software Subscription, MSN Hotmail Plus, MSN Bill Pay, and MSN Radio Plus), and MSN Mobile services.

The segment generates revenue principally from advertisers on the MSN Web sites, from consumers through subscriptions and transactions generated from MSN Premium Web Services, and from subscribers to MSN narrowband Internet access. According to studies performed by Nielson Net Ratings and comScore Media Metrix, MSN Web sites are among the most popular on the Internet, visited by more than 350 million unique users every month. MSN Hotmail is one of the world’s largest e-mail services with more than 187 million accounts, and MSN Messenger is one of the world’s largest instant-messaging services with more than 135 million accounts.

Mobile and Embedded Devices. The Mobile and Embedded Devices segment is responsible for the development and marketing of products that extend the advantages of the Windows platform to many types of devices, including mobile devices that incorporate voice, personal information management, and media capabilities, and a wide variety of other devices designed to improve people’s personal and work lives. Microsoft’s vision for mobile devices is rooted in the convergence of the computing and wireless industries, which brings new opportunities to improve communication and information access for customers. We see software as a key differentiator in making smart devices and wireless data services valuable to customers through rich experiences such as location-based services, media, and speech recognition. We are working closely with mobile operators, hardware and ISV partners to

PAGE |  | 3

##### Table of Contents

Part I

Item 1

accelerate the development and availability of smart devices and services, and to provide a broad range of choices for customers. Further, the segment is responsible for managing sales and customer relations with device manufacturers and with network service providers, including telecommunications, cable and wireless companies, and host and network equipment providers.

The segment consists of the Windows Mobile software platform, the Windows Embedded device operating system family, MapPoint, and Windows Automotive. The Windows Mobile software platform provides a familiar and integrated customer experience that is the basis for specific products like the Pocket PC, Pocket PC Phone Edition, Smartphone, and new Portable Media Center. Windows Embedded, including Windows CE and Windows XP Embedded, is a family of embedded device software platforms used in non-PC computing devices. Windows Embedded software is used widely in advanced consumer electronics devices, including digital televisions, Internet Protocol (IP)-based set top boxes, network gateways, and portable media players, as well as in enterprise devices such as industrial controllers, retail point-of-sale systems, and voice-over-IP phones. The MapPoint family of location-enabled products and services includes the MapPoint Web Service, a hosted programmable XML Web service that allows developers to integrate location intelligence in applications, business processes and Web sites, and business and consumer oriented mapping CD-ROM products. Windows Automotive is an automotive-grade software platform that provides developers with the building blocks to quickly and reliably create a broad range of advanced telematics solutions.

Home and Entertainment. The Home and Entertainment segment is primarily responsible for realizing Microsoft’s plans to grow a range of new consumer businesses, building on the Windows platform to offer a broad range of services and applications running on a wide variety of devices in the home. The Home and Entertainment segment is responsible for the development of and business strategy for the Microsoft Xbox video game system, including hardware, third-party games development, games development published under the Microsoft label, Xbox and Xbox Live operations, marketing, research, and sales and support. The segment leads the development efforts of our Home Products Division (HPD) product lines. It also carries out all retail sales and marketing for Microsoft Office, the Windows operating systems, Xbox, games, and HPD products. It is also responsible for the development, sales, and deployment of Microsoft’s TV platform products for the interactive television industry.

Microsoft Xbox, released in fiscal 2002, is our video game console system that delivers high-quality graphics and audio experiences. We offer several types of entertainment products, including classic software games, online games, simulations, and strategy games. HPD includes Microsoft’s line of consumer hardware and software products, such as the Encarta line of learning products and services, the Macintosh applications business, and Microsoft hardware products.

EQUITY METHOD INVESTMENTS

We have entered into joint venture arrangements to take advantage of creative talent and content from other organizations. The majority of our joint ventures are managed by the MSN segment. MSNBC Cable L.L.C., a 24-hour cable news and information channel and MSNBC Interactive News L.L.C., an interactive news service, both of which are owned 50% by us and 50% by National Broadcasting Company (NBC); ninemsn Pty Ltd, an Australian internet portal; and T1MSN, an internet portal serving Mexico are some of our joint venture arrangements.

OPERATIONS

We develop products for sale throughout the world. Our major geographic sales and marketing organizations are the North American Region; the Latin American Region; the Europe, Middle East, and Africa Region (EMEA); Japan; the Asia-Pacific Region; Greater China; and the worldwide OEM channel. To serve the needs of customers around the world, we “localize” many of our products to reflect local languages and conventions, and to improve the quality and usability of the product in international markets. Localizing a product may require modifying the user interface, altering dialog boxes, and translating text. Our research and development facilities are located primarily in Redmond, with smaller facilities located in Mountain View, California; Fargo, North Dakota; Beijing, China; Dublin, Ireland; Vedbaek, Denmark; Hyderabad, India; Haifa, Israel; and Cambridge, England.

We have regional operations centers in Ireland, Singapore, and the greater Seattle area. The centers support all operations in their regions, including information processing and vendor management and logistics. The regional center in Dublin, Ireland, supports the Europe, Middle East, and Africa region; the center in Singapore supports the

PAGE |  | 4

##### Table of Contents

Part I

Item 1

Japan, Greater China and Asia-Pacific region; and the center in the greater Seattle area supports North America and Latin America. Microsoft Licensing, GP, a wholly-owned entity in Reno, Nevada, manages our original equipment manufacturer (OEM) and certain organizational licensing operations and billing.

We contract most of our manufacturing activities to third parties. Outside manufacturers produce the Xbox, various retail software packaged products, and Microsoft hardware. Our products may include some components that are available from only one or limited sources. Key components that are currently obtained from a single source include the Xbox central processing unit (CPU) from Intel Corporation and the Xbox graphics processing unit (GPU) from NVIDIA Corporation. With the exception of the Xbox CPU and GPU, we generally have the ability to use other custom manufacturers if the current manufacturing vendor becomes unavailable. We generally have multiple sources for raw materials, supplies, and components, and are often able to acquire component parts and materials on a volume discount basis.

Pressure to globalize our pricing structure might require that we reduce the sales price of our software in the United States and other countries. A number of other factors could also have a negative effect on our business and results from operations outside of the United States, including changes in trade protection laws, policies and measures, and other regulatory requirements affecting trade and investment; unexpected changes in regulatory requirements for software; social, political, labor, or economic conditions in a specific country or region, including foreign exchange rates; difficulties in staffing and managing foreign operations; and potential adverse foreign tax consequences. We hedge a portion of our international currency exposures, thereby reducing our overall translation exposures.

PRODUCT DEVELOPMENT

During fiscal 2002, 2003, and 2004, research and development expense was $6.30 billion, $6.60 billion, and $7.78 billion respectively. Those amounts represented 22.2%, 20.5%, and 21.1%, respectively, of revenue in each of those years. Fiscal 2002 and 2003 have been restated to reflect the retroactive adoption of SFAS 123, Accounting for Stock-Based Compensation. We plan to continue significant investment on a broad range of research and product development.

Most of our software products are developed internally. We also purchase technology, license intellectual property rights, and oversee third-party development and localization of certain products. We believe we are not materially dependent upon licenses and other agreements with third parties relating to the development of our products. Internal development allows us to maintain closer technical control over our products. It also gives us the freedom to decide which modifications and enhancements are most important and when they should be implemented. Product documentation generally is also created internally. We strive to obtain information at the earliest possible time about changing usage patterns and hardware advances that may affect software design. Before releasing new software platforms, we provide application vendors with a range of resources and guidelines for development, training, and testing.

Business and Product Development Strategy. The key to Microsoft’s growth is innovation. In fiscal 2004, we filed for more than 2,000 patents for new technologies, and we expect that number to increase. We expect these innovations to lead to revenue growth from market expansion, share growth, new scenarios and market opportunities, and value-added through services.

Key areas of focus include:

| • |  | PC Market Growth: It took more than 20 years to grow the worldwide base of PC users to 600+ million. By 2010, we expect this base to grow to 1 billion, due to opportunities in emerging markets and new scenarios and form factors expected to stimulate demand. Our continued success will depend on delivering secure, groundbreaking software and compelling scenarios that capture the imagination of end users. We are working on new PC and Windows designs to make PCs affordable to millions of additional people around the world.

| • |  | New Information Worker Scenarios: We believe one of our biggest growth opportunities is with our existing base of Office users. We plan to pursue this market by delivering new information worker scenarios such as collaboration, authoring, communications, planning and analysis, and expanding the toolset with new technologies such as SharePoint, Live Meeting, OneNote and InfoPath.

PAGE |  | 5

##### Table of Contents

Part I

Item 1

| • |  | Enhanced Server Position: We believe Windows Server 2003 and our other server offerings provide customers with significant advantages in many areas, including innovation, performance, productivity, applications development tools and environment, security and manageability. In addition, we offer an integrated platform that includes our server and Information Worker applications as well as partner ISV workloads and applications.

| • |  | Reducing Complexity and Cost for IT Professionals and Developers: We believe that building applications, integration, and managing information technology are still too hard for customers. We are working on new ways to further lower costs and speed time to deploy technology for IT professionals and developers. We believe we are already helping reduce costs and increase business value with products such as Windows Server 2003, Visual Studio .NET, SMS 2003, the Dynamic Systems Initiative, and Microsoft Operations Manager 2005.

| • |  | IT Services for Smaller Business and Consumers: The MSN, Windows, and Office teams are working together on a set of integrated IT services for smaller businesses and consumers designed to enhance security, lower costs, and improve the end-user experience in areas such as communication, collaboration, and desktop management.

| • |  | Business Solutions: Microsoft Business Solutions continues to expand its small and mid-market offerings with key investments in technologies for CRM, online services, retail management, and small business. We believe we have a significant opportunity to help this underserved market, while creating great opportunities for ISVs and partners.

| • |  | Non-PC Consumer Electronics: We believe that our work to integrate the richness and intelligence of the PC world with everyday devices such as mobile phones, handheld devices, home entertainment and TV provides a broad new market opportunity. At the center of our efforts are products such as Pocket PC and Smartphone, Portable Media Center, MSTV, MSN TV, Windows Automotive, the Windows Media Center Extender, and other electronic devices built on Windows CE and Windows XP Embedded.

| • |  | Entertainment: Likewise, we believe there is significant opportunity in delivering compelling entertainment experiences in key scenarios such as music, TV, movies, photos and games. Our vision centers on creating new and exciting ways for people to have fun with friends and family with Media Center PCs, devices like Xbox and Portable Media Center, and many of the other applications and services that Microsoft and our partners deliver.

| • |  | Advertising/Information: The value that MSN and our platform bring to advertisers is already significant, as evidenced by the fact that our MSN advertising business today is a $1 billion-plus business. We believe the potential to expand advertising in all our online offerings is significant. In fiscal 2005, we will invest in and deliver improvements in search, music and other information services that should continue to provide good growth opportunities. We believe our industry has only scratched the surface in search. We are making significant investments to improve the user experience and deliver the information people want more efficiently and effectively.

| • |  | Communications: Broadband and wireless technology is increasing the amount of time people spend online. Younger and savvier Internet users want communications experiences to build their social network on any device. We believe professionals and information workers want integrated, secure functionality that help them manage their personal and professional lives: personalized email, instant messaging, contact management, shared calendars, and relationship management. We are pursuing these opportunities by developing communications offerings designed to provide the greatest benefit to consumers and device manufacturers. For example, our Windows Mobile software is the basis for new mobile smartphones and for Portable Media Center devices from leading consumer electronics companies.

DISTRIBUTION, SALES AND MARKETING

We distribute our products primarily through the following channels: OEM; distributors and resellers; and online services. Our six major geographic sales and marketing organizations are the North American Region; the Latin American Region; the Europe, Middle East, and Africa Region; Japan; the Asia-Pacific Region and Greater China.

OEM. Our operating systems are licensed primarily to OEMs under agreements that grant the OEMs the right to build computing devices based on our operating systems, principally PCs. Under similar arrangements, we also market and license certain server operating systems, desktop applications, hardware devices, and consumer software products to OEMs. We have OEM agreements covering one or more of our products with virtually all of the

PAGE |  | 6

##### Table of Contents

Part I

Item 1

major PC OEMs, including Acer, Actebis, Dell, eMachines, Fujitsu, Gateway, HP, IBM, NEC, Samsung, Siemens Computers, Sony, and Toshiba. A substantial amount of OEM business is also conducted with system builders, which are low-volume customized PC vendors operating in local markets.

Distributors and Resellers. We distribute our finished goods products primarily through independent non-exclusive distributors, authorized replicators, resellers, and retail outlets. Organizations license our products primarily through Large Account Resellers (LARs), Direct Market Resellers (DMRs), and value-added resellers. Many organizations that license products through Enterprise Agreements (EAs) now transact directly with us, with sales support from our Enterprise Software Advisor channel partners. These Enterprise Software Advisors typically are also authorized as LARs and operate as resellers for our other licensing programs. Although each type of reselling partner reaches organizations of all sizes, LARs are primarily engaged with large organizations and value-added resellers typically reach the breadth of small- and medium-sized organizations. Some of our distributors include Ingram Micro and Tech Data, and some of our largest resellers include Software Spectrum, Software House International, Dell, CDW, and Insight Enterprises. Individual consumers obtain our products primarily through retail outlets, including Best Buy, Wal-Mart, and Target. We have a network of field sales representatives and field support personnel that solicits orders from distributors and resellers and provides product training and sales support.

We license software to organizations under arrangements that allow the end-user customer to acquire multiple licenses of product. These arrangements are designed to provide organizations with a means of acquiring multiple licenses, without having to acquire separate packaged product through retail channels. In delivering organizational licensing arrangements to the market, we use different programs designed to provide flexibility for organizations of various sizes. While these programs may differ in various parts of the world, generally they are as follows:

Open. Designed primarily for small-to-medium organizations (5 to over 250 licenses), this program allows customers to acquire perpetual licenses and, at the customer’s election, rights to future versions of software products over a specified time period (generally two years). The offering that conveys rights to future versions of software product over the contract period is called Software Assurance. Software Assurance also provides support, tools, and training to help customers deploy and use software efficiently. Under the Open program, customers can acquire licenses only, or licenses with Software Assurance. They can also renew Software Assurance upon the expiration of existing volume licensing agreements.

Select. Designed primarily for medium-to-large organizations (greater than 250 licenses), this program allows customers to acquire perpetual licenses and, at the customer’s election, Software Assurance, which consists of rights to future versions of software products, support, tools, and training over a specified time period (generally three years). Similar to the Open program, customers can acquire licenses only, acquire licenses with Software Assurance, or renew Software Assurance upon the expiration of existing volume licensing agreements.

Enterprise Agreement. The Enterprise Agreement is targeted at medium and large organizations that want to acquire perpetual licenses to software products for all or substantial parts of their enterprise, along with rights to future versions of software products, generally over a three-year period.

Enterprise Subscription Agreement. The Enterprise Subscription Agreement (ESA) is a time-based, multi-year licensing agreement. Under an ESA, customers acquire the right to use the current version of software products and the future versions that are released during the three-year term of the agreement. At the end of the term, customers may either renew their ESA or exercise a buy-out option to obtain perpetual licenses for the latest version of the covered products. If they do not elect one of these options, then all previously covered software must be uninstalled.

Online Services. We distribute online content and services through MSN and other online services. MSN delivers Internet access and other premium services and tools to consumers. MSN also delivers online e-mail and messaging communication services as well as information services such as online search and premium content. Microsoft Business Solutions operates the bCentral small-business portal, which is delivered online. The bCentral portal provides tools and expertise for small-business owners to build, market, and manage their businesses online. Other services delivered online include Xbox Live, Microsoft Developer Networks (MSDN) subscription content and updates, periodic product updates, and online technical and practice readiness resources to support our partners in developing and selling our products and solutions.

PAGE |  | 7

##### Table of Contents

Part I

Item 1

CUSTOMERS

Our customers include individual consumers, small and medium-sized organizations, enterprises, governmental institutions, educational institutions, Internet Service Providers, application developers, and OEMs. Consumers and small and medium-sized organizations obtain our products primarily through resellers and OEMs. Sales to Dell and its subsidiaries in the aggregate accounted for approximately 10% of fiscal 2004 revenue. These sales were made primarily through our OEM and volume licensing channels. No single customer accounted for more than 10% of revenue in 2002 or 2003. Our practice is to ship our products promptly upon receipt of purchase orders from customers; consequently, backlog is not significant.

COMPETITION

The software business is intensely competitive and subject to rapid technological change, evolving customer requirements, and changing business models in every segment. We face significant competition in all areas of our business. The rapid pace of technological change continually creates new opportunities for existing competitors and start-ups and can quickly render existing technologies less valuable. Customer requirements and preferences continually change as other information technologies emerge or become less expensive, and as concerns such as security and privacy become more important. Our direct competitors include firms adopting alternative business models to the commercial software model. Firms adopting the non-commercial software model typically provide customers with open source software at nominal cost and earn revenue on complementary services and products, without having to bear the full costs of research and development for the open source software. Global software piracy – the unlawful copying and distribution of our copyrighted software products – deprives us of significant amounts of revenue on an annual basis. Future versions of our products compete with the existing versions licensed to our installed base of customers. This means that future versions must deliver significant additional value in order to induce existing customers to purchase a new version of our product.

Our competitive position may be adversely affected in the future by one or more of the factors described in this section, or as yet undefined additional factors that may arise.

Client. Although we are the leader in PC operating system software products, we face strong competition from well-established companies and entities with differing approaches to the market. Competing commercial software products, including variants of Unix, are supplied by competitors such as IBM, Hewlett-Packard, Apple Computer, Sun Microsystems and others, which are vertically integrated in both software development and hardware manufacturing and have developed operating systems that they preinstall on their own computers. Personal computer OEMs who preinstall third-party operating systems may also license these firms’ operating systems. The Linux operating system, which is also derived from Unix and is available without payment under a General Public License, has gained increasing acceptance as competitive pressures lead personal computer OEMs to reduce costs. The Microsoft Windows operating systems also face competition from alternative platforms, as well as innovative devices that may reduce consumer demand for traditional personal computers. We believe our operating system products compete effectively by delivering better innovation, an easy-to-use interface, compatibility with a broad range of hardware and software applications, and the largest support network for any operating system.

Server and Tools. Our server operating system products face intense competition from a wide variety of competing server operating systems and server applications, offered by firms with a variety of market approaches. Vertically integrated computer manufacturers such as IBM, Hewlett-Packard, Sun Microsystems and others offer their own variant of Unix preinstalled on server hardware, and nearly all computer manufacturers offer server hardware for the Linux operating system. IBM’s endorsement of Linux has accelerated its acceptance as an alternative to both traditional Unix and Windows server operating systems. Linux’s competitive position has also benefited from the large number of compatible applications now produced by many leading commercial software developers as well as non-commercial software developers. A number of companies supply versions of Linux, including Novell and Red Hat.

We compete in the business of providing enterprise-wide computing solutions with several companies that provide competing solutions as well as middleware technology platforms. IBM and Sun Microsystems lead a group of companies focused on the Java 2 Platform Enterprise Edition (J2EE). Commercial software developers that provide competing server applications for the PC-based distributed client/server environments include Oracle, IBM, and Computer Associates. There are also a number of non-commercial software server applications available.

PAGE |  | 8

##### Table of Contents

Part I

Item 1

Numerous commercial software vendors offer competing commercial software applications for connectivity (both Internet and intranet), security, hosting, and e-business servers. Additionally, IBM has a large installed base of Lotus Notes and cc:Mail, both of which compete with our collaboration and e-mail products. There are also a significant number of non-commercial software products that compete with our solutions, including Apache Web Server.

Our developer products compete against offerings from BEA Systems, Borland, IBM, Macromedia, Oracle, Sun Microsystems, and other companies.

We believe that our server products provide customers with significant advantages in innovation, performance (both relative to total costs of ownership and in absolute terms), productivity, applications development tools and environment, compatibility with a broad base of hardware and software applications, security, and manageability.

Information Worker. While we are the leader in business productivity software applications for personal computers, competitors to the Microsoft Office System include many software application vendors such as Apple, Corel, IBM, Oracle, Sun Microsystems, and local application developers in Europe and Asia. IBM and Corel have significant installed bases with their office productivity products, and both have aggressive pricing strategies. Also, Apple and IBM preinstall certain of their application software products on various models of their PCs, competing directly with our applications. Corel’s suite and Sun Microsystems’ Star Office are aggressively priced and attractive for OEMs to preinstall on low-priced PCs. The OpenOffice.org project provides a freely downloadable cross-platform application that is gaining popularity in certain market segments. In addition to traditional client-side applications, Web-based offerings such as SimDesk provide an alternative to Microsoft Office System products. In addition, IBM has a significant installed base of messaging and collaboration software. We believe that our products compete effectively by providing customers significant benefits, such as ease of use, personal productivity, support for effective teaming and collaboration, and better information management and control, and by providing many customers a lower total cost of ownership than alternatives.

Microsoft Business Solutions. The small and mid-market business applications segment is highly fragmented and is intensely competitive in all sectors where we compete. We face competition from a large number of companies in this business. Well-known vendors focused on small and mid-market business solutions, such as Intuit and Sage (along with many others), compete against us for a portion of this segment. In addition, large-enterprise focused vendors, such as Oracle, PeopleSoft, and SAP, are repositioning some of their business applications to focus on small and medium-sized business and thus also compete against us for a portion of this segment. In addition, there are thousands of other vendors in specific localities or industries that offer their own enterprise resource planning (ERP), customer relationship management (CRM), and/or analytic solutions. We believe that our business applications products across financial management, supply chain management, and CRM compete effectively in our target segments by offering solutions and services that address multiple segment needs across industries through consistent innovation in product functionality delivered through a growing network of partners.

MSN. MSN competes with Yahoo!, Google, AOL, Earthlink, U.S. cable and DSL providers, and a vast array of Web sites and portals that offer content and online services of all types. MSN also competes with traditional advertising and print media. As the broadband access market grows, we expect to have increasing opportunities to deliver rich and compelling services and experiences for consumers. MSN’s advertising revenue has grown considerably over the last year, and we expect this trend to continue in display advertising as well as in search-based advertising, as online advertising continues to gain market acceptance. This growth has led to competitors aggressively pursuing both advertisers and consumers with expanded offerings and new technology. We are building our own algorithmic search engine and investing to support the continued growth of our advertising business. Due to the continuing trend of consumers migrating from narrowband to broadband Internet access, we expect our narrowband Internet access subscriber base to decline. We believe our competitive advantage comes from our ability to empower people globally through information software and services that help them find, discover, and experience what they want online.

Mobile and Embedded Devices. Windows Mobile software faces substantial competition from Nokia, Openwave Systems, PalmSource, QUALCOMM, and Symbian. The embedded operating system market is highly fragmented with many competitive offerings. Key competitors include IBM, Wind River, and versions of embeddable Linux from commercial Linux vendors such as Metrowerks and MontaVista Software. MapPoint competitors include DeLorme, MapInfo, Mapquest.com, Rand McNally, Webraska Mobile Technologies, and Yahoo! The telematics market is also highly fragmented, with competitive offerings from IBM and automotive suppliers building on various real-time

PAGE |  | 9

##### Table of Contents

Part I

Item 1, 2

operating system platforms from commercial Linux vendors, QNX Software Systems, Wind River, and others. We believe that our products compete effectively by providing a familiar development framework that enables developers to easily write and deploy innovative applications for mobile or embedded devices; providing a flexible platform that allows customers and partners to build differentiated and profitable business models; and providing end users significant benefits such as ease of use, personal productivity, and better information management and control.

Home and Entertainment. The home and entertainment business is highly competitive and is characterized by limited platform life cycles, frequent introductions of new products and titles, and the development of new technologies. The markets for our products are characterized by significant price competition, and we anticipate continued pricing pressure from our competitors. These pressures have, from time to time, required us to reduce prices on certain products. Our competitors vary in size from very small companies with limited resources to very large, diversified corporations with substantial financial and marketing resources. We compete primarily on the basis of price, product quality and variety, timing of product releases, and effectiveness of distribution and marketing.

Our Xbox hardware business competes with console platforms from Nintendo and Sony, both of which have a large established base of customers. In addition to competing against software published for non-Xbox platforms, our games business also competes with numerous companies that have been licensed by us to develop and publish software for the Xbox console. These competitors include Acclaim Entertainment, Activision, Atari, Capcom, Eidos, Electronic Arts, Sega, Take-Two Interactive, Tecmo, THQ, and Ubi Soft, among others. Success in the games business is increasingly driven by hit titles, which are difficult to develop and require substantial investments in development and marketing. In addition, other forms of entertainment such as music, motion pictures, and television compete against our entertainment software for consumer spending. We believe that our Xbox products compete effectively by providing customers benefits such as superior game console performance, exclusive game content, and innovative online multiplayer gaming through Xbox Live. Our PC hardware products face aggressive competition from computer and other hardware manufacturers, many of which are also current or potential partners.

EMPLOYEES

As of June 30, 2004, we employed approximately 57,000 people on a full-time basis, 37,000 in the United States and 20,000 internationally. Of the total, 24,000 were in product research and development, 16,000 in sales and marketing, 11,000 in product support and consulting services, 2,000 in manufacturing and distribution, and 4,000 in general and administration. Our success is highly dependent on our ability to attract and retain qualified employees. Competition for employees is intense in the software industry. We believe we have been successful in our efforts to recruit qualified employees, but we cannot guarantee that we will continue to be as successful in the future. None of our employees are subject to collective bargaining agreements. We believe that our relationship with our employees is excellent.

AVAILABLE INFORMATION

Our Internet address is www.microsoft.com. There we make available, free of charge, our annual report on Form 10-K, quarterly reports on Form 10-Q, current reports on Form 8-K, and any amendments to those reports, as soon as reasonably practicable after we electronically file such material with or furnish it to the SEC. Our SEC reports can be accessed through the investor relations section of our Web site. The information found on our Web site is not part of this or any other report we file with or furnish to the SEC.

ITEM 2. PROPERTIES

Our corporate offices consist of approximately 8.9 million square feet of office building space located in King County, Washington: 7.5 million square feet of that total is corporate campus space situated on slightly more than 300 acres of owned land and approximately 1.4 million square feet is leased. We are currently renovating two buildings with approximately 392,000 square feet that we plan to occupy in fiscal 2005. To accommodate future expansion needs we purchased approximately 63 acres, and have an option to purchase approximately 45 additional acres in Issaquah, Washington, which can accommodate 2.1 million square feet of additional office space. We own approximately 576,000 square feet of office building space domestically (outside of the Puget Sound corporate campus) and lease many sites domestically totaling approximately 2.8 million square feet of office building space.

PAGE |  | 10

##### Table of Contents

Part I

Item 2, 3, 4

We occupy many sites internationally, totaling approximately 6.1 million square feet that is leased and approximately 223,000 square feet that is owned. These facilities include our European Operations Center that leases a 187,000 square-foot campus in Dublin, Ireland, a 56,000 square-foot disk duplication facility in Humacao, Puerto Rico, and a 96,000 square-foot facility in Singapore for our Asia Pacific Operations Center and Regional headquarters. Leased office building space includes the following locations: Tokyo, Japan 459,000 square feet; Unterschleissheim, Germany 381,000 square feet; Les Ulis, France 261,000 square feet; Reading, England 241,000 square feet; and Mississauga, Canada 235,000 square feet. In addition to the above, we have various product development facilities, both domestically and internationally, as described in “Operations” above.

Our facilities are fully used for current operations of all segments, and suitable additional space is available to accommodate expansion needs.

ITEM 3. LEGAL PROCEEDINGS

See Note 17 – Contingencies of the Notes to Financial Statements (Item 8) for information regarding legal proceedings.

ITEM 4. SUBMISSION OF MATTERS TO A VOTE OF SECURITY HOLDERS

No matters were submitted to a vote of security holders during the fourth quarter of fiscal 2004.

EXECUTIVE OFFICERS OF THE REGISTRANT

Our executive officers as of August 25, 2004 were as follows:

Name |  | Age |  | Position with the Company
William H. Gates III |  | 48 |  | Chairman of the Board; Chief Software Architect
Steven A. Ballmer |  | 48 |  | Chief Executive Officer
James E. Allchin |  | 52 |  | Group Vice President, Platforms Group
Robert J. (Robbie) Bach |  | 42 |  | Senior Vice President, Home and Entertainment
Douglas J. Burgum |  | 48 |  | Senior Vice President, Microsoft Business Solutions
David W. Cole |  | 42 |  | Senior Vice President, MSN and Personal Services Group
John G. Connors |  | 45 |  | Senior Vice President; Chief Financial Officer
Jean-Philippe Courtois |  | 44 |  | Senior Vice President; CEO, Microsoft Europe, Middle East, and Africa
Kenneth A. DiPietro |  | 45 |  | Corporate Vice President, Human Resources
Kevin R. Johnson |  | 43 |  | Group Vice President, Worldwide Sales, Marketing and Services
Michelle (Mich) Mathews |  | 37 |  | Corporate Vice President, Marketing
Craig J. Mundie |  | 55 |  | Senior Vice President; Chief Technical Officer, Advanced Strategies and Policy
Jeffrey S. Raikes |  | 46 |  | Group Vice President, Information Worker Business
Eric D. Rudder |  | 37 |  | Senior Vice President, Server and Tools Business
Bradford L. Smith |  | 45 |  | Senior Vice President, General Counsel and Secretary
David Vaskevitch |  | 51 |  | Senior Vice President; Chief Technical Officer, Business Platforms

Mr. Gates co-founded Microsoft in 1975 and served as its Chief Executive Officer from the time the original partnership was incorporated in 1981 until January 2000, when he resigned as Chief Executive Officer and assumed the position of Chief Software Architect. Mr. Gates has served as Chairman since our incorporation.

Mr. Ballmer was named Chief Executive Officer and a director of the Company in January 2000. He served as President from July 1998 to February 2001. Previously, he had served as Executive Vice President, Sales and Support since February 1992. He joined Microsoft in 1980.

Mr. Allchin was named Group Vice President, Platforms Group in December 1999. He had been Senior Vice President, Platforms since March 1999. He was previously Senior Vice President, Personal and Business Systems since February 1996. Mr. Allchin joined Microsoft in 1990.

Mr. Bach was named Senior Vice President, Home and Entertainment in March 2000. He had been Vice President, Home and Retail since March 1999. Before holding that position, he had been Vice President, Learning, Entertainment and Productivity, and Vice President, Desktop Applications Marketing since 1996. Mr. Bach joined Microsoft in 1988.

PAGE |  | 11

##### Table of Contents

Part I

Item 4

Mr. Burgum joined the Company as Senior Vice President upon Microsoft’s acquisition of Great Plains Software, Inc. in April 2001. Prior to the acquisition, he had served as the Chairman and Chief Executive Officer of Great Plains. He joined Great Plains in 1983.

Mr. Cole was named Senior Vice President, MSN and Personal Services Group in November 2001. Before holding that position, he had been Senior Vice President, Services Platform Division since August 2000. He had been Senior Vice President, Consumer Services since December 1999 and Vice President, Consumer Windows since March 1999. Previously, he was Vice President, Web Client and Consumer Experience and Vice President, Internet Client and Collaboration. Mr. Cole joined Microsoft in 1986.

Mr. Connors was named Senior Vice President and Chief Financial Officer in December 1999. He had been Vice President, Worldwide Enterprise Group since March 1999. Mr. Connors had been Vice President, Information Technology Group, and Chief Information Officer since July 1996. He joined Microsoft in 1989.

Mr. Courtois was named Senior Vice President and Chief Executive Officer, Microsoft Europe, Middle East, and Africa in March 2003. He had been Senior Vice President and President, Microsoft Europe, Middle East, and Africa since July 2000. Before holding that position, he had been Vice President, Worldwide Customer Marketing since July 1998. Mr. Courtois joined Microsoft in 1984.

Mr. DiPietro joined Microsoft in January 2003 as Corporate Vice President, Human Resources. Prior to joining Microsoft, he was Vice President of Human Resources for the Americas at Dell Computer Corporation. Before joining Dell, he was Senior Vice President of Human Resources at Pepsi-Cola International.

Mr. Johnson was named Group Vice President, Worldwide Sales, Marketing and Services in March 2003. He had been Senior Vice President, Microsoft Americas since February 2002. Mr. Johnson had been Senior Vice President, U.S. Sales, Marketing, and Services since August 2001, and before that Vice President, U.S. Sales, Marketing and Services. He joined Microsoft in 1992.

Ms. Mathews was named Corporate Vice President, Marketing in August 2001. Before holding her current position, Ms. Mathews had been Vice President Corporate Public Relations since 1999. Ms. Mathews joined Microsoft in 1993.

Mr. Mundie was named Senior Vice President and Chief Technical Officer, Advanced Strategies and Policy in August 2001. He was named Senior Vice President, Consumer Platforms in February 1996. He joined Microsoft in 1992.

Mr. Raikes was named Group Vice President, Information Worker Business in June 2004. He had been Group Vice President, Productivity and Business Services since August 2000. Mr. Raikes had been Group Vice President, Sales and Support since July 1998. Mr. Raikes joined Microsoft in 1981.

Mr. Rudder was named Senior Vice President, Server and Tools Business in June 2003. Prior to assuming that role, he was responsible for managing Developer and Platform Evangelism. Mr. Rudder joined Microsoft in 1988.

Mr. Smith was named Senior Vice President, General Counsel and Secretary in November 2001. He had been Deputy General Counsel for Worldwide Sales and previously was responsible for managing the European Law and Corporate Affairs Group, based in Paris. He joined Microsoft in 1993.

Mr. Vaskevitch was named Senior Vice President and Chief Technical Officer, Business Platforms in August 2001. He had been Senior Vice President, Business Applications since March 2000. Mr. Vaskevitch had been Senior Vice President, Developer since December 1999. Before holding that position, he had been Vice President, Distributed Applications Platform. He joined Microsoft in 1986.

PAGE |  | 12

##### Table of Contents

Part II

Item 5

PART II

ITEM 5. MARKET FOR REGISTRANT’S COMMON EQUITY, RELATED STOCKHOLDER MATTERS, AND ISSUER PURCHASES OF EQUITY SECURITIES

Our common stock is traded on The NASDAQ Stock Market under the symbol MSFT. On August 10, 2004, there were 141,975 registered holders of record of our common stock. The high and low common stock prices per share were as follows:

Quarter Ended |  | Sep. 30 |  | Dec. 31 |  | Mar. 31 |  | June 30 |  | Year
Fiscal 2003 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Common stock price per share: |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
High |  | $ | 27.43 |  | $ | 29.12 |  | $ | 28.49 |  | $ | 26.37 |  | $ | 29.12
Low |  |  | 21.42 |  |  | 21.89 |  |  | 22.80 |  |  | 23.67 |  |  | 21.42
Fiscal 2004 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Common stock price per share: |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
High |  | $ | 29.96 |  | $ | 29.35 |  | $ | 28.80 |  | $ | 28.57 |  | $ | 29.96
Low |  |  | 25.54 |  |  | 25.10 |  |  | 24.15 |  |  | 25.08 |  |  | 24.15

In September 2003, our board of directors declared a common stock dividend of $0.16 per share, which was paid in November 2003. That was the only dividend declared or paid in fiscal 2004. Our dividend policy is based on, among other considerations, our views on potential future capital requirements relating to research and development, creation and expansion of sales distribution channels, investments and acquisitions, share dilution management, legal risks, and challenges to our business model.

On July 20, 2004, our board of directors approved a quarterly dividend of $0.08 per share payable on September 14, 2004, to shareholders of record on August 25, 2004. In addition, the board approved a plan to buy back up to $30 billion in Microsoft common stock over the next four years. The specific timing and amount of repurchases will vary based on market conditions, securities law limitations, and other factors. The repurchases will be made using our cash resources. The repurchase program may be suspended or discontinued at any time without prior notice. The board also approved a one-time special dividend of $3.00 per share, or approximately $32 billion, subject to shareholder approval of stock plan amendments that will allow certain adjustments to employee equity compensation awards to offset the impact of the special dividend. The special dividend will be payable on December 2, 2004, to shareholders of record on November 17, 2004, conditioned upon shareholder approval of amendments to the employee stock plans at the annual meeting of shareholders scheduled to be held November 9, 2004.

We did not repurchase any of our shares in the fourth quarter of fiscal 2004.

PAGE |  | 13

##### Table of Contents

Part II

Item 6

ITEM 6. SELECTED FINANCIAL DATA

FINANCIAL HIGHLIGHTS

(In millions, except per share data) |  |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2000(1) |  | 2001(1,2) |  | 2002(1,3) |  | 2003(1,4) |  | 2004
Revenue |  | $ | 22,956 |  | $ | 25,296 |  | $ | 28,365 |  | $ | 32,187 |  | $ | 36,835
Operating income |  |  | 11,006 |  |  | 11,720 |  |  | 8,272 |  |  | 9,545 |  |  | 9,034
Income before accounting change |  |  | 9,421 |  |  | 7,721 |  |  | 5,355 |  |  | 7,531 |  |  | 8,168
Net income |  |  | 9,421 |  |  | 7,346 |  |  | 5,355 |  |  | 7,531 |  |  | 8,168
Diluted earnings per share before accounting change |  | $ | 0.85 |  | $ | 0.69 |  | $ | 0.48 |  | $ | 0.69 |  | $ | 0.75
Diluted earnings per share |  | $ | 0.85 |  | $ | 0.66 |  | $ | 0.48 |  | $ | 0.69 |  | $ | 0.75
Cash dividends per share |  | $ | – |  | $ | – |  | $ | – |  | $ | 0.08 |  | $ | 0.16
Cash and short-term investments |  |  | 23,798 |  |  | 31,600 |  |  | 38,652 |  |  | 49,048 |  |  | 60,592
Total assets |  |  | 51,694 |  |  | 58,830 |  |  | 69,910 |  |  | 81,732 |  |  | 92,389
Stockholders’ equity |  |  | 41,368 |  |  | 47,289 |  |  | 54,842 |  |  | 64,912 |  |  | 74,825

(1) |  | The financial data presented for fiscal 2002 and 2003 has been restated as prescribed by SFAS 148, Accounting for Stock-Based Compensation – Transition and Disclosure and amendment of FASB Statement No. 123, to reflect the retroactive adoption of the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation as discussed in Note 13. The information presented for 2000 and 2001 has not been restated. If fiscal 2000 had been restated, the operating income and net income would have been $9,113 million and $8,172 million. If fiscal 2001 had been restated, the operating income and net income would have been $8,343 million and $5,084 million.

(2) |  | Fiscal 2001 includes an unfavorable cumulative effect of accounting change of $375 million or $0.03 per diluted share, reflecting the adoption of SFAS No. 133. Fiscal 2001 also includes the acquisition of Great Plains Software, Inc. for approximately $1.1 billion in stock.

(3) |  | Fiscal 2002 includes a $1.25 billion (pre-tax) gain on the sale of Expedia, Inc.

(4) |  | Fiscal 2003 includes the acquisition of Navision a/s, Rare Ltd. and Placeware, Inc. for a total of $1.23 billion in cash and $788 million in stock and other consideration.

PAGE |  | 14

##### Table of Contents

Part II

Item 7

ITEM 7. MANAGEMENT’S DISCUSSION AND ANALYSIS OF

FINANCIAL CONDITION AND RESULTS OF OPERATIONS

RESULTS OF OPERATIONS FOR 2002, 2003, AND 2004

Management’s Discussion and Analysis (MD&A) contains statements that are forward-looking. These statements are based on current expectations and assumptions that are subject to risks and uncertainties. Actual results could differ materially because of factors discussed in “Issues and Uncertainties” and elsewhere in this report.

OVERVIEW

The following Management’s Discussion and Analysis (“MD&A”) is intended to help the reader understand Microsoft Corporation. MD&A is provided as a supplement to, and should be read in conjunction with, our financial statements and the accompanying notes (“Notes”).

We generate revenues, income and cash flows by developing, manufacturing, licensing, and supporting a wide range of software products for many computing devices. Our software products include operating systems for servers, personal computers (PCs), and intelligent devices; server applications for distributed computing environments; information worker productivity applications; business solutions applications; and software development tools. We provide consulting and product support services, and we train and certify system integrators and developers. We sell the Xbox video game console and games, PC games and peripherals. Online communication services and information services are delivered through our MSN portals and channels around the world.

We also research and develop advanced technologies for future software products. Delivering breakthrough innovation and high-value solutions through our integrated platform are the key to meeting customer needs and to our future growth.

We believe that over the last few years we have laid a foundation for long-term growth, delivering innovative new products, creating opportunity for partners, improving customer satisfaction with key audiences, putting some of our most significant legal challenges behind us, and solidifying internal processes. Our focus in fiscal 2005 is building on this foundation and executing well in key areas, including continuing to innovate on our integrated software platform, delivering compelling value propositions to customers, responding effectively to customer and partner needs, and continuing to focus internally on product excellence, business efficacy, and accountability across the company.

Key market opportunities include:

| • |  | Meeting the needs of a growing worldwide base of PC users, which we project will top 1 billion by 2010;

| • |  | Delivering new scenarios such as collaboration, authoring, communicating, planning, and analysis for information workers;

| • |  | Continuing to compete against Linux and Unix for commercial workloads;

| • |  | Reducing complexity and cost for IT professionals and developers;

| • |  | Delivering IT services for smaller business, and consumers;

| • |  | Creating and delivering business solutions for small and mid-market segments;

| • |  | Creating non-PC consumer electronics in areas such as mobile phones, handheld devices, home entertainment and TV;

| • |  | Delivering compelling entertainment experiences in areas such as music, TV, movies, photos, and games;

| • |  | Expanding online advertising, and advances in search, music and other information services;

| • |  | Delivering integrated communications services for consumers and information workers.

For fiscal 2005, we believe industry-wide factors such as PC unit growth and the success of non-commercial software could significantly affect our results of operations and financial condition. PC unit growth was very strong in fiscal 2004, increasing approximately 13% from fiscal 2003. We do not expect similar growth to occur in fiscal 2005.

PAGE |  | 15

##### Table of Contents

Part II

Item 7

We believe that PC unit shipments will grow 7% to 9%, resulting in a forecasted fiscal 2005 Client revenue growth rate that we believe will be between 5% and 7%.

We continue to watch the evolution of open source software development and distribution, and continue to differentiate our products from competitive products including those based on open source software. We believe that Microsoft’s share of server units grew modestly in fiscal 2004, while Linux distributions rose slightly faster on an absolute basis. The increase in Linux distributions reflects some significant public announcements of support and adoption of open source software in both the server and desktop markets in the last year. To the extent open source software products gain increasing market acceptance, sales of our products may decline, which could result in a reduction in our revenue and operating margins.

Additionally, due primarily to our announced special dividend and quarterly dividend payments, if continued, we expect investment balances and resulting investment income to decrease significantly in fiscal 2005.

We have approximately $1.1 billion in original Upgrade Advantage contract value that will reach their expiration dates in the first quarter of fiscal 2005. This revenue was recognized over the last two years and in the first quarter of fiscal 2005 the contract period expires.

Summary

(In millions, except percentages) |  | 2002 |  | 2003 |  | Percentage inc./ (dec.) |  |  | 2004 |  | Percentage inc./ (dec.) |
Revenue |  | $ | 28,365 |  | $ | 32,187 |  | 13 | % |  | $ | 36,835 |  | 14 | %
Operating income |  | $ | 8,272 |  | $ | 9,545 |  | 15 | % |  | $ | 9,034 |  | (5 | )%

Our revenue growth for fiscal 2004 was driven by licensing of Windows Client operating systems through OEMs; Windows Server operating systems, Office, and other server applications as a result of growth in PC and server hardware shipments; and the continuing impact from multi-year licensing that occurred prior to the transition to our Licensing 6.0 program in the first quarter of fiscal 2003. We estimate growth in PC shipments was 13% during fiscal 2004, reflecting global economic improvement, which led to strength in the consumer segment in the first half of fiscal 2004 and to replacement PC and notebook sales in the enterprise segment in the second half of fiscal 2004. We estimate that total server hardware shipments grew 16%, with Windows Server shipments growing faster than the overall sector at 18% in fiscal 2004. The net impact of foreign exchange rates on revenue was positive in fiscal 2004, primarily due to a relative strengthening of most foreign currencies versus the U.S. dollar. Had the rates from the prior year been in effect in fiscal 2004, translated international revenue earned in local currencies would have been approximately $1.10 billion lower. We hedge a portion of our international currency exposures, thereby reducing our overall translation exposure. Prior to the July 31, 2002 Licensing 6.0 transition date, we experienced a significant increase in multi-year licensing arrangements as customers enrolled in our maintenance programs, primarily Upgrade Advantage. Revenue growth in fiscal 2003 was driven primarily by multi-year licensing that occurred before the Licensing 6.0 transition date in the first quarter of fiscal 2003. The revenue growth also reflected a $933 million or 13% increase associated with OEM licensing of Microsoft Windows operating systems and a $309 million or 23% increase in revenue from Microsoft Xbox video game consoles. Revenue growth in fiscal 2002 was led by the addition of $1.35 billion of Xbox video game system revenue and $1.20 billion of revenue growth from Microsoft Windows XP Professional and Home operating systems.

For fiscal 2004, the operating income decline of $511 million was primarily caused by the $2.53 billion of charges related to the Sun Microsystems settlement and a fine imposed by the European Commission in the third quarter of fiscal 2004 and $2.21 billion of stock-based compensation expense related to our employee stock option transfer program in the second quarter of fiscal 2004. Operating income was positively influenced by the revenue growth described above and operational improvements in our MSN business. In fiscal 2003, the growth in operating income reflected an increase of $3.82 billion in revenue, partially offset by an increase of $2.55 billion in operating expenses, primarily related to employee and related costs associated with additional headcount and increased legal settlement expenses, primarily the Time Warner settlement charge of $750 million. In fiscal 2002, the growth in operating income reflected an increase of $3.07 billion in revenue, substantially offset by an increase of $3.14 billion in operating expenses, which included the onset of costs related to Xbox video game systems.

We adopted the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, on July 1, 2003 and restated prior periods to reflect compensation cost under the recognition provisions of SFAS 123 for

PAGE |  | 16

##### Table of Contents

Part II

Item 7

all awards granted to employees after July 1, 1995. Stock-based compensation expenses are included in operating expenses as part of headcount-related costs. Total stock-based compensation costs included in operating expenses were $5.73 billion in fiscal 2004, $3.75 billion in fiscal 2003, and $3.78 billion in fiscal 2002.

In fiscal 2005, we do not expect revenue to grow at similarly high rates as fiscal 2004, even if information technology spending continues to improve. While we expect general economic conditions to remain stable with the improvements seen in the second half of fiscal 2004, we expect PC and server unit shipment growth rates to decline in fiscal 2005 from the high growth rates in fiscal 2004. We estimate PC shipments will grow from 7% to 9% and Server unit shipments will grow from 13% to 15% in fiscal 2005 compared to fiscal 2004. These lower growth rates may cause slower revenue growth in fiscal 2005. We are anticipating little or no year-over-year foreign exchange rate benefit in fiscal 2005.

We anticipate that we will renew between 10% and 30% of the expiring Upgrade Advantage program revenue through conversions to Software Assurance or migration to Enterprise Agreements. Total revenue expected to be recognized in our Information Worker, Server and Tools, and Client businesses from previously deferred Upgrade Advantage revenue is $56 million.

MSN had a strong year in fiscal 2004 with revenue growth of 13% driven by over 40% growth in advertising revenue. In fiscal 2005, we expect MSN to see growth in advertising revenue and subscription and transaction revenue from premium Web services, partially offset by a reduction in access revenue as narrowband subscribers continue to decline. Accordingly, we do not expect the same level of revenue growth for MSN in fiscal 2005.

Home and Entertainment revenue grew moderately in fiscal 2004. We do not expect significant growth in Home and Entertainment in fiscal 2005 as price reductions in the second half of fiscal 2004 related to the late stage of the Xbox lifecycle are expected to lead to lower revenue for the Xbox business.

We expect our operating income growth in fiscal 2005 to exceed our revenue growth. Operating income is expected to reflect lower operating expenses due to the absence of certain legal settlements which occurred in fiscal 2004, lower stock-based compensation costs, and benefits achieved through continued progress in our previously announced cost efficacy initiative. We expect that our segments in fiscal 2004 that reported a segment operating loss – Mobile and Embedded Devices, Microsoft Business Solutions, and Home and Entertainment – will make significant progress toward segment profitability in fiscal 2005 with improved operations.

SEGMENT PRODUCT REVENUE/OPERATING INCOME (LOSS)

Our seven segments are: Client; Server and Tools; Information Worker; Microsoft Business Solutions; MSN; Mobile and Embedded Devices; and Home and Entertainment.

The revenue and operating income/(loss) amounts MD&A are presented on a basis consistent with U.S. GAAP applied at the segment level. Certain corporate level expenses have been excluded. Those expenses primarily include corporate operations related to sales and marketing, product support services, human resources, legal, finance, IT, corporate development and procurement activities, research and development and other costs, and accrued legal contingencies. Corporate expenses were $3.08 billion, $3.74 billion and $4.66 billion in fiscal 2002, 2003 and 2004 respectively. Segment information appearing in Note 18 – Segment Information of the Notes to Financial Statements is presented in accordance with SFAS 131, Disclosures about Segments of an Enterprise and Related Information.

The tables that follow below for each segment present our segment revenue and operating income, determined on a basis consistent with U.S. GAAP:

Client

(In millions, except percentages) |  | 2002 |  | 2003 |  | Percentage inc./ (dec.) |  |  | 2004 |  | Percentage inc./ (dec.) |
Revenue |  | $ | 9,360 |  | $ | 10,394 |  | 11 | % |  | $ | 11,546 |  | 11 | %
Operating income |  | $ | 7,105 |  | $ | 8,017 |  | 13 | % |  | $ | 8,015 |  | nm |

PAGE |  | 17

##### Table of Contents

Part II

Item 7

Client includes revenue from Windows XP Professional and Home, Windows 2000 Professional, and other standard Windows operating systems. The growth of the Client segment’s revenue is largely correlated with the growth of purchases of PCs from OEMs that pre-install versions of Windows operating systems.

Client revenue increase was driven by a 14% growth in OEM licenses and 16% growth in OEM revenue on increased consumer PC unit shipments in the first half of the fiscal year and growth in business PC unit shipments in the second half of fiscal 2004. Revenue from commercial and retail licensing declined 4% due to lower revenue earned from Upgrade Advantage licensing agreements and lower packaged product sales. In fiscal 2003, Client revenue growth was driven by OEM licensing revenue growth of $933 million and a 9 percentage point increase in the mix of the higher priced Windows Professional operating systems, the majority of which was in the OEM channel. Windows Professional revenue growth for fiscal 2003 was $1.59 billion, or 31%, compared to fiscal 2002. The Windows Professional growth in fiscal 2003 was partially offset by a $573 million decline in revenue from earlier versions of Windows operating systems.

Client operating income was flat for fiscal 2004 compared to fiscal 2003 due to increased operating expenses primarily related to the charge for the Sun Microsystems settlement of $700 million in the third quarter of fiscal 2004 and $307 million of stock-based compensation expense from the employee stock option transfer program in the second quarter of fiscal 2004, offset by growth in revenue. Operating income for fiscal 2003 increased primarily as a result of the 11% growth in revenue, partially offset by an increase in operating expenses, largely attributed to headcount additions and related costs.

We estimate that PC market growth will be from 7% to 9% in fiscal 2005. We expect emerging markets to continue to outpace mature market growth rates and we expect to hold our share in these respective markets. The differential market growth rate is expected to result in lower unit license growth in the OEM business and lower revenue growth, as piracy continues to be problematic in emerging markets, and significant price changes are not anticipated. We plan to continue our efforts to increase premium product mix but expect to see only modest improvements in fiscal 2005. The Client commercial and retail licensing revenues are expected to continue to lag behind overall Client revenue growth. We expect operating profits as a percentage of Client revenue to improve in fiscal 2005, due to the legal settlements expenses and stock-based compensation expense from the employee stock option transfer program in fiscal 2004. Major investments in fiscal 2005 include development of the Windows Client next generation operating system (Longhorn), security programs, and marketing initiatives, including those related to Windows XP Service Pack 2 and other new products.

Server and Tools

(In millions, except percentages) |  | 2002 |  | 2003 |  | Percentage inc./ (dec.) |  |  | 2004 |  | Percentage inc./ (dec.) |
Revenue |  | $ | 6,157 |  | $ | 7,140 |  | 16 | % |  | $ | 8,483 |  | 19 | %
Operating income |  | $ | 747 |  | $ | 1,121 |  | 50 | % |  | $ | 96 |  | (91 | )%

Server and Tools consists of server software licenses and client access licenses (CALs) for Windows Server, SQL Server, Exchange Server, and other servers. It also includes developer tools, training, certification, Microsoft Press, Premier product support services, and Microsoft consulting services. Growth in the overall market for information technology, both hardware and software, is the principal driver for Server and Tools revenue growth. The segment concentrates on licensing products, applications, tools, content, and services that make information technology professionals and developers more productive and efficient. Products are sold through OEMs, distributors, direct to customers, and through one-time licenses or multi-year volume license agreements.

We estimate that overall server hardware shipments grew 16% in fiscal 2004 compared to the prior year. Server and Server applications revenue, including CAL revenue, grew $1.28 billion or 25% driven primarily by an estimated 18% increase in Windows-based server shipments resulting in 15% growth in new Windows Server licenses, and by favorable conversion of revenue billed in foreign currencies to U.S. dollars. Consulting and Premier product support services revenue increased $189 million or 19% compared to fiscal 2003 due to increased customer penetration from new product offerings. Revenue from developer tools, training, certification, and Microsoft Press and other services declined $128 million or 14% compared to fiscal 2003 due to recognition of revenue deferred in prior years. Foreign exchange rates contributed approximately $350 million or 5% of Server and Tools revenue growth.

PAGE |  | 18

##### Table of Contents

Part II

Item 7

Total Server and Tools revenue grew $983 million or 16% in fiscal 2003, driven by an increase in Windows-based server shipments and growth in SQL Server and Exchange revenue. Windows Server and CALs revenue grew $787 million or 18% from fiscal 2002 as a result of increased new and anniversary multi-year licensing agreements. Consulting and Premier product support services increased $91 million or 10% compared to fiscal 2002. Revenue from developer tools, training, certification, Microsoft Press, and other services increased $105 million or 13% from fiscal 2002.

Server and Tools operating income for fiscal 2004 declined primarily due to the charge for the Sun Microsystems settlement of $1.22 billion in the third quarter of fiscal 2004 and $651 million of stock-based compensation costs from the employee stock option transfer program in the second quarter of fiscal 2004. Server and Tools operating income for fiscal 2003 grew 50%, primarily as a result of the 16% increase in revenue.

We anticipate that overall server hardware shipments will grow from 13% to 15% in fiscal 2005 and new licenses of Windows Server operating system will grow slightly faster than the overall market. We believe that Windows Server 2003 shipments will create opportunities for sales of Windows Server System products. However, we face strong competition from the Linux-based, Unix, and other server operating systems. In addition, Server and Tools net revenue for fiscal 2005 will be unfavorably affected by the absence of revenue earned from our Upgrade Advantage program and no anticipated foreign exchange benefit.

Information Worker

(In millions, except percentages) |  | 2002 |  | 2003 |  | Percentage inc./ (dec.) |  |  | 2004 |  | Percentage inc./ (dec.) |
Revenue |  | $ | 8,212 |  | $ | 9,229 |  | 12 | % |  | $ | 10,800 |  | 17 | %
Operating income |  | $ | 5,932 |  | $ | 6,486 |  | 9 | % |  | $ | 7,151 |  | 10 | %

Information Worker consists of the Microsoft Office System of programs, servers, services, and solutions designed to increase personal, team, and organization productivity. Information Worker includes Microsoft Office, Microsoft Project, Microsoft Visio, SharePoint Portal Server CALs, other information worker products including Microsoft LiveMeeting and OneNote, and professional product support services. Most revenue from this segment comes from licensing our Office System products. Revenue growth depends on the ability to add value to the core Office product set and expand our product offerings in other Information Worker areas such as document lifecycle and collaboration.

Revenue growth for fiscal 2004 from volume licensing, retail packaged product and pre-installed versions of Office in Japan was 15% in aggregate. This increase was driven by recognition of unearned revenue primarily from a large increase in multi-year licenses signed prior to the transition to our Licensing 6.0 programs and approximately $110 million related to the launch of Office 2003. OEM licensing revenue grew 29% or $325 million. Foreign exchange rates provided approximately $485 million or 5% of total Information Worker revenue growth. The $1.02 billion or 12% increase in revenue in fiscal 2003 compared to fiscal 2002 was primarily due to growth in Office suites revenue associated with new and anniversary multi-year licensing agreements and a $264 million or 28% increase in revenue from the combined total of Microsoft Project, Microsoft Visio, and other stand-alone applications.

Information Worker operating income in fiscal 2004 increased from the prior year primarily due to growth in revenue, partially offset by an increase in operating expenses, primarily related to $351 million of stock-based compensation expense from the employee stock option transfer program in the second quarter of fiscal 2004 and higher sales and marketing expenses. Information Worker operating profit for fiscal 2003 grew 9% compared to fiscal 2002, led by the 12% increase in revenue and partially offset by a 20% growth in operating expenses related to headcount additions and marketing expenses.

Fiscal 2005 Information Worker revenue is expected to be similar to fiscal 2004. We are expecting a reduction in revenue earned from our Upgrade Advantage licensing agreements and no anticipated foreign exchange rate benefit. The significant reduction in Upgrade Advantage earned revenue is expected to be offset by sustained momentum in our OEM and multi-year licensing offerings and increased purchasing of Office System 2003 as enterprises complete their product evaluations.

PAGE |  | 19

##### Table of Contents

Part II

Item 7

Microsoft Business Solutions

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  |  | Percentage inc./ (dec.) |
Revenue |  | $ | 308 |  |  | $ | 567 |  |  | 84 | % |  | $ | 667 |  |  | 18 | %
Operating loss |  | $ | (301 | ) |  | $ | (309 | ) |  | 3 | % |  | $ | (255 | ) |  | (17 | )%

Microsoft Business Solutions includes Microsoft Great Plains, Microsoft Navision, Microsoft Axapta, Microsoft Solomon, Microsoft CRM, MBN/Retail Manager and other business applications and services. Our revenue is generally derived from developing and marketing integrated, end-to-end business applications and services designed to help small and mid-market businesses. The small and mid-market business applications market is highly fragmented and is intensely competitive in all sectors. Microsoft Business Solutions revenues are affected by the general economic environment and enterprise information technology spending in particular.

The revenue increase in fiscal 2004 was primarily attributable to continued growth in licensing of Navision and Axapta ERP products, and new sales of Microsoft CRM. Microsoft Business Solutions revenue for fiscal 2003 grew $259 million from fiscal 2002, of which $246 million was attributable to the acquisition of Navision at the beginning of the fiscal year.

The operating loss for fiscal 2004 declined from fiscal 2003 due to the increase in revenue and lower operating expenses including $42 million of lower amortization costs, partially offset by $27 million in stock-based compensation expense from the employee stock option transfer program in the second quarter of fiscal 2004. Microsoft Business Solutions operating loss for fiscal 2003 increased from fiscal 2002 primarily due to operating losses associated with Navision, increases in sales and marketing expenses, research and development expenses, and acquisition-related costs.

We announced in the fourth quarter of fiscal 2004 a plan to align and include the Small and Mid-Market Solutions & Partners (SMS&P) organization in the Microsoft Business Solutions segment. This change is designed to optimize our focus on delivering business applications to small and mid-market segment businesses. The SMS&P organization is currently part of the Information Worker segment. This reorganization will result in a corresponding change to the Microsoft Business Solutions and Information Worker reported results, primarily from the reorganization of approximately $100 million in revenue and costs associated with our Partner program offerings, which will move from Information Worker segment to Microsoft Business Solutions. In fiscal 2005, we expect continued growth for Microsoft Business Solutions through CRM, Axapta, Navision, and Great Plains product lines with increased sales and marketing focus from the SMS&P organization, and new product launches for Great Plains and Navision.

MSN

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  | Percentage inc./ (dec.) |
Revenue |  | $ | 1,571 |  |  | $ | 1,953 |  |  | 24 | % |  | $ | 2,216 |  | 13 | %
Operating income/(loss) |  | $ | (909 | ) |  | $ | (567 | ) |  | (38 | )% |  | $ | 121 |  | nm |

The MSN segment includes personal communications services, such as e-mail and instant messaging, and information services, such as MSN Search and the MSN portals and channels around the World. MSN also provides a variety of paid services resulting in revenue for the segment including MSN Internet Access, and MSN Premium Web Services. Revenue is principally generated from advertisers on MSN, from consumers through subscriptions and transactions generated from MSN Premium Web Services and from subscribers to MSN Narrowband Internet Access.

In fiscal 2004, MSN advertising revenue increased $360 million or 43% as a result of growth in paid search and growth in the overall Internet advertising market. This increase was partially offset by a decline of $168 million or 15% in Internet access revenue, primarily from the migration of internet access subscribers to broadband or other competitively priced Internet service providers. Revenue from subscription and transaction services other than Internet access increased $71 million in fiscal 2004 to $95 million. At the end of the current fiscal year, MSN had 4.3 million internet access subscribers compared to 6.5 million at the end of the prior fiscal year and 8.8 million total subscribers compared to 8.6 million at the end of the prior year. In addition, MSN has over 350 million unique users

PAGE |  | 20

##### Table of Contents

Part II

Item 7

monthly, 187 million active Hotmail accounts, and 135 million active Messenger accounts. Compared to fiscal 2002, MSN advertising revenue grew $270 million or 48% in fiscal 2003 as a result of growth in paid search and strong online advertising sales across all geographic regions. MSN subscription revenue grew $112 million or 11% in fiscal 2003 reflecting an increase in the number of paying non-promotion subscribers.

MSN reached segment profitability in the first quarter of fiscal 2004 and was profitable for the full fiscal year. The improvement in profitability was primarily driven by an increase in revenue from advertising in both display and paid search, a decline in customer acquisition costs and other expenses related to the Internet access business, efficiency gains in the operations of the advertising and subscription businesses, and a $48 million refund of prior year taxes, partially offset by $144 million of stock-based compensation expense related to the employee stock option transfer program in the second quarter of fiscal 2004. MSN operating loss for fiscal 2003 decreased from fiscal 2002, primarily as a result of the growth in revenue and lower relative subscription acquisition and support costs.

MSN expects advertising revenue and revenue from subscriptions and transactions for premium Web services to increase in fiscal 2005. Advertising revenue should benefit from expected increases in Internet spending and additions to the advertising platform including music download service, communication innovations, and an improved search engine. We expect revenue from narrowband Internet access to decline in fiscal 2005 as narrowband subscribers continue to migrate to broadband Internet access. We announced in the fourth quarter of fiscal 2004 an increase to the amount of storage we will provide for select MSN and Hotmail email accounts which will increase operating costs and may impact the revenues from our extra storage customers. However, we expect the segment to increase its profitability in fiscal 2005, led by continued operational efficiencies and lower unit margin costs in both the subscriber and advertising businesses.

Mobile and Embedded Devices

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  |  | Percentage inc./ (dec.) |
Revenue |  | $ | 112 |  |  | $ | 156 |  |  | 39 | % |  | $ | 247 |  |  | 58 | %
Operating loss |  | $ | (275 | ) |  | $ | (277 | ) |  | 1 | % |  | $ | (224 | ) |  | (19 | )%

Mobile and Embedded Devices includes Windows Mobile software, Windows Embedded device operating systems, MapPoint, and Windows Automotive. The segment’s products extend the advantages of the Windows platform to mobile phones and Pocket PCs. The segment is also responsible for managing sales and customer relations with device manufacturers and with network service providers, including telecommunications, cable and wireless companies, and host and network equipment providers. The embedded operating system market is highly fragmented with many competitive offerings and relatively short product life cycles that affect our continuing revenue streams.

Unit volume increases drove revenue growth for fiscal 2004 over fiscal 2003 in all product lines. The growth was primarily due to the increase in the number of OEMs and mobile operators shipping Windows Mobile software for SmartPhones, increases in market share for our Pocket PC and embedded products and increased usage by existing customers of our MapPoint Web Service. Revenue for fiscal 2003 grew $44 million driven by increased Pocket PC shipments and MapPoint licensing.

Mobile and Embedded Devices’ operating loss for fiscal 2004 decreased compared to fiscal 2003 primarily due to growth in revenue and lower marketing expenses, partially offset by $58 million of stock-based compensation expense from the employee stock option transfer program in the second quarter of fiscal 2004. Operating loss for fiscal 2003 grew 1% from the prior year as higher marketing expenses and headcount-related costs associated with product development offset the growth in revenue.

We expect demand for mobile and embedded devices based on Windows Mobile software to be driven by an overall increase in customer demand for connectivity as well as by an increase in the number of OEMs and mobile operators offering Windows-based devices.

PAGE |  | 21

##### Table of Contents

Part II

Item 7

Home and Entertainment

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  |  | Percentage inc./ (dec.) |
Revenue |  | $ | 2,453 |  |  | $ | 2,748 |  |  | 12 | % |  | $ | 2,876 |  |  | 5 | %
Operating loss |  | $ | (1,135 | ) |  | $ | (1,191 | ) |  | 5 | % |  | $ | (1,215 | ) |  | 2 | %

Home and Entertainment includes the Microsoft Xbox video game console system, PC games, the Home Products Division (HPD), and TV platform products for the interactive television industry. The relative success of competing video game consoles is determined by console functionality, the portfolio of video game content for the console, and the relative market share of the console. We are a relatively new entrant in the video game console businesses with our first release in fiscal 2002, and have established ourselves as one of the leaders. Revenue and unit volumes have grown quickly since 2002, but revenue growth moderated in fiscal 2004 due to price reductions typical at this stage in the console lifecycle. We believe our competitive position and revenue is bolstered by our increasing software game attach rates, providing higher margins to offset the decreasing price trend on consoles sold.

In fiscal 2004, Xbox revenue increased $144 million or 9% with $269 million related to higher Xbox software volumes and $117 million due to higher Xbox console volumes, partially offset by a $242 million decline related to price reductions of Xbox consoles and software. Overall, Xbox console volumes increased 11% in fiscal 2004 compared to fiscal 2003. The Xbox life-to-date U.S. games attach rate increased to 6.9 games per console according to industry analyst NPD as of June 30, 2004. Revenue from consumer hardware and software, PC games and TV platforms declined $16 million or 1% compared to fiscal 2003 due to lower PC games software and PC gaming devices sales, partially offset by the new release of Mac Office. The increase in Home and Entertainment revenue in fiscal 2003 from fiscal 2002 was the result of sales of Xbox video game systems and related games which were available for all of fiscal 2003. Xbox revenue grew $309 million or 23% in fiscal 2003 reflecting a $779 million increase from higher volumes for Xbox consoles, games, and peripherals partially offset by a $470 million decrease due to price changes. Revenue from consumer hardware and software and PC games declined $14 million or 1% in fiscal 2003, driving the decrease in Home Products revenue.

The increase in operating loss in fiscal 2004 was primarily due to $141 million of stock-based compensation expense from the employee stock option transfer program in the second quarter of fiscal 2004, increased sales of negative margin consoles, and costs associated with the next generation console development efforts, partially offset by increased Xbox and Mac Office software sales. The operating loss increase from fiscal 2003 also included a lower of cost or market adjustment of approximately $90 million, reflecting the current stage in the lifecycle of the Xbox console. Operating loss in 2003 increased by $56 million or 5% from the prior year as the product costs associated with the increased Xbox console sales and increased marketing expense more than offset the 12% increase in revenue.

In fiscal 2005, we expect Xbox console unit volumes and revenue to decrease from fiscal 2004 consistent with this stage of the Xbox console lifecycle, partially offset by increased unit volumes driven by the launch of software titles such as Halo2. In fiscal 2005 we expect PC games revenue to decrease from fiscal 2004 driven by fewer new game titles. Other HPD revenue are expected to increase moderately as a result of the launch of the latest version of Mac Office late in the fourth quarter of fiscal 2004. In fiscal 2005, we expect operating margins to improve from fiscal 2004 driven by lower unit volumes of negative margin consoles and increased sales of high margin software. We expect development spending to be higher in fiscal 2005 driven by investment in the next generation Xbox platform design.

Cost of revenue

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  |  | Percentage inc./ (dec.) |
Cost of revenue |  | $ | 5,699 |  |  | $ | 6,059 |  |  | 6 | % |  | $ | 6,716 |  |  | 11 | %
As a percent of revenue |  |  | 20.1 | % |  |  | 18.8 | % |  | (1.3 | )pp |  |  | 18.2 | % |  | (0.6 | )pp

PAGE |  | 22

##### Table of Contents

Part II

Item 7

Cost of revenue includes manufacturing and distribution costs for products and programs sold, operating costs related to product support service centers and product distribution centers, costs incurred to support and maintain Internet-based products and services, and costs associated with the delivery of consulting services. The increase in fiscal 2004 was primarily due to increased product support and consulting services costs of $508 million, $214 million of stock-based compensation expense from the employee stock option transfer program, and a lower of cost or market adjustment in the fourth quarter of fiscal 2004 by approximately $90 million, reflecting the current stage of the life cycle of the Xbox console, partially offset by $365 million decrease in MSN services costs. In fiscal 2003, the primary driver of the increase was a 4.4 percentage point increase from Home and Entertainment products and a 1.6 percentage point decrease from MSN product and service costs in fiscal 2003 compared to fiscal 2002.

Research and development

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  |  | Percentage inc./ (dec.) |
Research and development |  | $ | 6,299 |  |  | $ | 6,595 |  |  | 5 | % |  | $ | 7,779 |  |  | 18 | %
As a percent of revenue |  |  | 22.2 | % |  |  | 20.5 | % |  | (1.7 | )pp |  |  | 21.1 | % |  | 0.6 | pp

Research and development expenses include payroll, employee benefits, equity compensation and other headcount-related costs associated with product development. Research and development expenses also include third-party development and programming costs, localization costs incurred to translate software for international markets, and the amortization of purchased software code and services content. The increase in fiscal 2004 was primarily due to $1.31 billion of stock-based compensation expenses related to the option transfer program in the second quarter of fiscal 2004 as well as other headcount-related payroll and other employee costs related to a 3% growth in research and development headcount from fiscal 2003. In fiscal 2003, the increase reflects an increase in headcount-related costs, a 25% increase in third-party product development costs, and a 29% increase in testing laboratory equipment and expense.

Sales and marketing

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  |  | Percentage inc./ (dec.) |
Sales and marketing |  | $ | 6,252 |  |  | $ | 7,562 |  |  | 21 | % |  | $ | 8,309 |  |  | 10 | %
As a percent of revenue |  |  | 22.0 | % |  |  | 23.5 | % |  | 1.5 | pp |  |  | 22.6 | % |  | (0.9 | )pp

Sales and marketing expenses include payroll, employee benefits, equity compensation and other headcount-related costs associated with sales and marketing personnel and advertising, promotions, tradeshows, seminars, and other marketing-related programs. Sales and marketing costs increased in fiscal 2004 due to $400 million of stock-based compensation expenses related to the option transfer program in the second quarter of fiscal 2004 and other headcount-related costs related to a 9% growth in sales and marketing headcount. In fiscal 2003, the sales and marketing expense increase of $1.31 billion dollars was due to an increase in sales expenses related to headcount additions, principally related to the Enterprise and Small/Medium Business sales forces, and a 21% increase in marketing expenses.

General and administrative

(In millions, except percentages) |  | 2002 |  |  | 2003 |  |  | Percentage inc./ (dec.) |  |  | 2004 |  |  | Percentage inc./ (dec.) |
General and administrative |  | $ | 1,843 |  |  | $ | 2,426 |  |  | 32 | % |  | $ | 4,997 |  |  | 106 | %
As a percent of revenue |  |  | 6.5 | % |  |  | 7.5 | % |  | 1.0 | pp |  |  | 13.6 | % |  | 6.1 | pp

PAGE |  | 23

##### Table of Contents

Part II

Item 7

General and administrative costs include payroll, employee benefits, equity compensation and other headcount-related costs associated with the finance, legal, facilities, certain human resources, and other administrative headcount, and legal costs and other administrative fees. General and administrative costs increased in fiscal 2004 primarily due to legal expenses including $1.92 billion of charges related to the Sun Microsystems settlement, a $605 million fine imposed by the European Commission in the third quarter of fiscal 2004, $280 million of stock-based compensation expense related to the employee stock option transfer program in the second quarter of fiscal 2004, other legal costs of approximately $104 million, and other headcount related costs. General and administrative costs in fiscal 2003 increased $583 million from fiscal 2002 due to a charge of $750 million related to a settlement with Time Warner in the fourth quarter of 2003 and a $256 million charge reflecting an increase in our estimate of costs related to resolving pending antitrust and unfair competition consumer class action lawsuits.

Investment Income/(Loss), and Income Taxes

Investment Income/(Loss)

The components of investment income/(loss) in each fiscal year are as follows:

(In millions) / Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Dividends and interest |  | $ | 2,119 |  |  | $ | 1,957 |  |  | $ | 1,892 |
Net recognized gains (losses) on investments |  |  | (1,807 | ) |  |  | 44 |  |  |  | 1,563 |
Net losses on derivatives |  |  | (617 | ) |  |  | (424 | ) |  |  | (268 | )
Investment income /(loss) |  | $ | (305 | ) |  | $ | 1,577 |  |  | $ | 3,187 |

Dividends and interest income decreased $65 million in fiscal 2004 mainly due to lower dividend income resulting from the exchange of AT&T 5% convertible preferred debt for common shares of Comcast during fiscal 2003 and declining interest rates, partly offset by a larger investment portfolio. Net recognized gains (losses) on investments include other-than-temporary impairments of $82 million in fiscal 2004 compared to $1.15 billion in the prior year as well as higher net realized gains on sales in fiscal 2004 as we moved to more liquid investment asset classes. Net realized gains on sales were $1.65 billion in fiscal 2004 and $1.19 billion in fiscal 2003. The decline in impairments was due to improved market conditions. Derivative losses decreased $156 million to $268 million in fiscal 2004 compared to fiscal 2003 primarily due to the combined effects of interest rate movements on interest rate sensitive instruments and equity market price movements relative to positions used to hedge the fair value of certain equity securities.

In fiscal 2003, dividends and interest income decreased $162 million driven primarily by a reduction in dividend income of $97 million resulting from the exchange of AT&T 5% convertible preferred debt for common shares of Comcast during the second quarter of fiscal 2003, and declining interest rates partially offset by a larger investment portfolio. Net recognized gains (losses) on investments includes other-than-temporary impairments of $1.15 billion in fiscal 2003 compared to $4.32 billion in fiscal 2002 and net realized gains on investments of $1.19 billion in fiscal 2003 compared to $2.52 billion in fiscal 2002. The decrease in other-than-temporary impairments in 2003 was also due to the reduced cost-basis of investments resulting from significant 2002 impairments of investments in the cable and telecommunications sectors.

In fiscal 2002, other-than-temporary impairments of $4.32 billion primarily related to our investment in AT&T and other cable and telecommunication investments. Net realized gains on the sales of investments of $2.52 billion included a $1.25 billion gain on sale of our interest in Expedia.

Investments are considered to be impaired when a decline in fair value is judged to be other than temporary. We employ a systematic methodology that considers available evidence in evaluating potential impairment of our investments. If the cost of an investment exceeds its fair value, we evaluate, among other factors, general market conditions, the duration and extent to which the fair value is less than cost, and our intent and ability to hold the investment. We also consider specific adverse conditions related to the financial health of and business outlook for the investee, including industry and sector performance, changes in technology, operational and financing cash flow factors, and rating agency actions. Once a decline in fair value is determined to be other than temporary, an impairment charge is recorded and a new cost basis in the investment is established.

PAGE |  | 24

##### Table of Contents

Part II

Item 7

Income Taxes

Our effective tax rate for fiscal 2004 was 33%. A benefit of $208 million was recorded during the fourth quarter from the reversal of previously accrued taxes from resolving the remaining open issue remanded by the 9th Circuit Court of Appeals ruling in December 2002. The effective tax rate for the fourth quarter of fiscal 2004 was approximately 27%. During the third quarter the tax rate increased due to the European Commission fine, which is not tax deductible.

The effective tax rate for fiscal 2003 and fiscal 2002 was 32% each year. The fiscal 2003 rate reflected a benefit in the second quarter of $126 million from the reversal of previously accrued taxes related to the initial items from the 9th Circuit Court of Appeals ruling referred to above, that reversed, in part, a previous Tax Court ruling that had denied tax benefits on certain revenue earned from the distribution of software to foreign customers. Excluding this reversal, the effective tax rate would have been 33%.

Stock-based Compensation. We implemented changes in fiscal 2004 in employee compensation designed to help us continue to attract and retain the best employees, and to better align employee interests with those of our shareholders. Generally, employees are now granted stock awards instead of stock options. The stock award program offers employees the opportunity to earn shares of our stock over time, rather than options that give employees the right to purchase stock at a set price. We also completed an employee stock option transfer program in the second quarter of fiscal 2004 whereby employees could elect to transfer all of their vested and unvested stock options with a strike price of $33 or higher (“eligible options”) to JPMorgan Chase Bank (JPMorgan). The unvested eligible options that were transferred to JPMorgan became vested upon the transfer. The price paid by JPMorgan for the transferred options was determined by reference to the arithmetic average of the closing prices of Microsoft common stock during the period from November 14, 2003 to December 8, 2003, which was $25.5720. Note 13 – Employee Stock and Savings Plan of the Notes to the Financial Statements provides additional information on employee stock and savings plans.

In addition, effective July 1, 2003, we adopted the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, using the retroactive restatement method described in SFAS 148, Accounting for Stock-Based Compensation – Transition and Disclosure. Under the fair value recognition provisions of SFAS 123, stock-based compensation cost is measured at the grant date based on the value of the award and is recognized as expense over the vesting period. The June 30, 2003 balance sheet has been restated for the retroactive adoption of the fair value recognition provisions of SFAS 123, which resulted in a $13.89 billion increase in common stock and paid-in capital, a $10.00 billion decrease in retained earnings, and a $3.89 billion increase in deferred income taxes.

Given these changes the following table provides stock-based compensation expense for fiscal 2002 through 2004 by segment.

(In millions, except expense per share)(1) |  | 2002 |  | 2003 |  | 2004
Client |  | $ | 471 |  | $ | 450 |  | $ | 738
Server and Tools |  |  | 1,301 |  |  | 1,274 |  |  | 1,862
Information Worker |  |  | 516 |  |  | 510 |  |  | 848
Microsoft Business Solutions |  |  | 125 |  |  | 129 |  |  | 147
MSN |  |  | 268 |  |  | 262 |  |  | 392
Mobile and Embedded Devices |  |  | 118 |  |  | 129 |  |  | 170
Home and Entertainment |  |  | 261 |  |  | 257 |  |  | 381
Corporate |  |  | 724 |  |  | 738 |  |  | 1,196
Stock-based employee compensation expense |  | $ | 3,784 |  | $ | 3,749 |  | $ | 5,734
After-tax stock-based employee compensation expense |  | $ | 2,573 |  | $ | 2,512 |  | $ | 3,842
After-tax stock-based employee compensation expense per diluted share |  | $ | 0.23 |  | $ | 0.23 |  | $ | 0.35

(1) |  | The amounts for fiscal 2004 include $2.21 billion ($1.48 billion after-tax or $0.14 per diluted share) due to the completion of the employee stock option transfer program.

PAGE |  | 25

##### Table of Contents

Part II

Item 7

FINANCIAL CONDITION

Our cash and short-term investment portfolio totaled $60.59 billion as of June 30, 2004. Equity and other investments were $12.21 billion as of June 30, 2004. The portfolio consists primarily of fixed-income securities, diversified among industries and individual issuers. Our investments are generally liquid and investment grade. The portfolio is invested predominantly in U.S. dollar denominated securities, but also includes foreign currency positions, in order to diversify financial risk. The portfolio is primarily invested in short-term securities to minimize interest rate risk and facilitate rapid deployment for immediate cash needs.

Unearned revenue from volume licensing programs represents customer billings, paid either upfront or annually at the beginning of each billing coverage period, that are accounted for as subscriptions with revenue recognized ratably over the billing coverage period. For certain other licensing arrangements revenue attributable to undelivered elements, including free post-delivery telephone support and the right to receive unspecified upgrades/enhancements of Microsoft Internet Explorer on a when-and-if-available basis, is based on the sales price of those elements when sold separately and is recognized ratably on a straight-line basis over the related product’s life cycle. The percentage of revenue recorded as unearned due to undelivered elements ranges from approximately 15% to 25% of the sales price for Windows XP Home, approximately 5% to 15% of the sales price for Windows XP Professional, and approximately 1% to 15% of the sales price for desktop applications, depending on the terms and conditions of the license and prices of the elements. Product life cycles are currently estimated at three-and-one-half years for Windows operating systems and two years for desktop applications. Unearned revenue also includes payments for online advertising for which the advertisement has yet to be displayed and payments for post-delivery support services to be performed in the future.

Unearned revenue as of June 30, 2004 decreased $838 million from June 30, 2003, reflecting recognition of unearned revenue from multi-year licensing that has outpaced additions by $397 million, primarily due to recognition from Upgrade Advantage licensing agreements and a $489 million decline in revenue deferred for undelivered elements. Starting April 1, 2003 revenue deferred for undelivered elements reflected lower deferral rates, partially offset by lengthened product life cycles for the underlying products licensed, resulting in a higher proportion of revenue earned. We earned approximately $1.8 billion and $1.1 billion from the Upgrade Advantage programs for fiscal 2003 and 2004, respectively and expect to earn approximately $56 million in fiscal 2005 from those programs.

Cash Flows

Cash flow from operations for fiscal 2004 decreased $1.17 billion to $14.63 billion. The decrease primarily reflects the combined cash outflows of $2.56 billion related to the Sun Microsystems settlement and the European Commission fine mentioned above partially offset by increased cash receipts from customers driven by the rise in revenue billings. Cash used for financing was $2.36 billion in fiscal 2004, a decrease of $2.86 billion from the prior year. The decrease reflects that we did not repurchase any common stock in the fourth quarter of fiscal 2004 combined with a $628 million increase primarily from stock issuances related to employee stock options exercises, partially offset by an $872 million increase in cash dividends paid. We repurchased 123.7 million shares of common stock under our share repurchase program in fiscal 2004. Cash used for investing was $2.75 billion in fiscal 2004, a decrease of $4.47 billion from fiscal 2003, due to a $3.63 billion decrease in net investment purchases and a $1.06 billion decrease in acquisition spending.

Cash flow from operations was $15.80 billion for fiscal 2003, an increase of $1.29 billion from fiscal 2002. The increase primarily reflects the rise in cash receipts from customers driven by the increase in revenue billings and maintenance of relatively stable accounts receivable levels. Cash used for financing was $5.22 billion in fiscal 2003, an increase of $651 million from the prior year. The increase reflects a cash dividend payment of $857 million in 2003 and an increase of $417 million in common stock repurchase, offsetting $623 million received for common stock issued. We repurchased 238.2 million shares of common stock under our share repurchase program in fiscal 2003. Cash used for investing was $7.21 billion in fiscal 2003, a decrease of $3.63 billion from fiscal 2002, due to stronger portfolio performance on sold and matured investments.

Cash flow from operations was $14.51 billion for fiscal 2002, an increase of $1.09 billion from fiscal 2001. The increase reflected strong growth in unearned revenue as a result of the significant number of customers that purchased Upgrade Advantage during the Licensing 6.0 transition period. This resulted in an increase in billings and a corresponding increase in the unearned revenue amount. Cash used for financing was $4.57 billion in fiscal 2002, a decrease of $1.01 billion from the prior year. The decrease reflected the repurchase of put warrants in the prior year.

PAGE |  | 26

##### Table of Contents

Part II

Item 7

We repurchased 245.6 million shares of common stock under our share repurchase program in fiscal 2002. In addition, 10.2 million shares of common stock were acquired in fiscal 2002 under a structured stock repurchase transaction. We entered into the structured stock repurchase transaction in fiscal 2001, which gave us the right to acquire 10.2 million of our shares in exchange for an up-front net payment of $264 million. Cash used for investing was $10.85 billion in fiscal 2002, an increase of $2.11 billion from fiscal 2001.

We have no material long-term debt. Stockholders’ equity at June 30, 2004 was $74.8 billion. We will continue to invest in sales, marketing, product support infrastructure, and existing and advanced areas of technology. Additions to property and equipment will continue, including new facilities and computer systems for research and development, sales and marketing, support, and administrative staff. Commitments for constructing new buildings were $129 million on June 30, 2004. We have operating leases for most U.S. and international sales and support offices and certain equipment under which we incurred rental expense totaling $318 million, $290 million, and $331 million in fiscal 2002, 2003, and 2004, respectively. We have issued residual value guarantees in connection with various operating leases. These guarantees provide that if we do not purchase the leased property from the lessor at the end of the lease term, then we are liable to the lessor for an amount equal to the shortage (if any) between the proceeds from the sale of the property and an agreed value. As of June 30, 2004, the maximum amount of the residual value guarantees was approximately $271 million. We believe that proceeds from the sale of properties under operating leases would exceed the payment obligation and therefore no liability currently exists. We have not engaged in any related party transactions or arrangements with unconsolidated entities or other persons that are reasonably likely to materially affect liquidity or the availability of requirements for capital resources.

On July 20, 2004, our board of directors approved a quarterly dividend of $0.08 per share payable on September 14, 2004, to shareholders of record on August 25, 2004. In addition, the board approved a plan to buy back up to $30 billion in Microsoft Common stock over the next four years. The specific timing and amount of repurchases will vary based on market conditions, securities law limitations, and other factors. The repurchases will be made using our cash resources. The repurchase program may be suspended or discontinued at any time without prior notice. The board also approved a one-time special dividend of $3.00 per share, or approximately $32 billion, subject to shareholder approval of stock plan amendments that will allow certain adjustments to employee equity compensation awards to offset the impact of the special dividend. The special dividend will be payable on December 2, 2004, to shareholders of record on November 17, 2004, conditioned upon shareholder approval of amendments to the employee stock plans at the annual meeting of shareholders scheduled to be held November 9, 2004.

We believe existing cash and short-term investments, together with funds generated from operations should be sufficient to meet operating requirements and our special dividend as well as regular quarterly dividends. Our philosophy regarding the maintenance of a balance sheet with a large component of cash and short-term investments, as well as equity and other investments, reflects our views on potential future capital requirements relating to research and development, creation and expansion of sales distribution channels, investments and acquisitions, share dilution management, legal risks, and challenges to our business model. We continuously assess our investment management approach in view of our current and potential future needs.

Off-balance sheet arrangements and contractual obligations

Off-balance sheet arrangements

We have unconditionally guaranteed the repayment of certain Japanese yen denominated bank loans and related interest and fees of Jupiter Telecommunication, Ltd., a Japanese cable company (Jupiter). These guarantees arose on February 1, 2003 in conjunction with the expiration of prior financing arrangements, including previous guarantees by us. The financing arrangements were entered into by Jupiter as part of financing its operations. As part of Jupiter’s new financing agreement, we agreed to guarantee repayment by Jupiter of the loans of approximately $51 million. The estimated fair value and the carrying value of the guarantees was $11 million and did not result in a charge to operations. The guarantees are in effect until the earlier of either repayment of the loans, including accrued interest and fees, or February 1, 2009. The maximum amount of the guarantees is limited to the sum of the total due and unpaid principal amounts, accrued and unpaid interest, and any other related expenses. Additionally, the maximum amount of the guarantees, denominated in Japanese yen, will vary based on fluctuations in foreign exchange rates. If we were required to make payments under the guarantees, we might recover all or a portion of those payments upon liquidation of Jupiter’s assets. The proceeds from an asset liquidation cannot be accurately estimated due to the many factors that would affect the valuation and realization of the proceeds.

PAGE |  | 27

##### Table of Contents

Part II

Item 7

We provide indemnifications of varying scope and amount to certain customers against claims of intellectual property infringement made by third parties arising from the use of our products. We evaluate estimated losses for such indemnifications under SFAS 5, Accounting for Contingencies, as interpreted by FIN 45. We consider factors such as the degree of probability of an unfavorable outcome and the ability to make a reasonable estimate of the amount of loss. To date, we have not encountered material costs as a result of such obligations and have not accrued any liabilities related to such indemnifications in our financial statements.

Contractual obligations

The following table summarizes our outstanding contractual obligations as of June 30, 2004:

(In millions)(1) |  |
|  | Payments due by period
|  | 2005 |  | 2006-2008 |  | 2009-2011 |  | 2012 and thereafter |  | Total
Long-term debt |  | $ | – |  | $ | – |  | $ | – |  | $ | – |  | $ | –
Construction commitments(2) |  |  | 127 |  |  | 2 |  |  | – |  |  | – |  |  | 129
Lease obligations: |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Capital leases |  |  | 7 |  |  | 17 |  |  | 10 |  |  | – |  |  | 34
Operating leases(3) |  |  | 141 |  |  | 250 |  |  | 86 |  |  | 24 |  |  | 501
Purchase commitments(4) |  |  | 1,340 |  |  | 130 |  |  | 90 |  |  | – |  |  | 1,560
Other long-term liabilities(5) |  |  | – |  |  | 204 |  |  | 14 |  |  | 4 |  |  | 222
Total contractual obligations |  | $ | 1,615 |  | $ | 603 |  | $ | 200 |  | $ | 28 |  | $ | 2,446

(1) |  | We have excluded the recorded $1.04 billion contingent liability related to the antitrust and unfair competition class action lawsuits referred to in the third paragraph of Note 17 – Contingencies of the Notes to Financial Statements as the timing and amount to be resolved in cash versus vouchers is subject to uncertainty.

(2) |  | We have certain commitments for the construction of buildings. We expect to fund these commitments with existing cash and cash flows from operations.

(3) |  | Our future minimum rental commitments under noncancellable leases comprise the majority of the operating lease obligations presented above. We expect to fund these commitments with existing cash and cash flows from operations.

(4) |  | Purchase commitments represent obligations under agreements which are not unilaterally cancelable by us, are legally enforceable and specify fixed or minimum amounts or quantities of goods or services at fixed or minimum prices. We generally require purchase orders for vendor and third-party spending. The amount presented above as purchase commitments includes an analysis of all known contracts exceeding $5 million in the aggregate as well as all known open purchase orders. We expect to fund these commitments with existing cash and cash flows from operations.

(5) |  | We have excluded unearned revenue of $1.66 billion from other long-term liabilities presented above as these will not be settled in cash. We have also excluded the liability recorded for the Jupiter guarantee of $11 million.

RECENTLY ISSUED ACCOUNTING STANDARDS

In December 2003, the Financial Accounting Standards Board (FASB) issued Interpretation 46R (FIN 46R), a revision to Interpretation 46 (FIN 46), Consolidation of Variable Interest Entities. FIN 46R clarifies some of the provisions of FIN 46 and exempts certain entities from its requirements. FIN 46R is effective at the end of the first interim period ending after March 15, 2004. Entities that have adopted FIN 46 prior to this effective date can continue to apply the provisions of FIN 46 until the effective date of FIN 46R or elect early adoption of FIN 46R. The adoption of FIN 46 and FIN 46R did not have a material impact on our financial statements.

In March 2004, the FASB ratified the recognition and measurement guidance and certain disclosure requirements for impaired securities as described in Emerging Issues Task Force (EITF) Issue No. 03-1, The Meaning of Other-Than-Temporary Impairment and Its Application to Certain Investments. The recognition and measurement guidance will be

PAGE |  | 28

##### Table of Contents

Part II

Item 7

applied to other-than-temporary impairment evaluations in reporting periods beginning with our first fiscal quarter 2005. We do not believe the adoption of the recognition and measurement guidance in EITF Issue No. 03-1 will have a material impact on our financial statements.

In July 2004, the FASB ratified Emerging Issues Task Force (EITF) consensus on Issue No. 02-14, Whether an Investor Should Apply the Equity Method of Accounting to Investments Other Than Common Stock, which provides guidance regarding application of the equity method of accounting to investments other than common stock. EITF Issue No. 02-14 will be effective beginning with our second quarter of fiscal 2005. We do not believe the adoption of EITF Issue No. 02-14 will have a material impact on our financial statements.

APPLICATION OF CRITICAL ACCOUNTING POLICIES

Our financial statements and accompanying notes are prepared in accordance with U.S. GAAP. Preparing financial statements requires management to make estimates and assumptions that affect the reported amounts of assets, liabilities, revenue, and expenses. These estimates and assumptions are affected by management’s application of accounting policies. Critical accounting policies for us include revenue recognition, impairment of investment securities, impairment of goodwill, accounting for research and development costs, accounting for legal contingencies, and accounting for income taxes.

We account for the licensing of software in accordance with American Institute of Certified Public Accountants (AICPA) Statement of Position (SOP) 97-2, Software Revenue Recognition. The application of SOP 97-2 requires judgment, including whether a software arrangement includes multiple elements, and if so, whether vendor-specific objective evidence (VSOE) of fair value exists for those elements. Customers receive certain elements of our products over a period of time. These elements include free post-delivery telephone support and the right to receive unspecified upgrades/enhancements of Microsoft Internet Explorer on a when-and-if-available basis, the fair value of which is recognized over the product’s estimated life cycle. Changes to the elements in a software arrangement, the ability to identify VSOE for those elements, the fair value of the respective elements, and changes to a product’s estimated life cycle could materially impact the amount of earned and unearned revenue. Judgment is also required to assess whether future releases of certain software represent new products or upgrades and enhancements to existing products.

SFAS 115, Accounting for Certain Investments in Debt and Equity Securities, and Securities and Exchange Commission (SEC) Staff Accounting Bulletin (SAB) 59, Accounting for Noncurrent Marketable Equity Securities, provide guidance on determining when an investment is other-than-temporarily impaired. Investments are reviewed quarterly for indicators of other-than-temporary impairment. This determination requires significant judgment. In making this judgment, we evaluate, among other factors, the duration and extent to which the fair value of an investment is less than its cost; the financial health of and near-term business outlook for the investee, including factors such as industry and sector performance, changes in technology, and operational and financing cash flow; and our intent and ability to hold the investment. Investments with an indicator are further evaluated to determine the likelihood of a significant adverse affect on the fair value and amount of the impairment as necessary. In the past, we have had substantial impairments in our portfolio as discussed in Note 4 – Investment Income/(Loss). If market, industry and/or investee conditions deteriorate, we may incur future impairments.

SFAS 142, Goodwill and Other Intangible Assets, requires that goodwill be tested for impairment at the reporting unit level (operating segment or one level below an operating segment) on an annual basis (July 1 for us) and between annual tests if an event occurs or circumstances change that would more likely than not reduce the fair value of a reporting unit below its carrying value. These events or circumstances could include a significant change in the business climate, legal factors, operating performance indicators, competition, sale or disposition of a significant portion of a reporting unit. Application of the goodwill impairment test requires judgment, including the identification of reporting units, assignment of assets and liabilities to reporting units, assignment of goodwill to reporting units, and determination of the fair value of each reporting unit. The fair value of each reporting unit is estimated using a discounted cash flow methodology. This requires significant judgments including estimation of future cash flows, which is dependent on internal forecasts, estimation of the long-term rate of growth for our business, the useful life over which cash flows will occur, and determination of our weighted average cost of capital. Changes in these estimates and assumptions could materially affect the determination of fair value and/or goodwill impairment for each reporting unit.

We account for research and development costs in accordance with several accounting pronouncements, including SFAS 2, Accounting for Research and Development Costs, and SFAS 86, Accounting for the Costs of Computer

PAGE |  | 29

##### Table of Contents

Part II

Item 7

Software to be Sold, Leased, or Otherwise Marketed. SFAS 86 specifies that costs incurred internally in researching and developing a computer software product should be charged to expense until technological feasibility has been established for the product. Once technological feasibility is established, all software costs should be capitalized until the product is available for general release to customers. Judgment is required in determining when technological feasibility of a product is established. We have determined that technological feasibility for our software products is reached shortly before the products are released to manufacturing. Costs incurred after technological feasibility is established are not material, and accordingly, we expense all research and development costs when incurred.

The outcomes of legal proceedings and claims brought against us are subject to significant uncertainty. SFAS 5, Accounting for Contingencies, requires that an estimated loss from a loss contingency such as a legal proceeding or claim should be accrued by a charge to income if it is probable that an asset has been impaired or a liability has been incurred and the amount of the loss can be reasonably estimated. Disclosure of a contingency is required if there is at least a reasonable possibility that a loss has been incurred. In determining whether a loss should be accrued we evaluate, among other factors, the degree of probability of an unfavorable outcome and the ability to make a reasonable estimate of the amount of loss. Changes in these factors could materially impact our financial position or our results of operations.

SFAS 109, Accounting for Income Taxes, establishes financial accounting and reporting standards for the effect of income taxes. The objectives of accounting for income taxes are to recognize the amount of taxes payable or refundable for the current year and deferred tax liabilities and assets for the future tax consequences of events that have been recognized in an entity’s financial statements or tax returns. Judgment is required in assessing the future tax consequences of events that have been recognized in our financial statements or tax returns. Variations in the actual outcome of these future tax consequences could materially impact our financial position or our results of operations.

ISSUES AND UNCERTAINTIES

This Annual Report on Form 10-K contains statements that are forward-looking. These statements are based on current expectations and assumptions that are subject to risks and uncertainties. Actual results could differ materially because of issues and uncertainties such as those listed below and elsewhere in this report, which, among others, should be considered in evaluating our future financial performance.

Challenges to our Business Model. Since our inception, our business model has been based upon customers agreeing to pay a fee to license software developed and distributed by us. Under this commercial software model, software developers bear the costs of converting original ideas into software products through investments in research and development, offsetting these costs with the revenue received from the distribution of their products. We believe the commercial software model has had substantial benefits for users of software, allowing them to rely on our expertise and the expertise of other software developers that have powerful incentives to develop innovative software that is useful, reliable, and compatible with other software and hardware. In recent years, there has been a growing challenge to the commercial software model. Under the non-commercial software model, open source software produced by loosely associated groups of unpaid programmers and made available for license to end users without charge is distributed by firms at nominal cost that earn revenue on complementary services and products, without having to bear the full costs of research and development for the open source software. The most notable example of open source software is the Linux operating system. While we believe our products provide customers with significant advantages in security and productivity, and generally have a lower total cost of ownership than open source software, the popularization of the non-commercial software model continues to pose a significant challenge to our business model, including recent efforts by proponents of open source software to convince governments worldwide to mandate the use of open source software in their purchase and deployment of software products. To the extent opens source software gains increasing market acceptance, sales of our products may decline, we may have to reduce the prices we charge for our products, and revenue and operating margins may consequently decline.

Intellectual Property Rights. We defend our intellectual property rights, but unlicensed copying and use of software and intellectual property rights represents a loss of revenue to us. While this adversely affects U.S. revenue, the impact on revenue from outside the United States is more significant, particularly in countries where laws are less protective of intellectual property rights. Throughout the world, we actively educate consumers about the benefits of

PAGE |  | 30

##### Table of Contents

Part II

Item 7

licensing genuine products and educate lawmakers about the advantages of a business climate where intellectual property rights are protected. However, continued educational and enforcement efforts may not affect revenue positively, and revenue could be adversely affected by further deterioration in compliance with existing legal protections or reductions in the legal protection for intellectual property rights of software developers.

From time to time we receive notices from others claiming we infringe their intellectual property rights. The number of these claims may grow. Responding to these claims may require us to enter into royalty and licensing agreements on unfavorable terms, require us to stop selling or to redesign affected products, or to pay damages or to satisfy indemnification commitments with our customers. If we are required to enter into such agreements or take such actions, our operating margins may decline as a result.

We have made and expect to continue making significant expenditures to acquire the use of technology and intellectual property rights, including via cross-licenses of broad patent portfolios.

Unauthorized Disclosure of Source Code. Source code, the detailed program commands for our operating systems and software programs, is the most significant asset we own. While we license certain portions of our source code for various software programs and operating systems to a number of licensees, we take significant measures to protect the secrecy of large portions of our source code. If an unauthorized disclosure of a significant portion of our source code occurs, we could potentially lose future trade secret protection for that source code. The loss of future trade secret protection could make it easier for third parties to compete with our products by copying functionality, which could adversely affect our revenue and operating margins. Unauthorized disclosure of source code could also increase certain risks described below under “Security”.

New Products and Services. We have made significant investments in research, development and marketing for new products, services, and technologies, including Longhorn, Microsoft .NET, Xbox, business applications, MSN, and mobile and wireless technologies. Significant revenue from new product and service investments may not be achieved for a number of years, if at all. Moreover, these products and services may not be profitable, and even if they are profitable, operating margins for these businesses may not be as high as the margins we have experienced historically.

Litigation. As discussed in Note 17 – Contingencies of the Notes to Financial Statements, we are subject to a variety of claims and lawsuits. Adverse outcomes in some or all of the pending cases may result in significant monetary damages or injunctive relief against us. We are also subject to a variety of other claims and suits that arise from time to time in the ordinary course of our business. While management currently believes that resolving all of these matters, individually or in the aggregate, will not have a material adverse impact on our financial position or results of operations, the litigation and other claims noted above are subject to inherent uncertainties and management’s view of these matters may change in the future. There exists the possibility of a material adverse impact on our financial position and the results of operations for the period in which the effect of an unfavorable final outcome becomes probable and reasonably estimable.

Security. Maintaining the security of computers and computer networks is an issue of critical importance for us and our customers. There are malicious hackers who develop and deploy viruses, worms, and other malicious software programs that attack our products. While this is an industry-wide phenomenon that affects computers across all platforms, our customers in particular have been victims of such attacks and will likely continue to be so. We are devoting significant resources to addressing these critical issues. We are focusing our efforts on engineering more secure products, optimizing security and reliability options and settings when we deliver products, and providing guidance to help our customers make the best use of our products and services to protect against computer viruses and other attacks on their computing environment. In addition, we are working to improve the deployment of software updates to address security vulnerabilities discovered after our products are released. We are also investing in mitigation technologies that help to secure customers from attacks even when such software updates are not deployed. We are also advising customers on how to help protect themselves from security threats through the use of our online automated security tools, our published security guidance, and the deployment of security software such as firewalls, antivirus, and other security software. These steps could adversely affect our operating margins. Despite these efforts, actual or perceived security vulnerabilities in our products could lead some customers to seek to return products, to reduce or delay future purchases, or to purchase competitive products. Customers may also increase their expenditures on protecting their computer systems from attack, which could delay adoption of new technologies. Any of these actions by customers could adversely affect our revenue.

PAGE |  | 31

##### Table of Contents

Part II

Item 7

Declines in Demand for Software. If overall market demand for PCs, servers, and other computing devices declines significantly, or consumer or corporate spending for such products declines, our revenue will be adversely affected. Additionally, our revenue would be unfavorably impacted if customers reduce their purchases of new software products or upgrades to existing products because new product offerings are not perceived as adding significant new functionality or other value to prospective purchasers. A significant number of customers purchased license agreements providing upgrade rights to specific licensed products prior to the transition to Licensing 6.0 in July 2002. These agreements generally expired throughout fiscal 2004 and will largely be expired by the end of the first fiscal quarter in 2005. The rate at which such customers renew these contracts could adversely affect future revenue. We are making significant investments in the next release of the Windows operating system, code-named Longhorn. If this system is not perceived as offering significant new functionality or value to prospective purchasers, our revenue and operating margins could be adversely affected.

Product Development Schedule. The development of software products is a complex and time-consuming process. New products and enhancements to existing products can require long development and testing periods. Significant delays in new product releases or significant problems in creating new products, particularly any delays in the Longhorn operating system, could adversely affect our revenue.

General Economic and Geo-Political Risks. Softness in corporate information technology spending or other changes in general economic conditions that affect demand for computer hardware or software could adversely affect our revenue. Terrorist activity and armed conflict pose the additional risk of general economic disruption and could require changes in our operations and security arrangements, thus increasing our operating costs. These conditions lend additional uncertainty to the timing and budget for technology investment decisions by our customers.

Competition. We continue to experience intensive competition across all markets for our products and services. These competitive pressures may result in decreased sales volumes, price reductions, and/or increased operating costs, such as for marketing and sales incentives, resulting in lower revenue, gross margins, and operating income.

Taxation of Extraterritorial Income. In August 2001, a World Trade Organization (“WTO”) dispute panel determined that the tax provisions of the FSC Repeal and Extraterritorial Income Exclusion Act of 2000 (“ETI”) constitute an export subsidy prohibited by the WTO Agreement on Subsidies and Countervailing Measures. The U.S. government appealed the panel’s decision and lost its appeal. On March 1, 2004, the European Union began imposing retaliatory tariffs on a specified list of U.S.-source goods. In May, the U.S. Senate passed the Jumpstart our Business Strength (JOBS) Act that would repeal ETI, provide a three-year phase-out of current ETI benefits, and would replace ETI with a phased-in 9% domestic production activity deduction that would not be fully effective until 2012. The U.S. House of Representatives passed similar legislation in June that would repeal ETI effective December 31, 2004, provide a two-year phase-out of ETI benefits, and replace ETI with a 3% tax rate reduction for income from domestic production activities that would be full phased in by 2006. Neither bill will fully replace our current ETI tax benefits. Both bills must still be reconciled in conference, and significant changes could be made to the final legislation, so we remain unable to assess the ultimate form and financial impact of this legislation, if enacted. If the ETI provisions are repealed and financially comparable replacement tax legislation is not enacted, the loss of the ETI tax benefit to us could be significant.

Other Potential Tax Liabilities. We are subject to income taxes in both the United States and numerous foreign jurisdictions. Significant judgment is required in determining our worldwide provision for income taxes. In the ordinary course of our business, there are many transactions and calculations where the ultimate tax determination is uncertain. We are regularly under audit by tax authorities. Although we believe our tax estimates are reasonable, the final determination of tax audits and any related litigation could be materially different than that which is reflected in historical income tax provisions and accruals. Should additional taxes be assessed as a result of an audit or litigation, a material effect on our income tax provision and net income in the period or periods for which that determination is made could result.

Insurance Programs. In addition to conventional third-party insurance arrangements, we have entered into captive insurance arrangements for the purpose of protecting against possible catastrophic and other risks not covered by traditional insurance markets. As of June 30, 2004, the face value of captive insurance arrangements was $2.0

PAGE |  | 32

##### Table of Contents

Part II

Item 7, 7A

billion. Actual value at any particular time will vary due to deductibles, exclusions, other restrictions, and claims. While we believe these arrangements are an effective way to insure against such risks, the potential liabilities associated with certain of the issues and uncertainties discussed in this document or other events could exceed the coverage provided by such arrangements.

Business Disruptions in the Event of a Catastrophic Event. We are a highly automated business and a disruption or failure of our systems in the event of a major earthquake, cyber-attack, terrorist attack, or other catastrophic event could cause delays in completing sales and providing services. Our corporate headquarters, a significant portion of our research and development activities, and certain other critical business operations are located in the Seattle, Washington area, and we have other business operations in the Silicon Valley area of California, both of which are near major earthquake faults. A catastrophic event that results in the destruction or disruption of any of our critical business or information technology systems could severely affect our ability to conduct normal business operations and, as a result, our future operating results could be adversely affected.

Other. Other issues and uncertainties may include:

| • |  | warranty and other claims for hardware products such as Xbox;

| • |  | sales channel disruption, such as the bankruptcy of a major distributor;

| • |  | the effects of the Consent Decree in U.S. v. Microsoft and Final Judgment in State of New York v. Microsoft on the Windows operating system and server business, including those associated with protocol and other disclosures required by the Decree and Final Judgment and the ability of PC manufacturers to hide end-user access to certain new Windows features;

| • |  | currency fluctuations;

| • |  | our ability to implement operating cost structures that align with revenue growth;

| • |  | the continued availability of third-party distribution channels for MSN service and other online services;

| • |  | factors associated with our international operations, as described under Operations in Part I, Item 1 of this report; and

| • |  | financial market volatility or other changes affecting the value of our investments, such as the Comcast Corporation securities held by us that may result in a reduction in carrying value and recognition of losses including impairment charges.

ITEM 7A. QUANTITATIVE AND QUALITATIVE DISCLOSURES ABOUT MARKET RISK

We are exposed to foreign currency, interest rate, and fixed income and equity price risks. A portion of these risks is hedged, but fluctuations could impact our results of operations and financial position. We hedge a portion of anticipated revenue and accounts receivable exposure to foreign currency fluctuations, primarily with option contracts. We monitor our foreign currency exposures daily to maximize the overall effectiveness of our foreign currency hedge positions. Principal currencies hedged include the Euro, Japanese yen, British pound, and Canadian dollar. Fixed income securities are subject to interest rate risk. The portfolio is diversified and structured to minimize credit risk. Securities held in our equity and other investments portfolio are subject to price risk, and are generally not hedged. However, we use options to hedge our price risk on certain equity securities that are held primarily for strategic purposes.

We use a value-at-risk (VAR) model to estimate and quantify our market risks. VAR is the expected loss, for a given confidence level, in fair value of our portfolio due to adverse market movements over a defined time horizon. The VAR model is not intended to represent actual losses in fair value, but is used as a risk estimation and management tool. The model used for currencies and equities is geometric Brownian motion, which allows incorporation of optionality with regard to these risk exposures. For interest rate risk, the mean reverting geometric Brownian motion is used to reflect the principle that fixed-income securities prices revert to maturity value over time.

Value-at-risk is calculated by, first, simulating 10,000 market price paths over 20 days for equities, interest rates and foreign exchange rates, taking into account historical correlations among the different rates and prices. Each

PAGE |  | 33

##### Table of Contents

Part II

Item 7A

resulting unique set of equities prices, interest rates, and foreign exchange rates is then applied to substantially all individual holdings to re-price each holding. The 250th worst performance (out of 10,000) represents the value-at-risk over 20 days at the 97.5 percentile confidence level. Several risk factors are not captured in the model, including liquidity risk, operational risk, credit risk, and legal risk.

Certain securities in our equity portfolio are held for strategic purposes. We hedge the value of a portion of these securities through the use of derivative contracts such as put-call collars. In these arrangements, we hedge a security’s equity price risk below the purchased put strike and forgo most or all of the benefits of the security’s appreciation above the sold call strike, in exchange for premium received for the sold call. We also hold equity securities for general investment return purposes. We have incurred material impairment charges related to these securities in prior periods. The VAR amounts disclosed below are used as a risk management tool and reflect an estimate of potential reductions in fair value of our portfolio. Losses in fair value over a 20-day holding period can exceed the reported VAR by significant amounts and can also accumulate over a longer time horizon than the 20-day holding period used in the VAR analysis. VAR amounts are not necessarily reflective of potential accounting losses, including determinations of other-than-temporary losses in fair value in accordance with U.S. GAAP.

The VAR numbers are shown separately for interest rate, currency, and equity risks. These VAR numbers include the underlying portfolio positions and related hedges. We use historical data to estimate VAR. Given the reliance on historical data, VAR is most effective in estimating risk exposures in markets in which there are no fundamental changes or shifts in market conditions. An inherent limitation in VAR is that the distribution of past changes in market risk factors may not produce accurate predictions of future market risk.

The following table sets forth the VAR calculations for substantially all of our positions:

(In millions) |  |  |  |  |  |  |  |  |  |
|  |  |  |  |  | Year ended June 30, 2004
Risk Categories |  | 2003 |  | 2004 |  | Average |  | High |  | Low
Interest rates |  | $ | 448 |  | $ | 298 |  | $ | 625 |  | $ | 817 |  | $ | 298
Currency rates |  | $ | 141 |  | $ | 207 |  | $ | 217 |  | $ | 326 |  | $ | 117
Equity prices |  | $ | 869 |  | $ | 773 |  | $ | 969 |  | $ | 1,174 |  | $ | 770

The total VAR for the combined risk categories is $835 million at June 30, 2004 and $987 million at June 30, 2003. The total VAR is 35% less at June 30, 2004 and 32% less at June, 30 2003 than the sum of the separate risk categories for each of those years in the above table, due to the diversification benefit of the combination of risks. The change in the absolute value of VAR is primarily due to asset allocation shifts and portfolio growth.

PAGE |  | 34

##### Table of Contents

Part II

Item 8

ITEM 8. FINANCIAL STATEMENTS AND SUPPLEMENTARY DATA

INCOME STATEMENTS

(In millions, except earnings per share) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002(1) |  |  | 2003(1) |  |  | 2004 |
Revenue |  | $ | 28,365 |  |  | $ | 32,187 |  |  | $ | 36,835 |
Operating expenses: |  |  |  |  |  |  |  |  |  |  |  |
Cost of revenue |  |  | 5,699 |  |  |  | 6,059 |  |  |  | 6,716 |
Research and development |  |  | 6,299 |  |  |  | 6,595 |  |  |  | 7,779 |
Sales and marketing |  |  | 6,252 |  |  |  | 7,562 |  |  |  | 8,309 |
General and administrative |  |  | 1,843 |  |  |  | 2,426 |  |  |  | 4,997 |
Total operating expenses |  |  | 20,093 |  |  |  | 22,642 |  |  |  | 27,801 |
Operating income |  |  | 8,272 |  |  |  | 9,545 |  |  |  | 9,034 |
Losses on equity investees and other |  |  | (92 | ) |  |  | (68 | ) |  |  | (25 | )
Investment income/(loss) |  |  | (305 | ) |  |  | 1,577 |  |  |  | 3,187 |
Income before income taxes |  |  | 7,875 |  |  |  | 11,054 |  |  |  | 12,196 |
Provision for income taxes |  |  | 2,520 |  |  |  | 3,523 |  |  |  | 4,028 |
Net income |  | $ | 5,355 |  |  | $ | 7,531 |  |  | $ | 8,168 |
Earnings per share: |  |  |  |  |  |  |  |  |  |  |  |
Basic |  | $ | 0.50 |  |  | $ | 0.70 |  |  | $ | 0.76 |
Diluted |  | $ | 0.48 |  |  | $ | 0.69 |  |  | $ | 0.75 |
Weighted average shares outstanding: |  |  |  |  |  |  |  |  |  |  |  |
Basic |  |  | 10,811 |  |  |  | 10,723 |  |  |  | 10,803 |
Diluted |  |  | 11,106 |  |  |  | 10,882 |  |  |  | 10,894 |

(1) |  | Income Statements for the years ended June 30, 2002 and 2003 have been restated to reflect the retroactive adoption of the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, as discussed in Note 13.

See accompanying notes.

PAGE |  | 35

##### Table of Contents

Part II

Item 8

BALANCE SHEETS

(In millions) |  |  |  |
June 30 |  | 2003(1) |  | 2004
Assets |  |  |  |  |  |
Current assets: |  |  |  |  |  |
Cash and equivalents |  | $ | 6,438 |  | $ | 15,982
Short-term investments |  |  | 42,610 |  |  | 44,610
Total cash and short-term investments |  |  | 49,048 |  |  | 60,592
Accounts receivable, net |  |  | 5,196 |  |  | 5,890
Inventories |  |  | 640 |  |  | 421
Deferred income taxes |  |  | 2,506 |  |  | 2,097
Other |  |  | 1,583 |  |  | 1,566
Total current assets |  |  | 58,973 |  |  | 70,566
Property and equipment, net |  |  | 2,223 |  |  | 2,326
Equity and other investments |  |  | 13,692 |  |  | 12,210
Goodwill |  |  | 3,128 |  |  | 3,115
Intangible assets, net |  |  | 384 |  |  | 569
Deferred income taxes |  |  | 2,161 |  |  | 1,829
Other long-term assets |  |  | 1,171 |  |  | 1,774
Total assets |  | $ | 81,732 |  | $ | 92,389
Liabilities and stockholders’ equity |  |  |  |  |  |
Current liabilities: |  |  |  |  |  |
Accounts payable |  | $ | 1,573 |  | $ | 1,717
Accrued compensation |  |  | 1,416 |  |  | 1,339
Income taxes |  |  | 2,044 |  |  | 3,478
Short-term unearned revenue |  |  | 7,225 |  |  | 6,514
Other |  |  | 1,716 |  |  | 1,921
Total current liabilities |  |  | 13,974 |  |  | 14,969
Long-term unearned revenue |  |  | 1,790 |  |  | 1,663
Other long-term liabilities |  |  | 1,056 |  |  | 932
Commitments and contingencies |  |  |  |  |  |
Stockholders’ equity: |  |  |  |  |  |
Common stock and paid-in capital – shares authorized 24,000; outstanding 10,771 and 10,862 |  |  | 49,234 |  |  | 56,396
Retained earnings, including accumulated other comprehensive income of $1,840 and $1,119 |  |  | 15,678 |  |  | 18,429
Total stockholders’ equity |  |  | 64,912 |  |  | 74,825
Total liabilities and stockholders’ equity |  | $ | 81,732 |  | $ | 92,389

(1) |  | June 30, 2003 balance sheet has been restated to reflect the retroactive adoption of the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, as discussed in Note 13.

See accompanying notes.

PAGE |  | 36

##### Table of Contents

Part II

Item 8

CASH FLOWS STATEMENTS

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002(1) |  |  | 2003(1) |  |  | 2004 |
Operations |  |  |  |  |  |  |  |  |  |  |  |
Net income |  | $ | 5,355 |  |  | $ | 7,531 |  |  | $ | 8,168 |
Depreciation, amortization, and other noncash items |  |  | 938 |  |  |  | 1,393 |  |  |  | 1,186 |
Stock-based compensation |  |  | 3,784 |  |  |  | 3,749 |  |  |  | 5,734 |
Net recognized (gains)/losses on investments |  |  | 2,424 |  |  |  | 380 |  |  |  | (1,296 | )
Stock option income tax benefits |  |  | 1,596 |  |  |  | 1,365 |  |  |  | 1,100 |
Deferred income taxes |  |  | (1,580 | ) |  |  | (894 | ) |  |  | (1,479 | )
Unearned revenue |  |  | 11,152 |  |  |  | 12,519 |  |  |  | 11,777 |
Recognition of unearned revenue |  |  | (8,929 | ) |  |  | (11,292 | ) |  |  | (12,527 | )
Accounts receivable |  |  | (1,623 | ) |  |  | 187 |  |  |  | (687 | )
Other current assets |  |  | (264 | ) |  |  | 412 |  |  |  | 478 |
Other long-term assets |  |  | (9 | ) |  |  | (28 | ) |  |  | 34 |
Other current liabilities |  |  | 1,449 |  |  |  | 35 |  |  |  | 2,063 |
Other long-term liabilities |  |  | 216 |  |  |  | 440 |  |  |  | 75 |
Net cash from operations |  |  | 14,509 |  |  |  | 15,797 |  |  |  | 14,626 |
Financing |  |  |  |  |  |  |  |  |  |  |  |
Common stock issued |  |  | 1,497 |  |  |  | 2,120 |  |  |  | 2,748 |
Common stock repurchased |  |  | (6,069 | ) |  |  | (6,486 | ) |  |  | (3,383 | )
Common stock dividend |  |  | – |  |  |  | (857 | ) |  |  | (1,729 | )
Net cash used for financing |  |  | (4,572 | ) |  |  | (5,223 | ) |  |  | (2,364 | )
Investing |  |  |  |  |  |  |  |  |  |  |  |
Additions to property and equipment |  |  | (770 | ) |  |  | (891 | ) |  |  | (1,109 | )
Acquisition of companies, net of cash acquired |  |  | – |  |  |  | (1,063 | ) |  |  | (4 | )
Purchases of investments |  |  | (89,386 | ) |  |  | (89,621 | ) |  |  | (92,495 | )
Maturities of investments |  |  | 8,654 |  |  |  | 9,205 |  |  |  | 5,561 |
Sales of investments |  |  | 70,657 |  |  |  | 75,157 |  |  |  | 85,302 |
Net cash used for investing |  |  | (10,845 | ) |  |  | (7,213 | ) |  |  | (2,745 | )
Net change in cash and equivalents |  |  | (908 | ) |  |  | 3,361 |  |  |  | 9,517 |
Effect of exchange rates on cash and equivalents |  |  | 2 |  |  |  | 61 |  |  |  | 27 |
Cash and equivalents, beginning of period |  |  | 3,922 |  |  |  | 3,016 |  |  |  | 6,438 |
Cash and equivalents, end of period |  | $ | 3,016 |  |  | $ | 6,438 |  |  | $ | 15,982 |

(1) |  | June 30, 2002 and 2003 cash flow statements have been restated for retroactive adoption of the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, as discussed in Note 13.

See accompanying notes.

PAGE |  | 37

##### Table of Contents

Part II

Item 8

STOCKHOLDERS’ EQUITY STATEMENTS

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002(1) |  |  | 2003(1) |  |  | 2004 |
Common stock and paid-in capital |  |  |  |  |  |  |  |  |  |  |  |
Balance, beginning of period |  | $ | 28,390 |  |  | $ | 41,845 |  |  | $ | 49,234 |
Cumulative SFAS 123 retroactive adjustments |  |  | 6,560 |  |  |  | – |  |  |  | – |
Common stock issued |  |  | 1,655 |  |  |  | 2,966 |  |  |  | 2,815 |
Common stock repurchased |  |  | (676 | ) |  |  | (691 | ) |  |  | (416 | )
Stock-based compensation expense |  |  | 3,784 |  |  |  | 3,749 |  |  |  | 5,734 |
Stock option income tax benefits/(deficiencies) |  |  | 1,596 |  |  |  | 1,365 |  |  |  | (989 | )
Other, net |  |  | 536 |  |  |  | – |  |  |  | 18 |
Balance, end of period |  |  | 41,845 |  |  |  | 49,234 |  |  |  | 56,396 |
Retained earnings |  |  |  |  |  |  |  |  |  |  |  |
Balance, beginning of period |  |  | 18,899 |  |  |  | 12,997 |  |  |  | 15,678 |
Cumulative SFAS 123 retroactive adjustments |  |  | (5,062 | ) |  |  | – |  |  |  | – |
Net income |  |  | 5,355 |  |  |  | 7,531 |  |  |  | 8,168 |
Other comprehensive income: |  |  |  |  |  |  |  |  |  |  |  |
Net gains/(losses) on derivative instruments |  |  | (91 | ) |  |  | (102 | ) |  |  | 101 |
Net unrealized investments gains/(losses) |  |  | 5 |  |  |  | 1,243 |  |  |  | (873 | )
Translation adjustments and other |  |  | 82 |  |  |  | 116 |  |  |  | 51 |
Comprehensive income |  |  | 5,351 |  |  |  | 8,788 |  |  |  | 7,447 |
Common stock dividend |  |  | – |  |  |  | (857 | ) |  |  | (1,729 | )
Common stock repurchased |  |  | (6,191 | ) |  |  | (5,250 | ) |  |  | (2,967 | )
Balance, end of period |  |  | 12,997 |  |  |  | 15,678 |  |  |  | 18,429 |
Total stockholders’ equity |  | $ | 54,842 |  |  | $ | 64,912 |  |  | $ | 74,825 |

(1) |  | June 30, 2002 and 2003 stockholders’ equity statements have been restated for retroactive adoption of the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, as discussed in Note 13.

See accompanying notes.

PAGE |  | 38

##### Table of Contents

Part II

Item 8

NOTES TO FINANCIAL STATEMENTS

NOTE 1 ACCOUNTING POLICIES

ACCOUNTING PRINCIPLES

The financial statements and accompanying notes are prepared in accordance with accounting principles generally accepted in the United States of America.

PRINCIPLES OF CONSOLIDATION

The financial statements include the accounts of Microsoft Corporation and its subsidiaries (Microsoft). Intercompany transactions and balances have been eliminated. Equity investments in which we exercised significant influence but do not control and are not the primary beneficiary are accounted for using the equity method. Investments in which we are not able to exercise significant influence over the investee are accounted for under the cost method.

ESTIMATES AND ASSUMPTIONS

Preparing financial statements requires management to make estimates and assumptions that affect the reported amounts of assets, liabilities, revenue, and expenses. Examples include estimates of loss contingencies and product life cycles, and assumptions such as the elements comprising a software arrangement, including the distinction between upgrades/enhancements and new products; when technological feasibility is achieved for our products; the potential outcome of future tax consequences of events that have been recognized in our financial statements or tax returns; and determining when investment impairments are other-than-temporary. Actual results and outcomes may differ from management’s estimates and assumptions.

FOREIGN CURRENCIES

Assets and liabilities recorded in foreign currencies are translated at the exchange rate on the balance sheet date. Revenue and expenses are translated at average rates of exchange prevailing during the year. Translation adjustments resulting from this process are charged or credited to other comprehensive income (OCI).

REVENUE RECOGNITION

Revenue is recognized when persuasive evidence of an arrangement exists, delivery has occurred, the fee is fixed or determinable, and collectibility is probable. We enter into certain arrangements where we are obligated to deliver multiple products and/or services (multiple elements). In these transactions, we allocate the total revenue among the elements based on the sales price of each element when sold separately (vendor-specific objective evidence).

Revenue for retail packaged products, products licensed to original equipment manufacturers (OEMs), and perpetual licenses for current products under our Open and Select volume licensing programs generally is recognized as products are shipped, with a portion of the revenue recorded as unearned due to undelivered elements including, in some cases, free post-delivery telephone support and the right to receive unspecified upgrades/enhancements of Microsoft Internet Explorer on a when-and-if-available basis. The amount of revenue allocated to undelivered elements is based on the vendor-specific objective evidence of fair value for those elements using the residual method. Under the residual method, the total fair value of the undelivered elements, as indicated by vendor-specific objective evidence, is recorded as unearned, and the difference between the total arrangement fee and the amount recorded as unearned for the undelivered elements is recognized as revenue related to delivered elements. Unearned revenue due to undelivered elements is recognized ratably on a straight-line basis over the related product’s life cycle.

Revenue from multi-year licensing arrangements are accounted for as subscriptions, with billings recorded as unearned revenue and recognized as revenue ratably over the billing coverage period. Certain multi-year licensing arrangements include rights to receive future versions of software product on a when-and-if-available basis under Open and Select volume licensing programs (currently named Software Assurance and, previously named Upgrade Advantage). In addition, other multi-year licensing arrangements include a perpetual license for current products combined with rights to receive future versions of software products on a when-and-if-available basis under Open, Select, and Enterprise Agreement volume licensing programs. Premier support services agreements, MSN Internet Access subscriptions, Xbox Live, Microsoft bCentral subscriptions, and Microsoft Developer Network subscriptions are also accounted for as subscriptions.

PAGE |  | 39

##### Table of Contents

Part II

Item 8

Revenue related to our Xbox game console is recognized upon shipment of the product to retailers. Revenue related to games published by us is recognized when those games have been delivered to retailers net of allowances for returns and price concessions. Revenue related to games published by third parties for use on the Xbox platform is recognized when manufactured for the game publishers. Online advertising revenue is recognized as advertisements are displayed. Search advertising revenue is recognized when the ad appears in the search results or when the action necessary to earn the revenue has been completed. Consulting services revenue is recognized as services are rendered, generally based on the negotiated hourly rate in the consulting arrangement and the number of hours worked during the period.

Costs related to insignificant obligations, which include telephone support for developer tools software, PC games, computer hardware, and Xbox, are accrued when the related revenue is recognized. Provisions are recorded for estimated returns, concessions, and bad debts.

RESEARCH AND DEVELOPMENT

Research and development expenses include payroll, employee benefits, equity compensation, and other headcount-related costs associated with product development. We have determined that technological feasibility for our software products is reached shortly before the products are released to manufacturing. Costs incurred after technological feasibility is established are not material, and accordingly, we expense all research and development costs when incurred.

SALES AND MARKETING

Sales and marketing expenses include payroll, employee benefits, equity compensation, and other headcount-related costs as well as expenses related to advertising, promotions, tradeshows, seminars, and other programs. Advertising costs are expensed as incurred. Advertising expense was $1.13 billion in fiscal 2002, $1.06 billion in fiscal 2003, and $904 million in fiscal 2004.

INCOME TAXES

Income tax expense includes U.S. and international income taxes, plus the provision for U.S. taxes on undistributed earnings of international subsidiaries not deemed to be permanently invested. Certain items of income and expense are not reported in tax returns and financial statements in the same year. The tax effect of such temporary differences is reported as deferred income taxes.

DERIVATIVE AND FINANCIAL INSTRUMENTS

We consider all highly liquid interest-earning investments with a maturity of three months or less at the date of purchase to be cash equivalents. Investments with maturities beyond one year may be classified as short-term based on their highly liquid nature and because such marketable securities represent the investment of cash that is available for current operations. All cash and short-term investments are classified as available for sale and are recorded at market value using the specific identification method; unrealized gains and losses (excluding other-than-temporary impairments) are reflected in OCI.

Equity and other investments include both debt and equity instruments. Debt securities and publicly traded equity securities are classified as available for sale and are recorded at market using the specific identification method. Unrealized gains and losses (excluding other-than-temporary impairments) are reflected in OCI. All other investments, excluding those accounted for using the equity method, are recorded at cost.

We lend certain fixed income and equity securities to enhance investment income. Collateral and/or security interest is determined based upon the underlying security and the creditworthiness of the borrower. The fair value of collateral that we are permitted to sell or repledge was $499 million at both June 30, 2003 and 2004.

Investments are considered to be impaired when a decline in fair value is judged to be other-than-temporary. We employ a systematic methodology that considers available evidence in evaluating potential impairment of our investments on a quarterly basis. If the cost of an investment exceeds its fair value, we evaluate, among other factors, general market conditions, the duration and extent to which the fair value is less than cost, as well as our intent and ability to hold the investment. We also consider specific adverse conditions related to the financial health of and business outlook for the investee, including industry and sector performance, changes in technology, operational and financing cash flow factors, and rating agency actions. Once a decline in fair value is determined to be other-than-temporary, an impairment charge is recorded and a new cost basis in the investment is established.

PAGE |  | 40

##### Table of Contents

Part II

Item 8

We use derivative instruments to manage exposures to foreign currency, equities price, interest rate, and credit risks. Our objectives for holding derivatives include reducing, eliminating, and efficiently managing the economic impact of these exposures as effectively as possible. Derivative instruments are recognized as either assets or liabilities and are measured at fair value. The accounting for changes in the fair value of a derivative depends on the intended use of the derivative and the resulting designation. For a derivative instrument designated as a fair-value hedge, the gain or loss is recognized in earnings in the period of change together with the offsetting loss or gain on the hedged item attributed to the risk being hedged. For a derivative instrument designated as a cash-flow hedge, the effective portion of the derivative’s gain or loss is initially reported as a component of OCI and subsequently reclassified into earnings when the hedged exposure affects earnings. The ineffective portion of the gain or loss is recognized in earnings. For options designated either as fair-value or cash-flow hedges, changes in the time value are excluded from the assessment of hedge effectiveness and are recognized in earnings. Gains and losses from changes in fair values of derivatives that are not designated as hedges for accounting purposes are recognized in earnings.

Foreign Currency Risk. Certain forecasted transactions and assets are exposed to foreign currency risk. We monitor our foreign currency exposures daily to maximize the overall effectiveness of our foreign currency hedge positions. Options are used to hedge a portion of forecasted international revenue for up to three years in the future and are designated as cash-flow hedging instruments under Statement of Financial Accounting Standards (SFAS) 133, Accounting for Derivative Instruments and Hedging Activities. Principal currencies hedged include the Euro, Japanese yen, British pound, and Canadian dollar. Certain non-U.S. dollar denominated securities are hedged using foreign exchange forward contracts that are designated as fair-value hedging instruments under SFAS 133. Certain options and forwards not designated as hedging instruments under SFAS 133 are also used to hedge the impact of the variability in exchange rates on accounts receivable and collections denominated in certain foreign currencies and to manage other foreign currency exposures.

Equities Price Risk. Equity investments are subject to market price risk. From time to time, we use and designate options to hedge fair values and cash flows on certain equity securities. We determine the security, or forecasted sale thereof, selected for hedging by evaluating market conditions, up-front costs, and other relevant factors. Once established, the hedges are not dynamically managed or traded, and are generally not removed until maturity. Certain options, futures and swap contracts, not designated as hedging instruments under SFAS 133, are also used to manage equity exposures.

Interest Rate Risk. Fixed-income securities are subject to interest rate risk. The fixed-income portfolio is diversified and consists primarily of investment grade securities to minimize credit risk. We use exchange-traded option and future contracts and over-the-counter swap contracts, not designated as hedging instruments under SFAS 133, to hedge interest rate risk.

Other Derivatives. Swap contracts, not designated as hedging instruments under SFAS 133, are used to manage exposures to credit risks. In addition, we may invest in warrants to purchase securities of other companies as a strategic investment. Warrants that can be net share settled are deemed derivative financial instruments and are not designated as hedging instruments. To Be Announced forward purchase commitments of mortgage-backed assets are also considered derivatives in cases where physical delivery of the assets are not taken at the earliest available delivery date. All derivative instruments not designated as hedging instruments are recorded at fair value, with changes in value recognized in the income statement during the period of change.

PAGE |  | 41

##### Table of Contents

Part II

Item 8

ALLOWANCE FOR DOUBTFUL ACCOUNTS

The allowance for doubtful accounts reflects our best estimate of probable losses inherent in the accounts receivable balance. We determine the allowance based on known troubled accounts, historical experience, and other currently available evidence. Activity in the allowance for doubtful accounts is as follows:

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | Balance at beginning of period |  | Charged to costs and expenses |  | Write-offs and other |  |  | Balance at end of period
2002 |  | $ | 174 |  | $ | 192 |  | $ | (157 | ) |  | $ | 209
2003 |  |  | 209 |  |  | 118 |  |  | (85 | ) |  |  | 242
2004 |  |  | 242 |  |  | 44 |  |  | (120 | ) |  |  | 166

INVENTORIES

Inventories are stated at the lower of cost or market, using the average cost method. Cost includes materials, labor, and manufacturing overhead related to the purchase and production of inventories. We regularly review inventory quantities on hand, future purchase commitments with our suppliers, and the estimated utility of our inventory. If our review indicates a reduction in utility below carrying value, we reduce our inventory to a new cost basis.

PROPERTY AND EQUIPMENT

Property and equipment is stated at cost and depreciated using the straight-line method over the shorter of the estimated life of the asset or the lease term, ranging from one to 15 years. Computer software developed or obtained for internal use is depreciated using the straight-line method over the estimated useful life of the software, generally three years or less.

GOODWILL

Goodwill is tested for impairment on an annual basis as of July 1, and between annual tests if indicators of potential impairment exist, using a fair-value-based approach. No impairment of goodwill has been identified during any of the periods presented.

INTANGIBLE ASSETS

Intangible assets are amortized using the straight-line method over their estimated period of benefit, ranging from one to ten years. We evaluate the recoverability of intangible assets periodically and take into account events or circumstances that warrant revised estimates of useful lives or that indicate that impairment exists. All of our intangible assets are subject to amortization. No impairments of intangible assets have been identified during any of the periods presented.

NOTE 2 UNEARNED REVENUE

Unearned revenue is comprised of the following items:

Volume licensing programs – Represents customer billings, paid either upfront or annually at the beginning of each billing coverage period, which are accounted for as subscriptions with revenue recognized ratably over the billing coverage period.

Undelivered elements – Represents free post-delivery telephone support and the right to receive unspecified upgrades/enhancements of Microsoft Internet Explorer on a when-and-if-available basis. The amount recorded as unearned is based on the sales price of those elements when sold separately and is recognized ratably on a straight-line basis over the related product’s life cycle. The percentage of revenue recorded as unearned due to undelivered elements ranges from approximately 15% to 25% of the sales price for Windows XP Home, approximately 5% to 15% of the sales price for Windows XP Professional, and approximately 1% to 15% of the sales price for desktop

PAGE |  | 42

##### Table of Contents

Part II

Item 8

applications, depending on the terms and conditions of the license and prices of the elements. Product life cycles are currently estimated at three and one-half years for Windows operating systems and two years for desktop applications.

Other – Represents primarily payments for online advertising for which the advertisement has yet to be displayed and payments for post-delivery support services to be performed in the future.

The components of unearned revenue are as follows:

(In millions) |  |  |  |
June 30 |  | 2003 |  | 2004
Volume licensing programs |  | $ | 5,472 |  | $ | 5,075
Undelivered elements |  |  | 2,847 |  |  | 2,358
Other |  |  | 696 |  |  | 744
Unearned revenue |  | $ | 9,015 |  | $ | 8,177

Unearned revenue by segment is as follows:

(In millions) |  |  |  |
June 30 |  | 2003 |  | 2004
Client |  | $ | 3,165 |  | $ | 2,822
Server and Tools |  |  | 2,185 |  |  | 2,370
Information Worker |  |  | 3,305 |  |  | 2,586
Other segments |  |  | 360 |  |  | 399
Unearned revenue |  | $ | 9,015 |  | $ | 8,177

PAGE |  | 43

##### Table of Contents

Part II

Item 8

NOTE 3 INVESTMENTS

The components of investments are as follows:

(In millions) |  | Cost basis |  | Unrealized gains |  | Unrealized losses |  |  | Recorded basis |  | Cash and equivalents |  | Short - term investments |  | Equity and other investments
June 30, 2003 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Fixed maturity securities |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Cash |  | $ | 1,308 |  | $ | – |  | $ | – |  |  | $ | 1,308 |  | $ | 1,308 |  | $ | – |  | $ | –
Money market mutual funds |  |  | 1,263 |  |  | – |  |  | – |  |  |  | 1,263 |  |  | 1,263 |  |  | – |  |  | –
Commercial paper |  |  | 874 |  |  | – |  |  | – |  |  |  | 874 |  |  | 774 |  |  | 100 |  |  | –
Certificates of deposit |  |  | 297 |  |  | – |  |  | – |  |  |  | 297 |  |  | 28 |  |  | 269 |  |  | –
U. S. Government and Agency securities |  |  | 7,205 |  |  | 126 |  |  | (28 | ) |  |  | 7,303 |  |  | 1,889 |  |  | 5,414 |  |  | –
Foreign government bonds |  |  | 5,364 |  |  | 79 |  |  | (16 | ) |  |  | 5,427 |  |  | – |  |  | 5,427 |  |  | –
Mortgage backed securities |  |  | 6,257 |  |  | 65 |  |  | (3 | ) |  |  | 6,319 |  |  | – |  |  | 6,319 |  |  | –
Corporate notes and bonds |  |  | 17,913 |  |  | 1,033 |  |  | (170 | ) |  |  | 18,776 |  |  | 828 |  |  | 16,089 |  |  | 1,859
Municipal securities |  |  | 9,081 |  |  | 265 |  |  | (6 | ) |  |  | 9,340 |  |  | 348 |  |  | 8,992 |  |  | –
Fixed maturity securities |  |  | 49,562 |  |  | 1,568 |  |  | (223 | ) |  |  | 50,907 |  |  | 6,438 |  |  | 42,610 |  |  | 1,859
Equity securities |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Common stock and equivalents |  |  | 8,395 |  |  | 1,686 |  |  | (3 | ) |  |  | 10,078 |  |  | – |  |  | – |  |  | 10,078
Preferred stock |  |  | 1,262 |  |  | – |  |  | – |  |  |  | 1,262 |  |  | – |  |  | – |  |  | 1,262
Other investments |  |  | 493 |  |  | – |  |  | – |  |  |  | 493 |  |  | – |  |  | – |  |  | 493
Equity securities |  |  | 10,150 |  |  | 1,686 |  |  | (3 | ) |  |  | 11,833 |  |  | – |  |  | – |  |  | 11,833
Total |  | $ | 59,712 |  | $ | 3,254 |  | $ | (226 | ) |  | $ | 62,740 |  | $ | 6,438 |  | $ | 42,610 |  | $ | 13,692
(In millions) |  | Cost basis |  | Unrealized gains |  | Unrealized losses |  |  | Recorded basis |  | Cash and equivalents |  | Short - term investments |  | Equity and other investments
June 30, 2004 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Fixed maturity securities |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Cash |  | $ | 1,812 |  | $ | – |  | $ | – |  |  | $ | 1,812 |  | $ | 1,812 |  | $ | – |  | $ | –
Money market mutual funds |  |  | 3,595 |  |  | – |  |  | – |  |  |  | 3,595 |  |  | 3,595 |  |  | – |  |  | –
Commercial paper |  |  | 7,286 |  |  | – |  |  | – |  |  |  | 7,286 |  |  | 4,109 |  |  | 3,177 |  |  | –
Certificates of deposit |  |  | 415 |  |  | – |  |  | – |  |  |  | 415 |  |  | 330 |  |  | 85 |  |  | –
U. S. Government and Agency securities |  |  | 20,565 |  |  | 26 |  |  | (54 | ) |  |  | 20,537 |  |  | 4,083 |  |  | 16,454 |  |  | –
Foreign government bonds |  |  | 4,524 |  |  | 41 |  |  | (60 | ) |  |  | 4,505 |  |  | – |  |  | 4,505 |  |  | –
Mortgage backed securities |  |  | 3,656 |  |  | 21 |  |  | (42 | ) |  |  | 3,635 |  |  | – |  |  | 3,635 |  |  | –
Corporate notes and bonds |  |  | 15,048 |  |  | 122 |  |  | (50 | ) |  |  | 15,120 |  |  | 1,010 |  |  | 12,629 |  |  | 1,481
Municipal securities |  |  | 5,154 |  |  | 39 |  |  | (25 | ) |  |  | 5,168 |  |  | 1,043 |  |  | 4,125 |  |  | –
Fixed maturity securities |  |  | 62,055 |  |  | 249 |  |  | (231 | ) |  |  | 62,073 |  |  | 15,982 |  |  | 44,610 |  |  | 1,481
Equity securities |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Common stock and equivalents |  |  | 7,722 |  |  | 1,571 |  |  | (62 | ) |  |  | 9,231 |  |  | – |  |  | – |  |  | 9,231
Preferred stock |  |  | 1,290 |  |  | – |  |  | – |  |  |  | 1,290 |  |  | – |  |  | – |  |  | 1,290
Other investments |  |  | 208 |  |  | – |  |  | – |  |  |  | 208 |  |  | – |  |  | – |  |  | 208
Equity securities |  |  | 9,220 |  |  | 1,571 |  |  | (62 | ) |  |  | 10,729 |  |  | – |  |  | – |  |  | 10,729
Total |  | $ | 71,275 |  | $ | 1,820 |  | $ | (293 | ) |  | $ | 72,802 |  | $ | 15,982 |  | $ | 44,610 |  | $ | 12,210

PAGE |  | 44

##### Table of Contents

Part II

Item 8

At June 30, 2004 unrealized losses of $293 million consisted of: $188 million related to investment grade fixed income securities, $43 million related to investments in high yield and emerging market fixed income securities, $49 million related to domestic equity securities and $13 million related to international equity securities. Unrealized losses from fixed income securities are primarily attributable to changes in interest rates. Unrealized losses from domestic and international equities are due to market price movements. Of the unrealized losses of $293 million at June 30, 2004,$51 million exceeded twelve months. Management does not believe any unrealized losses represent an other-than temporary impairment based on our evaluation of available evidence as of June 30, 2004.

Common and preferred stock and other investments that are restricted for more than one year or are not publicly traded are recorded at cost. At June 30, 2003, the recorded basis of these investments was $2.15 billion, and their estimated fair value was $2.56 billion. At June 30, 2004 the recorded basis of these investments was $1.65 billion, and their estimated fair value was $2.12 billion. The estimate of fair value is based on publicly available market information or other estimates determined by management.

The maturities of debt securities at June 30, 2004 were as follows:

(In millions) |  | Cost basis |  | Estimated fair value
Due in one year or less |  | $ | 37,348 |  | $ | 37,388
Due after one year through five years |  |  | 14,077 |  |  | 14,064
Due after five years through ten years |  |  | 5,636 |  |  | 5,665
Due after ten years |  |  | 4,994 |  |  | 4,956
Total |  | $ | 62,055 |  | $ | 62,073

Debt securities include fixed maturity securities.

NOTE 4 INVESTMENT INCOME/(LOSS)

The components of investment income/(loss) are as follows:

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Dividends and interest |  | $ | 2,119 |  |  | $ | 1,957 |  |  | $ | 1,892 |
Net recognized gains/(losses) on investments |  |  | (1,807 | ) |  |  | 44 |  |  |  | 1,563 |
Net losses on derivatives |  |  | (617 | ) |  |  | (424 | ) |  |  | (268 | )
Investment income/(loss) |  | $ | (305 | ) |  | $ | 1,577 |  |  | $ | 3,187 |

Net recognized gains/(losses) on investments include other-than-temporary impairments of $4.32 billion in fiscal 2002, $1.15 billion in fiscal 2003, and $82 million in fiscal 2004. Realized gains and (losses) from sales of available-for-sale securities (excluding other-than-temporary impairments) were $3.02 billion and $(504) million in fiscal 2002, $1.44 billion and $(245) million in fiscal 2003, and $2.16 billion and $(518) million in fiscal 2004.

NOTE 5 DERIVATIVES

For derivative instruments designated as hedges, hedge ineffectiveness, determined in accordance with SFAS 133, did not have a significant impact on earnings for fiscal 2002, 2003, and 2004. During fiscal 2002, $30 million in gains on fair value hedges from changes in time value and $331 million in losses on cash flow hedges from changes in time value were excluded from the assessment of hedge effectiveness and included in investment income/(loss). During fiscal 2003, $74 million in losses on fair value hedges from changes in time value and $229 million in losses on cash flow hedges from changes in time value were excluded from the assessment of hedge effectiveness and included in investment income/(loss). During fiscal 2004, $31 million in gains on fair value hedges from changes in time value and $325 million in losses on cash flow hedges from changes in time value were excluded from the assessment of hedge effectiveness and included in investment income/(loss).

PAGE |  | 45

##### Table of Contents

Part II

Item 8

Derivative gains and losses included in OCI are reclassified into earnings at the time forecasted revenue or the sale of an equity investment is recognized. During fiscal 2002, $234 million of derivative gains were reclassified to revenue and $10 million in derivative losses were reclassified to investment income/(loss). During fiscal 2003, $40 million of derivative gains were reclassified to revenue and $2 million in derivative gains were reclassified to investment income/(loss). During fiscal 2004, $14 million of derivative gains were reclassified to revenue and no derivative gains or losses were reclassified to investment income/(loss).

We estimate that $119 million of net derivative gains included in OCI will be reclassified into earnings within the next twelve months. No significant fair value hedges or cash flow hedges were derecognized or discontinued for fiscal 2002, 2003, and 2004.

NOTE 6 INVENTORIES

(In millions) |  |  |  |
Year Ended June 30 |  | 2003 |  | 2004
Finished goods |  | $ | 393 |  | $ | 271
Raw materials and work in process |  |  | 247 |  |  | 150
Inventories |  | $ | 640 |  | $ | 421

We recorded lower of cost or market adjustments totaling approximately $90 million in fiscal 2004.

NOTE 7 PROPERTY AND EQUIPMENT

(In millions) |  |  |  |  |  |
Year Ended June 30 |  | 2003 |  |  | 2004 |
Land |  | $ | 248 |  |  | $ | 274 |
Buildings and improvements |  |  | 1,854 |  |  |  | 1,981 |
Leasehold improvements |  |  | 768 |  |  |  | 805 |
Computer equipment and software |  |  | 2,464 |  |  |  | 2,637 |
Furniture and equipment |  |  | 744 |  |  |  | 792 |
Property and equipment, at cost |  |  | 6,078 |  |  |  | 6,489 |
Accumulated depreciation |  |  | (3,855 | ) |  |  | (4,163 | )
Property and equipment, net |  | $ | 2,223 |  |  | $ | 2,326 |

Property and equipment are stated at cost. Depreciation is computed principally on the straight-line method over the estimated useful lives of the assets. The useful lives for buildings range from five to fifteen years, leasehold improvements range from the shorter of five years or applicable lease term, computer equipment and software range from two to three years, and furniture and equipment range from one to five years. Land is not depreciated.

During fiscal 2002, 2003, and 2004, depreciation expense was $820 million, $929 million, and $647 million, the majority of which related to computer equipment.

PAGE |  | 46

##### Table of Contents

Part II

Item 8

NOTE 8 GOODWILL

Changes in the carrying amount of goodwill for fiscal 2003 and 2004 by segment, are as follows:

(In millions) |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
|  | Balance as of June 30, 2002 |  | Acquisitions / purchase accounting adjustments |  |  | Balance as of June 30, 2003 |  | Acquisitions / purchase accounting adjustments |  |  | Divestitures |  |  | Balance as of June 30, 2004
Client |  | $ | 26 |  | $ | 11 |  |  | $ | 37 |  | $ | – |  |  | $ | – |  |  | $ | 37
Server and Tools |  |  | 97 |  |  | 9 |  |  |  | 106 |  |  | – |  |  |  | – |  |  |  | 106
Information Worker |  |  | – |  |  | 180 |  |  |  | 180 |  |  | (2 | ) |  |  | – |  |  |  | 178
Microsoft Business Solutions |  |  | 1,021 |  |  | 1,198 |  |  |  | 2,219 |  |  | 7 |  |  |  | (19 | ) |  |  | 2,207
MSN |  |  | 160 |  |  | (6 | ) |  |  | 154 |  |  | – |  |  |  | – |  |  |  | 154
Mobile and Embedded Devices |  |  | 5 |  |  | 23 |  |  |  | 28 |  |  | 2 |  |  |  | – |  |  |  | 30
Home and Entertainment |  |  | 117 |  |  | 287 |  |  |  | 404 |  |  | (1 | ) |  |  | – |  |  |  | 403
Total |  | $ | 1,426 |  | $ | 1,702 |  |  | $ | 3,128 |  | $ | 6 |  |  | $ | (19 | ) |  | $ | 3,115

We test goodwill for impairment annually during the first quarter of each fiscal year at the reporting unit level using a fair value approach, in accordance with the provisions of SFAS 142. Our annual testing resulted in no impairment charges to goodwill in fiscal 2003 and 2004. If an event occurs or circumstances change that would more likely than not reduce the fair value of a reporting unit below its carrying value, goodwill will be evaluated for impairment between annual tests.

During fiscal 2004, we had no material acquisitions. Goodwill decreased $13 million primarily as a result of goodwill allocated to a business that was divested in the current year.

The $1.7 billion increase in goodwill during fiscal 2003 related principally to the following acquisitions: Navision a/s with $1.2 billion allocated to Microsoft Business Solutions; $281 million for the Rare Ltd. acquisition allocated to Home and Entertainment; and Placeware, Inc. with $180 million allocated to Information Worker.

NOTE 9 INTANGIBLE ASSETS

The components of finite-lived intangible assets are as follows:

(In millions) |  |  |  |  |  |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2003 |  | 2004
|  | Gross carrying amount |  | Accumulated amortization |  |  | Net carrying amount |  | Gross carrying amount |  | Accumulated amortization |  |  | Net carrying amount
Contract-based |  | $ | 584 |  | $ | (376 | ) |  | $ | 208 |  | $ | 908 |  | $ | (476 | ) |  | $ | 432
Technology-based |  |  | 261 |  |  | (137 | ) |  |  | 124 |  |  | 278 |  |  | (183 | ) |  |  | 95
Marketing-related |  |  | 34 |  |  | (9 | ) |  |  | 25 |  |  | 35 |  |  | (19 | ) |  |  | 16
Customer-related |  |  | 28 |  |  | (1 | ) |  |  | 27 |  |  | 30 |  |  | (4 | ) |  |  | 26
Total |  | $ | 907 |  | $ | (523 | ) |  | $ | 384 |  | $ | 1,251 |  | $ | (682 | ) |  | $ | 569

PAGE |  | 47

##### Table of Contents

Part II

Item 8

During fiscal 2004, we recorded additions to intangible assets of $355 million, of which $266 million was related to a comprehensive intellectual property license that we received in conjunction with the settlement of InterTrust v. Microsoft. No other material intangibles were acquired in fiscal 2004. During fiscal 2003, we recorded additions to intangible assets of $306 million, primarily related to the acquisition of Navision a/s and Rare Ltd., as described at Note 15 – Acquisitions. The components of intangible assets acquired during fiscal 2003 and 2004 are as follows – no significant residual value is estimated for these assets:

(In millions) |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2003 |  | 2004
|  | Amount |  | Weighted average life |  | Amount |  | Weighted average life
Contract-based |  | $ | 162 |  | 5 years |  | $ | 324 |  | 9 years
Technology-based |  |  | 97 |  | 4 years |  |  | 28 |  | 4 years
Marketing-related |  |  | 19 |  | 4 years |  |  | – |  | –
Customer-related |  |  | 28 |  | 9 years |  |  | 3 |  | 3 years
Total |  | $ | 306 |  | 5 years |  | $ | 355 |  | 9 years

During 2003, research and development assets of $17 million were acquired and written off in accordance with FASB Interpretation No. 4 (FIN 4), Applicability of FASB Statement No. 2 to Business Combinations Accounted for by the Purchase Method. Those write-offs are included in Research and Development expenses.

Acquired finite-lived intangibles are generally amortized on a straight line basis over weighted average periods. Intangible assets amortization expense was $161 million for fiscal 2003 and $170 million for fiscal 2004. The estimated future amortization expense related to intangible assets as of June 30, 2004 is as follows:

(In millions) |  |
June 30 |  | Amount
2005 |  | $ | 154
2006 |  |  | 104
2007 |  |  | 81
2008 |  |  | 62
2009 |  |  | 38
Total |  | $ | 439

NOTE 10 INCOME TAXES

The components of the provision for income taxes are as follows:

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Current taxes: |  |  |  |  |  |  |  |  |  |  |  |
U.S. and state |  | $ | 3,644 |  |  | $ | 3,861 |  |  | $ | 3,940 |
International |  |  | 575 |  |  |  | 808 |  |  |  | 1,056 |
Current taxes |  |  | 4,219 |  |  |  | 4,669 |  |  |  | 4,996 |
Deferred taxes |  |  | (1,699 | ) |  |  | (1,146 | ) |  |  | (968 | )
Provision for income taxes |  | $ | 2,520 |  |  | $ | 3,523 |  |  | $ | 4,028 |

PAGE |  | 48

##### Table of Contents

Part II

Item 8

U.S. and international components of income before income taxes are as follows:

(In millions) |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  | 2003 |  | 2004
U.S. |  | $ | 5,282 |  | $ | 7,674 |  | $ | 8,088
International |  |  | 2,593 |  |  | 3,380 |  |  | 4,108
Income before income taxes |  | $ | 7,875 |  | $ | 11,054 |  | $ | 12,196

The items accounting for the difference between income taxes computed at the federal statutory rate and the provision for income taxes are as follows:

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Federal statutory rate |  | 35.0 | % |  | 35.0 | % |  | 35.0 | %
Effect of: |  |  |  |  |  |  |  |  |
Extraterritorial income exclusion tax benefit |  | (3.1 | )% |  | (1.6 | )% |  | (0.9 | )%
Permanent reinvestment of foreign earnings |  | (1.8 | )% |  | (1.3 | )% |  | (1.7 | )%
Other reconciling items |  | 1.9 | % |  | – |  |  | 0.6 | %
Total |  | 32.0 | % |  | 32.1 | % |  | 33.0 | %

The 2004 other reconciling items include the $208 million benefit from the resolution of the issue remanded by the 9th Circuit Court of Appeals and the impact of the non-deductible European Commission fine.

Deferred income taxes were:

(In millions) |  |  |  |  |  |
June 30 |  | 2003 |  |  | 2004 |
Deferred income tax assets: |  |  |  |  |  |  |  |
Revenue items |  | $ | 2,556 |  |  | $ | 2,032 |
Expense items |  |  | 1,048 |  |  |  | 1,308 |
Impaired investments |  |  | 1,525 |  |  |  | 1,246 |
Stock-based compensation expense |  |  | 3,892 |  |  |  | 3,749 |
Deferred income tax assets |  | $ | 9,021 |  |  | $ | 8,335 |
Deferred income tax liabilities: |  |  |  |  |  |  |  |
Unrealized gain on investments |  | $ | (1,584 | ) |  | $ | (1,087 | )
International earnings |  |  | (1,809 | ) |  |  | (2,227 | )
Other |  |  | (961 | ) |  |  | (1,095 | )
Deferred income tax liabilities |  |  | (4,354 | ) |  |  | (4,409 | )
Net deferred income taxes |  | $ | 4,667 |  |  | $ | 3,926 |
Reported as: |  |  |  |  |  |  |  |
Current deferred tax assets |  | $ | 2,506 |  |  | $ | 2,097 |
Long-term deferred tax assets |  |  | 2,161 |  |  |  | 1,829 |
Net deferred income taxes |  | $ | 4,667 |  |  | $ | 3,926 |

Deferred income tax balances reflect the effects of temporary differences between the carrying amounts of assets and liabilities and their tax bases and are stated at enacted tax rates expected to be in effect when taxes are actually paid or recovered.

We have not provided for U.S. deferred income taxes or foreign withholding taxes on $2.30 billion of our undistributed earnings for certain non-U.S. subsidiaries, all of which relate to fiscal 2002, 2003, and 2004 earnings, because these earnings are intended to be permanently reinvested in operations outside the United States.

PAGE |  | 49

##### Table of Contents

Part II

Item 8

On December 3, 2002, the Ninth Circuit Court of Appeals reversed, in part, an earlier U.S. Tax Court decision. In 2004, the remaining issue remanded by the Ninth Circuit Court of Appeals was resolved closing all tax years with the IRS through 1996. The IRS is currently auditing 1997 through 2003. Management believes any adjustments that may ultimately be required will not be material to the financial statements. Income taxes paid were $1.9 billion in fiscal 2002, $2.8 billion in fiscal 2003, and $2.5 billion in fiscal 2004.

NOTE 11 STOCKHOLDERS’ EQUITY

Shares of common stock outstanding are as follows:

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Beginning balance |  | 10,766 |  |  | 10,718 |  |  | 10,771 |
Issued |  | 208 |  |  | 291 |  |  | 215 |
Repurchased |  | (256 | ) |  | (238 | ) |  | (124 | )
Balance, end of year |  | 10,718 |  |  | 10,771 |  |  | 10,862 |

As discussed in Note 13 – Employee Stock and Savings Plans, 344.6 million options were transferred to JPMorgan Chase Bank (JPMorgan) under the stock option transfer program. The options transferred to JPMorgan were amended and restated upon transfer to contain terms and conditions typical of equity option transactions entered into between sophisticated financial counterparties at arm’s length using standard terms and definitions for equity derivatives. As of June 30, 2004, the options have strike prices ranging from $33.03 to $101.25 per share and have expiration dates between December 2005 and December 2006.

Our board of directors has approved a program to repurchase shares of our common stock to reduce the dilutive effect of our stock option and stock purchase plans. A total of 618 million shares have been repurchased on open market transactions over the last three fiscal years for approximately $16.2 billion. We repurchased 256 million shares for $6.9 billion, 238 million shares for $5.9 billion, and 124 million shares for $3.4 billion in fiscal 2002, 2003, and 2004, respectively. Additionally, in 2002, we acquired 10.2 million of our shares as a result of a structured stock repurchase transaction entered into in 2001, which gave us the right to acquire such shares in exchange for an up-front net payment of $264 million. In any period, cash used in financing activities related to common stock repurchased may differ from the comparable change in Stockholders’ Equity, reflecting timing differences between the recognition of share repurchase transactions and their settlement for cash.

On January 16 and September 12, 2003, our board of directors declared annual dividends on our common stock of $0.08 and $0.16 per share, respectively. The dividends were paid on March 7 and November 7, 2003, respectively, to shareholders of record at the close of business on February 21, and October 17, 2003.

PAGE |  | 50

##### Table of Contents

Part II

Item 8

NOTE 12 OTHER COMPREHENSIVE INCOME

The activity in other comprehensive income and related tax effects are as follows:

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Net gains/ (losses) on derivative instruments: |  |  |  |  |  |  |  |  |  |  |  |
Unrealized gains/ (losses), net of tax effect of $30 in 2002, $(69) in 2003 and $49 in 2004 |  | $ | 55 |  |  | $ | (129 | ) |  | $ | 92 |
Reclassification adjustment for (gains)/losses included in net income, net of tax effect of $(79) in 2002, $15 in 2003 and $5 in 2004 |  |  | (146 | ) |  |  | 27 |  |  |  | 9 |
Net gains/ (losses) on derivative instruments |  |  | (91 | ) |  |  | (102 | ) |  |  | 101 |
Net unrealized investment gains/ (losses): |  |  |  |  |  |  |  |  |  |  |  |
Unrealized holding gains/ (losses), net of tax effect of $(955) in 2002, $610 in 2003 and $(994) in 2004 |  |  | (1,774 | ) |  |  | 1,132 |  |  |  | (1,846 | )
Reclassification adjustment for (gains)/losses included in net income, net of tax effect of $958 in 2002, $60 in 2003 and $524 in 2004 |  |  | 1,779 |  |  |  | 111 |  |  |  | 973 |
Net unrealized investment gains/ (losses) |  |  | 5 |  |  |  | 1,243 |  |  |  | (873 | )
Translation adjustments and other |  |  | 82 |  |  |  | 116 |  |  |  | 51 |
Other comprehensive income / (loss) |  | $ | (4 | ) |  | $ | 1,257 |  |  | $ | (721 | )

The components of accumulated other comprehensive income were:

(In millions) |  | 2003 |  |  | 2004
Year Ended June 30 |  |  |  |  |
Net gains/ (losses) on derivative instruments |  | $ | (16 | ) |  | $ | 85
Net unrealized investment gains |  |  | 1,846 |  |  |  | 973
Translation adjustments and other |  |  | 10 |  |  |  | 61
Accumulated other comprehensive income |  | $ | 1,840 |  |  | $ | 1,119

NOTE 13 EMPLOYEE STOCK AND SAVINGS PLANS

Effective July 1, 2003, we adopted the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, using the retroactive restatement method described in SFAS 148, Accounting for Stock-Based Compensation – Transition and Disclosure. Under the fair value recognition provisions of SFAS 123, stock-based compensation cost is measured at the grant date based on the value of the award and is recognized as expense over the vesting period. In connection with the use of the retroactive restatement method, income statement amounts have been restated for fiscal 2002 and 2003 to reflect results as if the fair-value method of SFAS 123 had been applied from its original effective date. Total compensation cost recognized in income for stock-based employee compensation awards was $3.78 billion in fiscal 2002, $3.75 billion in fiscal 2003, and $5.73 billion in fiscal 2004. The amounts for fiscal 2004 include $2.21 billion ($1.48 billion after-tax or $0.14 per diluted share) due to the completion of the employee stock option transfer program.

Employee Stock Purchase Plan. We have an employee stock purchase plan for all eligible employees. Under the plan, shares of our common stock could be purchased at six month intervals at 85% of the lower of the fair market value on the first or the last day of each six month period. Employees could purchase shares having a value not exceeding 15% of their gross compensation during an offering period. During fiscal 2002, 2003, and 2004 employees purchased 10.8 million shares, 15.2 million shares, and 16.7 million shares at average prices of $25.26, $22.56, and $22.74 per share. At June 30, 2004, 175.5 million shares were reserved for future issuance.

PAGE |  | 51

##### Table of Contents

Part II

Item 8

During the fourth quarter of fiscal 2004, the administrative committee under the plan approved a change to the common stock purchase discount and approved the elimination of the related look back period and a change to quarterly purchase periods. As a result, effective beginning in fiscal 2005, shares of our common stock may be purchased by employees at three months intervals at 90% of the fair market value on the last day of each three month period.

Savings Plan. We have a savings plan in the United States, that qualifies under Section 401(k) of the Internal Revenue Code, as well as a number of savings plans in international locations. Participating U.S. employees may contribute up to 25% of their pretax salary, but not more than statutory limits. We contribute fifty cents for each dollar a participant contributes in this plan, with a maximum contribution of 3% of a participant’s earnings. Matching contributions for all plans were $101 million, $118 million, and $141 million in fiscal 2002, 2003, and 2004. Matching contributions are invested proportionate to each participant’s voluntary contributions in the investment options provided under the plan. Investment options in the U.S. plan include Microsoft common stock, but neither participant nor our matching contributions are required to be invested in Microsoft common stock.

Stock Plans. In fiscal 2004 we implemented changes in employee compensation designed to help us continue to attract and retain the best employees, and to better align employee interests with those of our shareholders.

In fiscal 2004, we began granting employees stock awards instead of stock options. The stock award program offers employees the opportunity to earn shares of our stock over time, rather than options that give employees the right to purchase stock at a set price. We also completed an employee stock option transfer program in the second quarter of fiscal 2004 whereby employees could elect to transfer all of their vested and unvested stock options with a strike price of $33 or higher (“eligible options”) to JPMorgan. The unvested eligible options that were transferred to JPMorgan became vested upon the transfer. The price paid by JPMorgan for the transferred options was determined by reference to the arithmetic average of the closing prices of Microsoft common stock during the period from November 14, 2003 to December 8, 2003, which was $25.57.

A total of 18,503 (51%) of the 36,539 eligible employees elected to participate in the stock option transfer program and 344.6 million (55%) of the 621.4 million eligible options were tendered. Under the terms of the program, JPMorgan paid us $382 million for the transferred options. We made an initial payment of $219 million to participating employees for the transferred options, with a remaining portion to be paid in one or more payments that are subject to participating employees’ continued employment over the next two or three years. The options that were transferred to JPMorgan resulted in stock-based compensation expense of $2.21 billion ($1.48 billion after-tax or $0.14 per diluted share) which is reflected in the results of fiscal 2004. This expense consists of the unrecognized compensation costs of the options that were transferred, less the amounts payable applicable to those previously unvested options for which payment is contingent upon continued employment of participating employees. The contingent payments applicable to unvested eligible options that are subject to continued employment of participating employees will be recognized as compensation expense over the vesting period of the contingent payments.

The stock option transfer program also resulted in a decrease to our long-term deferred tax assets due to the excess of recorded compensation expense for these options over the related tax deduction reported on our tax return. For fiscal 2004, deferred tax assets were reduced by approximately $2.01 billion with an offsetting reduction in paid-in capital, reflecting the reduction of previously recorded deductions reported on our tax return in excess of stock based compensation expense. A description of our stock plans follows.

We have stock plans for directors and for officers, employees, consultants and advisors. The plans provide for awards of stock options and stock awards. At June 30, 2004, an aggregate of 807 million shares were available for future grant under our stock plans. Our plans under which awards may be issued do not contain separate limitations on the number of stock awards; all 807 million shares remaining available for grant at June 30, 2004 could be awarded as stock awards. In addition, awards that expire or are cancelled without delivery of shares generally become available for issuance under the plans. The options transferred to JPMorgan have been removed from our plans; any options transferred to JPMorgan that expire without being exercised will not become available for grant under any of our plans.

Stock Awards and Shared Performance Stock Awards. Stock awards are grants that entitle the holder to shares of common stock as the award vests. During fiscal 2004, 32.6 million stock awards with a weighted-average fair value of $26.12 per share were granted and generally vest ratably over a five-year period. Approximately 787,000 stock awards vested and 1.1 million stock awards were cancelled during fiscal 2004.

PAGE |  | 52

##### Table of Contents

Part II

Item 8

Shared Performance Stock Awards are a form of stock award in which the number of shares ultimately received depends on our performance against specified performance targets. The performance period is July 1, 2003 through June 30, 2006 (January 1, 2004 through June 30, 2006 for certain executive officers). At the end of the performance period, the number of shares of stock and stock awards issued will be determined by adjusting upward or downward from the target in a range between 33% and 150% (0% to 150% for certain executive officers). The final performance percentage on which the payout will be based, considering performance metrics established for the performance period, will be determined by the board of directors or a committee of the board in its sole discretion. Shares of stock will be issued at the end of the performance period and as the stock awards vest ratably over the following two years. In fiscal 2004, Shared Performance Stock Awards representing the targeted number of shares for the performance period ending June 30, 2006 were granted in the aggregate amount of 31.7 million shares with a weighted average fair value of $26.08 per share. Because these awards cover a three-year period, Shared Performance Stock Awards will only be awarded in fiscal 2005 and 2006 to newly hired and promoted employees eligible to receive Shared Performance Stock Awards. No shared performance stock awards vested and 1.2 million shared performance stock awards were cancelled during fiscal 2004.

Stock Awards and Shared Performance Stock Awards are amortized over 5 years using the straight line method.

Stock Options. Nonqualified stock options have been granted to our directors under our non-employee director stock plans. Nonqualified and incentive stock options have been granted to our officers and employees under our employee stock plans. Options granted before 1995 generally vest over four and one-half years and expire ten years from the date of grant. Options granted between 1995 and 2001 generally vest over four and one-half years and expire seven years from the date of grant, while certain options vest either over four and one-half years or over seven and one-half years and expire ten years from the date of grant. Options granted after 2001 vest over four and one-half years and expire ten years from the date of grant. At June 30, 2004, stock options for 569 million shares were vested.

The weighted average Black-Scholes value of options granted under the stock plans during fiscal 2002, 2003, and 2004 was $15.79, $12.08, and $10.13, respectively. The fair value of each option grant is estimated on the date of grant using the Black-Scholes option-pricing model with the following weighted average assumptions used for grants:

Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Weighted average expected life in years |  |  | 7 |  |  |  | 7 |  |  |  | 7 |
Dividend per share |  | $ | – |  |  | $ | 0.08 |  |  | $ | 0.16 |
Volatility |  |  | 39.0 | % |  |  | 42.0 | % |  |  | 29.5 | %
Risk-free interest rate |  |  | 5.4 | % |  |  | 3.9 | % |  |  | 4.1 | %

Employee stock options outstanding are as follows:

(In millions, except per share amounts) |  |  |  |  |  |  |
|  |  |  |  | Price per Share
|  | Shares |  |  | Range |  | Weighted average
Balance, June 30, 2001 |  | 1,796 |  |  | $ | 0.28 – $59.57 |  | $ | 24.77
Granted |  | 82 |  |  |  | 24.31 – 36.29 |  |  | 31.25
Exercised |  | (198 | ) |  |  | 0.51 – 34.91 |  |  | 6.41
Canceled |  | (76 | ) |  |  | 0.58 – 58.28 |  |  | 34.34
Balance, June 30, 2002 |  | 1,604 |  |  |  | 0.40 – 59.57 |  |  | 26.88
Granted |  | 254 |  |  |  | 21.42 – 29.12 |  |  | 24.27
Exercised |  | (234 | ) |  |  | 0.51 – 28.22 |  |  | 6.89
Canceled |  | (75 | ) |  |  | 2.13 – 59.56 |  |  | 34.33
Balance, June 30, 2003 |  | 1,549 |  |  |  | 0.40 – 59.56 |  |  | 29.30
Granted |  | 2 |  |  |  | 25.46 – 29.96 |  |  | 26.76
Exercised |  | (198 | ) |  |  | 0.51 – 29.38 |  |  | 12.21
Stock Option Transfer Program |  | (345 | ) |  |  | 33.03 – 59.56 |  |  | 38.70
Canceled |  | (59 | ) |  |  | 2.31 – 58.28 |  |  | 31.29
Balance, June 30, 2004 |  | 949 |  |  |  | 0.40 – 59.56 |  |  | 29.26

PAGE |  | 53

##### Table of Contents

Part II

Item 8

For various price ranges, weighted average characteristics of outstanding employee stock options at June 30, 2004 are as follows:

(In millions, except per share amounts and years) |  |  |  |
|  |  |  | Outstanding options |  | Exercisable options
Range of exercise prices |  | Shares |  | Remaining life (years) |  | Weighted average price |  | Shares |  | Weighted average price
$ 0.00 – $15.00 |  | 37 |  | 1.82 |  | $ | 6.60 |  | 36 |  | $ | 6.53
15.01 – 25.00 |  | 244 |  | 7.24 |  | $ | 23.33 |  | 75 |  | $ | 21.78
25.01 – 33.00 |  | 387 |  | 5.62 |  | $ | 28.24 |  | 237 |  | $ | 28.17
33.01 – 41.00 |  | 169 |  | 4.17 |  | $ | 34.22 |  | 127 |  | $ | 34.25
41.01 – 59.56 |  | 112 |  | 4.40 |  | $ | 44.80 |  | 94 |  | $ | 44.66
|  | 949 |  |  |  |  |  |  | 569 |  |  |

As of June 30, 2004, 345 million transferred options to JP Morgan remained outstanding and are excluded from the amounts noted as employee options outstanding in the tables above. See Note 11. In addition, the tables above include in the total options outstanding 6.8 million options outstanding that were granted in conjunction with corporate acquisitions. These options are included in the option totals; however, they are excluded from the exercise price ranges presented. These options had an exercise price range of $0.00 to $204.09 and a weighted average exercise price of $14.13.

NOTE 14 EARNINGS PER SHARE

Basic earnings per share is computed on the basis of the weighted average number of shares of common stock outstanding during the period. Diluted earnings per share is computed on the basis of the weighted average number of shares of common stock plus the effect of dilutive potential common shares outstanding during the period using the treasury stock method. Dilutive potential common shares include outstanding stock options, stock awards, and shared performance stock awards. The components of basic and diluted earnings per share are as follows:

(In millions, except earnings per share) |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  | 2003 |  | 2004
Net income available for common shareholders (A) |  | $ | 5,355 |  | $ | 7,531 |  | $ | 8,168
Weighted average outstanding shares of common stock (B) |  |  | 10,811 |  |  | 10,723 |  |  | 10,803
Dilutive effect of employee stock options and awards |  |  | 295 |  |  | 159 |  |  | 91
Common stock and common stock equivalents (C) |  |  | 11,106 |  |  | 10,882 |  |  | 10,894
Earnings per share: |  |  |  |  |  |  |  |  |
Basic (A/B) |  | $ | 0.50 |  | $ | 0.70 |  | $ | 0.76
Diluted (A/C) |  | $ | 0.48 |  | $ | 0.69 |  | $ | 0.75

For the years ended June 30, 2002, 2003 and 2004, 746 million, 1.09 billion and 1.2 billion shares attributable to outstanding stock options were excluded from the calculation of diluted earnings per share because the exercise prices of the stock options were greater than or equal to the average price of the common shares, and therefore their inclusion would have been anti-dilutive. For the year ended June 30, 2004, 21.9 million shared performance stock awards, out of 31.7 million targeted amount granted, have been excluded from the calculation of diluted earnings per share because the number of shares ultimately issued is contingent on our performance against metrics established for the performance period, as discussed in Note 13 – Employee Stock and Savings Plans.

PAGE |  | 54

##### Table of Contents

Part II

Item 8

NOTE 15 ACQUISITIONS

In fiscal 2004, we had no material acquisitions. In fiscal 2003, we acquired all of the outstanding equity interests of Navision a/s, Rare Ltd., and Placeware, Inc. Navision, headquartered in Vedbaek, Denmark, is a provider of integrated business solutions software for small and mid-sized businesses in the European market that is part of the Microsoft Business Solutions segment. We acquired Navision on July 12, 2002 for $1.465 billion consisting primarily of $662 million in cash and the issuance of 29.1 million common shares of our common stock valued at $773 million. The value of the common shares issued was determined based on the average market price of our common shares over the two-day period before and after terms of the acquisition were agreed to and approved. Rare is a video game developer located outside Leicestershire, England, that has broaden the portfolio of games available for the Xbox video game system. Rare was acquired on September 24, 2002 for $377 million consisting primarily of $375 million in cash and is included in the Home and Entertainment segment. Placeware, located in Mountain View, California, facilitates secure, highly reliable, cross-firewall Web conferencing experiences allowing users to conduct business meetings online from a PC, and is part of our Real Time Collaboration business unit in the Information Worker segment. Placeware was acquired on April 30, 2003 for $202 million, consisting primarily of $189 million in cash. Navision, Rare, and Placeware have been consolidated into our financial statements since their respective acquisition dates. None of the acquisitions, individually or in the aggregate, are material to our consolidated results of operations. Accordingly, pro forma financial information is not included in this note.

The estimated fair values of the assets acquired and liabilities assumed at the date of the acquisitions for fiscal 2003 are as follows:

(In millions) |  |  |  |  |  |  |  |  |
|  | Navision a/s at July 12, 2002 |  |  | Rare Ltd. at September 24, 2002 |  |  | Placeware, Inc. at April 30, 2003 |
Current assets |  | $ | 240 |  |  | $ | 25 |  |  | $ | 30 |
Property, plant and equipment |  |  | 8 |  |  |  | 8 |  |  |  | 7 |
Intangible assets |  |  | 169 |  |  |  | 75 |  |  |  | 30 |
Goodwill |  |  | 1,197 |  |  |  | 281 |  |  |  | 180 |
Total assets acquired |  |  | 1,614 |  |  |  | 389 |  |  |  | 247 |
Current liabilities |  |  | (148 | ) |  |  | (12 | ) |  |  | (32 | )
Long-term liabilities |  |  | (1 | ) |  |  | – |  |  |  | (13 | )
Total liabilities assumed |  |  | (149 | ) |  |  | (12 | ) |  |  | (45 | )
Net assets acquired |  | $ | 1,465 |  |  | $ | 377 |  |  | $ | 202 |

The $1.20 billion of goodwill resulting from the Navision acquisition was assigned to the Microsoft Business Solutions segment. Of that total amount, approximately $900 million is expected to be deductible for tax purposes. The $281 million of goodwill in the Rare acquisition was assigned to the Home and Entertainment segment. Of that total amount, approximately $270 million is expected to be deductible for tax purposes. The $180 million of goodwill in the Placeware acquisition was assigned to the Information Worker segment. None of the goodwill is expected to be deductible for tax purposes.

The components of intangible assets acquired in the acquisitions above are as follows (no significant residual value is estimated for these assets):

(In millions) |  |  |  |  |  |  |  |  |  |  |  |  |  |
|  | Navision a/s |  |  | Weighted average life |  | Rare Ltd. |  |  | Weighted average life |  | Placeware, Inc. |  | Weighted average life
Contract-based |  | $ | 115 |  |  | 6 years |  | $ | 16 |  |  | 5 years |  | $ | 1 |  | 6 years
Technology-based |  |  | 48 |  |  | 4 years |  |  | 36 |  |  | 5 years |  |  | 4 |  | 4 years
Marketing-related |  |  | 4 |  |  | 3 years |  |  | 10 |  |  | 5 years |  |  | 2 |  | 1 year
Customer-related |  |  | – |  |  | – |  |  | – |  |  | – |  |  | 23 |  | 10 years
Research and Development |  |  | 2 | (1) |  | – |  |  | 13 | (1) |  | – |  |  | – |  | –
Total |  | $ | 169 |  |  | 5 years |  | $ | 75 |  |  | 5 years |  | $ | 30 |  | 8 years

(1) |  | Amounts assigned to research and development assets were written off in accordance with FIN 4. Those write-offs were included in Research and Development expenses.

PAGE |  | 55

##### Table of Contents

Part II

Item 8

NOTE 16 COMMITMENTS AND GUARANTEES

We have operating leases for most U.S. and international sales and support offices and certain equipment. Rental expense for operating leases was $318 million, $290 million, and $331 million in fiscal 2002, 2003, and 2004, respectively. Future minimum rental commitments under noncancellable leases, in millions of dollars, are as follows:

(In millions) |  |
Year Ended June 30 |  | Amount
2005 |  | $ | 148
2006 |  |  | 124
2007 |  |  | 81
2008 |  |  | 62
2009 and thereafter |  |  | 120
|  | $ | 535

We have committed $129 million for constructing new buildings.

We have unconditionally guaranteed the repayment of certain Japanese yen denominated bank loans and related interest and fees of Jupiter Telecommunication, Ltd., a Japanese cable company (Jupiter). These guarantees arose on February 1, 2003 in conjunction with the expiration of prior financing arrangements, including previous guarantees by us. The financing arrangements were entered into by Jupiter as part of financing its operations. As part of Jupiter’s new financing agreement, we agreed to guarantee repayment by Jupiter of the loans of approximately $51 million. The estimated fair value and the carrying value of the guarantees was $11 million which was added to the carrying value of the related investment. The guarantees are in effect until the earlier of repayment of the loans, including accrued interest and fees, or February 1, 2009. The maximum amount of the guarantees is limited to the sum of the total due and unpaid principal amounts, accrued and unpaid interest, and any other related expenses. Additionally, the maximum amount of the guarantees, denominated in Japanese yen, will vary based on fluctuations in foreign exchange rates. If we were required to make payments under the guarantees, we may recover all or a portion of those payments upon liquidation of the Jupiter’s assets. The proceeds from such liquidation cannot be accurately estimated due to the multitude of factors that would affect the valuation and realization of the proceeds in the event of liquidation.

In connection with various operating leases, we issued residual value guarantees, which provide that if we do not purchase the leased property from the lessor at the end of the lease term, then we are liable to the lessor for an amount equal to the shortage (if any) between the proceeds from the sale of the property and an agreed value. As of June 30, 2004, the maximum amount of the residual value guarantees was approximately $271 million. We believe that proceeds from the sale of properties under operating leases would exceed the payment obligation and therefore no liability to us currently exists.

We provide indemnifications of varying scope and size to certain customers against claims of intellectual property infringement made by third parties arising from the use of our products. In addition, we also provide indemnification against credit risk in several geographical locations to our volume license resellers in case the resellers fail to collect from the end user. Due to the nature of the indemnification provided to our resellers, we can not estimate the fair value, nor determine the total nominal amount of the indemnification. We evaluate estimated losses for such indemnifications under SFAS 5, Accounting for Contingencies, as interpreted by FIN 45. We consider such factors as the degree of probability of an unfavorable outcome and the ability to make a reasonable estimate of the amount of loss. To date, we have not encountered material costs as a result of such obligations and have not accrued any liabilities related to such indemnifications in our financial statements.

Our product warranty accrual reflects management’s best estimate of our probable liability under its product warranties (primarily relating to the Xbox console). We determine the warranty accrual based on known product failures (if any), historical experience, and other currently available evidence. Our warranty accrual totals $19 million. There has been no significant activity impacting the results of operations for any period presented.

PAGE |  | 56

##### Table of Contents

Part II

Item 8

NOTE 17 CONTINGENCIES

Government antitrust cases. We are the defendant in U.S. v. Microsoft and New York v. Microsoft, companion lawsuits filed by the Antitrust Division of the U.S. Department of Justice (DOJ) and a group of eighteen state Attorneys General alleging violations of the Sherman Act and various state antitrust laws. After the trial, the District Court entered Findings of Fact and Conclusions of Law stating that we had violated Sections 1 and 2 of the Sherman Act and various state antitrust laws. A Judgment was entered on June 7, 2000 ordering, among other things, our breakup into two companies. On June 28, 2001, the U.S. Court of Appeals for the District of Columbia Circuit affirmed in part, reversed in part, and vacated the Judgment in its entirety and remanded the case to the District Court for a new trial on one Section 1 claim and for entry of a new judgment consistent with its ruling. In its ruling, the Court of Appeals substantially narrowed the bases of liability found by the District Court, but affirmed some of the District Court’s conclusions that we had violated Section 2. We entered into a settlement with the United States on November 2, 2001. Nine states (New York, Ohio, Illinois, Kentucky, Louisiana, Maryland, Michigan, North Carolina and Wisconsin) agreed to settle on substantially the same terms on November 6, 2001. On November 1, 2002, the Court approved the settlement as being in the public interest, conditioned upon the parties’ agreement to a modification to one provision related to the Court’s ongoing jurisdiction. Two trade groups unsuccessfully sought to intervene to challenge the approval of the settlement and have appealed. Nine states and the District of Columbia continued to litigate the remedies phase of New York v. Microsoft. On November 1, 2002, the Court entered a Final Judgment in this part of the litigation that largely mirrored the settlement between us, the DOJ and the settling states, with some modifications and a different regime for enforcing compliance. The Court declined to impose other and broader remedies sought by the non-settling states. Two states, Massachusetts and West Virginia, appealed from this decision. West Virginia dismissed its appeal as part of a settlement with us of several other cases. On June 30, 2004, the U.S. Court of Appeals for the D.C. Circuit unanimously affirmed the settlement and the Final Judgment.

European Commission competition law matter. On March 25, 2004 the European Commission announced a decision in its competition law investigation of Microsoft. The Commission concluded that we infringed European competition law by refusing to provide our competitors with licenses to certain protocol technology in the Windows server operating systems and by including streaming media playback functionality in Windows desktop operating systems. The Commission ordered us to make the relevant licenses to our technology available to our competitors and to develop and make available a version of the Windows desktop operating system that does not include specified software relating to media playback. The decision also imposed a fine of €497 million, which resulted in a charge of €497 million ($605 million). We filed an appeal of the decision to the Court of First Instance on June 6, 2004 and will seek interim measures suspending the operation of certain provisions of the decision. We contest the conclusion that European competition law was infringed and will defend our position vigorously. A hearing on our petition for interim measures will be held on September 30 – October 1, 2004. In other ongoing investigations, various foreign governments and several state Attorneys General have requested information from us concerning competition, privacy, and security issues.

Antitrust, unfair competition and overcharge class actions. A large number of antitrust and unfair competition class action lawsuits have been filed against us in various state and federal courts. The federal cases have been consolidated in the U.S. District Court for Maryland. These cases allege that we have competed unfairly and unlawfully monopolized alleged markets for operating systems and certain software applications, and they seek to recover on behalf of variously defined classes of direct and indirect purchasers’ alleged overcharges for these products. To date, courts have dismissed all claims for damages brought against us by indirect purchasers under federal law and in 14 states. Nine of those state court decisions have been affirmed on appeal. Claims on behalf of foreign purchasers have also been dismissed by the federal court in Maryland. Appeals of these state rulings are pending in two states. Courts in eleven states have ruled that these cases may proceed as class actions, while courts in two states have denied class certification. The Maryland federal District Court has certified a class of direct purchasers of certain of our operating system software that acquired the software from the shop.Microsoft.com web site or pursuant to a direct marketing campaign and otherwise denied certification of the proposed classes. The denial of certification of the proposed classes has been appealed and that appeal is still pending. Members of the certified class licensed fewer than 550,000 copies of at-issue operating system software from us. In September 2003, we reached an agreement with plaintiffs’ counsel to settle that action, which received final approval in April 2004. In 2003, we reached an agreement with counsel for the California plaintiffs to settle all claims in 27 consolidated cases in that state. Under the proposed settlement, class members will be able to obtain vouchers on a

PAGE |  | 57

##### Table of Contents

Part II

Item 8

claims made basis that entitle the class members to be reimbursed up to the face value of their vouchers for purchases of a wide variety of platform-neutral computer hardware and software. The total amount of vouchers issued will depend on the number of class members who claim and are issued vouchers. Two-thirds of the amount of vouchers unissued or unredeemed by class members will be made available to certain schools in California in the form of vouchers that also may be redeemed for cash against purchases of a wide variety of platform-neutral computer hardware, software and related services. Since the beginning of 2003, we also reached similar agreements to settle all claims in a number of other states. The proposed settlements in these states are structured similarly to the California settlement, except that, among other differences, one-half of the amounts of vouchers unissued to class members will be made available to certain schools in the relevant states. The maximum amount of vouchers to be issued in these settlements, including the California settlement, is $1.55 billion. The actual costs of these settlements will be less than that maximum amount, depending on the number of class members and schools who are issued and redeem vouchers. The settlements in California, Florida, Kansas, Montana, North Carolina, North Dakota, South Dakota, Tennessee and West Virginia have received final approval by the relevant court. The proposed settlements in Arizona, the District of Columbia, Massachusetts, Minnesota, New Mexico and Vermont have received preliminary approval by the courts in those states, but still require final approval. We estimate the total cost to resolve all of these cases will range between $1.1 billion and $1.2 billion with the actual cost dependent upon many unknown factors such as the quantity and mix of products for which claims will be made, the number of eligible class members who ultimately use the vouchers, the nature of hardware and software that is acquired using the vouchers, and the cost of administering the claims process. In accordance with SFAS 5, Accounting for Contingencies, and FIN 14, Reasonable Estimation of the Amount of a Loss, we have recorded a contingent liability of $1.04 billion, net of administrative expenses and legal fees paid.

RealNetworks litigation. On December 18, 2003, RealNetworks, Inc. filed suit against us alleging violations of federal and state antitrust and unfair competition laws, related to streaming media features of Windows and related technologies. RealNetworks seeks damages and injunctive relief, including a permanent injunction requiring us to offer a version of Windows products with no streaming media features. We deny the allegations and will vigorously defend the action. RealNetworks filed the case in federal court in San Jose, California. It has been consolidated for pretrial purposes with other cases pending in the U.S. District Court in Baltimore.

Patent cases. We are the defendant in more than 30 patent infringement cases that we are defending vigorously. In the case of Eolas Technologies, Inc. and University of California v. Microsoft, filed in the U.S. District Court for the Northern District of Illinois on February 2, 1999, the plaintiffs accused the browser functionality of Windows of infringement. On August 11, 2003, the jury awarded the plaintiffs approximately $520 million in damages for infringement from the date the plaintiffs’ patent issued through September 2001. The plaintiffs are seeking an equitable accounting for damages from September 2001 to the present. On January 14, 2004, the trial court entered final judgment of $565 million, including post-trial interest of $45 million, and entered an injunction against distribution of any new products, but stayed execution of the judgment and the injunction pending our appeal. We filed our notice of appeal on February 12, 2004. On October 30, 2003, the U.S. Patent Office issued a letter stating that it has initiated a Director-ordered re-examination of the Eolas patent. On February 26, 2004, pursuant to this re-examination proceeding, the Patent Office issued an Office Action rejecting the claims of the Eolas patent. We believe the total cost to resolve this case will not be material to our financial position or results of operations. The actual costs are dependent upon many unknown factors such as success on appeal and the events of a retrial of the case should the case be remanded to trial following appeal. In Research Corporation Technologies, Inc. v. Microsoft, filed in U.S. District Court for the District of Arizona, plaintiff has asserted a family of six patents relating to halftoning which it believes are infringed by certain printing and display functionality allegedly present in different versions of Windows and Office. Plaintiff seeks an as yet unspecified amount of damages in the form of “reasonable royalties” on various Microsoft products dating as far back as Windows and Office 2000. The case is scheduled for trial in April of 2005. In TVI v. Microsoft, filed in U.S. District Court for the Northern District of California, plaintiff accuses the Autoplay feature of Windows of infringement. This case is scheduled for trial in September 2004. In Arendi USA, Inc. and Arendi Holding Limited v. Microsoft, filed in U.S. District Court for the District of Rhode Island, plaintiff has accused certain Smart Tags features in Microsoft Office XP and Office 2003 of infringing one patent. Trial is scheduled for September, 2004. Adverse outcomes in some or all of the pending cases may result in significant monetary damages or injunctive relief against us adversely affecting distribution of our operating system or application products. The risks associated with an adverse decision may result in material settlements.

PAGE |  | 58

##### Table of Contents

Part II

Item 8

Sun Microsystems agreements. On April 1, 2004, we entered into a series of agreements with Sun Microsystems, Inc. to resolve all pending litigation between the parties, attempt to avoid future disputes, and create an environment conducive to future cooperation. These agreements included a Settlement Agreement, a Patent Covenant and Standstill Agreement, and a Technology Collaboration Agreement. Pursuant to the agreements, we made payments totaling $1.95 billion to Sun.

In the Settlement Agreement, Sun agreed to discontinue its participation in proceedings pending against Microsoft instituted by the Commission of the European Communities and agreed to dismiss with prejudice the action it filed in the Northern District of California, Sun Microsystems, Inc. v. Microsoft Corp., Civil Action No. C-02-01150 RMW (PVT) (N.D. Cal.), and later transferred to the United States District Court for the District of Maryland under MDL Docket No. 1332. Sun released Microsoft from any claims that were or could have been asserted in the proceedings pending before the European Communities, its action pending in the U.S., and any claims based on any actions or events discussed in the Findings of Fact in United States v. Microsoft Corp. and New York, et al. v Microsoft Corp., 84 F. Supp. 2d 9 (D.D.C. 2002). Pursuant to the terms of the Settlement Agreement, Microsoft paid Sun $700 million, which was recorded as litigation related expense.

The Patent Covenant and Standstill Agreement provides that neither Sun nor Microsoft will sue the other, or certain authorized channel and end user licensees, for damages for past patent infringement. Microsoft has the option of extending this covenant not to sue each year until 2014 in exchange for an annual extension payment, so long as certain conditions are met. The agreement provides that on April 1, 2014, provided that certain conditions are met, the companies will grant each other irrevocable, non-exclusive, perpetual patent licenses, with some reciprocal limitations as to scope and use, as well as an additional ten year covenant not to sue for patent infringement with respect to certain products. Pursuant to the terms of this Agreement, Microsoft paid Sun $900 million, which was recorded as litigation related expense.

Sun and Microsoft also entered into a reciprocal Technology Collaboration Agreement. This collaboration agreement provides both companies with access to aspects of each other’s server-based technology for use in developing new server software products and/or enhancing existing server software products, in order to improve interoperability. It provides a perpetual license between Microsoft and Sun pursuant to all subject intellectual property rights (including patents and trade secrets) to enable either company to implement in its server operating system products any server-based communications protocols that are implemented over a seven year period by the other company in order to interoperate with their respectively identified server and/or client operating system products. Royalty obligations incurred by Microsoft for use or inclusion of covered Sun technology in Microsoft products will, as incurred, be credited against the $350 million already paid pursuant to the terms of the Technology Collaboration Agreement, based on royalty rates to be determined in the future by Sun. This license removes concerns under traditional patent and trade secret intellectual property frameworks by enabling Microsoft’s current and future client and server operating system products to interoperate with the most popular Sun products in a wide range of customer computing environments.

The extent and timing of Microsoft’s consumption of this credit is subject to uncertainty. Much of the technology that the companies agreed to license to each other does not exist in a useable form and the agreement does not specify individual royalty payments for implementation of specifications for particular communications protocols. After reaching this agreement with Sun, we valued the intellectual property rights received. In determining the fair value of the intellectual property received, we considered the uncertainty associated with the timing and likely use of Sun’s technology, which included estimating the likelihood of adoption of protocols and potential royalties saved. That valuation resulted in a fair value of $29 million for the right to use Sun’s licensed protocols in certain products, which we recorded as an intellectual property asset. Reflecting the uncertainty associated with the timing and likely use of Sun’s technology, the remaining amount of $321 million was recorded as litigation related expense.

Intertrust settlement. On April 3, 2004, the previously reported case of InterTrust v. Microsoft was settled by agreement of the parties. Under the terms of this agreement, we have taken a comprehensive license to InterTrust’s patent portfolio, including pending patent applications, and agreed to make a one-time payment to InterTrust of $440 million. The agreement involved a combination of a license of intellectual property assets for which we recorded an intangible asset of $266 million and a payment of $174 million for settlement of legal claims. Of the total payment, $174 million was recovered through insurance and had no impact on our results of operations. The agreement resolves all outstanding litigation between the parties.

Other. We are also subject to a variety of other claims and suits that arise from time to time in the ordinary course of our business. While management currently believes that resolving all of these matters, individually or in aggregate, will not have a material adverse impact on our financial position or our results of operations, the litigation and other claims noted above are subject to inherent uncertainties and management’s view of these matters may

PAGE |  | 59

##### Table of Contents

Part II

Item 8

change in the future. Were an unfavorable final outcome to occur, there exists the possibility of a material adverse impact on our financial position and the results of operations for the period in which the effect becomes reasonably estimable.

NOTE 18 SEGMENT INFORMATION

Segment revenue and operating income/(loss) is as follows: (1)

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Revenue |  |  |  |  |  |  |  |  |  |  |  |
Client |  | $ | 9,350 |  |  | $ | 10,287 |  |  | $ | 11,241 |
Server and Tools |  |  | 5,632 |  |  |  | 6,692 |  |  |  | 7,881 |
Information Worker |  |  | 8,328 |  |  |  | 9,695 |  |  |  | 10,924 |
Microsoft Business Solutions |  |  | 308 |  |  |  | 577 |  |  |  | 660 |
MSN |  |  | 1,924 |  |  |  | 2,396 |  |  |  | 2,444 |
Mobile and Embedded Devices |  |  | 124 |  |  |  | 153 |  |  |  | 239 |
Home and Entertainment |  |  | 2,411 |  |  |  | 2,779 |  |  |  | 2,870 |
Reconciling amounts |  |  | 288 |  |  |  | (392 | ) |  |  | 576 |
Consolidated |  | $ | 28,365 |  |  | $ | 32,187 |  |  | $ | 36,835 |
Operating Income/(Loss) |  |  |  |  |  |  |  |  |  |  |  |
Client |  | $ | 7,529 |  |  | $ | 8,362 |  |  | $ | 9,005 |
Server and Tools |  |  | 1,409 |  |  |  | 1,841 |  |  |  | 2,173 |
Information Worker |  |  | 6,440 |  |  |  | 7,495 |  |  |  | 8,067 |
Microsoft Business Solutions |  |  | (196 | ) |  |  | (202 | ) |  |  | (180 | )
MSN |  |  | (746 | ) |  |  | (378 | ) |  |  | 397 |
Mobile and Embedded Devices |  |  | (240 | ) |  |  | (162 | ) |  |  | (102 | )
Home and Entertainment |  |  | (866 | ) |  |  | (938 | ) |  |  | (894 | )
Reconciling amounts |  |  | (5,058 | ) |  |  | (6,473 | ) |  |  | (9,432 | )
Consolidated |  | $ | 8,272 |  |  | $ | 9,545 |  |  | $ | 9,034 |

(1) |  | Fiscal 2002 and 2003 information has been restated to reflect the retroactive adoption of the fair value recognition provisions of SFAS 123, Accounting for Stock-Based Compensation, as discussed in Note 13. In addition, fiscal 2003 information has been restated for certain internal reorganizations and changes to certain internal accounting methods to conform to the current period presentation. It was not practicable to restate fiscal 2002 information for these changes, nor was it practicable to present the current year on a basis consistent with fiscal 2002.

SFAS 131, Disclosures about Segments of an Enterprise and Related Information, establishes standards for reporting information about operating segments. This standard requires segmentation based on our internal organization and reporting of revenue and operating income based upon internal accounting methods. Our financial reporting systems present various data for management to run the business, including internal profit and loss statements prepared on a basis not consistent with U.S. GAAP. The segments are designed to allocate resources internally and provide a framework to determine management responsibility. Operating segments are defined as components of an enterprise about which separate financial information is available that is evaluated regularly by the chief operating decision maker, or decision making group, in deciding how to allocate resources and in assessing performance. Our chief operating decision maker is our Chief Executive Officer. The types of products and services provided by each segment are summarized below:

Client – Windows XP Professional and Home, Windows 2000 Professional, and other standard Windows operating systems.

PAGE |  | 60

##### Table of Contents

Part II

Item 8

Server and Tools – Server software licenses and client access licenses (CALs) for Windows Server, SQL Server, Exchange Server, and other servers. Also includes developer tools, training, certification, Microsoft Press, Premier product support services, and Microsoft consulting services.

Information Worker – Microsoft Office, Microsoft Project, Microsoft Visio, SharePoint Portal Server CALs, other information worker products including Microsoft LiveMeeting and OneNote, an allocation for Server CALs, and professional product support services.

Microsoft Business Solutions – Microsoft Great Plains, Microsoft Navision, Microsoft Axapta, Microsoft Solomon, Microsoft CRM, MBN/Retail Manager and other business applications and services.

MSN – Personal communication services, such as e-mail and instant messaging, information services, such as MSN Search and the MSN portals and channels, and paid services including MSN Internet access, MSN Premium Web services, and MSN Mobile service.

Mobile and Embedded Devices – Windows Mobile software, Windows Embedded device operating systems, MapPoint, and Windows Automotive.

Home and Entertainment – Xbox video game system, PC games, the Home Products Division (HPD), and TV platform products.

Because of our integrated business structure, operating costs included in one segment may benefit other segments, and therefore these segments are not designed to measure operating income or loss directly related to the products included in each segment. Inter-segment cost commissions are estimated by management and used to compensate or charge each segment for such shared costs and to incent shared efforts. Management will continually evaluate the alignment of product development organizations, sales organizations, and inter-segment commissions for segment reporting purposes, which may result in changes to segment allocations in future periods.

Assets are not allocated to segments for internal reporting presentations. A portion of amortization and depreciation is included with various other costs in an overhead allocation to each segment and it is impracticable for us to separately identify the amount of amortization and depreciation by segment that is included in the measure of segment profit or loss.

Reconciling amounts include adjustments to conform with U.S. GAAP and corporate level activity not specifically attributed to a segment. Significant internal accounting policies that differ from U.S. GAAP relate to revenue recognition, income statement classification, quarter end cut off timing, and accelerated amortization for depreciation, stock awards and performance-based stock awards. In addition, certain revenue and expenses are excluded from segments or included in corporate level activity including certain legal settlements and legal contingent liabilities.

Significant reconciling items are as follows:

(In millions) |  |  |  |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  |  | 2003 |  |  | 2004 |
Operating income reconciling amounts: |  |  |  |  |  |  |  |  |  |  |  |
Legal settlements and contingent liabilities |  |  | (673 | ) |  |  | (1,079 | ) |  |  | (2,778 | )
Stock-based compensation expense |  |  | (3,784 | ) |  |  | (3,749 | ) |  |  | (4,773 | )
Revenue reconciling amounts |  |  | 288 |  |  |  | (392 | ) |  |  | 576 |
Other |  |  | (889 | ) |  |  | (1,253 | ) |  |  | (2,457 | )
Total |  | $ | (5,058 | ) |  | $ | (6,473 | ) |  | $ | (9,432 | )

Other primarily includes corporate operations related to sales and marketing, product support services, human resources, legal, finance, IT, corporate development and procurement activities; research and development; and various amounts to conform with U.S. GAAP.

PAGE |  | 61

##### Table of Contents

Part II

Item 8

Sales to Dell and its subsidiaries in the aggregate accounted for approximately 10% of total fiscal 2004 revenue. These sales were made primarily through our OEM and volume licensing channels and were included in all operating segments. No single customer accounted for more than 10% of revenue in 2002 or 2003.

Revenue, classified by the major geographic areas in which we operate, is as follows:

(In millions) |  |  |  |  |  |
Year Ended June 30 |  | 2002 |  | 2003 |  | 2004
United States(1) |  | $ | 20,066 |  | $ | 22,077 |  | $ | 25,046
Other countries |  |  | 8,299 |  |  | 10,110 |  |  | 11,789
Total |  | $ | 28,365 |  | $ | 32,187 |  | $ | 36,835

(1) |  | Includes shipments to customers in the United States, licensing to certain OEMs and multinational organizations, and exports of finished goods, primarily to Asia, Latin America, and Canada.

Long-lived assets, classified by the geographic location of the controlling statutory company in which that company operates, are as follows:

(In millions) |  |  |  |
Year Ended June 30 |  | 2003 |  | 2004
United States |  | $ | 3,773 |  | $ | 5,365
Other countries |  |  | 1,962 |  |  | 645
Total |  | $ | 5,735 |  | $ | 6,010

NOTE 19 SUBSEQUENT EVENT

On July 20, 2004, our board of directors approved a quarterly dividend of $0.08 per share payable on September 14, 2004, to shareholders of record on August 25, 2004. In addition, the board approved a plan to buy back up to $30 billion in Microsoft common stock over the next four years. The specific timing and amount of repurchases will vary based on market conditions, securities law limitations, and other factors. The repurchases will be made using our cash resources. The repurchase program may be suspended or discontinued at any time without prior notice. The board also approved a one-time special dividend of $3.00 per share, or approximately $32 billion, subject to shareholder approval of stock plan amendments that will allow certain adjustments to employee equity compensation awards to offset the impact of the special dividend. The special dividend will be payable on December 2, 2004, to shareholders of record on November 17, 2004, conditioned upon shareholder approval of amendments to the employee stock plans at the annual meeting of shareholders scheduled to be held November 9, 2004.

PAGE |  | 62

##### Table of Contents

Part II

Item 8

QUARTERLY INFORMATION

(In millions, except per share amounts) (Unaudited) |  |  |  |  |  |  |  |  |  |  |  |  |
Quarter Ended |  | Sep. 30 |  | Dec. 31 |  |  | Mar. 31 |  |  | June 30 |  |  | Total
Fiscal 2003 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Revenue |  | $ | 7,746 |  | $ | 8,541 |  |  | $ | `7,835 |  |  | $ | 8,065 |  |  | $ | 32,187
Gross profit |  |  | 6,402 |  |  | 6,404 |  |  |  | 6,561 |  |  |  | 6,761 |  |  |  | 26,128
Net income |  |  | 2,041 |  |  | 1,865 |  |  |  | 2,142 |  |  |  | 1,483 | (1) |  |  | 7,531
Basic earnings per share |  |  | 0.19 |  |  | 0.17 |  |  |  | 0.20 |  |  |  | 0.14 |  |  |  | 0.70
Diluted earnings per share |  |  | 0.19 |  |  | 0.17 |  |  |  | 0.20 |  |  |  | 0.14 |  |  |  | 0.69
Fiscal 2004 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
Revenue |  | $ | 8,215 |  | $ | 10,153 |  |  | $ | 9,175 |  |  | $ | 9,292 |  |  | $ | 36,835
Gross profit |  |  | 6,735 |  |  | 7,809 |  |  |  | 7,764 |  |  |  | 7,811 |  |  |  | 30,119
Net income |  |  | 2,614 |  |  | 1,549 | (2) |  |  | 1,315 | (3) |  |  | 2,690 |  |  |  | 8,168
Basic earnings per share |  |  | 0.24 |  |  | 0.14 |  |  |  | 0.12 |  |  |  | 0.25 |  |  |  | 0.76
Diluted earnings per share |  |  | 0.24 |  |  | 0.14 |  |  |  | 0.12 |  |  |  | 0.25 |  |  |  | 0.75

(1) |  | Includes charges of $750 million (pre-tax) related to the Time Warner settlement and $1.15 billion in impairments of investments.

(2) |  | Includes stock-based compensation charges of $2.2 billion for the employee stock option transfer program.

(3) |  | Includes charges of $2.53 billion (pre-tax) related to the Sun Microsystems Inc. settlement and a fine imposed by the European Commission.

PAGE |  | 63

##### Table of Contents

Part II

Item 8

REPORT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM

To the Board of Directors and Stockholders of Microsoft Corporation:

We have audited the accompanying consolidated balance sheets of Microsoft Corporation and subsidiaries as of June 30, 2003 and 2004, and the related consolidated statements of income, cash flows, and stockholders’ equity for each of the three years in the period ended June 30, 2004. These financial statements are the responsibility of the Corporation’s management. Our responsibility is to express an opinion on these financial statements based on our audits.

We conducted our audits in accordance with standards of the Public Company Accounting Oversight Board (United States). Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement. An audit includes examining, on a test basis, evidence supporting the amounts and disclosures in the financial statements. An audit also includes assessing the accounting principles used and significant estimates made by management, as well as evaluating the overall financial statement presentation. We believe that our audits provide a reasonable basis for our opinion.

In our opinion, such consolidated financial statements present fairly, in all material respects, the financial position of Microsoft Corporation and subsidiaries as of June 30, 2003 and 2004, and the results of their operations and their cash flows for each of the three years in the period ended June 30, 2004 in conformity with accounting principles generally accepted in the United States of America.

As described in Note 13 to the financial statements, the Company retroactively adopted Statement of Financial Accounting Standards No. 123, Accounting for Stock-Based Compensation, effective July 1, 2003.

/s/ DELOITTE & TOUCHE LLP

Deloitte & Touche LLP

Seattle, Washington

August 24, 2004

PAGE |  | 64

##### Table of Contents

Part II

Item 9, 9A, 9B

ITEM 9. CHANGES IN AND DISAGREEMENTS WITH ACCOUNTANTS

ON ACCOUNTING AND FINANCIAL DISCLOSURE

None.

ITEM 9A. CONTROLS AND PROCEDURES

Under the supervision and with the participation of our management, including the Chief Executive Officer and Chief Financial Officer, we have evaluated the effectiveness of our disclosure controls and procedures pursuant to Exchange Act Rule 13a-15(b) as of the end of the period covered by this report. Based on that evaluation, the Chief Executive Officer and Chief Financial Officer have concluded that these disclosure controls and procedures are effective. There were no changes in our internal control over financial reporting during the quarter ended June 30, 2004 that have materially affected, or are reasonably likely to materially affect, our internal control over financial reporting.

ITEM 9B. OTHER INFORMATION

None.

PAGE |  | 65

##### Table of Contents

Part III

Item 10, 11, 12, 13, 14, 15

PART III

ITEM 10. DIRECTORS AND EXECUTIVE OFFICERS OF THE REGISTRANT

Information about our Directors may be found under the caption “Election of Directors and Management Information” of our Proxy Statement for the Annual Meeting of Shareholders to be held November 9, 2004 (the “Proxy Statement”). That information is incorporated herein by reference.

The information in the Proxy Statement set forth under the caption “Section 16(a) Beneficial Ownership Reporting Compliance” is incorporated herein by reference.

We have adopted the Microsoft Finance Code of Professional Conduct (the “finance code of ethics”), a code of ethics that applies to our Chief Executive Officer, Chief Financial Officer, Corporate Controller and other finance organization employees. The finance code of ethics is publicly available on our website at www.microsoft.com/msft. If we make any substantive amendments to the finance code of ethics or grant any waiver, including any implicit waiver, from a provision of the code to our Chief Executive Officer, Chief Financial Officer or Corporate Controller, we will disclose the nature of such amendment or waiver on that website or in a report on Form 8-K.

ITEM 11. EXECUTIVE COMPENSATION

The information in the Proxy Statement set forth under the captions “Information Regarding Executive Officer Compensation” and “Information About the Board and its Committees—Director Compensation” is incorporated herein by reference.

ITEM 12. SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT

The information in the Proxy Statement set forth under the captions “Equity Compensation Plan Information” and “Information Regarding Beneficial Ownership of Principal Shareholders, Directors, and Management” is incorporated herein by reference.

ITEM 13. CERTAIN RELATIONSHIPS AND RELATED TRANSACTIONS

The information set forth under the captions “Certain Relationships and Related Transactions” of the Proxy Statement is incorporated herein by reference.

ITEM 14. PRINCIPAL ACCOUNTANT FEES AND SERVICES

Information concerning principal accountant fees and services appears in the Proxy Statement under the heading “Fees Billed by Deloitte & Touche LLP” and is incorporated herein by reference.

PART IV

ITEM 15. EXHIBITS AND FINANCIAL STATEMENT SCHEDULES

(a) Financial Statements and Schedules

The financial statements are set forth under Item 8 of this Annual Report on Form 10-K. Financial statement schedules have been omitted since they are either not required, not applicable, or the information is otherwise included.

PAGE |  | 66

##### Table of Contents

Part IV

Item 15

(b) Exhibit Listing

Exhibit Number |  | Description
3.1 |  | Amended and Restated Articles of Incorporation of Microsoft Corporation(1)
3.2 |  | Bylaws of Microsoft Corporation(2)
4. |  | Call Option Transaction Confirmation dated December 11, 2003 between Microsoft Corporation and JPMorgan Chase Bank(3)
10.1* |  | Microsoft Corporation 2001 Stock Plan
10.2* |  | Microsoft Corporation 1991 Stock Option Plan(4)
10.3* |  | Microsoft Corporation 1999 Stock Plan for Non-Employee Directors
10.4* |  | Microsoft Corporation Stock Option Plan for Non-Employee Directors(5)
10.5 |  | Microsoft Corporation Stock Option Plan for Consultants and Advisors(6)
10.6* |  | Microsoft Corporation 2003 Employee Stock Purchase Plan
10.7* |  | Microsoft Corporation 1998 Stock Option Gain and Bonus Deferral Program
10.8* |  | Form of Stock Award Agreement
10.9* |  | Form of Stock Award Agreement for Non-Employee Directors
10.10* |  | Form of Shared Performance Stock Award Agreement for the January 1, 2004 to June 30, 2006 performance period
10.11* |  | Form of Shared Performance Stock Award Agreement for the July 1, 2003 to June 30, 2006 performance period
10.12* |  | Form of Stock Option Agreement
10.13* |  | Form of Stock Option Agreement for Non-Employee Directors
10.14 |  | Trust Agreement dated June 1, 1993 between Microsoft Corporation and BNY Western Trust Company as trustee (formerly with First Interstate Bank of Washington as trustee)(6)
10.15 |  | Trust Agreement dated June 30, 2003 between Microsoft Corporation and BNY Western Trust Company as trustee(7)
10.16 |  | Form of Indemnification Agreement(6)
21. |  | Subsidiaries of Registrant
23. |  | Consent of Independent Registered Public Accounting Firm
31.1 |  | Certifications of Chief Executive Officer Pursuant to Section 302 of the Sarbanes-Oxley Act of 2002
31.2 |  | Certifications of Chief Financial Officer Pursuant to Section 302 of the Sarbanes-Oxley Act of 2002
32. |  | Certifications of Chief Executive Officer and Chief Financial Officer Pursuant to Section 906 of the Sarbanes-Oxley Act of 2002

(1) |  | Incorporated by reference to Quarterly Report on Form 10-Q for the Quarterly Period Ended December 31, 2002.

(2) |  | Incorporated by reference to Quarterly Report on Form 10-Q for the Quarterly Period Ended March 31, 2003.

(3) |  | Incorporated by reference to Quarterly Report on Form 10-Q for the Quarterly Period Ended December 31, 2003.

(4) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 1997.

(5) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 1994.

(6) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 2002.

(7) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 2003.

* |  | Indicates a management contract or compensatory plan or arrangement.

PAGE |  | 67

##### Table of Contents

SIGNATURES

Pursuant to the requirements of Section 13 or 15(d) of the Securities Exchange Act of 1934, the Registrant has duly caused this report to be signed on its behalf by the undersigned; thereunto duly authorized, in the City of Redmond, State of Washington, on September 1, 2004.

MICROSOFT CORPORATION
By: |  | /s/ JOHN G. CONNORS
|  | John G. Connors
|  | Senior Vice President; Chief Financial Officer

Pursuant to the requirements of the Securities Exchange Act of 1934, this report has been signed below by the following persons on behalf of Registrant and in the capacities indicated on September 1, 2004.

Signature |  | Title
/s/ WILLIAM H. GATES III William H. Gates III |  | Chairman and Chief Software Architect
/s/ STEVEN A. BALLMER Steven A. Ballmer |  | Director and Chief Executive Officer
/s/ JAMES I. CASH, JR. James I. Cash, Jr. |  | Director
/s/ RAYMOND V. GILMARTIN Raymond V. Gilmartin |  | Director
/s/ ANN MCLAUGHLIN KOROLOGOS Ann McLaughlin Korologos |  | Director
/s/ DAVID F. MARQUARDT David F. Marquardt |  | Director
/s/ CHARLES H. NOSKI Charles H. Noski |  | Director
/s/ HELMUT PANKE Helmut Panke |  | Director
/s/ WM. G. REED, JR. Wm. G. Reed, Jr. |  | Director
/s/ JON A. SHIRLEY Jon A. Shirley |  | Director
/s/ JOHN G. CONNORS John G. Connors |  | Senior Vice President; Chief Financial Officer (Principal Financial and Accounting Officer)

PAGE |  | 68

##### Table of Contents

EXHIBIT INDEX

Exhibit Number |  | Description
3.1 |  | Amended and Restated Articles of Incorporation of Microsoft Corporation(1)
3.2 |  | Bylaws of Microsoft Corporation(2)
4. |  | Call Option Transaction Confirmation dated December 11, 2003 between Microsoft Corporation and JPMorgan Chase Bank(3)
10.1* |  | Microsoft Corporation 2001 Stock Plan
10.2* |  | Microsoft Corporation 1991 Stock Option Plan(4)
10.3* |  | Microsoft Corporation 1999 Stock Plan for Non-Employee Directors
10.4* |  | Microsoft Corporation Stock Option Plan for Non-Employee Directors(5)
10.5 |  | Microsoft Corporation Stock Option Plan for Consultants and Advisors(6)
10.6* |  | Microsoft Corporation 2003 Employee Stock Purchase Plan
10.7* |  | Microsoft Corporation 1998 Stock Option Gain and Bonus Deferral Program
10.8* |  | Form of Stock Award Agreement
10.9* |  | Form of Stock Award Agreement for Non-Employee Directors
10.10* |  | Form of Shared Performance Stock Award Agreement for the January 1, 2004 to June 30, 2006 performance period
10.11* |  | Form of Shared Performance Stock Award Agreement for the July 1, 2003 to June 30, 2006 performance period
10.12* |  | Form of Stock Option Agreement
10.13* |  | Form of Stock Option Agreement for Non-Employee Directors
10.14 |  | Trust Agreement dated June 1, 1993 between Microsoft Corporation and BNY Western Trust Company as trustee (formerly with First Interstate Bank of Washington as trustee)(6)
10.15 |  | Trust Agreement dated June 30, 2003 between Microsoft Corporation and BNY Western Trust Company as trustee(7)
10.16 |  | Form of Indemnification Agreement(6)
21. |  | Subsidiaries of Registrant
23. |  | Consent of Independent Registered Public Accounting Firm
31.1 |  | Certifications of Chief Executive Officer Pursuant to Section 302 of the Sarbanes-Oxley Act of 2002
31.2 |  | Certifications of Chief Financial Officer Pursuant to Section 302 of the Sarbanes-Oxley Act of 2002
32. |  | Certifications of Chief Executive Officer and Chief Financial Officer Pursuant to Section 906 of the Sarbanes-Oxley Act of 2002

(1) |  | Incorporated by reference to Quarterly Report on Form 10-Q for the Quarterly Period Ended December 31, 2002.

(2) |  | Incorporated by reference to Quarterly Report on Form 10-Q for the Quarterly Period Ended March 31, 2003.

(3) |  | Incorporated by reference to Quarterly Report on Form 10-Q for the Quarterly Period Ended December 31, 2003.

(4) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 1997.

(5) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 1994.

(6) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 2002.

(7) |  | Incorporated by reference to Annual Report on Form 10-K for the Fiscal Year Ended June 30, 2003.

* |  | Indicates a management contract or compensatory plan or arrangement.

EX-10.1 2 dex101.htm 2001 STOCK PLAN
2001 Stock Plan

Exhibit 10.1

MICROSOFT CORPORATION

2001 STOCK PLAN

(as amended and restated August 24, 2004)*

1. Purpose of the Plan. The purposes of this Stock Plan are to attract and retain the best available individuals for positions of substantial responsibility, to provide additional incentive to such individuals, and to promote the success of the Company’s business by aligning the financial interests of Employees and Consultants providing personal services to the Company or to any Parent or Subsidiary of the Company with long-term shareholder value.

Awards granted hereunder may be Incentive Stock Options, Nonqualified Stock Options, Stock Awards, or SARs, at the discretion of the Board and as reflected in the terms of the Award Agreement.

2. Definitions. As used herein, the following definitions shall apply:

(a) “Award” shall mean any award or benefits granted under the Plan, including Options, Stock Awards, and SARs.

(b) “Award Agreement” shall mean a written or electronic agreement between the Company and the Awardee setting forth the terms of the Award.

(c) “Awardee” shall mean the holder of an outstanding Award.

(d) “Board” shall mean (i) the Board of Directors of the Company or (ii) both the Board and the Committee, if a Committee has been appointed in accordance with Section 4(a) of the Plan.

(e) “Code” shall mean the Internal Revenue Code of 1986, as amended.

(f) “Committee” shall mean the Compensation Committee appointed by the Board of Directors in accordance with Section 4(a) of the Plan, if one is appointed; provided, however, if the Board of Directors appoints more than one Committee pursuant to Section 4(a), then “Committee” shall refer to the appropriate Committee, as indicated by the context of the reference.

(g) “Common Shares” shall mean the common shares of Microsoft Corporation.

(h) “Company” shall mean Microsoft Corporation, a Washington corporation and any successor thereto.

(i) “Consultant” shall mean any person, except an Employee, engaged by the Company or any Parent or Subsidiary of the Company, to render personal services to such entity, including as an advisor.

(j) “Continuous Status as a Participant” shall mean (1) for Employees, the absence of any interruption or termination of service as an Employee, and (2) for Consultants, the absence of any interruption, expiration, or termination of such person’s consulting or advisory relationship with the Company or the occurrence of any termination event as set forth in such person’s Award Agreement. Continuous Status as a Participant shall not be considered interrupted (i) for an Employee in the case of sick leave, maternity leave, infant care leave, medical emergency leave, military leave, or any other leave of absence for which Continuous Status is not considered interrupted in accordance with the Company’s policies on such matters, and (ii) for a Consultant, in the case of any temporary interruption in such person’s availability to provide services to the Company which has been authorized in writing by a Vice President of the Company prior to its commencement.

(k) “Conversion Options” shall mean the Options described in Section 6(c) of the Plan.

(l) “Employee” shall mean any person, including an officer, who is a common law employee of, receives remuneration for personal services to, is reflected on the official human resources database as an employee of, and is on the payroll of the Company or any Parent or Subsidiary of the Company. A person is on the payroll if he or she is paid from the payroll department of the Company, or any Parent or Subsidiary of the Company. Persons providing services to the Company, or to any Parent or Subsidiary of the Company, pursuant to an agreement with a staff leasing organization, temporary workers engaged through or employed by temporary or leasing agencies, and workers who hold themselves out to the Company, Parent, or Subsidiary to which they are providing services as being independent contractors, or as being employed by or engaged through another company while providing the services are not Employees for purposes of this Plan, whether or not such persons are, or may be reclassified by the courts, the Internal Revenue Service, the U. S. Department of Labor, or other person or entity as, common law employees of the Company, Parent, or Subsidiary, either solely or jointly with another person or entity.

(m) “Effective Date” shall mean January 1, 2001.

(n) “Exchange Act” shall mean the Securities Exchange Act of 1934, as amended.

(o) “Incentive Stock Option” shall mean any Option intended to qualify as an incentive stock option within the meaning of Section 422 of the Code.

(p) “Maximum Annual Participant Award” shall have the meaning set forth in Section 5(b).

(q) “Nonqualified Stock Option” shall mean an Option not intended to qualify as an Incentive Stock Option.

(r) “Option” shall mean a stock option granted pursuant to Section 6 of the Plan.

(s) “Parent” shall mean a “parent corporation,” whether now or hereafter existing, as defined in Section 424(e) of the Code.

2

(t) “Participant” shall mean an Employee or Consultant.

(u) “Plan” shall mean this 2001 Stock Plan, including any amendments thereto.

(v) “Share” shall mean one Common Share, as adjusted in accordance with Section 14 of the Plan.

(w) “SAR” shall mean a stock appreciation right awarded pursuant to Section 8 of the Plan.

(x) “Stock Award” shall mean a grant of Shares or of a right to receive Shares or their cash equivalent (or both) pursuant to Section 7 of the Plan.

(y) “Subsidiary” shall mean (i) in the case of an Incentive Stock Option a “subsidiary corporation,” whether now or hereafter existing, as defined in Section 424(f) of the Code, and (ii) in the case of a Nonqualified Stock Option, a Stock Award or an SAR, in addition to a subsidiary corporation as defined in (i), a limited liability company, partnership or other entity in which the Company controls 50 percent or more of the voting power or equity interests.

3. Shares Subject to the Plan. Subject to the provisions of Sections 14 and 16 of the Plan, the maximum aggregate number of Shares (increased, proportionately, in the event of any stock split, stock dividend or similar event with respect to the Shares) which may be awarded and delivered under the Plan shall not exceed the sum of (a) any Shares available for future awards, as of the Effective Date, under the Microsoft Corporation 1991 Stock Option Plan, as amended (“1991 Stock Plan”) and (b) any Shares that are represented by awards under the 1991 Stock Plan which, after the Effective Date, are forfeited, expire, are cancelled without delivery of Shares, or otherwise result in the return of Shares to the Company, minus (c) 100,000,000 Shares (unadjusted for any stock split or stock dividend with respect to the Shares). The Shares may be authorized, but unissued, or reacquired Common Shares.

Subject to the provisions of the following sentence, if an Award should expire or become unexercisable for any reason without having been exercised in full, the undelivered Shares which were subject thereto shall, unless the Plan shall have been terminated, become available for future Awards under the Plan. Notwithstanding anything to the contrary contained herein, any Awards of Options that are transferred to a third party pursuant to a program under which the holder of certain Options may transfer such Options to such third party in exchange for cash or other consideration, shall be removed from the Plan and the Shares subject to such Awards shall not be available for regrant under the Plan regardless of whether the transferred Options are exercised or expire without exercise.

4. Administration of the Plan.

(a) Procedure. The Plan shall be administered by the Board of Directors of the Company.

(i) The Board of Directors may appoint one or more Committees each consisting of not less than two members of the Board of Directors to administer the Plan on behalf of the Board of Directors, subject to such terms and conditions as the Board of Directors may prescribe. Once appointed, such Committees shall continue to serve until otherwise directed by the Board of Directors.

3

(ii) From time to time the Board of Directors may increase the size of the Committee(s) and appoint additional members thereof, remove members (with or without cause) and appoint new members in substitution therefor, or fill vacancies however caused.

(b) Powers of the Board. Subject to the provisions of the Plan, the Board shall have the authority, in its discretion: (i) to grant Incentive Stock Options, Nonqualified Stock Options, Stock Awards, and SARs; (ii) to determine, in accordance with Section 11(b) of the Plan, the fair market value of the Shares; (iii) to determine, in accordance with Section 11(a) of the Plan, the exercise price per share of Awards to be granted; (iv) to determine the Participants to whom, and the time or times at which, Awards shall be granted and the number of Shares to be represented by each Award; (v) to interpret the Plan; (vi) to prescribe, amend, and rescind rules and regulations relating to the Plan; including the form of Award Agreement, and manner of acceptance of an Award, (vii) to determine the terms and provisions of each Award to be granted (which need not be identical) and, with the consent of the Awardee, modify or amend each Award; (viii) to authorize conversion or substitution under the Plan of any or all Conversion Options; (ix) to accelerate or defer (with the consent of the Awardee) the exercise date of any Option; (x) to authorize any person to execute on behalf of the Company any instrument required to effectuate the grant of an Award previously granted by the Board; and (xi) to make all other determinations deemed necessary or advisable for the administration of the Plan.

The Board may, but need not, determine that an award shall vest or be granted subject to the satisfaction of one or more performance goals. Performance goals for awards will be determined by the Compensation Committee of the Board and will be designed to support the business strategy, and align executives’ interests with customer and shareholder interests. For awards that are intended to qualify as performance-based compensation under Section 162(m), performance goals will be based on one or more of the following business criteria: sales or licensing volume, revenues, customer satisfaction, expenses, organizational health/productivity, earnings (which includes similar measurements such as net profits, operating profits and net income, and which may be calculated before or after taxes, interest, depreciation, amortization or taxes), margins, cash flow, shareholder return, return on equity, return on assets or return on investments, working capital, product shipments or releases, brand or product recognition or acceptance and/or stock price. These criteria may be measured: individually, alternatively or in any combination; with respect to the Company, a subsidiary, division, business unit, product line, product or any combination of the foregoing; on an absolute basis, or relative to a target, to a designated comparison group, to results in other periods or to other external measures; and including or excluding items that could affect the measurement, such as extraordinary or unusual and nonrecurring gains or losses, litigation or claim judgments or settlements, material changes in tax laws, acquisitions or divestitures, the cumulative effect of accounting changes, asset write-downs, restructuring charges, or the results of discontinued operations.

(c) Effect of Board’s Decision. All decisions, determinations, and interpretations of the Board shall be final and binding on all Participants and Awardees.

4

5. Eligibility.

(a) Awards may be granted to Participants and to persons to whom offers of employment as an Employee have been extended; provided that Incentive Stock Options may only be granted to Employees. For avoidance of doubt, directors are not eligible to participate in the Plan unless they are Employees or Consultants.

(b) The maximum number of Shares with respect to which an Award or Awards may be granted to any Participant in any one taxable year of the Company (the “Maximum Annual Participant Award”) shall not exceed 20,000,000 Common Shares for Options or SARs, or 5,000,000 shares for Stock Awards (increased, in both cases proportionately, in the event of any stock split, stock dividend or similar event with respect to the Shares). If an Option is in tandem with an SAR, such that the exercise of the Option or SAR with respect to a Share cancels the tandem SAR or Option right, respectively, with respect to each Share, the tandem Option and SAR rights with respect to each Share shall be counted as covering but one Share for purposes of the Maximum Annual Participant Award.

6. Options.

(a) Each Option shall be designated in the written or electronic option agreement as either an Incentive Stock Option or a Nonqualified Stock Option. However, notwithstanding such designations, to the extent that the aggregate fair market value of the Shares with respect to which Options designated as Incentive Stock Options are exercisable for the first time by any Employee during any calendar year (under all plans of the Company) exceeds $100,000, such Options shall be treated as Nonqualified Stock Options.

(b) For purposes of Section 6(a), Options shall be taken into account in the order in which they were granted, and the fair market value of the Shares shall be determined as of the time the Option with respect to such Shares is granted.

(c) Options converted or substituted under the Plan for any or all outstanding stock options and stock appreciation rights held by employees, consultants, advisors or other option holders granted by entities subsequently acquired by the Company or a subsidiary or affiliate of the Company (“Conversion Options”) shall be effective as of the close of the respective mergers and acquisitions of such entities by the Company. The Conversion Options may be Incentive Stock Options or Nonqualified Stock Options, as determined by the Committee; provided, however, that stock appreciation rights in the acquired entity shall only be converted to or substituted with Nonqualified Stock Options. The Conversion Options shall be options to purchase the number of Common Shares determined by multiplying the number of shares of the acquired entity’s common stock underlying each such stock option or stock appreciation right immediately prior to the closing of such merger or acquisition by the number specified in the applicable merger or acquisition agreement for conversion of each share of such entity’s common stock to a Common Share (the “Merger Ratio”). Such Conversion Options shall be exercisable at an exercise price per Common Share (increased to the nearest whole cent) equal to the exercise price per share of the acquired entity’s common stock under each such stock option or stock appreciation right immediately prior to closing divided by the Merger Ratio. No fractional Common Shares will be issued upon exercise of Conversion Options. In lieu of such issuance, the Common Shares issued pursuant to each such exercise shall be rounded to the closest whole Share. All other terms and conditions applicable to such stock options and stock appreciation rights prior to closing of the acquisition, including vesting, shall remain unchanged under the Conversion Options.

5

7. Stock Awards.

(a) Stock Awards may be granted either alone, in addition to, or in tandem with other Awards granted under the Plan. After the Committee determines that it will offer a Stock Award, it will advise the Awardee in writing or electronically, by means of an Award Agreement, of the terms, conditions and restrictions, including vesting, if any, related to the offer, including the number of Shares that the Awardee shall be entitled to receive or purchase, the price to be paid, if any, and, if applicable, the time within which the Awardee must accept the offer. The offer shall be accepted by execution of an Award Agreement in the manner determined by the Committee.

(b) Unless the Committee determines otherwise, the Award Agreement shall provide for the forfeiture of the non-vested Common Shares underlying such Stock Award upon the Awardee ceasing to be a Participant. To the extent that the Awardee purchased the Shares granted under such Stock Award and any such Shares remain non-vested at the time the Awardee ceases to be a Participant, the cessation of Participant status shall cause an immediate sale of such non-vested Shares to the Company at the original price per Common Share paid by the Awardee.

8. SARs.

(a) The Committee shall have the full power and authority, exercisable in its sole discretion, to grant SARs to selected Awardees. The Committee is authorized to grant both tandem stock appreciation rights (“Tandem SARs”) and stand-alone stock appreciation rights (“Stand-Alone SARs”) as described below.

(b) Tandem SARs.

(i) Awardees may be granted a Tandem SAR, exercisable upon such terms and conditions as the Committee shall establish, to elect between the exercise of the underlying Section 6 Option for Common Shares or the surrender of the Option in exchange for a distribution from the Company in an amount equal to the excess of (A) the fair market value (on the Option surrender date) of the number of Shares in which the Awardee is at the time vested under the surrendered Option (or surrendered portion thereof) over (B) the aggregate exercise price payable for such vested Shares.

(ii) No such Option surrender shall be effective unless it is approved by the Committee, either at the time of the actual Option surrender or at any earlier time. If the surrender is so approved, then the distributions to which the Awardee shall become entitled under this Section 8(b) may be made in Common Shares valued at fair market value on the Option surrender date, in cash, or partly in Shares and partly in cash, as the Committee shall deem appropriate.

6

(iii) If the surrender of an Option is not approved by the Committee, then the Awardee shall retain whatever rights he or she had under the surrendered Option (or surrendered portion thereof) on the Option surrender date and may exercise such rights at any time prior to the later of (A) five (5) business days after the receipt of the rejection notice or (B) the last day on which the Option is otherwise exercisable in accordance with the terms of the instrument evidencing such Option, but in no event may such rights be exercised more than ten (10) years after the date of the Option grant.

(c) Stand-Alone SARs.

(i) An Awardee may be granted a Stand-Alone SAR not tied to any underlying Option under Section 6 of the Plan. The Stand-Alone SAR shall cover a specified number of Common Shares and shall be exercisable upon such terms and conditions as the Committee shall establish. Upon exercise of the Stand-Alone SAR, the holder shall be entitled to receive a distribution from the Company in an amount equal to the excess of (A) the aggregate fair market value (on the exercise date) of the Common Shares underlying the exercised right over (B) the aggregate base price in effect for those Shares.

(ii) The number of Common Shares underlying each Stand-Alone SAR and the base price in effect for those Shares shall be determined by the Committee at the time the Stand-Alone SAR is granted. In no event, however, may the base price per Share be less than the fair market value per underlying Common Share on the grant date.

(iii) The distribution with respect to an exercised Stand-Alone SAR may be made in Common Shares valued at fair market value on the exercise date, in cash, or partly in Shares and partly in cash, as the Committee shall deem appropriate.

(d) The Common Shares underlying any SARs exercised under this Section 8 shall not be available for subsequent issuance under the Plan.

9. Term of Plan. The Plan shall become effective as of the Effective Date. It shall continue in effect until terminated under Section 17 of the Plan.

10. Term of Award; Limitations on Vesting and Repricing.

(a) The term of each Award shall be no more than ten (10) years from the date of grant. However, in the case of an Incentive Stock Option granted to a Participant who, at the time the Option is granted, owns Shares representing more than ten percent (10%) of the voting power of all classes of shares of the Company or any Parent or Subsidiary, the term of the Option shall be no more than five (5) years from the date of grant.

(b) Each award shall vest over a period of not less than three (3) years from the date of grant, provided that awards covering up to 50,000,000 shares (increased, proportionately, in the event of any stock split, stock dividend or similar event) may be granted without regard to the 3-year vesting restriction; provided further, that Conversion Options and awards that are granted or vest based on performance goals shall not count toward the limit of this Section 10(b).

7

(c) No Award may be repriced, replaced, regranted through cancellation, or modified without approval of the shareholders of the Company (except in connection with an adjustment pursuant to Section 14) if the effect would be to reduce the exercise price for the Shares underlying such Award.

11. Exercise Price and Consideration.

(a) The per Share exercise price under each Award shall be such price as is determined by the Board, subject to the following:

(i) In the case of an Incentive Stock Option

(A) granted to an Employee who, at the time of the grant of such Incentive Stock Option, owns shares representing more than ten percent (10%) of the voting power of all classes of shares of the Company or any Parent or Subsidiary, the per Share exercise price shall be no less than 110% of the fair market value per Share on the date of grant.

(B) granted to any other Employee, the per Share exercise price shall be no less than 100% of the fair market value per Share on the date of grant.

(ii) Except for Conversion Options under Section 6(c), the per Share exercise price under a Nonqualified Stock Option or SAR shall be no less than seventy-five percent (75%) of the fair market value per Share on the date of grant. Notwithstanding the foregoing (or any other provision of the Plan), Options and SARs that are granted to Employees who are non-exempt for purposes of the FLSA, shall satisfy the requirements for exclusion from regular rate of pay for purposes of the FLSA and shall have an exercise price that is at least eighty-five percent (85%) of the fair market value of the underlying Shares at the time of grant; furthermore, such Options or SARs shall not be exercisable within the six (6) month period immediately following the date of grant, except, if so provided in the Award Agreement, in the event of the Awardee’s death, disability, or retirement, upon a change in corporate control of the Company, or under such other circumstances as are permitted under the FLSA or rules and regulations thereunder.

(iii) The maximum aggregate number of Shares underlying all Nonqualified Stock Options and SARs with a per Share exercise price of less than fair market value on any grant date that may be granted under this Plan is 50,000,000 Shares (increased, proportionately, in the event of any stock split, stock dividend or similar event with respect to the Shares); provided that Conversion Options shall not count against the limit of this Section 11(a)(iii).

(b) The fair market value per Share shall be the closing price per share of the Common Share on the Nasdaq Stock Market (“Nasdaq”) on the date of grant. If the Shares cease to be listed on Nasdaq, the Board shall designate an alternative method of determining the fair market value of the Shares.

8

(c) The consideration to be paid for the Shares to be issued upon exercise of an Award, including the method of payment, shall be determined by the Board at the time of grant and may consist of cash and/or check. Payment may also be made by delivering a properly executed exercise notice together with irrevocable instructions to a broker to promptly deliver to the Company the amount of sale proceeds necessary to pay the exercise price. If the Awardee is an officer of the Company within the meaning of Section 16 of the Exchange Act, the officer may, in addition, be allowed to pay all or part of the purchase price with Shares which, as of the exercise date, the officer has owned for six (6) months or more. If the Awardee is a participant in the 1998 Microsoft Corporation Stock Option Gain And Bonus Deferral Program, he may in addition be allowed to pay all or part of the purchase price of any deferred Option with Shares. Shares used by officers to pay the exercise price shall be valued at their fair market value on the exercise date.

(d) Prior to issuance of the Shares upon exercise of an Award, the Awardee shall pay any federal, state, and local income and employment tax withholding obligations applicable to such Award. If an Awardee is an officer of the Company within the meaning of Section 16 of the Exchange Act, he may elect to pay such withholding tax obligations by having the Company withhold Shares having a value equal to the amount required to be withheld, and any Award under the Plan may permit or require that such withholding tax obligations be paid by having the Company withhold Shares having a value equal to the amount required to be withheld. The value of the Shares to be withheld shall equal the fair market value of the Shares on the day the Award is exercised. The right of an officer to dispose of Shares to the Company in satisfaction of withholding tax obligations shall be deemed to be approved as part of the initial grant of an Award, unless thereafter rescinded, and shall otherwise be made in compliance with Rule 16b-3 and other applicable regulations, and any Award under the Plan may permit or require that such withholding tax obligations be paid by having the Company withhold Shares having a value equal to the amount required to be withheld.

12. Exercise of Award.

(a) Procedure for Exercise; Rights as a Shareholder. Any Award granted hereunder shall be exercisable at such times and under such conditions as determined by the Board at the time of grant, and as shall be permissible under the terms of the Plan.

An Award may not be exercised for a fraction of a Share.

An Award shall be deemed to be exercised when written or electronic notice of such exercise has been given to the Company in accordance with the terms of the Award by the person entitled to exercise the Award and full payment for the Shares with respect to which the Award is exercised has been received by the Company. Full payment may, as authorized by the Board, consist of any consideration and method of payment allowable under Section 11(c) of the Plan. Until the issuance (as evidenced by the appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company) of the share certificate evidencing such Shares, no right to vote or receive dividends or any other rights as a shareholder shall exist with respect to the Shares subject to the Award, notwithstanding the exercise of the Award. The Company shall issue (or cause to be issued) such share certificate promptly upon exercise of the Award. In the event that the exercise of an Award is treated in part as the exercise of an Incentive Stock Option and in part as the exercise of a Nonqualified Stock Option pursuant to Section 6(a), the Company shall issue a share certificate evidencing the Shares treated as acquired upon the exercise of an Incentive Stock Option and a separate share certificate evidencing the Shares treated as acquired upon the exercise of a Nonqualified Stock Option, and shall identify each such certificate accordingly in its share transfer records. No adjustment will be made for a dividend or other right for which the record date is prior to the date the share certificate is issued, except as provided in Section 14 of the Plan.

9

Exercise of an Award in any manner and delivery of the Shares subject to such Award shall result in a decrease in the number of Shares which thereafter may be available, both for purposes of the Plan and for sale under the Award, by the number of Shares as to which the Award is exercised.

(b) Termination of Status as a Participant. In the event of termination of an Awardee’s Continuous Status as a Participant, such Awardee may exercise his or her rights under any outstanding Awards to the extent exercisable on the date of termination (but in no event later than the date of expiration of the term of such Award as set forth in the Award Agreement). To the extent that the Awardee was not entitled to exercise his or her rights under such Awards at the date of such termination, or does not exercise such rights within the time specified in the individual Award Agreements, the Awards shall terminate.

(c) Disability of Awardee. Notwithstanding the provisions of Section 12(b) above, in the event of termination of an Awardee’s Continuous Status as a Participant as a result of total and permanent disability (i.e., the inability to engage in any substantial gainful activity by reason of any medically determinable physical or mental impairment which can be expected to result in death or which has lasted or can be expected to last for a continuous period of twelve (12) months), the Awardee will vest in the Award, but only to the extent of the vesting that would have occurred had the Awardee remained in Continuous Status as a Participant for a period of twelve (12) months after the date on which the Participant ceased performing services as a result of the total and permanent disability. An Option or SAR that is vested pursuant to this Section 12(c) must be exercised within eighteen (18) months (or such shorter time as is specified in the grant) from the date on which the Participant ceased performing services as a result of the total and permanent disability (but in no event later than the date of expiration of the term of such Option or SAR as set forth in the Award Agreement). To the extent that the Awardee was not entitled to exercise such Option or SAR within the time specified herein, the Award shall terminate.

(d) Death of Awardee. Notwithstanding the provisions of Section 12(b) above, in the event of the death of an Awardee:

(i) who is at the time of death a Participant, the Award will vest, but only to the extent of the vesting that would have occurred had the Awardee continued living and remained in Continuous Status as a Participant twelve (12) months following the date of death, by the Awardee’s estate or by a person who acquired the right to exercise the Award by bequest or inheritance, or

(ii) whose Option or SAR has not yet expired but whose Continuous Status as a Participant terminated prior to the date of death, the Option or SAR may be exercised, at any time within twelve (12) months following the date of death, by the Awardee’s estate or by a person who acquired the right to exercise the Option or SAR by bequest or inheritance, but only to the extent of the right to exercise that had vested at the date of termination.

10

(e) Notwithstanding subsections (b), (c), and (d) of this Section 12, the Board shall have the authority to extend the expiration date of any outstanding Option in circumstances in which it deems such action to be appropriate (provided that no such extension shall extend the term of an Award beyond the date on which the Award would have expired if no termination of the Employee’s Continuous Status as a Participant had occurred).

13. Non-Transferability of Awards. An Award may not be sold, pledged, assigned, hypothecated, transferred, or disposed of in any manner other than by will or by the laws of descent or distribution and may be exercised, during the lifetime of the Awardee, only by the Awardee; provided that the Board may permit further transferability, on a general or specific basis, and may impose conditions and limitations on any permitted transferability.

14. Adjustments to Shares Subject to the Plan.

The number of Shares covered by each outstanding Award, the Maximum Annual Employee Award and the number of Shares which have been authorized for issuance under the Plan but as to which no Awards have yet been granted or which have been returned to the Plan upon cancellation or expiration of an Award, as well as the price per Share covered by each such outstanding Award, shall be proportionately adjusted for any increase or decrease in the number of issued Shares resulting from a stock split, reverse stock split, stock dividend, combination, or reclassification of the Shares, or any other increase or decrease in the number of issued Shares effected without receipt of consideration by the Company; provided, however, that conversion of any convertible securities of the Company shall not be deemed to have been “effected without receipt of consideration.” Such adjustment shall be made by the Board, whose determination in that respect shall be final, binding, and conclusive. Except as expressly provided herein, no issuance by the Company of shares of any class, or securities convertible into shares of any class, shall affect, and no adjustment by reason thereof shall be made with respect to, the number or price of Shares subject to an Award.

In the event of the proposed dissolution or liquidation of the Company, the Award will terminate immediately prior to the consummation of such proposed action, unless otherwise provided by the Board. The Board may, in the exercise of its sole discretion in such instances, declare that any Award shall terminate as of a date fixed by the Board and give each Awardee the right to exercise an Award as to all or any part of the Shares subject to an Award, including Shares as to which the Award would not otherwise be exercisable. In the event of a proposed sale of all or substantially all of the assets of the Company, or the merger of the Company with or into another corporation, each Award shall be assumed or an equivalent award shall be substituted by such successor corporation or a parent or subsidiary of such successor corporation, unless such successor corporation does not agree to assume the Award or to substitute an equivalent award, in which case the Board shall, in lieu of such assumption or substitution, provide for the Awardee to have the right to exercise the Award as to all of the Shares subject to Awards, including Shares as to which the Award would not otherwise be exercisable. If the Board makes an Award fully exercisable in lieu of assumption or substitution in the event of a merger or sale of assets, the Board shall notify the Awardee that the Award shall be fully exercisable for a period of fifteen (15) days from the date of such notice, and the Award will terminate upon the expiration of such period.

11

15. Time of Granting Awards. The date of grant of an Award shall, for all purposes, be the date on which the Company completes the corporate action relating to the grant of such Award and all conditions to the grant have been satisfied, provided that conditions to the grant, exercise or vesting of an Award shall not defer the date of grant. Notice of a grant shall be given to each Participant to whom an Award is so granted within a reasonable time after the determination has been made.

16. Substitutions and Assumptions. The Board shall have the right to substitute or assume Awards in connection with mergers, reorganizations, separations, or other transactions to which Section 424(a) of the Code applies, provided such substitutions and assumptions are permitted by Section 424 of the Code and the regulations promulgated thereunder. The number of Shares reserved pursuant to Section 3 may be increased by the corresponding number of Awards assumed and, in the case of a substitution, by the net increase in the number of Shares subject to Awards before and after the substitution.

17. Amendment and Termination of the Plan.

(a) Amendment and Termination. The Board may amend or terminate the Plan from time to time in such respects as the Board may deem advisable (including, but not limited to amendments which the Board deems appropriate to enhance the Company’s ability to claim deductions related to stock option exercises); provided that any increase in the number of Shares subject to the Plan, other than in connection with an adjustment under Section 14 of the Plan, and any amendment described in Section 10(b) of the Plan, shall require approval of or ratification by the shareholders of the Company.

(b) Participants in Foreign Countries. The Board shall have the authority to adopt such modifications, procedures, and subplans as may be necessary or desirable to comply with provisions of the laws of foreign countries in which the Company or its Subsidiaries may operate to assure the viability of the benefits from Awards granted to Participants performing services in such countries and to meet the objectives of the Plan.

(c) Effect of Amendment or Termination. Any such amendment or termination of the Plan shall not affect Awards already granted and such Awards shall remain in full force and effect as if this Plan had not been amended or terminated, unless mutually agreed otherwise between the Awardee and the Board, which agreement must be in writing and signed by the Awardee and the Company.

18. Conditions Upon Issuance of Shares. Shares shall not be issued pursuant to the exercise of an Award unless the exercise of such Award and the issuance and delivery of such Shares pursuant thereto shall comply with all relevant provisions of law, including, without limitation, the Securities Act of 1933, as amended, the Exchange Act, the rules and regulations promulgated thereunder, and the requirements of any stock exchange upon which the Shares may then be listed, and shall be further subject to the approval of counsel for the Company with respect to such compliance.

19. Reservation of Shares. The Company, during the term of this Plan, will at all times reserve and keep available such number of Shares as shall be sufficient to satisfy the requirements of the Plan.

12

20. No Employment/Service Rights. Nothing in the Plan shall confer upon any Participant the right to an Award or to continue in service as an Employee or Consultant for any period of specific duration, or interfere with or otherwise restrict in any way the rights of the Company (or any Parent or Subsidiary employing or retaining such person), or of any Participant or Awardee, which rights are hereby expressly reserved by each, to terminate such person’s services at any time for any reason, with or without cause.

21. Shareholder Approval. The Plan, as amended and restated, is subject to approval by the shareholders of the Company.

* | As amended and restated as of August 24, 2004, excluding amendments made July 20, 2004 that will be effective only after approval by the shareholders at the 2004 Annual Meeting of Shareholders.

All share numbers in the Plan reflect the 2-for-1 stock split effected February 2003.

13

EX-10.3 3 dex103.htm 1999 STOCK PLAN FOR NON-EMPLOYEE DIRECTORS
1999 Stock Plan for Non-Employee Directors

Exhibit 10.3

MICROSOFT CORPORATION

1999 STOCK PLAN FOR NON-EMPLOYEE DIRECTORS

(as amended and restated August 24, 2004)*

1. Purpose

The purpose of the Microsoft Corporation 1999 Stock Plan for Non-Employee Directors (the “Plan”) is to attract and retain the services of experienced and knowledgeable independent directors of Microsoft Corporation (the “Corporation”) for the benefit of the Corporation and its stockholders and to provide additional incentive for such directors to continue to work for the best interests of the Corporation and its stockholders through continuing ownership of its common stock.

2. Shares Subject to the Plan

The total number of shares of common stock of the Corporation (“Shares”) for which Awards (as defined in Section 4) may be granted under the Plan shall not exceed 3,500,000 in the aggregate, subject to adjustment in accordance with Section 12 hereof. Within the foregoing limitation, Shares underlying Awards that have been granted pursuant to the Plan but which Awards have lapsed or otherwise terminated without delivery of Shares shall become available for the grant of additional Awards.

3. Administration of Plan

The Board of Directors of the Corporation shall administer the Plan. The Board may delegate responsibility for administration of the Plan to a Board committee (the “Committee”) composed solely of two or more directors, each of whom is a “Non-Employee Director” (as that term is defined in Rule 16b-3(b) promulgated by the Securities and Exchange Commission pursuant to its authority under the Securities Exchange Act of 1934 (the “Exchange Act”)). The Board or the Committee, as the case may be, shall have the power to construe the Plan, to determine all questions arising thereunder, and to adopt and amend such rules and regulations for the administration of the Plan as it may deem desirable. References to the “Board” in this Plan shall be deemed to refer to either the Board or the Committee, whichever is appropriate in the context in which the word is used.

4. Discretionary Award Grants

Pursuant to this Plan, the Board may grant in its discretion an Award (as defined in this Section 4) to any person who (a) is elected a director of the Corporation, and (b) is not, and has not during the immediately preceding 12 month period been, an employee of the Corporation or any subsidiary of the Corporation. An “Award” may be either (i) a grant of a stock option (an “Option”) or (ii) a grant of Shares or of a right to receive Shares or their cash equivalent (or both) (a “Stock Award”). No Awards under this Section 4 may be granted to any individual director with respect to more than 10,000 shares for any calendar year or, in the case of a newly elected director, more than 25,000 shares for the year in which the director is first elected. No director shall have any claim or right to be granted an Award under this Plan. Having received an Award under this Plan shall not give a director any right to receive any other Award under this Plan and the Board may determine that any or all director(s) are not eligible to receive an Award under this Plan for an indefinite period or for a specified year or years.

5. Award Agreement

Each Award granted under the Plan shall be evidenced by an Award agreement (the “Agreement”) duly executed on behalf of the Corporation and by the director to whom such Award is granted, which Agreements may but need not be identical and which shall (a) comply with and be subject to the terms and conditions of the Plan and (b) provide that the director agrees to continue to serve as a director of the Corporation during the term for which he or she was elected. Each Award shall vest over a period of not less than three (3) years from the date of grant, except with respect to Awards that are granted in lieu of cash compensation. Any Agreement may contain such other terms, provisions, and conditions not inconsistent with the Plan as may be determined by the Board. No Award shall be deemed granted within the meaning of the Plan and no purported grant of any Award shall be effective, until such Agreement shall have been duly executed on behalf of the Corporation and the director to whom the Award is to be granted.

6. Stock Awards

(a) Stock Awards may be granted either alone, in addition to, or in tandem with other Awards granted under the Plan. After the Board determines that it will offer a Stock Award, it will advise the director in writing or electronically, by means of an Agreement, of the terms, conditions and restrictions, including vesting, if any, related to the offer, including the number of Shares that the director shall be entitled to receive or purchase, the price to be paid, if any, and, if applicable, the time within which the director must accept the offer. The offer shall be accepted by execution of an Agreement in the manner determined by the Board.

(b) Unless the Board determines otherwise, the Agreement shall provide for the forfeiture of the non-vested Shares underlying such Stock Award upon the director ceasing to be a director for any reason, including death. To the extent that the director purchased the Shares granted under such Stock Award and any such Shares remain non-vested at the time the director ceases to be a director, the cessation of director status shall cause an immediate sale of such non-vested Shares to the Company at the original price per Share paid by the director.

7. Options

(a) The Board shall set the exercise price for an Option granted pursuant to Section 4 of the Plan in its discretion.

(b) Each Option shall expire no more than ten years from the date of the granting thereof, but shall be subject to earlier termination as follows:

(i) In the event of the death of an Option holder, the Option granted to such person may be exercised to the extent exercisable on the date of death, within the earlier of (x) 180 days after the date of death of such person and (y) the date on which the Option expires by its terms, by the estate of such person, or by any person or persons who acquired the right to exercise such Option by will or by the laws of descent and distribution.

2

(ii) In the event that an Option holder ceases to be a director of the Corporation, other than by reason of his or her death, an Option granted to such person may be exercised, to the extent exercisable on the date such person ceases to be a director, within the earlier of (x) 180 days after the date such person ceases to be a director and (y) the date on which the Option expires by its terms.

8. Vesting and Exercise of Awards

(a) The Board shall set the vesting schedule for Awards granted pursuant to Section 4 of the Plan in its discretion.

(b) To the extent that the right to exercise an Option has vested and is in effect, the Option may be exercised from time to time, by giving written notice, signed by the person or persons exercising the Option, to the Corporation, stating the number of whole Shares with respect to which the Option is being exercised, accompanied by payment in full for such Shares, which payment may be in whole or in part in shares of the common stock of the Corporation already owned by the person or persons exercising the Option, valued at fair market value on the date of payment. For purposes hereof, the fair market value of the Shares covered by an Option shall be the closing price of the Shares on the applicable date as reported in the National Market List of the National Association of Securities Dealers Inc. Automated Quotation System or on the principal national securities exchange on which the Shares are then listed for trading.

(c) Upon exercise of the Option, delivery of a certificate for fully paid and non-assessable Shares shall be made at the principal office of the Corporation in the State of Washington to the person or persons exercising the Option as soon as practicable (but in no event more than 30 days) after the date of receipt of the notice of exercise by the Corporation, or at such time, place, and manner as may be agreed upon by the Corporation and the person or persons exercising the Option.

(d) Upon a Stock Award becoming fully vested and nonforfeitable, delivery of a certificate for fully paid and non-assessable Shares shall be made at the principal office of the Corporation in the State of Washington to the person to whom the Stock Award was granted as soon as practicable (but in no event more than 30 days) after the date on which the Stock Award becomes fully vested and nonforfeitable, or at such time, place, and manner as may be agreed upon by the Corporation and the holder of the Stock Award.

(e) Prior to issuance of the Shares in connection with an Award, the director receiving the Award may request the Corporation to withhold and pay on the director’s behalf any federal, state, and local income tax obligations applicable to such Award by having the Corporation withhold Shares having a value equal to the amount requested to be withheld, and any Award under the Plan may permit that such withholding tax be paid by having the Corporation withhold Shares having a value equal to the amount requested to be withheld. The value of the Shares to be withheld shall equal the fair market value of the Shares on the day the Award is exercised or granted, as applicable. The right of a director to dispose of Shares to the Corporation in satisfaction of withholding tax obligations shall be deemed to be approved as part of the initial grant of an Award, unless thereafter rescinded, and shall otherwise be made in compliance with Rule 16b-3 and other applicable regulations.

3

9. Merger, Consolidation, Sale of Assets, etc., Resulting in a Change in Control

(a) In the event of a Change in Control (as hereinafter defined), notwithstanding the vesting provisions contained in the Agreement granting an Option or Stock Award, as applicable, to a director pursuant to this Plan, such Option shall become fully exercisable or Stock Award shall become fully vested and nonforfeitable if, within one year of such Change in Control, such director shall cease for any reason to be a member of the Board. For purposes hereof, a Change in Control of the Corporation shall be deemed to have occurred if (i) there shall be consummated (x) any consolidation or merger of the Corporation in which the Corporation is not the continuing or surviving corporation or pursuant to which shares of the common stock of the Corporation would be converted into cash, securities, or other property, other than a merger of the Corporation in which the holders of the common stock of the Corporation immediately prior to the merger have the same proportionate ownership of common stock of the surviving corporation immediately after the merger, or (y) any sale, lease, exchange, or other transfer (in one transaction or a series of related transactions) of all, or substantially all, of the assets of the Corporation; or (ii) the stockholders of the Corporation approve any plan or proposal for the liquidation or dissolution of the Corporation; or (iii) any person (as such term is used in Sections 13(d) and 14(d)(2) of the Exchange Act), other than William H. Gates III, shall become the beneficial owner (within the meaning of Rule 13d-3 under the Exchange Act) of 30% or more of the Corporation’s outstanding common stock; or (iv) during any period of two consecutive years, individuals who at the beginning of such period constitute the entire Board of Directors shall cease for any reason to constitute a majority thereof unless the election, or the nomination for election by the Corporation’s stockholders, of each new director was approved by a vote of at least two-thirds of the directors then still in office who were directors at the beginning of the period.

(b) Any exercise of an Option permitted pursuant to this Section 9 shall be made within 180 days of the related director’s termination as a director of the Corporation.

10. Awards Not Transferable

An Award granted pursuant to the Plan may not be sold, pledged, assigned, hypothecated, transferred, or disposed of in any manner other than by will or by the laws of descent or distribution and may be exercised, during the lifetime of the holder of an Award, only by the holder; provided that the Board may permit further transferability, on a general or specific basis, and may impose conditions and limitations on any permitted transferability.

11. No Rights as Stockholder Until Holder

Neither the recipient of an Award under the Plan nor his successors in interest shall have any rights as a stockholder of the Corporation with respect to any Shares subject to an Award granted to such person until such person becomes a holder of record of such Shares.

4

12. Adjustments Upon Changes in Capitalization or Merger

Subject to any required action by the stockholders of the Corporation, the number of shares of common stock covered by each outstanding Award, and the number of shares of common stock which have been authorized for issuance under the Plan but as to which no Awards have yet been granted or which have been returned to the Plan upon cancellation or expiration of an Award, as well as the price per share of common stock covered by each outstanding Award, shall be proportionately adjusted for any increase or decrease in the number of issued shares of common stock resulting from a stock split, reverse stock split, stock dividend, combination or reclassification of the common stock, or any other increase or decrease in the number of issued shares of common stock effected without receipt of consideration by the Corporation; provided, however, that conversion of any convertible securities of the Corporation shall not be deemed to have been “effected without receipt of consideration.” Such adjustment shall be made by the Board, whose determination in that respect shall be final, binding, and conclusive. Except as expressly provided herein, no issuance by the Corporation of shares of stock of any class, or securities convertible into shares of stock of any class, shall affect, and no adjustment by reason thereof shall be made with respect to, the number or price of shares of common stock subject to an Award.

In the event of the proposed dissolution or liquidation of the Corporation, an outstanding Award (i.e., an Option that has not been exercised or a Stock Award that has not become fully vested and nonforfeitable) will terminate immediately prior to the consummation of such proposed action, unless otherwise provided by the Board. The Board may, in the exercise of its sole discretion in such instances, declare that any Option shall terminate as of a date fixed by the Board and give each Option holder the right to exercise an Option as to all or any part of the stock covered by such Option, including Shares as to which the Option would not otherwise be exercisable. In the event of a proposed sale of all or substantially all of the assets of the Corporation, or the merger of the Corporation with or into another corporation, each Award shall be assumed or an equivalent Award shall be substituted by such successor corporation or a parent or subsidiary of such successor corporation, unless such successor corporation does not agree to assume each and every Award or to substitute an equivalent Award, in which case the Board shall, in lieu of such assumption or substitution, provide for the immediate full vesting of any Stock Awards not yet fully vested, or provide for the Option holder to have the right to exercise such Option as to all of the stock covered by such Option, including Shares as to which such Option would not otherwise be exercisable, or both. If the Board makes an Option fully exercisable in lieu of assumption or substitution in the event of a merger or sale of assets, the Board shall notify the Option holder that the Option shall be fully exercisable for a period of fifteen (15) days from the date of such notice, and the Option will terminate upon the expiration of such period.

13. Restrictions on Issue of Shares

Notwithstanding anything in this Plan to the contrary, the Corporation may delay the issuance of Shares covered by any Award and the delivery of a certificate for such Shares until one of the following conditions shall be satisfied:

(a) the Shares to be issued in connection with the grant or exercise of an Award, as applicable, are at the time of the issue of such Shares by the Corporation effectively registered under applicable federal securities laws now in force or hereafter amended; or

5

(b) counsel for the Corporation shall have given an opinion, which opinion shall not be unreasonably conditioned or withheld, that such Shares are exempt from registration under applicable federal securities laws now in force or hereafter amended.

It is intended that all grants of Stock Awards and exercises of Options shall be effective. Accordingly, the Corporation shall use its best efforts to bring about compliance with the above conditions within a reasonable time, except that the Corporation shall be under no obligation to cause a registration statement or a post-effective amendment to any registration statement to be prepared at its expense solely for the purpose of covering the issuance of Shares in connection with the grant or exercise of any Award.

14. Purchase for Investment

Unless the Shares to be issued in connection with the grant or exercise of an Award granted under the Plan have been effectively registered under the Securities Act of 1933 as now in force or hereafter amended, the Corporation shall be under no obligation to issue any Shares covered by any Award unless the person or persons to whom the Shares are to be issued, in whole or in part, shall give a written representation and undertaking to the Corporation, which is satisfactory in form and scope to counsel to the Corporation and upon which, in the opinion of such counsel, the Corporation may reasonably rely, that he or she is acquiring the shares issued or transferred to him or her for his or her own account as an investment and not with a view to, or for sale in connection with, the distribution of any such Shares, and that he or she will make no transfer of the same except in compliance with any rules and regulations in force at the time of such transfer under the Securities Act of 1933, or any other applicable law, and that if Shares are issued or transferred without such registration a legend to this effect may be placed upon the certificates representing the Shares.

15. Effective Date

The effective date (the “Effective Date”) of this Plan is November 10, 1999, the date on which the Plan was approved by stockholders of the Corporation. The Plan is amended and restated as of September 11, 2003, subject to approval by stockholders of the Corporation.

16. Expenses of the Plan

All costs and expenses of the adoption and administration of the Plan shall be borne by the Corporation and none of such expenses shall be charged to any director.

17. Termination and Amendment of Plan

Unless sooner terminated as herein provided, the Plan shall terminate ten years from the Effective Date. The Board may at any time terminate the Plan or make such modification or amendment thereof as it deems advisable; provided, however, that stockholder approval will be required for any amendment that will (a) increase the total number of shares as to which Awards may be granted under the Plan, (b) modify the class of persons eligible to receive Awards, or (c) otherwise require stockholder approval under any applicable law or regulation. In addition, the Board shall not amend the provisions in the Plan regarding the amount, pricing, and timing for grants pursuant to this Plan more than once every six months, other than to comport with changes in the Internal Revenue Code, or the rules thereunder. Termination or any modification or amendment of the Plan shall not, without the consent of an Award holder, affect his or her rights under an Award previously granted to him or her.

* | As amended and restated as of August 24, 2004, excluding amendments made July 20, 2004 that will be effective only after approval by the shareholders at the 2004 Annual Meeting of Shareholders.

All share numbers in the Plan reflect the 2-for-1 stock split effected February 2003.

6

EX-10.6 4 dex106.htm 2003 EMPLOYEE STOCK PURCHASE PLAN
2003 Employee Stock Purchase Plan

Exhibit 10.6

Microsoft Corporation

2003 Employee Stock Purchase Plan

As amended effective July 1, 2004

MICROSOFT CORPORATION

2003 EMPLOYEE STOCK PURCHASE PLAN

The 2003 Employee Stock Purchase Plan (the “Plan”) was approved by Company’s Board of Directors on August 22, 2002 and by its Shareholders on November 5, 2002. The Plan was amended to read as set forth herein effective July 1, 2004.

1. Purpose and Structure of the Plan and its Sub-Plans.

1.1 The purpose of this Plan is to provide eligible employees of the Company and Participating Companies who wish to become shareholders in the Company a convenient method of doing so. It is believed that employee participation in the ownership of the business will be to the mutual benefit of both the employees and the Company. This Plan document is an omnibus document which includes a sub-plan (“Statutory Plan”) designed to permit offerings of grants to employees of certain Subsidiaries that are Participating Companies where such offerings are intended to satisfy the requirements of Section 423 of the Code (although the Company makes no undertaking nor representation to obtain or maintain qualification under Section 423 for any Subsidiary, individual, offering or grant) and also separate sub-plans (“Non-Statutory Plans”) which permit offerings of grants to employees of certain Participating Companies which are not intended to satisfy the requirements of Section 423 of the Code. Section 6 of the Plan sets forth the maximum number of shares to be offered under the Plan (and its sub-plans), subject to adjustments as permitted under Sections 19 and 20. The Committee shall determine from time to time the method for allocating the number of such total shares to be offered under each sub-plan. Such determination shall be in the Committee’s discretion and shall not require shareholder approval.

1.2 The Statutory Plan shall be a separate and independent plan from the Non-Statutory Plans, provided, however, that the total number of shares authorized to be issued under the Plan applies in the aggregate to both the Statutory Plan and the Non-Statutory Plans. Offerings under the Non-Statutory Plans may be made to achieve desired tax or other objectives in particular locations outside the United States of America or to comply with local laws applicable to offerings in such foreign jurisdictions. Offerings under the Non-Statutory Plans may also be made to employees of entities that are not Subsidiaries.

1.3 All employees who participate in the Statutory Plan shall have the same rights and privileges under such sub-plan except for differences that may be mandated by local law and are consistent with the requirements of Code Section 423(b)(5). The terms of the Statutory Plan shall be those set forth in this Plan document to the extent such terms are consistent with the requirements for qualification under Code Section 423. The Committee may adopt Non-Statutory Plans applicable to particular Participating Companies or locations that are not participating in the Statutory

2

Plan. The terms of each Non-Statutory Plan may take precedence over other provisions in this document, with the exception of Sections 6, 19 and 20 with respect to the total number of shares available to be offered under the Plan for all sub-plans. Unless otherwise superseded by the terms of such Non-Statutory Plan, the provisions of this Plan document shall govern the operation of such Non-Statutory Plan. Except to the extent expressly set forth herein or where the context suggests otherwise, any reference herein to “Plan” shall be construed to include a reference to the Statutory Plan and the Non-Statutory Plans.

2. Definitions.

2.1 “Account” shall mean the funds accumulated with respect to an individual employee as a result of deductions from such employee’s paycheck (or otherwise as permitted in certain circumstances under the terms of the Plan) for the purpose of purchasing stock under this Plan. The funds allocated to an employee’s Account shall remain the property of the respective employee at all times but may be commingled with the general funds of the Company, except to the extent such commingling may be prohibited by the laws of any applicable jurisdiction.

2.2 “Affiliate” means an entity, other than a Subsidiary, in which the Company has an equity or other ownership interest.

2.3 “Board” means the Board of Directors of the Company.

2.4 “Code” means the Internal Revenue Code of 1986, as amended from time to time.

2.5 “Committee” means any committee or officer(s) of the Company to which or to whom the Board has delegated any or all of its authority and obligations under this Plan pursuant to Section 22.1. To the extent the Board reserves authority to itself with respect to certain powers under this Plan, or if no Committee has been established, references to Committee shall be construed to mean the Board.

2.6 “Company” means Microsoft Corporation.

2.7 “Compensation” means total cash performance-based pay received by the participant from a Participating Company. By way of illustration, but not limitation, Compensation includes salary, wages, performance bonuses, commissions, incentive compensation and overtime but excludes relocation, equalization, patent and sign-on bonuses, expense reimbursements, meal allowances, commuting or automobile allowances, any payments (such as guaranteed bonuses in certain foreign jurisdictions) with respect to which salary reductions are not permitted by the laws of the applicable jurisdiction, and income realized as a result of participation in any stock plan, including without limitation any stock option, stock award, stock purchase, or similar plan, of the Company or any Subsidiary or Affiliate.

3

2.8 “Enrollment Agreement” means an agreement between the Company and an employee, in such form as may be established by the Company from time to time, pursuant to which the employee elects to participate in this Plan, or elects changes with respect to such participation as permitted under the Plan.

2.9 “ESPP Broker” means a stock brokerage or other entity designated by the Company to establish accounts for stock purchased under the Plan by participants.

2.10 “Fair Market Value” means the closing bid price as reported on the National Association of Securities Dealers Automated Quotation National Market System or the other primary trading market for the Company’s common stock.

2.11 “Offering Date” as used in this Plan shall be the commencement date of an offering.

2.12 “Participating Company” shall mean the Company and any Subsidiary or Affiliate that has been designated by the Committee to participate in the Plan. For purposes of participation in the Statutory Plan, only the Company and its Subsidiaries may be Participating Companies, and the Committee shall designate from time to time which Subsidiaries will be Participating Companies in the Statutory Plan. The Committee shall designate from time to time which Subsidiaries and Affiliates will be Participating Companies in particular Non-Statutory Plans provided, however, that at any given time, a Subsidiary that is a Participating Company in the Statutory Plan will not be a Participating Company in a Non-Statutory Plan. The foregoing designations and changes in designation by the Committee shall not require shareholder approval. Notwithstanding the foregoing, the term “Participating Company” shall not include any Subsidiary or Affiliate that offers its employees the opportunity to participate in an employee stock purchase plan covering such Subsidiary’s or Affiliate’s common stock.

2.13 “Plan” means this Microsoft Corporation 2003 Employee Stock Purchase Plan.

2.14 “Purchase Price” shall be the price per share of common stock of the Company as established pursuant to Section 5 hereof.

2.15 “Subsidiary” shall mean any corporation (other than the Company), domestic or foreign, that is in an unbroken chain of corporations beginning with Company if, on an Offering Date, each of the corporations other than the last corporation in the unbroken chain owns stock possessing 50% or more of the total combined voting power of all classes of stock in one of the other corporations in the chain, as described in Code section 424(f).

3. Employees Eligible to Participate. Any employee of a Participating Company who is in the employ of any Participating Company on the last business day preceding the Offering Date for an offering is eligible to participate in that offering, except employees whose customary employment is for not more than five months in any calendar year.

4

4. Offerings. Subject to the right of the Company in its sole discretion to sooner terminate the Plan or to change the commencement date or term of any offering, commencing July 1, 2004 the Plan will operate with separate consecutive three-month offerings with the following Offering Dates: July 1, October 1, January 1 and April 1. Unless a termination of or change to the Plan has previously been made by the Company, the final offering under this Plan shall commence on October 1, 2012 and terminate on December 31, 2012. In order to become eligible to purchase shares, an employee must complete and submit an Enrollment Agreement and any other necessary documents before the Offering Date of the particular offering in which she wishes to participate. Participation in one offering under the Plan shall neither limit, nor require, participation in any other offering.

5. Price. The Purchase Price per share shall be ninety percent (90%) of the Fair Market Value of the stock on the last regular business day of the offering.

6. Number of Shares to be Offered. The maximum number of shares that will be offered under the Plan is two hundred million (200,000,000) shares, subject to adjustment as permitted under Section 20. These two hundred million (200,000,000) shares include shares that were available but not used under the prior version of this Plan (i.e., the Microsoft Corporation 1997 Employee Stock Purchase Plan) as well as additional shares that were made available for issuance for the first time as part of the amendment and restatement of the Plan approved by the Board on August 22, 2002 and by the Shareholders on November 5, 2002. The shares to be sold to participants under the Plan will be common stock of the Company. If the total number of shares for which options are to be granted on any date in accordance with Section 12 exceeds the number of shares then available under the Plan or a given sub-plan (after deduction of all shares for which options have been exercised or are then outstanding), the Company shall make a pro rata allocation of the shares remaining available in as nearly a uniform manner as shall be practicable and as it shall determine to be equitable. In such event, the payroll deductions to be made pursuant to the authorizations therefor shall be reduced accordingly and the Company shall give written notice of such reduction to each employee affected thereby.

7. Participation.

7.1 An eligible employee may become a participant by completing an Enrollment Agreement provided by the Company and submitting it to the Company, or with such other entity designated by the Company for this purpose, prior to the commencement of the offering to which it relates. The Enrollment Agreement may be completed at any time after the employee becomes eligible to participate in the Plan, and will be effective as of the Offering Date next following the receipt of a properly completed Enrollment Agreement by the Company (or the Company’s designee for this purpose).

5

7.2 Payroll deductions for a participant shall commence on the Offering Date as described above and shall continue through subsequent offerings pursuant to Section 10 until the participant’s termination of employment, subject to modification by the employee as provided in Section 8.1 and unless participation is earlier withdrawn or suspended by the employee as provided in Section 9.

7.3 Payroll deduction shall be the sole means of accumulating funds in a participant’s Account, except in foreign countries where payroll deductions are not allowed, in which case the Company may authorize alternative payment methods.

7.4 The Company may require current participants to complete a new Enrollment Agreement at any time it deems necessary or desirable to facilitate Plan administration or for any other reason.

8. Payroll Deductions.

8.1 At the time an employee files his authorization for a payroll deduction, he shall elect to have deductions made from his Compensation on each payday during the time he is a participant in an offering at any non-fractional percentage rate from 1% to 15%. A participant may change his payroll deduction percentage election, including changing the payroll deduction percentage to zero, effective as of any Offering Date by filing a revised authorization, provided the revised authorization is filed prior to such Offering Date.

8.2 All payroll deductions made for a participant shall be credited to her Account under the Plan. A participant may not make any separate cash payment into such Account nor may payment for shares be made other than by payroll deduction, except as provided under Section 7.3 above.

8.3 A participant may withdraw from or suspend his participation in the Plan as provided in Section 9, but no other change can be made during an offering with respect to that offering. A participant may also make a prospective election, by changing his payroll deduction percentage to zero as set forth in Section 8.1, to cease participation in the Plan effective as of the next Offering Date. Other changes permitted under the Plan may only be made with respect to an offering that has not yet commenced.

9. Withdrawal and Suspension.

9.1 An employee may withdraw from an offering, in whole but not in part, at any time prior to the first day of the last calendar month of such offering by submitting a Withdrawal Notice to the Company, in which event the Company will refund the entire balance of her deductions as soon as practicable thereafter.

6

9.2 An employee may, at any time prior to the first day of the last calendar month of an offering, reduce to zero the percentage by which he has elected to have his Compensation reduced, thereby suspending participation in the Plan. Such reduction will be effective as soon as administratively feasible after receipt of the participant’s election. Shares shall be purchased in accordance with Section 13 based on the amounts accumulated in the participant’s Account prior to the suspension of payroll deductions.

9.3 If an employee withdraws or suspends her participation pursuant to Sections 9.1 or 9.2 above, she shall not participate in a subsequent offering unless and until she re-enters the Plan. To re-enter the Plan, an employee who has previously withdrawn or suspended participation by reducing payroll deductions to zero must file a new Enrollment Agreement in accordance with Section 7.1. The employee’s re-entry into the Plan will not become effective before the beginning of the next offering following her withdrawal or suspension, and if the employee is an officer of the Company within the meaning of Section 16 of the Securities Exchange Act of 1934, she may not re-enter the Plan before the beginning of the second offering following her withdrawal.

10. Automatic Re-Enrollment. At the termination of each offering each participating employee who continues to be eligible to participate pursuant to Section 3 shall be automatically re-enrolled in the next offering, unless the employee has advised the Company otherwise. Upon termination of the Plan, any balance in each employee’s Account shall be refunded to him.

11. Interest. No interest will be paid or allowed on any money in the Accounts of participating employees, except to the extent payment of interest on such amount is required by the laws of any applicable jurisdiction.

12. Granting of Option. On each Offering Date, this Plan shall be deemed to have granted to the participant an option for as many shares (which may include a fractional share) as she will be able to purchase with the amounts credited to her Account during her participation in that offering. Notwithstanding the foregoing, no participant may purchase more than 2,000 shares of stock during any single offering. This number may be adjusted as permitted pursuant to Section 20 of the Plan.

13. Exercise of Option. Each employee who continues to be a participant in an offering on the last business day of that offering shall be deemed to have exercised his option on such date and shall be deemed to have purchased from the Company such number of shares (which may include a fractional share) of common stock reserved for the purpose of the Plan as his accumulated payroll deductions on such date will pay for at the Purchase Price.

14. Tax Obligations. To the extent any (i) grant of an option to purchase shares hereunder, (ii) purchase of shares hereunder, or (iii) disposition of shares purchased hereunder gives rise to any tax withholding obligation (including, without

7

limitation, income and payroll withholding taxes imposed by any jurisdiction) the Committee may implement appropriate procedures to ensure that such tax withholding obligations are met. Such procedures may include, without limitation, increased withholding from an employee’s current compensation, cash payments to the Company or another Participating Company by an employee, or a sale of a portion of the stock purchased under the Plan, which sale may be required and initiated by the Company. Any such procedure, including offering choices among procedures, will be applied consistently with respect to all similarly situated employees participating in the Plan (or in an offering under the Plan), except to the extent any procedure may not be permitted under the laws of the applicable jurisdiction.

15. Employee’s Rights as a Shareholder. No participating employee shall have any right as a shareholder with respect to any shares until the shares have been purchased in accordance with Section 13 above and the stock has been issued by the Company.

16. Evidence of Stock Ownership.

16.1 Following the end of each offering, the number of shares of common stock purchased by each participant shall be deposited into an account established in the participant’s name at the ESPP Broker.

16.2 A participant shall be free to undertake a disposition (as that term is defined in Section 424(c) of the Code) of the shares in her account at any time, whether by sale, exchange, gift, or other transfer of legal title, but in the absence of such a disposition of the shares, the shares must remain in the participant’s account at the ESPP Broker until the holding period set forth in Section 423(a) of the Code has been satisfied. With respect to shares for which the Section 423(a) holding period has been satisfied, the participant may move those shares to another brokerage account of participant’s choosing or request that a stock certificate be issued and delivered to her.

16.3 Notwithstanding the above, a participant who is not subject to income taxation under the Code may move his shares to another brokerage account of his choosing or request that a stock certificate be issued and delivered to him at any time, without regard to the satisfaction of the Section 423(a) holding period.

17. Rights Not Transferable. No employee shall be permitted to sell, assign, transfer, pledge, or otherwise dispose of or encumber either the payroll deductions credited to her Account or an option or any rights with regard to the exercise of an option or rights to receive shares under the Plan other than by will or the laws of descent and distribution, and such right and interest shall not be liable for, or subject to, the debts, contracts, or liabilities of the employee. If any such action is taken by the employee, or any claim is asserted by any other party in respect of such right and interest whether by garnishment, levy, attachment or otherwise, such action or claim will be treated as an election to withdraw funds in accordance with Section 9. During the employee’s lifetime, only the employee can make decisions regarding the participation in or withdrawal from an offering under the Plan.

8

18. Termination of Employment. Upon termination of employment for any reason whatsoever, including but not limited to death or retirement, the balance in the Account of a participating employee shall be paid to the employee or his estate. Whether and when employment shall be deemed terminated for purposes of this Plan shall be determined by the Committee in its sole discretion and may be determined without regard to statutory notice periods or other periods following termination of active employment.

19. Amendment or Discontinuance of the Plan. The Committee shall have the right at any time and without notice to amend or modify the Plan except to the extent the Board has reserved such authority to itself with respect to any aspect of the Plan, and the Board shall have the right at any time and without notice to amend, modify or terminate the Plan; provided, that no employee’s existing rights under any offering already made under Section 4 hereof may be adversely affected thereby, and provided further that no such amendment of the Plan shall, except as provided in Section 20, increase above two hundred million (200,000,000) shares the total number of shares to be offered unless shareholder approval is obtained therefor.

20. Changes in Capitalization. In the event of reorganization, recapitalization, stock split, stock dividend, combination of shares, merger, consolidation, offerings of rights, or any other change in the structure of the common shares of the Company, the Committee may make such adjustment, if any, as it may deem appropriate in the number, kind, and the price of shares available for purchase under the Plan, and in the number of shares which an employee is entitled to purchase including, without limitation, closing an offering early and permitting purchase on the last business day of such reduced offering period, or terminating an offering and refunding participants’ Account balances.

21. Share Ownership. Notwithstanding anything herein to the contrary, no employee shall be permitted to subscribe for any shares under the Plan if such employee, immediately after such subscription, owns shares (including all shares which may be purchased under outstanding subscriptions under the Plan) possessing 5% or more of the total combined voting power or value of all classes of shares of the Company or of its parent or subsidiary corporations. For the foregoing purposes the rules of Section 424(d) of the Code shall apply in determining share ownership, and shares which the employee may purchase under outstanding options shall be treated as owned by the employee. In addition, no employee shall be allowed to subscribe for any shares under the Plan which permits his rights to purchase shares under all “employee stock purchase plans” of the Company and its parent or subsidiary corporations to accrue at a rate which exceeds $25,000 of Fair Market Value of such shares (determined at the time such right to subscribe is granted) for each calendar year in which such right to subscribe is outstanding at any time. Notwithstanding the above, lower limitations may be imposed with respect to participants in a Non-Statutory Plan or participants in the Statutory Plan who are subject to laws of a foreign jurisdiction where lower limitations are required.

9

22. Administration and Board Authority.

22.1 The Plan shall be administered by the Board. The Board may delegate any or all of its authority and obligations under this Plan to such committee or committees (including without limitation, a committee of the Board) or officer(s) of the Company as it may designate. Notwithstanding any such delegation of authority, the Board may itself take any action under the Plan in its discretion at any time, and any reference in this Plan document to the rights and obligations of the Committee shall be construed to apply equally to the Board. Any references to the Board mean only the Board. The authority that may be delegated by the Board includes, without limitation, the authority to (i) establish Non-Statutory Plans and determine the terms of such sub-plans, (ii) designate from time to time which Subsidiaries will participate in the Statutory Plan, which Subsidiaries and Affiliates will be Participating Companies, and which Participating Companies will participate in a particular Non-Statutory Plan, (iii) determine procedures for eligible employees to enroll in or withdraw from a sub-plan, setting or changing payroll deduction percentages, and obtaining necessary tax withholdings, (iv) allocate the available shares under the Plan to the sub-plans for particular offerings, and (v) adopt amendments to the Plan or any sub-plan including, without limitation, amendments to increase the shares available for issuance under the Plan pursuant to Section 20 (but not including increases in the available shares above the maximum permitted by Sections 6 and 20 which shall require Board and shareholder approval).

22.2 The Committee shall be vested with full authority and discretion to construe the terms of the Plan and make factual determinations under the Plan, and to make, administer, and interpret such rules and regulations as it deems necessary to administer the Plan, and any determination, decision, or action of the Committee in connection with the construction, interpretation, administration, or application of the Plan shall be final, conclusive, and binding upon all participants and any and all persons claiming under or through any participant. The Committee may retain outside entities and professionals to assist in the administration of the Plan including, without limitation, a vendor or vendors to perform enrollment and brokerage services. The authority of the Committee will specifically include, without limitation, the power to make any changes to the Plan with respect to the participation of employees of any Subsidiary or Affiliate that is organized under the laws of a country other than the United States of America when the Committee deems such changes to be necessary or appropriate to achieve a desired tax treatment in such foreign jurisdiction or to comply with the laws applicable to such non-U.S. Subsidiaries or Affiliates. Such changes may include, without limitation, the exclusion of particular Subsidiaries or Affiliates from participation in the plan; modifications to eligibility criteria, maximum number or value of shares that may be purchased in a given period, or other requirements set forth herein; and procedural or administrative modifications. Any modification relating to offerings to a particular Participating Company will apply only to such Participating Company, and

10

will apply equally to all similarly situated employees of such Participating Company. The rights and privileges of all employees granted options under the Statutory Plan shall be the same. To the extent any changes approved by the Committee would jeopardize the tax-qualified status of the Statutory Plan, such change shall cause the Participating Companies affected thereby to be considered to be Participating Companies under a Non-Statutory Plan or Non-Statutory Plans instead of the Statutory Plan.

23. Notices. All notices or other communications by a participant to the Company or other entity designated for a particular purpose under or in connection with the Plan shall be deemed to have been duly given when received by the Company or other designated entity, or when received in the form specified by the Company at the location, or by the person, designated by the Company for the receipt thereof.

24. Termination of the Plan. This Plan shall terminate at the earliest of the following:

24.1 December 31, 2012;

24.2 The date of the filing of a Statement of Intent to Dissolve by the Company or the effective date of a merger or consolidation wherein the Company is not to be the surviving corporation, which merger or consolidation is not between or among corporations related to the Company. Prior to the occurrence of either of such events, on such date as the Company may determine, the Company may permit a participating employee to exercise the option to purchase shares for as many shares as the balance of her Account will allow at the price set forth in accordance with Section 5. If the employee elects to purchase shares, any remaining balance of her Account will be refunded to her after such purchase.

24.3 The date the Board acts to terminate the Plan in accordance with Section 19 above.

24.4 The date when all shares reserved under the Plan have been purchased.

25. Limitations on Sale of Stock Purchased Under the Plan. The Plan is intended to provide common stock for investment and not for resale. The Company does not, however, intend to restrict or influence any employee in the conduct of his own affairs. An employee, therefore, may sell stock purchased under the Plan at any time he chooses, subject to compliance with any applicable Federal, state or foreign securities laws. THE EMPLOYEE ASSUMES THE RISK OF ANY MARKET FLUCTUATIONS IN THE PRICE OF THE STOCK.

26. Governmental Regulation. The Company’s obligation to sell and deliver shares of the Company’s common stock under this Plan is subject to the approval of any governmental authority required in connection with the authorization, issuance, or sale of such shares.

11

27. No Employment/Service Rights. Nothing in the Plan shall confer upon any employee the right to continue in employment for any period of specific duration, nor interfere with or otherwise restrict in any way the rights of the Company (or any Subsidiary or Affiliate employing such person), or of any employee, which rights are hereby expressly reserved by each, to terminate such person’s employment at any time for any reason, with or without cause.

28. Dates and Times. All references in the Plan to a date or time are intended to refer to dates and times determined pursuant to U.S. Pacific Time. Business days for purposes of the Plan are U.S. business days.

29. Masculine and Feminine, Singular and Plural. Whenever used herein, a pronoun shall include the opposite gender and the singular shall include the plural, and the plural shall include the singular, whenever the context shall plainly so require.

* All share numbers in the Plan reflect the 2-for-1 stock split effected February 2003.

12

EX-10.7 5 dex107.htm 1998 STOCK OPTION GAIN AND BONUS DEFERRAL PROGRAM
1998 Stock Option Gain and Bonus Deferral Program

Exhibit 10.7

1998 MICROSOFT CORPORATION

STOCK OPTION GAIN AND BONUS DEFERRAL PROGRAM

1. Purpose.

The purpose of this 1998 Microsoft Corporation Stock Option Gain and Bonus Deferral Program is to further the long-term growth of Microsoft Corporation by allowing selected Microsoft Corporation executives to defer the payment of cash bonuses and the issuance of stock equal to the gain realized upon the exercise of stock options in order to keep their financial interests aligned with Microsoft and provide them with a long-term incentive to continue employment with Microsoft.

2. Effective Date.

This Program is established effective November 18, 1998.

3. Definitions.

3.1 Account or Accounts means the account(s) established for a Participant pursuant to Section 8, consisting of a Deferred Bonus Account and/or a Deferred Stock Option Gain Account. Accounts shall be maintained solely as bookkeeping entries by the Company to evidence unfunded, unsecured obligations of the Company.

3.2 Board means the Board of Directors of Microsoft Corporation.

3.3 Bonus means the amount payable by the Company to an Eligible Executive as an individual performance bonus, executive bonus or any other bonus/incentive award that is approved by the Program Administrator for deferral under the Program.

3.4 Claimant means a Participant (or in the case of the Participant’s death, the personal representative of his estate) who makes a written application to the Program

1

Administrator for benefits that he believes are due under the Program. For purposes of determining the proper death beneficiary under this Program, this Program shall not be interpreted as preempting applicable state law regarding the ownership rights of Accounts upon the Participant’s death. For example, although this Program states that upon a Participant’s death, Account balances will be paid to his estate, the personal representative will be obligated to pay any benefits owed to a spouse or otherwise as a result of any applicable community property laws.

3.5 Code means the Internal Revenue Code of 1986, as amended.

3.6 Company means Microsoft Corporation.

3.7 Deferral Election means an election to defer (i) issuance of the shares of Stock equal to the Stock Option Gain realized upon the exercise of an Option or (ii) receipt of part or all of a Bonus.

3.8 Deferral Period means with respect to a specific deferral of a Bonus or Stock Option Gain, the period of five (5), seven (7), or ten (10) years from the date on which the corresponding Bonus would otherwise have been paid or the date the Option was scheduled to expire had it not been exercised; provided that in the event of the Participant’s Termination of Employment the Deferral Period shall end on the date of Termination of Employment.

3.9 Deferred Bonus Account means a bookkeeping account established pursuant to Section 8.1 for Bonuses that are subject to a Participant’s Deferral Election.

3.10 Deferred Stock Option Gain Account means a bookkeeping account established pursuant to Section 8.2 for Stock Option Gains deferred under this Program.

3.11 Disability means any long-term disability as defined under the Company’s long-term disability plan. The Program Administrator, in its complete and sole discretion, shall

2

determine a Participant’s Disability. The Program Administrator may require that the Participant submit to an examination on an annual basis, at the expense of the Company, by a competent physician or medical clinic selected by the Program Administrator to assist in the determination of Disability. On the basis of such medical evidence, the determination of the Program Administrator as to whether or not a condition of Disability exists or continues shall be conclusive.

3.12 Election Form means the form specified by the Program Administrator on which a Participant makes a Deferral Election.

3.13 Eligible Executive means a full-time employee of the Company who is (i) an elected officer of the Company, (ii) at the level of Vice President or above, (iii) at Level 80 or above on the Company’s salary range, and (iv) working within the United States of America. In addition, the Compensation Committee of the Board may, in its discretion, extend coverage to persons who are selected by the Committee and who either (x) meet all of the foregoing requirements except that they are working outside of the United States of America, (y) meet all of the foregoing requirements except that they are full-time employees of a subsidiary of the Company, or (z) are officers of a subsidiary of the Company.

3.14 ERISA means the Employee Retirement Income Security Act of 1974, as amended.

3.15 Exercise means an election to exercise an Option.

3.16 Mature Shares means shares of the Company’s Stock delivered by a Participant in payment of the Exercise price of an Option; provided that Mature Shares shall not include any shares of the Company’s Stock that may be received upon exercise of such Option, nor Stock that the Participant purchased pursuant to a prior stock option exercise which occurred less than six months prior to the exercise of such Option.

3

3.17 Fair Market Value of the Stock as of a particular date means the closing price of the Stock as reported on NASDAQ on such date.

3.18 Option shall mean one or more non-qualified stock options, issued to a Participant under any stock option plan of the Company, with respect to which the Participant has elected to defer the Stock Option Gain. Option shall not include any rights under the Company’s Employee Stock Purchase Plan

3.19 Participant means an Eligible Executive who has elected to participate in the Program and has made a Deferral Election.

3.20 Program means this 1998 Microsoft Corporation Stock Option Gain and Bonus Deferral Program, as amended from time to time.

3.21 Program Administrator means the Compensation Committee of the Board, or its delegate or delegates appointed to administer the Program.

3.22 Program Year means the 12-month period from January 1 to December 31, provided that the initial Program Year shall be a short Program Year that begins on the Effective Date and ends on December 31, 1998.

3.23 Stock means Microsoft Corporation common stock.

3.24 Stock Option Gain means the number of shares underlying an Option minus the number of Mature Shares required to pay the Exercise price for those shares. For example, if a Participant elects to defer the gain on 100 shares and is required to deliver 10 shares of Stock as payment for the Exercise price on the 100 shares, the Stock Option Gain will be 90 shares.

4

3.25 Termination of Employment means the termination of the Participant’s employment relationship with the Company for any reason including, without limitation, involuntary termination with or without cause, voluntary termination, disability, death, or retirement.

4. Participation.

Each Eligible Executive becomes an active Participant on the date he first submits an Election Form pursuant to Section 5 or 6. An individual’s eligibility to make additional deferrals under Section 5 or 6 shall cease upon the date he ceases to be an Eligible Executive. In the event an Eligible Executive ceases to be an Eligible Executive (but does not incur a Termination of Employment) between the date a Deferral Election is made and the date (i) a Bonus is scheduled to be paid (absent the deferral) or (ii) an Option is exercised, the Bonus will be deferred and the Option will be exercisable and the gain deferred pursuant to the Participant’s prior Deferral Election. An individual who has been an active Participant under the Program will cease to be a Participant on the date his Accounts are fully paid out.

5. Bonus Deferral Election.

5.1 Manner. Each Eligible Executive may make an election to defer under the Program any percentage (in 10% increments up to 100%) of his Bonus by submitting a valid Election Form to the Program Administrator. To be effective, an Eligible Executive’s Election Form for a Bonus deferral must set forth the percentage of his Bonus to be deferred (in 10% increments), the investment choice under Section 8.1 (in 1% increments ), the Deferral Period, and any other information that may be requested by the Program Administrator from time to time. A Participant is not required to defer all Bonuses expected to be paid in any given year.

5

5.2 Timing. Subject to the next two sentences, an Eligible Executive must make a Deferral Election with respect to his Bonus in the calendar year prior, and at least six (6) months prior, to the date on which the Bonus would otherwise be paid. A new hire who is an Eligible Executive may make a Deferral Election with respect to his Bonus to be paid during the current calendar year so long as the Deferral Election is made either before his date of hire or within thirty (30) days after his date of hire, and is made before the Bonus is earned. The Program Administrator may establish limited Deferral Election periods during which Eligible Executives must make Deferral Elections.

6. Stock Deferral Election.

6.1 Manner. Each Eligible Executive may make an election to defer under the Program the Stock Option Gain on 100% of the shares underlying an Option or on a portion of the shares underlying the Option (in 10,000 share increments) that would otherwise be recognized upon exercise of an Option, by submitting a valid Election Form to the Program Administrator. To be effective, an Eligible Executive’s Election Form for a deferral of a Stock Option Gain must set forth the specific Option and number of shares on which the gain will be deferred the Deferral Period, and any other information that may be requested by the Program Administrator from time to time.

6.2 Timing. An Eligible Executive must make a Deferral Election with respect to an Option (i) at least six (6) months prior to the date such Option will be exercised, and (ii) prior to the calendar year in which such Option will be exercised. The Program Administrator may establish limited Deferral Election periods during which Eligible Executives must make Deferral Elections. Deferred Options may only be exercised within the last two months prior to the date the term of the Option is scheduled to expire. Notwithstanding anything in this Program to the

6

contrary, in the event a Participant’s Option is expected to expire prior to its stated term (e.g., due to the termination of the Participant’s continuous status as an employee), the Deferred Options must be exercised during the two month period ending on the date the Option is expected to expire.

7. General Provisions Relating to Bonus and Stock Deferral Elections.

7.1 Separate Elections. A separate Deferral Election must be made by an Eligible Executive for each Bonus or Stock Option Gain deferral. If an Eligible Executive fails to file a properly completed and executed Election Form with the Program Administrator by the prescribed time, he will be deemed to have elected not to defer any Bonus or Stock Option Gain for the applicable Program Year.

7.2 Irrevocability of Elections. An election is irrevocable once received and determined by the Program Administrator to be properly completed. After the Program Administrator makes such determination, the Participant shall not be allowed to cancel the election nor increase or decrease the amount or percentage a Participant elects to defer.

7.3 Deferral Period. An Eligible Executive making a Deferral Election shall specify a Deferral Period of five (5), seven (7) or ten (10) years on his Election Form. On a one-time basis with respect to each deferral, a Participant may elect in writing to extend the Deferral Period for a Bonus or Stock Option Gain for an additional five (5), seven (7), or ten (10) years, provided that such extension is elected in the calendar year prior, and at least six (6) months prior, to the expiration of the initial Deferral Period and the Participant is an Eligible Executive at the time he makes the election to extend the Deferral Period.

8. Accounts.

8.1 Deferred Bonus Account.

7

(a) Any amount of Bonus deferred by an Eligible Executive for a Program Year will be deducted from the amount of his Bonus under the applicable compensation program at the time the Bonus would otherwise be paid and the amount deferred will be credited to the Participant’s Deferred Bonus Account. A Participant’s Deferred Bonus Account is a bookkeeping device to track the value of his deferrals (and the Company’s liability therefor). No assets shall be reserved or segregated in connection with any Deferred Bonus Account, and no Deferred Bonus Account shall be insured or otherwise secured. The Participant’s share of FICA and FUTA taxes owed on the deferred Bonus amount shall be deducted from the Participant’s salary or other cash compensation received on or about the date the deferred Bonus would otherwise have been paid. To the extent the Participant is not owed salary or other cash compensation sufficient to pay such taxes, the Participant must submit to the Company, a cash payment (by way of check, wire transfer, or otherwise) for the remaining amount of the Participant’s share of FICA and FUTA taxes owed on the deferred Bonus amount. In addition, a Participant may elect to pay the Company for the full amount of the Participant’s share of such employment taxes and avoid any reduction in his salary or other cash compensation. The Participant’s Deferred Bonus Account will not be credited with the deferred Bonus until the Company has received, through payroll withholding or directly from the Participant, the full amount of the Participant’s share of the employment taxes. Deemed investment earnings will not be credited for periods of time before the Bonus is credited to the Participant’s Deferred Bonus Account. In the event the Company does not receive the full amount of the Participant’s share of the employment taxes by the end of the calendar year in which the Bonus was otherwise to be paid, the Participant shall forfeit the Bonus and any obligation of the Company to pay the Bonus shall terminate.

8

(b) The Program Administrator shall specify two or more investment funds that shall serve as benchmarks for the investment performance of amounts credited to the Deferred Bonus Account. The Deferred Bonus Account shall be adjusted to reflect the gain or loss, net of any allocable costs or expenses, such account would experience had it actually been invested in the specified funds at the relevant times. The Deferred Bonus Account shall not be reduced for income or capital gains taxes the Company would have to pay on the investment income and gains it would earn if it invested the Deferred Bonus Account in the applicable investment funds. The Program Administrator may change the available investment funds from time to time, but not more frequently than quarterly. A Participant may select his investment options for his Deferred Bonus Account at such times and using such form or forms as the Program Administrator may specify. The investment options that the Participant selects will apply to his entire Deferral Bonus Account. The Company is not obligated to actually invest any assets in the investment funds selected by the Participant.

(c) The amount in a Participant’s Deferred Bonus Account shall be adjusted for gain or loss on the last day of each month (or more frequently, at the Program Administrator’s discretion) based on the performance of the investment options selected by the Participant in accordance with this Section 8.1.

(d) As of each December 31, the Program Administrator shall prepare and deliver to each Participant a statement listing the amount credited to his Deferred Bonus Account as of the close of business on December 31.

(e) A Participant’s interest in the value of his Deferred Bonus Account shall at all times be 100 percent vested, which means that it will not forfeit as a result of his Termination of Employment.

9

8.2 Deferred Stock Option Gain Account.

(a) A Participant must Exercise an Option during the two-month period that ends on the date the Option was scheduled to expire. On the date of Exercise, the Participant must deliver the Mature Shares to the Company in payment of the Exercise price. In addition, the Participant must deliver to the Company cash equal to the Participant’s share of the FICA and FUTA taxes owed with respect to such Exercise. An option exercise is not effective until the Company has received the required FICA and FUTA taxes from the Participant. Within thirty (30) days of Exercise, the Company will issue to the Participant a number of new shares equal to the number of Mature Shares and will credit the Stock Option Gain to the Participant’s Deferred Stock Option Gain Account.

(b) If a Participant fails to exercise an Option during the two-month period ending on the scheduled expiration date of the Option’s term, as required by Section 8.2(a) above, his Option will expire.

(c) A Participant’s Deferred Stock Option Gain Account is a bookkeeping device to track the value of his deferrals (and the Company’s liability therefor). No assets shall be reserved or segregated in connection with any Deferred Stock Option Gain Account, and no Deferred Stock Option Gain Account shall be insured or otherwise secured. The Deferred Stock Option Gain Account represents an unfunded obligation of the Company to issue to the Participant shares of Stock at the end of the Deferral Period. Although the shares of Stock will not be issued until the end of the Deferral Period as described in Section 9.1, the Company’s obligation to issue shares in the future shall be accounted for by denominating the obligation to each Participant in shares of Stock. Since the shares are not issued until the end of the Deferral Period, there are no voting or other shareholder rights associated with shares credited to the

10

Deferred Stock Option Gain Account; provided, however, that the amount of cash and stock dividends and stock splits declared from time to time on the Stock shall be credited to the Deferred Stock Option Gain Account as if the shares were issued at such time (and the amount of any cash dividend shall be deemed to have been reinvested on such date in additional Stock).

(d) If a Participant has not made a Deferral Election with respect to all options that were granted on the same date, and if he is not exercising all options available under said grant, then at the time of exercise the Participant shall identify which options are being exercised, deferred Options, options that were not deferred, or a combination of the two.

(e) As of each December 31, the Program Administrator shall provide each Participant with a statement setting forth the number of shares credited to the Participant’s Deferred Stock Option Gain Account, the value of such shares at the time originally credited to the Deferred Stock Option Gain Account based on the Fair Market Value on the date the shares were credited to the Deferred Stock Option Gain Account, and the value of such shares on such December 31 based on the Fair Market Value of Stock as of the close of business on such December 31.

(f) The Participant’s right to the value of his Deferred Stock Option Gain Account, as adjusted for gains and losses, shall be 100 percent vested at all times.

9. Distribution.

9.1 Timing. As soon as practicable following the final day of the Deferral Period for a specific deferral, the Company will distribute to the Participant (or in the case of the Participant’s death, his estate), all proceeds in the Participant’s Deferred Bonus Account and will issue to the Participant (or in the event of the Participant’s death, the personal representative or beneficiaries of his estate) shares of Stock credited to the Participant’s Deferred Stock Option

11

Gain Account, that are attributed to that deferral. With respect to a specific deferral, the final day of the Deferral Period shall be the earliest of the last day of the Deferral Period selected by the Participant in accordance with Section 7.3 or the date he has a Termination of Employment. Upon Termination of Employment, a Participant will have the same rights with respect to an unexercised Option that he would have if he had not elected to defer the Stock Option Gain relating to that Option. The portion of a Participant’s Accounts that can be attributed to a specific deferral shall be determined in the sole discretion of the Program Administrator.

9.2 Disability. In the event of a Participant’s Disability and upon application by such Participant, the Program Administrator may determine that payment of all, or part, of such Participant’s Accounts shall be made in a different manner, or on an earlier date than the time or times specified in Section 9.1 above, but only to the extent determined by the Program Administrator to be reasonably required to satisfy the Participant’s need.

10. Conditions Related to Benefits.

10.1 Nonalienation of Benefits. This Program inures to the benefit of and is binding upon the parties hereto and their successors, heirs and assigns; provided, however, that the amounts credited to the Accounts of a Participant are not, except as provided in Section 10.2, subject in any manner to anticipation, alienation, sale, transfer, assignment, pledge, encumbrance, charge, garnishment, execution or levy of any kind, either voluntary or involuntary, and any attempt to anticipate, alienate, sell, transfer, assign, pledge, encumber, charge or otherwise dispose of any right to any benefits payable hereunder, including, without limitation, any assignment or alienation in connection with a separation, divorce, child support or similar arrangement, will be null and void and not binding on the Program or the Company.

12

10.2 Withholding Taxes. If the whole or any part of any Participant’s Accounts becomes liable for the payment of any estate, inheritance, income, or other tax that the Company may be required to pay or withhold, the Company will have the full power and authority to withhold and pay such tax out of any moneys or other property in its hand for the account of the Participant. The Company will provide the Participant notice of such withholding. Prior to making any payment, the Company may require such releases or other documents from any lawful taxing authority as it shall deem necessary. Any payment of benefits under Section 9 shall be net of any amounts the Company is required to withhold and remit as payment for taxes on behalf of the Participant.

10.3 Participant’s Unsecured Rights. The benefits provided by this Program are unfunded. All benefits payable under this Program to Participants are paid either from the general assets of the Company or in newly issued shares of Stock. Nothing contained in this Program requires the Company to set aside or hold in trust any amounts or assets for the purpose of paying benefits to Participants. This Program creates only a contractual obligation on the part of the Company to pay the value of the Deferred Bonus Account and issue the shares of Stock equal to the amount credited to the Deferred Stock Option Gain Account. The Participant shall be no more than a general unsecured creditor of the Company with no special or prior right to any assets of the Company for payment of any obligations hereunder.

10.4 Participant’s Cooperation. The Participant shall cooperate with the Company by furnishing any and all information requested by the Program Administrator in order to facilitate the payment of benefits hereunder, taking such physical examinations as the Program Administrator may deem necessary and taking such other actions as may be requested by the Program Administrator. If the Participant refuses to cooperate, the Company shall have no further obligation to the Participant under the Program.

13

11. Administration of Program.

The Program Administrator shall administer the Program and shall have full discretionary authority to interpret, construe and apply its provisions and to make determinations as to an Eligible Executive’s right to participate in the Program and the timing and amount of benefits, if any, owed to the Participant (or in the case of the Participant’s death, his estate). The Program Administrator shall further establish, adopt or revise such rules and regulations as it may deem necessary or advisable for the administration of the Program. Subject to the appeal procedure set forth in Section 14.2 below, all decisions of the Program Administrator shall be final and binding on all parties. The Program Administrator (including any individual members thereof) shall, except as prohibited by law, be indemnified and held harmless by the Company from any and all liabilities, costs, and expenses (including legal fees), to the extent not covered by liability insurance, arising out of any action taken by the Program Administrator (including any individual members thereof) with respect to the Program, unless such liability arises from the individual’s own gross negligence or willful misconduct.

12. Amendment or Termination of the Program.

12.1 Amendment of Program. The Company may at any time amend the Program in whole or in part, provided, however, that such amendment shall not decrease the amount credited to the Participant’s Accounts at the time of such amendment.

12.2 Termination of Program. The Company may at any time terminate the Program. If the Company terminates the Program, the date of such termination shall be treated as each Participant’s date of Termination of Employment for the purpose of calculating Program

14

benefits, and the Company shall pay to the Participant in a cash lump sum the amount credited to the Participant’s Deferred Bonus Account and shall issue to the Participant shares of Stock credited to the Participant’s Deferred Stock Option Gain Account as of the date of Program termination (subject to applicable withholding of taxes pursuant to Section 10).

12.3 Constructive Receipt Termination. In the event the Program Administrator determines that amounts deferred under the Program with respect to a specific deferral have been constructively received by Participants and must be recognized as income for federal income tax purposes prior to the scheduled distribution of such amounts, the Program shall terminate with respect to such deferral and distributions shall be made to Participants of the Bonuses and Stock Option Gains (less applicable tax withholding) related to that deferral as determined by the Program Administrator. The determination of the Program Administrator under this Section shall be binding and conclusive on all parties.

12.4 Board Action. Amendment or termination of the Program shall be made by action of either the Board or the Compensation Committee of the Board.

13. Limitation of Rights.

13.1 No Right to Bonuses or Stock Options. Nothing in this Program shall be construed to give any Eligible Executive any right to be granted a bonus award or any stock options.

13.2 No Right to Continued Employment. Neither the Program nor a Participant’s deferral of any Bonus or Stock Option Gain, nor any other action taken pursuant to the Program, shall constitute, or be evidence of, any agreement or understanding, express or implied, that the Company or any of its subsidiaries or affiliates will employ any employee (including, without limitation, a Participant) for any period of time, in any position or at any particular rate of compensation. The Company reserves the right to terminate any employee’s employment at any time for any reason, except as otherwise expressly provided in a written employment agreement between the employee and the Company.

15

14. Claims Procedure.

14.1 Claims for Benefits. The Program Administrator shall notify a Claimant in writing, within ninety (90) days after it receives his written application for benefits, of his eligibility or noneligibility for benefits under the Program. If the Program Administrator determines that a Claimant is not eligible for benefits or full benefits, the notice shall set forth: (i) the specific reasons for such denial; (ii) a specific reference to the provisions of the Program on which the denial is based; (iii) a description of any additional information or material necessary for the Claimant to perfect his claim, and a description of why it is needed; and (iv) an explanation of the Program’s claims review procedure and other appropriate information as to the steps to be taken if the Claimant wishes to have the claim reviewed. If the Program Administrator determines that there are special circumstances requiring additional time to make a decision, the Program Administrator shall notify the Claimant of the special circumstances and the date by which a decision is expected to be made, and may extend the time of the initial review for up to an additional ninety-day period.

14.2 Appeals. If a Claimant is determined by the Program Administrator not to be eligible for benefits, or if the Claimant believes that he is entitled to greater or different benefits, the Claimant shall have the opportunity to have such claim reviewed by the Board by filing a petition for review with the Board within sixty (60) days after receipt of the notice issued by the Program Administrator. Said petition shall state the specific reasons that the Claimant believes entitle him to benefits or to greater or different benefits. Within sixty (60) days after receipt by

16

the Board of the petition, the Board shall afford the Claimant (and counsel, if any) an opportunity to present his position to the Board orally or in writing, and the Claimant (or counsel) shall have the right to review the pertinent documents. The Board shall notify the Claimant of its decision in writing within the sixty-day period. Such notice shall be written in a manner calculated to be understood by the Claimant, and shall state specifically the basis of the Board’s decision and the specific provisions of the Program on which the decision is based. If, because of the need for a hearing, the sixty-day period is not sufficient, the Board may defer its decision for up to another sixty-day period at the election of the Board, but notice of this deferral shall be given to the Claimant. The Board’s decision on appeal shall be final, binding and conclusive on all parties.

15. Miscellaneous.

15.1 ERISA Program. The Program is intended to be an unfunded program maintained primarily to provide deferred compensation benefits for “a select group of management or highly compensated employees” within the meaning of Sections 201, 301 and 401 of ERISA and therefore to be exempt from Parts 2, 3 and 4 of Title I of ERISA.

15.2 Gender, Singular and Plural. All pronouns and variations thereof shall be deemed to refer to the masculine, feminine, or neuter, as the identity of the person or persons may require. As the context may require, the singular may be read as the plural and the plural as the singular.

15.3 Captions. The captions of the sections and subsections of the Program are for convenience only and shall not control or affect the meaning or construction of any of its provisions.

15.4 Validity. If any provision of the Program is held invalid, void or unenforceable, the same shall not affect, in any respect whatsoever, the validity of any other provisions of the Program.

17

15.5 Waiver of Breach. The waiver by the Company of any breach of any provision of the Program by the Participant shall not operate or be construed as a waiver of any subsequent breach by the Participant.

15.6 Notice. Any notice or filing required or permitted to be given to the Program Administrator under the Program shall be sufficient if in writing and hand-delivered, or sent by first class mail to the principal office of the Company, directed to the attention of the Program Administrator. Such notice shall be deemed given as of the date of delivery, or, if delivery is made by mail, as of the date shown on the postmark.

16. Legally Binding.

In the event of any consolidation, merger, acquisition or reorganization, the obligations of the Company under this Program shall continue and be binding on the Company and its successors or assigns. The rights, privileges, benefits and obligations under the Program are intended to be legal obligations of the Company and binding upon the Company, its successors and assigns.

17. Other Benefits.

Nothing in this Program shall diminish or impair the Participant’s eligibility, participation or benefit entitlement under any qualified retirement plan for employees of the Company, or any other benefit, insurance or compensation plan or agreement of the Company now or hereinafter in effect. Notwithstanding the foregoing, benefits paid under this Program shall not be considered as salary, wages or other compensation for purposes of calculating the amount of benefits payable under any other benefit plan, program or arrangement sponsored by the Company, its subsidiaries or affiliates including, without limitation, any life, disability or severance benefits.

18

18. Venue and Governing Law.

In the event the Company or any Participant or (or in the case of the Participant’s death, his estate) initiates litigation related to this Program, it is agreed and understood that venue for such action will be in King County, Washington. It is further agreed and understood that this Program shall be governed by and construed under the laws of the State of Washington, or federal law to the extent it preempts Washington law.

19. Attorneys Fees and Costs.

In the event that a dispute regarding benefits arises between the Company or Program Administrator and Participants (or in the case of the Participant’s death, his estate) and such dispute is resolved through arbitration or litigation in court, the prevailing party(ies) shall be entitled to their reasonable attorneys’ fees and costs incurred in such action.

19

EX-10.8 6 dex108.htm FORM OF STOCK AWARD AGREEMENT
Form of Stock Award Agreement

Exhibit 10.8

STOCK AWARD AGREEMENT UNDER

THE MICROSOFT CORPORATION 2001 STOCK PLAN

Award Number <<GrantIdentifier>>

1. Award of Stock Awards. Microsoft Corporation (hereinafter the “Company”), in the exercise of its sole discretion pursuant to the Microsoft Corporation 2001 Stock Plan (the “Plan”), does on <<GrantDate>> (the “Award Date”) hereby award to <<FullName>> (the “Awardee”) <<SharesGrantedQuantity>> Stock Awards (“SAs”) upon the terms and subject to the conditions hereinafter contained. Capitalized terms used but not defined herein shall have the meanings assigned to them in the Plan. SAs represent the Company’s unfunded and unsecured promise to issue Common Shares at a future date, subject to the terms of this Award Agreement and the Plan. Awardee has no rights under the SAs other than the rights of a general unsecured creditor of the Company.

2. Vesting Schedule and Conversion of SAs.

(a) Subject to the terms of this Award Agreement and the Plan and provided that Awardee remains continuously employed throughout the vesting periods set out below, the SAs shall vest and be converted into an equivalent number of Common Shares that will be distributed to the Awardee as follows; provided that fractional SAs shall be converted into Common Shares as set out in Section 8(c) of this Award Agreement:

Vesting Date |  | Percentage of SAs
One (1) year from the Award Date |  | 20%
Two (2) years from the Award Date |  | 20%
Three (3) years from the Award Date |  | 20%
Four (4) years from the Award Date |  | 20%
Five (5) years from the Award Date |  | 20%

(b) THE AWARDEE’S RIGHTS IN THE SAs SHALL BE AFFECTED, WITH REGARD TO BOTH VESTING SCHEDULE AND TERMINATION, BY LEAVES OF ABSENCE, CHANGES IN THE NUMBER OF HOURS WORKED, PARTIAL DISABILITY, AND OTHER CHANGES IN AWARDEE’S EMPLOYMENT STATUS AS PROVIDED IN THE COMPANY’S CURRENT POLICIES IN SUCH MATTERS. ACCOMPANYING THIS AWARD AGREEMENT IS A CURRENT COPY OF THE COMPANY’S POLICIES IN SUCH MATTERS. THESE POLICIES MAY CHANGE FROM TIME TO TIME WITHOUT NOTICE IN THE COMPANY’S SOLE DISCRETION, AND AWARDEE’S RIGHTS WILL BE GOVERNED BY THE POLICIES IN EFFECT AT THE TIME OF ANY EMPLOYMENT STATUS CHANGE. CONTACT “STOCK” FOR A COPY OF THE MOST CURRENT POLICY STATEMENT AT ANY POINT IN TIME.

3. Termination. Unless terminated earlier under Section 4, 5, or 6 below, an Awardee’s rights under this Award Agreement with respect to the SAs issued under this Award Agreement shall terminate at the time such SAs are converted into Common Shares.

4. Termination of Awardee’s Status as a Participant. Except as otherwise specified in Section 5 and 6 below, in the event of termination of Awardee’s Continuous Status as a Participant (as such term is defined in Section 2(j) of the Plan), Awardee’s rights under this Award Agreement in any unvested SAs shall terminate. For the avoidance of doubt, an Awardee’s Continuous Status as a Participant terminates at the time the Awardee’s actual employer ceases to be the Company or a “Subsidiary” of the Company, as that term is defined in Section 2(z) of the Plan, and as further described in Section 10(g) of this Award Agreement.

1

5. Disability of Awardee. Notwithstanding the provisions of Section 4 above, in the event of termination of Awardee’s Continuous Status as a Participant as a result of total and permanent disability (as such term is defined in Section 12(c) of the Plan), the next vesting date for the SAs, set out in Section 2(a), above, shall accelerate by twelve (12) months as of such date of termination. If Awardee’s disability originally required him or her to take a short-term disability leave which was later converted into long-term disability, then for the purposes of the preceding sentence the date on which Awardee ceased performing services shall be deemed to be the date of commencement of the short-term disability leave. The Awardee’s rights in any unvested SAs that remain unvested after the application of this Section 5 shall terminate at the time Awardee ceases to be in Continuous Status as a Participant.

6. Death of Awardee. Notwithstanding the provisions of Section 4 above, in the event of the death of Awardee:

(a) If Awardee is, at the time of death, in Continuous Status as a Participant, the next vesting date for the SAs, set out in Section 2(a) above, shall accelerate by twelve (12) months as of the date of death.

(b) The Awardee’s rights in any unvested SAs that remain after the application of Section 6(a) shall terminate at the time of the Awardee’s death.

7. Value of Unvested SAs. In consideration of the award of these SAs, Awardee agrees that upon and following termination of Awardee’s Continuous Status as a Participant for any reason (whether or not in breach of applicable laws), and regardless of whether Awardee is terminated with or without cause, notice, or pre-termination procedure or whether Awardee asserts or prevails on a claim that Awardee’s employment was terminable only for cause or only with notice or pre-termination procedure, any unvested SAs under this Award Agreement shall be deemed to have a value of zero dollars ($0.00).

8. Conversion of SAs to Common Shares; Responsibility for Taxes.

(a) Provided Awardee has satisfied the requirements of Section 8(b) below, on the vesting of any SAs, such vested SAs shall be converted into an equivalent number of Common Shares that will be distributed to Awardee or, in the event of Awardee’s death, to Awardee’s legal representative, as soon as practicable. The distribution to the Awardee, or in the case of the Awardee’s death, to the Awardee’s legal representative, of Common Shares in respect of the vested SAs shall be evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means as determined by the Company. In the event ownership or issuance of Common Shares is not feasible due to applicable exchange controls, securities regulations, tax laws or other provisions of applicable law, as determined by the Company in its sole discretion, Awardee, or in the event of Awardee’s death, the Awardee’s legal representative, shall receive cash proceeds in an amount equal to the value of the Common Shares otherwise distributable to Awardee, net of the satisfaction of the requirements of Section 8(b) below.

(b) Regardless of any action the Company or Awardee’s actual employer takes with respect to any or all income tax (including federal, state and local taxes), social insurance, payroll tax or other tax-related withholding (“Tax Related Items”), Awardee acknowledges that the ultimate liability for all Tax Related Items legally due by Awardee is and remains Awardee’s responsibility and that the Company and/or the Awardee’s actual employer (i) make no representations or undertakings regarding the treatment of any Tax Related Items in connection with any aspect of the SAs, including the grant of the SAs, the vesting of SAs, the conversion of the SAs into Common Shares or the receipt of an equivalent cash payment, the subsequent sale of any Common Shares acquired at vesting and the receipt of any dividends; and (ii) do not commit to structure the terms of the grant or any aspect of the SAs to reduce or eliminate the Awardee’s liability for Tax Related Items.

2

Prior to the issuance of Common Shares upon vesting of SAs or the receipt of an equivalent cash payment as provided in Section 8(a) above, Awardee shall pay, or make adequate arrangements satisfactory to the Company or to the Awardee’s actual employer (in their sole discretion) to satisfy all withholding obligations of the Company and/or the Awardee’s actual employer. In this regard, Awardee authorizes the Company or the Awardee’s actual employer to withhold all applicable Tax Related Items legally payable by Awardee from Awardee’s wages or other cash compensation payable to Awardee by the Company or the Awardee’s actual employer. Alternatively, or in addition, if permissible under applicable law, the Company or the Awardee’s actual employer may, in their sole discretion, (i) sell or arrange for the sale of Common Shares to be issued on the vesting of SAs to satisfy the withholding obligation, and/or (ii) withhold in Common Shares, provided that the Company and the Awardee’s actual employer shall withhold only the amount of shares necessary to satisfy the minimum withholding amount. Awardee shall pay to the Company or to the Awardee’s actual employer any amount of Tax Related Items that the Company or the Awardee’s actual employer may be required to withhold as a result of Awardee’s receipt of SAs, the vesting of SAs, or the conversion of vested SAs to Common Shares that cannot be satisfied by the means previously described. Except where applicable legal or regulatory provisions prohibit, the standard process for the payment of an Awardee’s Tax Related Items shall be for the Company or the Awardee’s actual employer to withhold in Common Shares only to the amount of shares necessary to satisfy the minimum withholding amount. The Company may refuse to deliver Common Shares to Awardee if Awardee fails to comply with Awardee’s obligation in connection with the Tax Related Items as described herein.

(c) In lieu of issuing fractional Common Shares, on the vesting of a fraction of a SA, the Company shall round the shares to the nearest whole share and any such share which represents a fraction of a SA will be included in a subsequent vest date.

(d) Until the distribution to Awardee of the Common Shares in respect to the vested SAs is evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means, Awardee shall have no right to vote or receive dividends or any other rights as a shareholder with respect to such Common Shares, notwithstanding the vesting of SAs. The Company shall cause such distribution to Awardee to occur promptly upon the vesting of SAs. No adjustment will be made for a dividend or other right for which the record date is prior to the date Awardee is recorded as the owner of the Common Shares, except as provided in Section 14 of the Plan.

(e) By accepting the Award of SAs evidenced by this Award Agreement, Awardee agrees not to sell any of the Common Shares received on account of vested SAs at a time when applicable laws or Company policies prohibit a sale. This restriction shall apply so long as Awardee is an Employee, Consultant or outside director of the Company or a Subsidiary of the Company.

9. Non-Transferability of SAs. Awardee’s right in the SAs awarded under this Award Agreement and any interest therein may not be sold, pledged, assigned, hypothecated, transferred, or disposed of in any manner, other than by will or by the laws of descent or distribution, prior to the distribution of the Common Shares in respect of such SAs. SAs shall not be subject to execution, attachment or other process.

10. Acknowledgment of Nature of Plan and SAs. In accepting the Award, Awardee acknowledges that:

(a) the Plan is established voluntarily by the Company, it is discretionary in nature and may be modified, amended, suspended or terminated by the Company at any time, as provided in the Plan;

(b) the Award of SAs is voluntary and occasional and does not create any contractual or other right to receive future awards of SAs, or benefits in lieu of SAs even if SAs have been awarded repeatedly in the past;

(c) all decisions with respect to future awards, if any, will be at the sole discretion of the Company;

(d) Awardee’s participation in the Plan is voluntary;

3

(e) the future value of the underlying Common Shares is unknown and cannot be predicted with certainty;

(f) if Awardee receives Common Shares, the value of such Common Shares acquired on vesting of SAs may increase or decrease in value;

(g) notwithstanding any terms or conditions of the Plan to the contrary and consistent with Section 4, above, in the event of involuntary termination of Awardee’s employment (whether or not in breach of applicable laws), Awardee’s right to receive SAs and vest under the Plan, if any, will terminate effective as of the date that Awardee is no longer actively employed and will not be extended by any notice period mandated under applicable law; furthermore, in the event of involuntary termination of employment (whether or not in breach of applicable laws), Awardee’s right to receive Common Shares pursuant to the SAs after termination of employment, if any, will be measured by the date of termination of Awardee’s active employment and will not be extended by any notice period mandated under applicable law; the Committee shall have the exclusive discretion to determine when Awardee is no longer actively employed for purposes of the award of SAs; and

(h) Awardee acknowledges and agrees that, regardless of whether Awardee is terminated with or without cause, notice or pre-termination procedure or whether Awardee asserts or prevails on a claim that Awardee’s employment was terminable only for cause or only with notice or pre-termination procedure, Awardee has no right to, and will not bring any legal claim or action for, (a) any damages for any portion of the SAs that have been vested and converted into Common Shares, or (b) termination of any unvested SAs under this Award Agreement.

11. No Employment Right. Awardee acknowledges that neither the fact of this Award of SAs nor any provision of this Award Agreement or the Plan or the policies adopted pursuant to the Plan shall confer upon Awardee any right with respect to employment or continuation of current employment with the Company or with the Awardee’s actual employer, or to employment that is not terminable at will. Awardee further acknowledges and agrees that neither the Plan nor this Award of SAs makes Awardee’s employment with the Company or the Awardee’s actual employer for any minimum or fixed period, and that such employment is subject to the mutual consent of Awardee and the Company or the Awardee’s actual employer, and may be terminated by either Awardee or the Company or the Awardee’s actual employer at any time, for any reason or no reason, with or without cause or notice or any kind of pre- or post-termination warning, discipline or procedure.

12. Administration. The authority to manage and control the operation and administration of this Award Agreement shall be vested in the Committee (as such term is defined in Section 2(f) of the Plan), and the Committee shall have all powers and discretion with respect to this Award Agreement as it has with respect to the Plan. Any interpretation of the Award Agreement by the Committee and any decision made by the Committee with respect to the Award Agreement shall be final and binding on all parties.

13. Plan Governs. Notwithstanding anything in this Award Agreement to the contrary, the terms of this Award Agreement shall be subject to the terms of the Plan, and this Award Agreement is subject to all interpretations, amendments, rules and regulations promulgated by the Committee from time to time pursuant to the Plan.

14. Notices. Any written notices provided for in this Award Agreement which are sent by mail shall be deemed received three business days after mailing, but not later than the date of actual receipt. Notices shall be directed, if to Awardee, at the Awardee’s address indicated by the Company’s records and, if to the Company, at the Company’s principal executive office.

15. Electronic Delivery. The Company may, in its sole discretion, decide to deliver any documents related to SAs awarded under the Plan or future SAs that may be awarded under the Plan by electronic means or request Awardee’s consent to participate in the Plan by electronic means. Awardee hereby consents to receive such documents by electronic delivery and agrees

4

to participate in the Plan through an on-line or electronic system established and maintained by the Company or another third party designated by the Company.

16. Acknowledgment. By Awardee’s acceptance as evidenced below, Awardee acknowledges that Awardee has received and has read, understood and accepted all the terms, conditions and restrictions of this Award Agreement, the Plan, and the current policies referenced in Section 2(b) of this Award Agreement. Awardee understands and agrees that this Award Agreement is subject to all the terms, conditions, and restrictions stated in this Award Agreement and in the other documents referenced in the preceding sentence, as the latter may be amended from time to time in the Company’s sole discretion. I further acknowledge that I must accept this Award Agreement in the manner prescribed by the Company no later than the earlier of the first anniversary of Award Date or the first vesting date specified in Section 2 of this Award Agreement.

17. Board Approval. These SAs have been awarded pursuant to the Plan and accordingly this Award of SAs is subject to approval by an authorized committee of the Board of Directors. If this Award of SAs has not already been approved, the Company agrees to submit this Award for approval as soon as practical. If such approval is not obtained, this award is null and void.

18. Governing Law. This Award Agreement shall be governed by the laws of the State of Washington, U.S.A., without regard to Washington laws that might cause other law to govern under applicable principles of conflicts of law.

19. Severability. If one or more of the provisions of this Award Agreement shall be held invalid, illegal or unenforceable in any respect, the validity, legality and enforceability of the remaining provisions shall not in any way be affected or impaired thereby and the invalid, illegal or unenforceable provisions shall be deemed null and void; however, to the extent permissible by law, any provisions which could be deemed null and void shall first be construed, interpreted or revised retroactively to permit this Award Agreement to be construed so as to foster the intent of this Award Agreement and the Plan.

20. Complete Award Agreement and Amendment. This Award Agreement, the Notice of Receipt of Stock Awards (if any), and the Plan constitute the entire agreement between Awardee and the Company regarding SAs. Any prior agreements, commitments or negotiations concerning these SAs are superseded. This Award Agreement may be amended only by written agreement of Awardee and the Company, without consent of any other person. Awardee agrees not to rely on any oral information regarding this Award of SAs or any written materials not identified in this Section 20.

EXECUTED the day and year first above written.

MICROSOFT CORPORATION
/s/ KEN DIPIETRO
Ken DiPietro, Vice President, Human Resources

AWARDEE’S ACCEPTANCE:

I have read and fully understood this Award Agreement and, as referenced in Section 16 above, I accept and agree to be bound by all of the terms, conditions and restrictions contained in this Award Agreement and the other documents referenced in it. I intend to express my acceptance of the Award and this Award Agreement by typing my name in the Awardee acceptance window provided in “step 2” of the award acceptance checklist, and I further intend the typing of my name to have the same force and effect in all respects as a handwritten signature.

5

EX-10.9 7 dex109.htm FORM OF STOCK AWARD AGREEMENT FOR NON-EMPLOYEE DIRECTORS
Form of Stock Award Agreement for Non-Employee Directors

Exhibit 10.9

MICROSOFT CORPORATION

STOCK AWARD AGREEMENT

(Granted Under The Microsoft Corporation 1999 Stock Plan for Non-Employee Directors)

Award Number Number

1. Award of Stock Awards. Microsoft Corporation (hereinafter the “Company”), in the exercise of its sole discretion pursuant to the Microsoft Corporation 1999 Stock Plan for Non-Employee Directors (the “Plan”), does as of (the “Award Date”) hereby award to Name (the “Awardee”) Number (Number) Stock Awards (“SAs”) upon the terms and subject to the conditions hereinafter contained. SAs represent the Company’s unfunded and unsecured promise to issue Shares at a future date, subject to the terms of this Award Agreement and the Plan. Awardee has no rights under the SAs other than the rights of a general unsecured creditor of the Company.

Capitalized terms used but not defined herein shall have the meanings assigned to them in the Plan.

2. Vesting Schedule and Conversion of SAs. Subject to the terms of this Award Agreement and the Plan and provided that Awardee continues to serve as a director of the Company throughout the vesting periods set out below, the SAs shall vest and be converted into an equivalent number of Shares that will be distributed to the Awardee as follows; provided that fractional SAs shall be converted into Shares as set out in Section 4(c) of this Award Agreement:

Vesting Date |  | Percentage of SAs
One (1) year from the Award Date |  | 20%
Two (2) years from the Award Date |  | 20%
Three (3) years from the Award Date |  | 20%
Four (4) years from the Award Date |  | 20%
Five (5) years from the Award Date |  | 20%

The Change in Control provisions in Section 9 of the Plan shall, in appropriate circumstances, modify the application of the vesting provisions above.

3. Termination of Awardee’s Status as a Director. In the event of termination of Awardee’s status as a director of the Company, Awardee’s rights under this Award Agreement in any unvested SAs shall terminate.

4. Conversion of SAs to Shares; Responsibility for Taxes.

(a) Provided Awardee has satisfied the requirements of Section 4(b) below, on the vesting of any SAs, such vested SAs shall be converted into an equivalent number of Shares that will be distributed to Awardee or, in the event of Awardee’s death, to Awardee’s legal representative, as soon as practicable. An Awardee’s rights with respect to the SAs issued under this Award Agreement shall terminate at the time such SAs are converted into Shares. The distribution to the Awardee of Shares in respect of the vested SAs shall be evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means as determined by the Company. In the event ownership or

1

issuance of Shares is not feasible due to applicable exchange controls, securities regulations, tax laws or other provisions of applicable law, as determined by the Company in its sole discretion, Awardee shall receive cash proceeds in an amount equal to the value of the Shares otherwise distributable to Awardee, net of the satisfaction of the requirements of Section 4(b) below.

(b) Prior to the issuance of Common Shares upon vesting of SAs or the receipt of an equivalent cash payment as provided in Section 4(a) above, Awardee shall pay, or make adequate arrangements satisfactory to the Company to satisfy any withholding obligations of the Company. Except where applicable legal or regulatory provisions prohibit, the standard process for the payment of an Awardee’s withholding obligations shall be for the Company to withhold in Common Shares only to the amount of shares necessary to satisfy the minimum withholding amount.

(c) In lieu of issuing fractional Shares, on the vesting of a fraction of a SA, the Company shall convert any such fraction of a SA which represents 0.5 or more of a SA to one Common Share and shall extinguish any such fraction of a SA which represents less than 0.5 of a SA without issuing any Shares.

(d) Until the distribution to Awardee of the Shares in respect to the vested SAs is evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means, Awardee shall have no right to vote or receive dividends or any other rights as a shareholder with respect to such Shares, notwithstanding the vesting of SAs. The Company shall cause such distribution to Awardee to occur promptly upon the vesting of SAs. No adjustment will be made for a dividend or other right for which the record date is prior to the date Awardee is recorded as the owner of the Shares, except as provided in Section 12 of the Plan.

5. Non-Transferability of SAs. Awardee’s right in the SAs awarded under this Award Agreement and any interest therein may not be sold, pledged, assigned, hypothecated, transferred, or disposed of in any manner, other than by will or by the laws of descent or distribution, prior to the distribution of the Shares in respect of such SAs. SAs shall not be subject to execution, attachment or other process.

6. Agreements of Awardee. In accepting the Award, Awardee agrees to continue to serve as a director of the Company during the term for which he or she was elected. By accepting the Award of SAs evidenced by this Award Agreement, Awardee agrees not to sell any of the Shares received on account of vested SAs at a time when applicable laws or Company policies prohibit a sale. This restriction shall apply so long as Awardee is a director of the Company.

7. Plan Governs. Notwithstanding anything in this Award Agreement to the contrary, the terms of this Award Agreement shall be subject to the terms and conditions of the Plan.

8. Governing Law. This Award Agreement shall be governed by the laws of the State of Washington, U.S.A., without regard to Washington laws that might cause other law to govern under applicable principles of conflicts of law. For purposes of litigating any dispute that arises under this Award of SAs or this Award Agreement, the parties hereby submit to and consent to the jurisdiction of the State of Washington, and agree that such litigation shall be conducted in the courts of King County, Washington, or the federal courts for the United States for the Western District of Washington, and no other courts, where this Award of SAs is made and/or to be performed.

9. Complete Award Agreement; Severability. This Award Agreement and the Plan constitute the entire agreement between Awardee and the Company regarding SAs. If one or more of the provisions of this Award Agreement shall be held invalid, illegal or unenforceable in any respect,

2

the validity, legality and enforceability of the remaining provisions shall not in any way be affected or impaired thereby and the invalid, illegal or unenforceable provisions shall be deemed null and void; however, to the extent permissible by law, any provisions which could be deemed null and void shall first be construed, interpreted or revised retroactively to permit this Award Agreement to be construed so as to foster the intent of this Award Agreement and the Plan

EXECUTED at Redmond, Washington on [date]

MICROSOFT CORPORATION

Ken DiPietro,

Vice President, Human Resources

AWARDEE’S ACCEPTANCE:

I have read and fully understood this Award Agreement and accept and agree to the terms and conditions contained in this Award Agreement and the Plan.

By

Name

3

EX-10.10 8 dex1010.htm FORM OF SHARED PERFORMANCE STOCK AWARD AGREEMENT
Form of Shared Performance Stock Award Agreement

Exhibit 10.10

2003 SHARED PERFORMANCE STOCK AWARD AGREEMENT

UNDER

THE MICROSOFT CORPORATION 2001 STOCK PLAN

1. Award of Target Shared Performance Stock Awards. Microsoft Corporation (the “Company”), in the exercise of its sole discretion pursuant to the Microsoft Corporation 2001 Stock Plan (the “Plan”), does on <<SPSAEffectiveDate>> (the “Award Date”) hereby award to <<FullName>> (the “Awardee”) <<SPSAOriginalSharesGranted>> target Shared Performance Stock Awards (target “SPSAs”) upon the terms and subject to the conditions of this Award Agreement.

Target SPSAs are used solely to calculate the number of actual SPSAs awarded to Awardee in accordance with this Award Agreement, and do not create any separate rights or entitlements. ACTUAL SPSAs ARE CALCULATED FOLLOWING THE END OF THE COMPANY’S FISCAL YEAR ENDING IN 2006 (“FY06”) BASED ON THE METRICS AND METHODOLOGIES DESCRIBED IN APPENDIX A, AND BASED ON ANY ADJUSTMENTS IN TARGET SPSAs DUE TO EMPLOYMENT CHANGES AS DESCRIBED IN SECTION 3(b) BELOW AND ANY CHANGES IN THE SPSA PERFORMANCE PERCENTAGE PERMITTED UNDER THIS AGREEMENT.

SPSAs represent the Company’s unfunded and unsecured promise to issue Common Shares at a future date, subject to the terms of this Award Agreement and the Plan. Awardee has no rights under the SPSAs other than the rights of a general unsecured creditor of the Company.

Capitalized terms used but not defined in this Award Agreement shall have the meanings assigned to them in the Plan.

2. Calculation of SPSAs. Following the end of FY06, the Compensation Committee of the Board (the “Committee”) will calculate the Awardee’s actual SPSAs by multiplying the target SPSAs by the SPSA Performance Percentage. In calculating the number of actual SPSAs, target SPSAs will be determined after taking into account any adjustments due to employment changes, as described in Section 3(b) below.

The SPSA Performance Percentage is calculated in accordance with the methodology set forth in Appendix A, which measures the performance of the Company against the Shared Performance Index (“SPI”). The SPI metrics will be measured using the methods and procedures that Microsoft uses for its business purposes, and these methods and procedures may change without notice or consent.

If there is a significant change in the Company’s business or business strategy (for example, by a merger, acquisition or divestiture), as the Committee determines in its sole discretion, the Committee may adjust the SPSA Performance Percentage calculation by changing the SPI metrics, weights, performance levels and/or measurements as they consider appropriate in light of the change.

The final determination of the SPSA Performance Percentage and the actual number of SPSAs to which the Awardee is entitled will be made by the Committee in its sole discretion. Compensation attributable to the Award Agreement is intended to constitute qualified performance-based compensation under Section 162(m) of the Code and the regulations thereunder. This Award Agreement shall be construed and administered by the Committee in a manner consistent with this intent.

1

Notwithstanding this Section or any other provision of this Award Agreement, to the extent required to ensure that compensation attributable to this Award Agreement constitutes qualified performance-based compensation under Section 162(m) of the Code:

(a) The SPSA Performance Percentage calculation, the SPI metrics, and the Company’s policies on SPSAs (as described in Section 3(b)) as they apply to Awardee shall not be revised in a manner that would result in an increase in the actual SPSAs the awardee is entitled to receive under this Award Agreement, except for an adjustment under Paragraph 14 of the Plan as and to the extent permitted under Section 162(m) of the Code; and,

(b) Payment of compensation attributable to this Award Agreement shall be subject to the Company’s shareholders approving the material terms of the award in accordance with the requirements of Section 162(m) of the Code.

3. Vesting Schedule and Conversion of SPSAs; Adjustments Upon Employment Changes.

(a) Subject to the terms of this Award Agreement and the Plan and provided that Awardee remains continuously employed throughout the vesting periods set out below:

(1) One-third of the SPSAs shall vest and be converted into an equivalent number of Common Shares that will be distributed to the Awardee on or about August 31, 2006 (the “initial vest date”);

(2) One-third of the SPSAs shall vest and be converted into an equivalent number of Common Shares that will be distributed to the Awardee one year from the initial vest date; and

(3) One-third of the SPSAs shall vest and be converted into an equivalent number of Common Shares that will be distributed to the Awardee two years from the initial vest date.

Fractional SPSAs shall be converted into Common Shares as set out in Section 9(c) of this Award Agreement

(b) THE AWARDEE’S RIGHTS IN THE SPSAs SHALL BE SUBJECT TO INCREASE, DECREASE, LOSS OR MAY BE OTHERWISE AFFECTED, WITH REGARD TO AWARD ELIGIBILITY, SIZE, VESTING AND TERMINATION, BY HIRE DATE OR CHANGES IN LEVEL, PROMOTION AND DEMOTION, LEAVES OF ABSENCE, PART-TIME EMPLOYMENT, DISABILITY, AND OTHER CHANGES IN AWARDEE’S EMPLOYMENT AS PROVIDED IN THE COMPANY’S CURRENT POLICIES ON SPSAs, WHICH MAY VARY FROM THE POLICIES ON STOCK OPTIONS AND STOCK AWARDS. ACCOMPANYING THIS AWARD AGREEMENT IS A CURRENT COPY OF THE COMPANY’S POLICIES IN SUCH MATTERS. THESE POLICIES SHALL BE APPROVED AND ADMINISTERED AS SET FORTH IN SECTION 19 BELOW AND MAY CHANGE FROM TIME TO TIME, WITHOUT NOTICE, IN THE COMPANY’S SOLE DISCRETION. AWARDEE’S RIGHTS WILL BE GOVERNED BY THE POLICIES IN EFFECT AT THE TIME OF ANY EVENT OR CHANGE COVERED BY THE POLICIES. CONTACT “BENEFITS” FOR A COPY OF THE MOST CURRENT POLICY STATEMENT AT ANY POINT IN TIME.

4. Termination at Conversion of SPSAs. Unless terminated earlier under Section 5, 6, or 7 below, an Awardee’s rights under this Award Agreement with respect to the SPSAs issued under this Award Agreement shall terminate at the time such SPSAs are converted into Common Shares.

2

5. Termination of Awardee’s Status as a Participant. Except as otherwise specified in Sections 6 and 7 below, in the event of termination of Awardee’s Continuous Status as a Participant (as such term is defined in Section 2(j) of the Plan), Awardee’s rights under this Award Agreement in any unvested SPSAs shall terminate. For the avoidance of doubt, an Awardee’s Continuous Status as a Participant terminates at the time the Awardee’s actual employer ceases to be the Company or a “Subsidiary” of the Company, as that term is defined in Section 2(z) of the Plan.

6. Disability of Awardee. Notwithstanding the provisions of Section 5 above, in the event of termination of Awardee’s Continuous Status as a Participant as a result of total and permanent disability (as such term is defined in Section 12(c) of the Plan), then:

(1) If the termination of Awardee’s Continuous Status as a Participant occurs before FY06, no special vesting relating to total and permanent disability shall occur, and Awardee’s rights under this Award Agreement in any SPSAs shall terminate;

(2) If the termination of Awardee’s Continuous Status as a Participant occurs during FY06, Awardee shall vest in a number of SPSAs calculated by multiplying the target SPSAs by 0.33, rounded up to the nearest whole number; and

(3) If the termination of Awardee’s Continuous Status as a Participant occurs after FY06, then the next vesting date for the SPSAs, set forth in Section 3(a) above, shall accelerate so that Awardee vests in any SPSAs that would normally vest within twelve (12) months of the earlier of (i) such date of termination, or (ii) if Awardee’s disability originally required him or her to take a short-term disability leave which was later converted into long-term disability, the date of commencement of the short-term disability leave.

The Awardee’s rights in any unvested SPSAs that remain unvested after the application of this Section 6 shall terminate at the time Awardee ceases to be in Continuous Status as a Participant. An employee who fails to provide Microsoft with a medical determination of “total and permanent disability” that is acceptable to Microsoft and that establishes total and permanent disability to Microsoft’s satisfaction shall not be eligible for the vesting of SPSAs pursuant to this Section 6.

7. Death of Awardee. Notwithstanding the provisions of Section 5 above, in the event of the death of Awardee while in Continuous Status as a Participant, then:

(1) If the death of the Awardee occurs before FY06, then no special vesting relating to death shall occur, and Awardee’s rights under this Award Agreement in any SPSAs shall terminate;

(2) If the death occurs during FY06, then Awardee shall vest in a number of SPSAs calculated by multiplying the target SPSAs by 0.33, rounded up to the nearest whole number; and

(3) If the death occurs after FY06, then the next vesting date for the SPSAs, set forth in Section 3(a) above, shall accelerate so that Awardee vests in any SPSAs that would normally vest within twelve (12) months of the date of death.

The Awardee’s rights in any unvested SPSAs that remain unvested after the application of this Section 7 shall terminate at the time of the Awardee’s death.

8. Value of Unvested SPSAs. In consideration of the award of these SPSAs, Awardee agrees that upon and following termination of Awardee’s Continuous Status as a Participant for any

3

reason (whether or not in breach of applicable laws), and regardless of whether Awardee is terminated with or without cause, notice, or pre-termination procedure or whether Awardee asserts or prevails on a claim that Awardee’s employment was terminable only for cause or only with notice or pre-termination procedure, any unvested SPSAs under this Award Agreement shall be deemed to have a value of zero dollars ($0.00).

9. Conversion of SPSAs to Common Shares; Responsibility for Taxes.

(a) Provided Awardee has satisfied the requirements of Section 9(b) below, on the vesting of any SPSAs, such vested SPSAs shall be converted into an equivalent number of Common Shares that will be distributed to Awardee or, in the event of Awardee’s death, to Awardee’s legal representative, as soon as practicable. The distribution to the Awardee, or in the case of the Awardee’s death, to the Awardee’s legal representative, of Common Shares in respect of the vested SPSAs shall be evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means as determined by the Company. In the event ownership or issuance of Common Shares is not feasible due to applicable exchange controls, securities regulations, tax laws or other provisions of applicable law, as determined by the Company in its sole discretion, Awardee, or in the event of Awardee’s death, the Awardee’s legal representative, shall receive cash proceeds in an amount equal to the value of the Common Shares otherwise distributable to Awardee, as determined by the Company in its sole discretion, net of amounts withheld in satisfaction of the requirements of Section 9(b) below.

(b) Regardless of any action the Company or Awardee’s actual employer takes with respect to any or all income tax (including federal, state and local taxes), social insurance, payroll tax or other tax-related withholding (“Tax Related Items”), Awardee acknowledges that the ultimate liability for all Tax Related Items legally due by Awardee is and remains Awardee’s responsibility and that the Company and/or the Awardee’s actual employer (i) make no representations or undertakings regarding the treatment of any Tax Related Items in connection with any aspect of the SPSAs, including the grant of the SPSAs, the vesting of SPSAs, the conversion of the SPSAs into Common Shares or the receipt of an equivalent cash payment, the subsequent sale of any Common Shares acquired and the receipt of any dividends; and (ii) do not commit to structure the terms of the grant or any aspect of the SPSAs to reduce or eliminate the Awardee’s liability for Tax Related Items.

Prior to the issuance of Common Shares upon vesting of the SPSAs or the distribution of an equivalent cash payment as provided in Section 9(a) above, Awardee shall pay, or make adequate arrangements satisfactory to the Company or to the Awardee’s actual employer (in their sole discretion) to satisfy all withholding obligations of the Company and/or the Awardee’s actual employer. In this regard, Awardee authorizes the Company or the Awardee’s actual employer to withhold all applicable Tax Related Items legally payable by Awardee from Awardee’s wages or other cash compensation payable to Awardee by the Company or the Awardee’s actual employer. Alternatively, or in addition, if permissible under applicable law, the Company or the Awardee’s actual employer may, in their sole discretion, (i) sell or arrange for the sale of Common Shares to be issued upon the vesting of SPSAs to satisfy the withholding obligation, and/or (ii) withhold in Common Shares, provided that the Company and the Awardee’s actual employer shall withhold only the amount of shares necessary to satisfy the minimum withholding amount. Awardee shall pay to the Company or to the Awardee’s actual employer any amount of Tax Related Items that the Company or the Awardee’s actual employer may be required to withhold as a result of Awardee’s receipt of SPSAs, the vesting of SPSAs, or the conversion of vested SPSAs to Common Shares that cannot be satisfied by the means described in this paragraph. Except where applicable legal or regulatory provisions prohibit, the standard process for the payment of an Awardee’s Tax Related Items shall be for the Company or the Awardee’s actual employer to withhold in Common Shares only to the amount of shares necessary to satisfy the minimum withholding amount. The Company may refuse to deliver Common Shares to Awardee

4

if Awardee fails to comply with Awardee’s obligation in connection with the Tax Related Items as described in this Section 9.

(c) In lieu of issuing fractional Common Shares, on the vesting of a fraction of a SPSA, the Company shall convert any such fraction of a SPSA which represents 0.5 or more of a SPSA to one Common Share and any such fraction of a SPSA which represents less than 0.5 of a SPSA shall be included in the number of SPSAs that are scheduled to vest on the next vesting date.

(d) Until the distribution to Awardee of the Common Shares in respect of the vested SPSAs is evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means, Awardee shall have no right to vote or receive dividends or any other rights as a shareholder with respect to such Common Shares, notwithstanding the vesting of SPSAs. The Company shall cause such distribution to Awardee to occur promptly upon the vesting of SPSAs. No adjustment will be made for a dividend or other right for which the record date is prior to the date Awardee is recorded as the owner of the Common Shares, except as provided in Section 14 of the Plan.

(e) By accepting the Award of SPSAs evidenced by this Award Agreement, Awardee agrees not to sell any of the Common Shares received upon account of vested SPSAs at a time when applicable laws or Company policies prohibit a sale. This restriction shall apply so long as Awardee is an Employee, Consultant or outside director of the Company or a Subsidiary of the Company.

10. Non-Transferability of SPSAs. Awardee’s right in the SPSAs awarded under this Award Agreement and any interest therein may not be sold, pledged, assigned, hypothecated, transferred, or disposed of in any manner, other than by will or by the laws of descent or distribution. SPSAs shall not be subject to execution, attachment or other process.

11. Acknowledgment of Nature of Plan and SPSAs. In accepting the Award, Awardee acknowledges that:

(a) the Plan is established voluntarily by the Company, it is discretionary in nature and may be modified, amended, suspended or terminated by the Company at any time, as provided in the Plan;

(b) the Award of SPSAs is voluntary and occasional and does not create any contractual or other right to receive future awards of SPSAs, or benefits in lieu of SPSAs even if SPSAs have been awarded repeatedly in the past;

(c) all decisions with respect to future awards, if any, will be at the sole discretion of the Company;

(d) Awardee’s participation in the Plan is voluntary;

(e) the future value of the underlying Common Shares is unknown and cannot be predicted with certainty;

(f) if Awardee receives Common Shares, the value of such Common Shares acquired on vesting of SPSAs may increase or decrease in value;

(g) notwithstanding any terms or conditions of the Plan to the contrary and consistent with Section 5 above, in the event of termination of Awardee’s employment (whether or not in breach of applicable laws), Awardee’s right to receive SPSAs and vest under the Plan, if any, will terminate

5

effective as of the date that Awardee is no longer actively employed and will not be extended by any notice period mandated under applicable law; furthermore, in the event of termination of employment (whether or not in breach of applicable laws), Awardee’s right to receive Common Shares pursuant to the SPSAs after termination of employment, if any, will be calculated as of the date of termination of Awardee’s active employment and will not be extended by any notice period mandated under applicable law; the Board of Directors or Committee shall have the exclusive discretion to determine when Awardee is no longer actively employed for purposes of the award of SPSAs;

(h) Awardee acknowledges and agrees that, regardless of whether Awardee is terminated with or without cause, notice or pre-termination procedure or whether Awardee asserts or prevails on a claim that Awardee’s employment was terminable only for cause or only with notice or pre-termination procedure, Awardee has no right to, and will not bring any legal claim or action for, (a) any damages for any portion of the SPSAs that have been vested and converted into Common Shares, or (b) termination of any unvested SPSAs under this Award Agreement; and

(i) Awardee promises never to pursue any claim relating to the Plan or this Award Agreement before (1) notifying the Company in writing of Awardee’s claim within thirty (30) days after Awardee first knows or should have known the facts on which the claim is based, (2) if requested by the Company to do so within thirty (30) days after so notifying the Company, participating in good faith in any nonbinding dispute resolution procedure the Company prescribes, and (3) keeping Awardee’s claim completely confidential, except to the minimum extent needed to pursue the claim, until all the requirements of this subsection have been satisfied. The dispute resolution procedure the Company prescribes shall be paid for by the Company and must be reasonably capable of being completed within ninety (90) days after the Awardee is requested to use it. Awardee agrees that his or her right to any awards, stock or amounts under this Award Agreement are conditioned on Awardee’s strictly complying with the requirements of this subsection.

12. Data Privacy Notice and Consent. Awardee hereby explicitly and unambiguously consents to the collection, use and transfer, in electronic or other form, of Awardee’s personal data as described in this Award Agreement by and among, as applicable, Awardee’s employer, the Company, its Subsidiaries and its affiliates for the exclusive purpose of implementing, administering and managing Awardee’s participation in the Plan.

Awardee understands that the Company and Awardee’s employer may hold certain personal information about Awardee, including, but not limited to, Awardee’s name, home address and telephone number, date of birth, social insurance number or other identification number, salary, nationality, job title, any shares of stock or directorships held in the Company, details of all SPSAs or any other entitlement to Common Shares awarded, canceled, vested, unvested or outstanding in Awardee’s favor, for the purpose of implementing, administering and managing the Plan (“Data”). Awardee understands that Data may be transferred to any third parties assisting in the implementation, administration and management of the Plan, that these recipients may be located in Awardee’s country, or elsewhere, and that the recipient’s country may have different data privacy laws and protections than Awardee’s country. Awardee understands that Awardee may, to the extent required by local law, request a list with the names and addresses of any potential recipients of the Data by contacting Awardee’s local human resources representative. Awardee authorizes the recipients to receive, possess, use, retain and transfer the Data, in electronic or other form, for the purposes of implementing, administering and managing Awardee’s participation in the Plan, including any requisite transfer of such Data as may be required to a broker, escrow agent or other third party with whom the Common Shares received upon vesting of the SPSAs may be deposited. Awardee understands that Data will be held only as long as is necessary to implement,

6

administer and manage Awardee’s participation in the Plan. Awardee understands that Awardee may to the extent required by local law, at any time, view Data, request additional information about the storage and processing of Data, require any necessary amendments to Data or refuse or withdraw the consents herein, in any case without cost, by contacting in writing Awardee’s local human resources representative. Awardee understands that refusal or withdrawal of consent may affect Awardee’s ability to participate in the Plan. For more information on the consequences of Awardee’s refusal to consent or withdrawal of consent, Awardee understands that Awardee may contact Awardee’s local human resources representative.

13. No Employment Right; Effect of Relocation Outside U.S.A. Awardee acknowledges that neither the fact of this Award of SPSAs nor any provision of this Award Agreement or the Plan or the policies adopted pursuant to the Plan shall confer upon Awardee any right with respect to employment or continuation of current employment with the Company or with the Awardee’s actual employer, or to employment that is not terminable at will. Awardee further acknowledges and agrees that neither the Plan nor this Award of SPSAs makes Awardee’s employment with the Company or the Awardee’s actual employer for any minimum or fixed period, and that such employment is subject to the mutual consent of Awardee and the Company or the Awardee’s actual employer, and may be terminated by either Awardee or the Company or the Awardee’s actual employer at any time, for any reason or no reason, with or without cause or notice or any kind of pre- or post-termination warning, discipline or procedure. In the event Awardee’s employment with the Company is relocated outside the United States, this Stock Award Agreement shall be amended to include such provisions regarding employment rights with respect to the SPSAs as the Company, in its sole discretion, has determined to be appropriate for inclusion in SPSA Award Agreements for the location to which Awardee relocates.

14. Administration. The authority to manage and control the operation and administration of this Award Agreement shall be vested in the Committee (as such term is defined in Section 2(f) of the Plan), and the Committee shall have all powers and discretion with respect to this Award Agreement as it has with respect to the Plan. Any interpretation of the Award Agreement by the Committee and any decision made by the Committee with respect to the Award Agreement shall be final and binding on all parties.

15. Plan Governs. Notwithstanding anything in this Award Agreement to the contrary, the terms of this Award Agreement shall be subject to the terms of the Plan, and this Award Agreement is subject to all interpretations, amendments, rules and regulations promulgated by the Committee from time to time pursuant to the Plan.

16. Notices. Any written notices provided for in this Award Agreement which are sent by mail shall be deemed received three business days after mailing, but not later than the date of actual receipt. Notices shall be directed, if to Awardee, at the Awardee’s address indicated by the Company’s records and, if to the Company, at the Company’s principal executive office.

17. Electronic Delivery. The Company may, in its sole discretion, decide to deliver any documents related to SPSAs awarded under the Plan or future SPSAs that may be awarded under the Plan by electronic means or request Awardee’s consent to participate in the Plan by electronic means. Awardee hereby consents to receive such documents by electronic delivery and agrees to participate in the Plan through an on-line or electronic system established and maintained by the Company or another third party designated by the Company.

18. Acknowledgment. By Awardee’s acceptance as evidenced below, Awardee acknowledges that Awardee has received and has read, understood and accepted all the terms, conditions and restrictions of this Award Agreement, the Plan, and the current policies referenced in Section 3(b) of this Award Agreement. Awardee understands and agrees that this Award Agreement is subject to all the terms, conditions, and restrictions stated in this Award Agreement and in the

7

other documents referenced in the preceding sentence, as the latter may be amended from time to time in the Company’s sole discretion.

19. Committee Approval. These SPSAs have been awarded pursuant to the Plan and accordingly this Award of SPSAs is subject to approval by the Committee. If this Award of SPSAs has not already been approved by the Committee, the Company agrees to submit this Award for approval as soon as practical. If such approval is not obtained, this award is null and void.

20. Governing Law. This Award Agreement shall be governed by the laws of the State of Washington, U.S.A., without regard to Washington laws that might cause other law to govern under applicable principles of conflicts of law. For purposes of litigating any dispute that arises under this Award of SPSAs or this Award Agreement, the parties hereby submit to and consent to the jurisdiction of the State of Washington, and agree that such litigation shall be conducted in the courts of King County, Washington, or the federal courts for the United States for the Western District of Washington, and no other courts, where this Award of SPSAs is made and/or to be performed. This Award Agreement is not subject to the Employee Retirement Income Security Act of 1974, as amended (“ERISA”).

21. Severability. If one or more of the provisions of this Award Agreement shall be held invalid, illegal or unenforceable in any respect, the validity, legality and enforceability of the remaining provisions shall not in any way be affected or impaired thereby and the invalid, illegal or unenforceable provisions shall be deemed null and void; however, to the extent permissible by law, any provisions which could be deemed null and void shall first be construed, interpreted or revised retroactively to permit this Award Agreement to be construed so as to foster the intent of this Award Agreement and the Plan.

22. Complete Award Agreement and Amendment. This Award Agreement (which includes the SPSA Performance Percentage calculations made in accordance with Appendix A and the policies referenced in Section 3(b), each as modified from time to time), the Notice of Receipt of Stock Awards (if any), and the Plan constitute the entire agreement between Awardee and the Company regarding SPSAs. Any prior agreements, commitments or negotiations concerning these SPSAs are superseded. This Award Agreement may be amended only by written agreement of Awardee and the Company, except that Appendix A and the policies referenced in Section 3(b) may be modified by the Company as described in this Award Agreement from time to time. Awardee agrees not to rely on any oral information regarding this Award of SPSAs or any written materials not identified in this Section 22.

EXECUTED the day and year first above written.

MICROSOFT CORPORATION
/s/ KEN DIPIETRO
Ken DiPietro, Vice President, Human Resources

AWARDEE’S ACCEPTANCE:

I have read and fully understood this Award Agreement and, as referenced in Section 18 above, I accept and agree to be bound by all of the terms, conditions and restrictions contained in this Award Agreement and the other documents referenced in it. I intend to express my acceptance of the Award and this Award Agreement by typing my name in the Awardee acceptance window provided in “step 2” of the award acceptance checklist, and I further intend the typing of my name to have the same force and effect in all respects as a handwritten signature.

8

EX-10.11 9 dex1011.htm FORM OF SHARED PERFORMANCE STOCK AWARD AGREEMENT
Form of Shared Performance Stock Award Agreement

Exhibit 10.11

2003 SHARED PERFORMANCE STOCK AWARD AGREEMENT UNDER

THE MICROSOFT CORPORATION 2001 STOCK PLAN

1. Award of Target Shared Performance Stock Awards. Microsoft Corporation (the “Company”), in the exercise of its sole discretion pursuant to the Microsoft Corporation 2001 Stock Plan (the “Plan”), does on <<SPSAEffectiveDate>> (the “Award Date”) hereby award to <<FullName>> (the “Awardee”) <<SPSAOriginalSharesGranted>> target Shared Performance Stock Awards (target “SPSAs”) upon the terms and subject to the conditions of this Award Agreement.

Target SPSAs are used solely to calculate the number of actual SPSAs awarded to Awardee in accordance with this Award Agreement, and do not create any separate rights or entitlements. ACTUAL SPSAs ARE CALCULATED FOLLOWING THE END OF THE COMPANY’S FISCAL YEAR ENDING IN 2006 (“FY06”) BASED ON THE METRICS AND METHODOLOGIES DESCRIBED IN THE CONTENTS OF THE TAB ENTITLED “SPSA MODELING” ON THE STOCK@MICROSOFT SITE MAINTAINED BY THE COMPANY, AND BASED ON ANY ADJUSTMENTS IN TARGET SPSAs DUE TO EMPLOYMENT CHANGES AS DESCRIBED IN SECTION 3(b) BELOW AND ANY CHANGES IN THE SPSA PERFORMANCE PERCENTAGE PERMITTED UNDER THIS AGREEMENT.

SPSAs represent the Company’s unfunded and unsecured promise to issue Common Shares at a future date, subject to the terms of this Award Agreement and the Plan. Awardee has no rights under the SPSAs other than the rights of a general unsecured creditor of the Company.

Capitalized terms used but not defined in this Award Agreement shall have the meanings assigned to them in the Plan.

2. Calculation of SPSAs. Following the end of FY06, the Awardee’s actual SPSAs will be calculated by multiplying the target SPSAs by the greater of (i) the SPSA Performance Percentage, rounded up to the nearest whole number, or (ii) thirty-three percent (33%). In calculating the number of actual SPSAs, target SPSAs will be determined after taking into account any adjustments due to employment changes, as described in Section 3(b) below.

The SPSA Performance Percentage is calculated in accordance with the methodology set forth in the contents of the tab entitled “SPSA Modeling” on the STOCK@MICROSOFT site, which measures the performance of the Company against the Shared Performance Index. The SPI metrics will be measured using the methods and procedures that Microsoft uses for its business purposes, and these methods and procedures may change without notice or consent.

The final determination of the SPSA Performance Percentage will be made by the Company’s Board of directors or a designated committee of the Board (the “Committee”) in its sole discretion. If there is a significant change in the Company’s business or business strategy (for example, by a merger, acquisition or divestiture), as the Board or the Committee determines in its sole discretion, the Board or the Committee may adjust the SPSA Performance Percentage calculation by changing the SPI metrics, weights, performance levels and/or measurements as they consider appropriate in light of the change. The tab entitled “SPSA Modeling” on the STOCK@MICROSOFT site may be modified from time to time without notice or consent.

3. Vesting Schedule and Conversion of SPSAs; Adjustments Upon Employment Changes.

(a) Subject to the terms of this Award Agreement and the Plan and provided that Awardee remains continuously employed throughout the vesting periods set out below:

(1) One-third of the SPSAs shall vest and be converted into an equivalent number of Common Shares that will be distributed to the Awardee on or about August 31, 2006 (the “initial vest date”);

1

(2) One-third of the SPSAs shall vest and be converted into an equivalent number of Common Shares that will be distributed to the Awardee one year from the initial vest date; and

(3) One-third of the SPSAs shall vest and be converted into an equivalent number of Common Shares that will be distributed to the Awardee two years from the initial vest date.

Fractional SPSAs shall be converted into Common Shares as set out in Section 9(c) of this Award Agreement

(b) THE AWARDEE’S RIGHTS IN THE SPSAs SHALL BE SUBJECT TO INCREASE, DECREASE, LOSS OR MAY BE OTHERWISE AFFECTED, WITH REGARD TO AWARD ELIGIBILITY, SIZE, VESTING AND TERMINATION, BY HIRE DATE OR CHANGES IN LEVEL, PROMOTION AND DEMOTION, LEAVES OF ABSENCE, PART-TIME EMPLOYMENT, DISABILITY, AND OTHER CHANGES IN AWARDEE’S EMPLOYMENT AS PROVIDED IN THE COMPANY’S CURRENT POLICIES ON SPSAs, WHICH MAY VARY FROM THE POLICIES ON STOCK OPTIONS AND STOCK AWARDS. ACCOMPANYING THIS AWARD AGREEMENT IS A CURRENT COPY OF THE COMPANY’S POLICIES IN SUCH MATTERS. THESE POLICIES SHALL BE APPROVED AND ADMINISTERED AS SET FORTH IN SECTION 19 BELOW AND MAY CHANGE FROM TIME TO TIME, WITHOUT NOTICE, IN THE COMPANY’S SOLE DISCRETION. AWARDEE’S RIGHTS WILL BE GOVERNED BY THE POLICIES IN EFFECT AT THE TIME OF ANY EVENT OR CHANGE COVERED BY THE POLICIES. CONTACT “BENEFITS” FOR A COPY OF THE MOST CURRENT POLICY STATEMENT AT ANY POINT IN TIME.

4. Termination at Conversion of SPSAs. Unless terminated earlier under Section 5, 6, or 7 below, an Awardee’s rights under this Award Agreement with respect to the SPSAs issued under this Award Agreement shall terminate at the time such SPSAs are converted into Common Shares.

5. Termination of Awardee’s Status as a Participant. Except as otherwise specified in Sections 6 and 7 below, in the event of termination of Awardee’s Continuous Status as a Participant (as such term is defined in Section 2(j) of the Plan), Awardee’s rights under this Award Agreement in any unvested SPSAs shall terminate. For the avoidance of doubt, an Awardee’s Continuous Status as a Participant terminates at the time the Awardee’s actual employer ceases to be the Company or a “Subsidiary” of the Company, as that term is defined in Section 2(z) of the Plan.

6. Disability of Awardee. Notwithstanding the provisions of Section 5 above, in the event of termination of Awardee’s Continuous Status as a Participant as a result of total and permanent disability (as such term is defined in Section 12(c) of the Plan), then:

(1) If the termination of Awardee’s Continuous Status as a Participant occurs before FY06, no special vesting relating to total and permanent disability shall occur, and Awardee’s rights under this Award Agreement in any SPSAs shall terminate;

(2) If the termination of Awardee’s Continuous Status as a Participant occurs during FY06, Awardee shall vest in a number of SPSAs calculated by multiplying the target SPSAs by 0.33, rounded up to the nearest whole number; and

(3) If the termination of Awardee’s Continuous Status as a Participant occurs after FY06, then the next vesting date for the SPSAs, set forth in Section 3(a) above, shall accelerate so that Awardee vests in any SPSAs that would normally vest within twelve (12) months of the earlier of (i) such date of termination, or (ii) if Awardee’s disability originally required him or her to take a short-term disability leave which was later converted into long-term disability, the date of commencement of the short-term disability leave.

2

The Awardee’s rights in any unvested SPSAs that remain unvested after the application of this Section 6 shall terminate at the time Awardee ceases to be in Continuous Status as a Participant. An employee who fails to provide Microsoft with a medical determination of “total and permanent disability” that is acceptable to Microsoft and that establishes total and permanent disability to Microsoft’s satisfaction shall not be eligible for the vesting of SPSAs pursuant to this Section 6.

7. Death of Awardee. Notwithstanding the provisions of Section 5 above, in the event of the death of Awardee while in Continuous Status as a Participant, then:

(1) If the death of the Awardee occurs before FY06, then no special vesting relating to death shall occur, and Awardee’s rights under this Award Agreement in any SPSAs shall terminate;

(2) If the death occurs during FY06, then Awardee shall vest in a number of SPSAs calculated by multiplying the target SPSAs by 0.33, rounded up to the nearest whole number; and

(3) If the death occurs after FY06, then the next vesting date for the SPSAs, set forth in Section 3(a) above, shall accelerate so that Awardee vests in any SPSAs that would normally vest within twelve (12) months of the date of death.

The Awardee’s rights in any unvested SPSAs that remain unvested after the application of this Section 7 shall terminate at the time of the Awardee’s death.

8. Value of Unvested SPSAs. In consideration of the award of these SPSAs, Awardee agrees that upon and following termination of Awardee’s Continuous Status as a Participant for any reason (whether or not in breach of applicable laws), and regardless of whether Awardee is terminated with or without cause, notice, or pre-termination procedure or whether Awardee asserts or prevails on a claim that Awardee’s employment was terminable only for cause or only with notice or pre-termination procedure, any unvested SPSAs under this Award Agreement shall be deemed to have a value of zero dollars ($0.00).

9. Conversion of SPSAs to Common Shares; Responsibility for Taxes.

(a) Provided Awardee has satisfied the requirements of Section 9(b) below, on the vesting of any SPSAs, such vested SPSAs shall be converted into an equivalent number of Common Shares that will be distributed to Awardee or, in the event of Awardee’s death, to Awardee’s legal representative, as soon as practicable. The distribution to the Awardee, or in the case of the Awardee’s death, to the Awardee’s legal representative, of Common Shares in respect of the vested SPSAs shall be evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means as determined by the Company. In the event ownership or issuance of Common Shares is not feasible due to applicable exchange controls, securities regulations, tax laws or other provisions of applicable law, as determined by the Company in its sole discretion, Awardee, or in the event of Awardee’s death, the Awardee’s legal representative, shall receive cash proceeds in an amount equal to the value of the Common Shares otherwise distributable to Awardee, as determined by the Company in its sole discretion, net of amounts withheld in satisfaction of the requirements of Section 9(b) below.

(b) Regardless of any action the Company or Awardee’s actual employer takes with respect to any or all income tax (including federal, state and local taxes), social insurance, payroll tax or other tax-related withholding (“Tax Related Items”), Awardee acknowledges that the ultimate liability for all Tax Related Items legally due by Awardee is and remains Awardee’s responsibility and that the Company and/or the Awardee’s actual employer (i) make no representations or undertakings regarding the treatment of any Tax Related Items in connection with any aspect of

3

the SPSAs, including the grant of the SPSAs, the vesting of SPSAs, the conversion of the SPSAs into Common Shares or the receipt of an equivalent cash payment, the subsequent sale of any Common Shares acquired and the receipt of any dividends; and (ii) do not commit to structure the terms of the grant or any aspect of the SPSAs to reduce or eliminate the Awardee’s liability for Tax Related Items.

Prior to the issuance of Common Shares upon vesting of the SPSAs or the distribution of an equivalent cash payment as provided in Section 9(a) above, Awardee shall pay, or make adequate arrangements satisfactory to the Company or to the Awardee’s actual employer (in their sole discretion) to satisfy all withholding obligations of the Company and/or the Awardee’s actual employer. In this regard, Awardee authorizes the Company or the Awardee’s actual employer to withhold all applicable Tax Related Items legally payable by Awardee from Awardee’s wages or other cash compensation payable to Awardee by the Company or the Awardee’s actual employer. Alternatively, or in addition, if permissible under applicable law, the Company or the Awardee’s actual employer may, in their sole discretion, (i) sell or arrange for the sale of Common Shares to be issued upon the vesting of SPSAs to satisfy the withholding obligation, and/or (ii) withhold in Common Shares, provided that the Company and the Awardee’s actual employer shall withhold only the amount of shares necessary to satisfy the minimum withholding amount. Awardee shall pay to the Company or to the Awardee’s actual employer any amount of Tax Related Items that the Company or the Awardee’s actual employer may be required to withhold as a result of Awardee’s receipt of SPSAs, the vesting of SPSAs, or the conversion of vested SPSAs to Common Shares that cannot be satisfied by the means described in this paragraph. Except where applicable legal or regulatory provisions prohibit, the standard process for the payment of an Awardee’s Tax Related Items shall be for the Company or the Awardee’s actual employer to withhold in Common Shares only to the amount of shares necessary to satisfy the minimum withholding amount. The Company may refuse to deliver Common Shares to Awardee if Awardee fails to comply with Awardee’s obligation in connection with the Tax Related Items as described in this Section 9.

(c) In lieu of issuing fractional Common Shares, on the vesting of a fraction of a SPSA, the Company shall round the shares to the nearest whole share and any such share which represents a fraction of a SPSA will be included in a subsequent vest date.

(d) Until the distribution to Awardee of the Common Shares in respect of the vested SPSAs is evidenced by a stock certificate, appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company, or other appropriate means, Awardee shall have no right to vote or receive dividends or any other rights as a shareholder with respect to such Common Shares, notwithstanding the vesting of SPSAs. The Company shall cause such distribution to Awardee to occur promptly upon the vesting of SPSAs. No adjustment will be made for a dividend or other right for which the record date is prior to the date Awardee is recorded as the owner of the Common Shares, except as provided in Section 14 of the Plan.

(e) By accepting the Award of SPSAs evidenced by this Award Agreement, Awardee agrees not to sell any of the Common Shares received upon account of vested SPSAs at a time when applicable laws or Company policies prohibit a sale. This restriction shall apply so long as Awardee is an Employee, Consultant or outside director of the Company or a Subsidiary of the Company.

10. Non-Transferability of SPSAs. Awardee’s right in the SPSAs awarded under this Award Agreement and any interest therein may not be sold, pledged, assigned, hypothecated, transferred, or disposed of in any manner, other than by will or by the laws of descent or distribution. SPSAs shall not be subject to execution, attachment or other process.

11. Acknowledgment of Nature of Plan and SPSAs. In accepting the Award, Awardee acknowledges that:

4

(a) the Plan is established voluntarily by the Company, it is discretionary in nature and may be modified, amended, suspended or terminated by the Company at any time, as provided in the Plan;

(b) the Award of SPSAs is voluntary and occasional and does not create any contractual or other right to receive future awards of SPSAs, or benefits in lieu of SPSAs even if SPSAs have been awarded repeatedly in the past;

(c) all decisions with respect to future awards, if any, will be at the sole discretion of the Company;

(d) Awardee’s participation in the Plan is voluntary;

(e) the future value of the underlying Common Shares is unknown and cannot be predicted with certainty;

(f) if Awardee receives Common Shares, the value of such Common Shares acquired on vesting of SPSAs may increase or decrease in value;

(g) notwithstanding any terms or conditions of the Plan to the contrary and consistent with Section 5 above, in the event of termination of Awardee’s employment (whether or not in breach of applicable laws), Awardee’s right to receive SPSAs and vest under the Plan, if any, will terminate effective as of the date that Awardee is no longer actively employed and will not be extended by any notice period mandated under applicable law; furthermore, in the event of termination of employment (whether or not in breach of applicable laws), Awardee’s right to receive Common Shares pursuant to the SPSAs after termination of employment, if any, will be calculated as of the date of termination of Awardee’s active employment and will not be extended by any notice period mandated under applicable law; the Board of Directors or Committee shall have the exclusive discretion to determine when Awardee is no longer actively employed for purposes of the award of SPSAs;

(h) Awardee acknowledges and agrees that, regardless of whether Awardee is terminated with or without cause, notice or pre-termination procedure or whether Awardee asserts or prevails on a claim that Awardee’s employment was terminable only for cause or only with notice or pre-termination procedure, Awardee has no right to, and will not bring any legal claim or action for, (a) any damages for any portion of the SPSAs that have been vested and converted into Common Shares, or (b) termination of any unvested SPSAs under this Award Agreement; and

(i) Awardee promises never to pursue any claim relating to the Plan or this Award Agreement before (1) notifying the Company in writing of Awardee’s claim within thirty (30) days after Awardee first knows or should have known the facts on which the claim is based, (2) if requested by the Company to do so within thirty (30) days after so notifying the Company, participating in good faith in any nonbinding dispute resolution procedure the Company prescribes, and (3) keeping Awardee’s claim completely confidential, except to the minimum extent needed to pursue the claim, until all the requirements of this subsection have been satisfied. The dispute resolution procedure the Company prescribes shall be paid for by the Company and must be reasonably capable of being completed within ninety (90) days after the Awardee is requested to use it. Awardee agrees that his or her right to any awards, stock or amounts under this Award Agreement are conditioned on Awardee’s strictly complying with the requirements of this subsection.

12. Data Privacy Notice and Consent. Awardee hereby explicitly and unambiguously consents to the collection, use and transfer, in electronic or other form, of Awardee’s personal data as described in this Award Agreement by and among, as applicable, Awardee’s employer, the Company, its Subsidiaries and its affiliates for the exclusive purpose of implementing, administering and managing Awardee’s participation in the Plan.

5

Awardee understands that the Company and Awardee’s employer may hold certain personal information about Awardee, including, but not limited to, Awardee’s name, home address and telephone number, date of birth, social insurance number or other identification number, salary, nationality, job title, any shares of stock or directorships held in the Company, details of all SPSAs or any other entitlement to Common Shares awarded, canceled, vested, unvested or outstanding in Awardee’s favor, for the purpose of implementing, administering and managing the Plan (“Data”). Awardee understands that Data may be transferred to any third parties assisting in the implementation, administration and management of the Plan, that these recipients may be located in Awardee’s country, or elsewhere, and that the recipient’s country may have different data privacy laws and protections than Awardee’s country. Awardee understands that Awardee may, to the extent required by local law, request a list with the names and addresses of any potential recipients of the Data by contacting Awardee’s local human resources representative. Awardee authorizes the recipients to receive, possess, use, retain and transfer the Data, in electronic or other form, for the purposes of implementing, administering and managing Awardee’s participation in the Plan, including any requisite transfer of such Data as may be required to a broker, escrow agent or other third party with whom the Common Shares received upon vesting of the SPSAs may be deposited. Awardee understands that Data will be held only as long as is necessary to implement, administer and manage Awardee’s participation in the Plan. Awardee understands that Awardee may to the extent required by local law, at any time, view Data, request additional information about the storage and processing of Data, require any necessary amendments to Data or refuse or withdraw the consents herein, in any case without cost, by contacting in writing Awardee’s local human resources representative. Awardee understands that refusal or withdrawal of consent may affect Awardee’s ability to participate in the Plan. For more information on the consequences of Awardee’s refusal to consent or withdrawal of consent, Awardee understands that Awardee may contact Awardee’s local human resources representative.

13. No Employment Right; Effect of Relocation Outside U.S.A. Awardee acknowledges that neither the fact of this Award of SPSAs nor any provision of this Award Agreement or the Plan or the policies adopted pursuant to the Plan shall confer upon Awardee any right with respect to employment or continuation of current employment with the Company or with the Awardee’s actual employer, or to employment that is not terminable at will. Awardee further acknowledges and agrees that neither the Plan nor this Award of SPSAs makes Awardee’s employment with the Company or the Awardee’s actual employer for any minimum or fixed period, and that such employment is subject to the mutual consent of Awardee and the Company or the Awardee’s actual employer, and may be terminated by either Awardee or the Company or the Awardee’s actual employer at any time, for any reason or no reason, with or without cause or notice or any kind of pre- or post-termination warning, discipline or procedure. In the event Awardee’s employment with the Company is relocated outside the United States, this Stock Award Agreement shall be amended to include such provisions regarding employment rights with respect to the SPSAs as the Company, in its sole discretion, has determined to be appropriate for inclusion in SPSA Award Agreements for the location to which Awardee relocates.

14. Administration. The authority to manage and control the operation and administration of this Award Agreement shall be vested in the Committee (as such term is defined in Section 2(f) of the Plan), and the Committee shall have all powers and discretion with respect to this Award Agreement as it has with respect to the Plan. Any interpretation of the Award Agreement by the Committee and any decision made by the Committee with respect to the Award Agreement shall be final and binding on all parties.

6

15. Plan Governs. Notwithstanding anything in this Award Agreement to the contrary, the terms of this Award Agreement shall be subject to the terms of the Plan, and this Award Agreement is subject to all interpretations, amendments, rules and regulations promulgated by the Committee from time to time pursuant to the Plan.

16. Notices. Any written notices provided for in this Award Agreement which are sent by mail shall be deemed received three business days after mailing, but not later than the date of actual receipt. Notices shall be directed, if to Awardee, at the Awardee’s address indicated by the Company’s records and, if to the Company, at the Company’s principal executive office.

17. Electronic Delivery. The Company may, in its sole discretion, decide to deliver any documents related to SPSAs awarded under the Plan or future SPSAs that may be awarded under the Plan by electronic means or request Awardee’s consent to participate in the Plan by electronic means. Awardee hereby consents to receive such documents by electronic delivery and agrees to participate in the Plan through an on-line or electronic system established and maintained by the Company or another third party designated by the Company.

18. Acknowledgment. By Awardee’s acceptance as evidenced below, Awardee acknowledges that Awardee has received and has read, understood and accepted all the terms, conditions and restrictions of this Award Agreement, the Plan, and the current policies referenced in Section 3(b) of this Award Agreement. Awardee understands and agrees that this Award Agreement is subject to all the terms, conditions, and restrictions stated in this Award Agreement and in the other documents referenced in the preceding sentence, as the latter may be amended from time to time in the Company’s sole discretion.

19. Board Approval. These SPSAs have been awarded pursuant to the Plan and accordingly this Award of SPSAs is subject to approval by the Committee. If this Award of SPSAs has not already been approved, the Company agrees to submit this Award for approval as soon as practical. If such approval is not obtained, this award is null and void.

20. Governing Law. This Award Agreement shall be governed by the laws of the State of Washington, U.S.A., without regard to Washington laws that might cause other law to govern under applicable principles of conflicts of law. For purposes of litigating any dispute that arises under this Award of SPSAs or this Award Agreement, the parties hereby submit to and consent to the jurisdiction of the State of Washington, and agree that such litigation shall be conducted in the courts of King County, Washington, or the federal courts for the United States for the Western District of Washington, and no other courts, where this Award of SPSAs is made and/or to be performed.

21. Severability. If one or more of the provisions of this Award Agreement shall be held invalid, illegal or unenforceable in any respect, the validity, legality and enforceability of the remaining provisions shall not in any way be affected or impaired thereby and the invalid, illegal or unenforceable provisions shall be deemed null and void; however, to the extent permissible by law, any provisions which could be deemed null and void shall first be construed, interpreted or revised retroactively to permit this Award Agreement to be construed so as to foster the intent of this Award Agreement and the Plan.

22. Complete Award Agreement and Amendment. This Award Agreement (which includes the SPSA Performance Percentage calculations made in accordance with the contents of the tab entitled “SPSA Modeling” on the STOCK@MICROSOFT site and the policies referenced in Section 3(b), each as modified from time to time), the Notice of Receipt of Stock Awards (if any), and the Plan constitute the entire agreement between Awardee and the Company regarding SPSAs. Any prior agreements, commitments or negotiations concerning these SPSAs are superseded. This Award Agreement may be amended only by written agreement of Awardee

7

and the Company, except that the contents of the tab entitled “SPSA Modeling” on the STOCK@MICROSOFT site and the policies referenced in Section 3(b) may be modified by the Company as described in this Award Agreement from time to time. Awardee agrees not to rely on any oral information regarding this Award of SPSAs or any written materials not identified in this Section 22.

EXECUTED the day and year first above written.

MICROSOFT CORPORATION
/s/ KEN DIPIETRO
Ken DiPietro, Vice President, Human Resources

AWARDEE’S ACCEPTANCE:

I have read and fully understood this Award Agreement and, as referenced in Section 18 above, I accept and agree to be bound by all of the terms, conditions and restrictions contained in this Award Agreement and the other documents referenced in it. I intend to express my acceptance of the Award and this Award Agreement by typing my name in the Awardee acceptance window provided in “step 2” of the award acceptance checklist, and I further intend the typing of my name to have the same force and effect in all respects as a handwritten signature.

8

EX-10.12 10 dex1012.htm FORM OF STOCK OPTION AGREEMENT
Form of Stock Option Agreement

Exhibit 10.12

NON-QUALIFIED STOCK OPTION AGREEMENT FOR PURCHASE OF STOCK UNDER THE

2001 STOCK PLAN OF MICROSOFT CORPORATION

Grant Number <<GrantIdentifier>>

1. Grant of Option. For valuable consideration, Microsoft Corporation (the “Company”), in the exercise of its sole discretion, does on <<GrantDate>> hereby grant to <<FirstName>> <<LastName>> (the “Optionee”) the option to purchase <<SharesGrantedQuantity>> shares of the common stock of the Company for a price of $<<OptionPriceAmount>> per share.

2. Vesting Schedule.

(a) The right to exercise this option shall vest as follows: subject to the remaining terms of this Agreement, the right to purchase one-eighth of the shares covered hereby shall vest on <<FirstVestDate>>, and the right to purchase additional one-eighth increments of the shares covered hereby shall vest at six-month intervals thereafter, such that this option becomes fully vested fifty-four (54) months after the date hereof, provided that Optionee remains continuously employed on a full-time basis throughout that period.

(b) THIS OPTION WILL BE AFFECTED, WITH REGARD TO BOTH VESTING SCHEDULE AND TERMINATION, BY LEAVES OF ABSENCE, CHANGES IN THE NUMBER OF HOURS WORKED, PARTIAL DISABILITY, AND OTHER CHANGES IN OPTIONEE’S EMPLOYMENT STATUS. ACCOMPANYING THIS AGREEMENT IS A COPY OF THE COMPANY’S CURRENT POLICIES IN SUCH MATTERS. THESE POLICIES MAY CHANGE FROM TIME TO TIME WITHOUT NOTICE IN THE COMPANY’S SOLE DISCRETION, AND OPTIONEE’S RIGHTS WILL BE GOVERNED BY THE POLICIES IN EFFECT AT THE TIME OF ANY EMPLOYMENT STATUS CHANGE. CONTACT “STOCK” FOR A COPY OF THE MOST CURRENT POLICY STATEMENT AT ANY POINT IN TIME.

3. Expiration Date. This option shall expire ten (10) years from the date hereof.

4. Termination of Optionee’s Status as a Participant. In the event of termination of Optionee’s Continuous Status as a Participant (as such term is defined in the 2001 Stock Plan (the “Plan”)), Optionee may exercise this option to the extent exercisable on the date of termination. Such exercise must occur within three (3) months after the date of such termination (but in no event later than the date of expiration of the term of this option as set forth in Section 3 above). To the extent that Optionee does not exercise this option within the time specified in this Section 4, this option shall terminate.

5. Disability of Optionee. Notwithstanding the provisions of Section 4 above, in the event of termination of Optionee’s Continuous Status as a Participant as a result of total and permanent disability (as such term is defined in the Plan), the Optionee may exercise this option, but only to the extent of the right to exercise that would have accrued had Optionee remained in Continuous Status as a Participant for a period of twelve (12) months after the date on which Optionee ceased working as a result of the total and permanent disability. If Optionee’s disability originally required him or her to take a short-term disability leave which was later converted into long-term disability, then for the purposes of the preceding sentence the date on which Optionee ceased working shall be deemed to be the date of commencement of the short-term disability leave. Such exercise must occur within eighteen (18) months from the date on which Optionee ceased working as a result of the total and permanent disability (but in no event later than the date of expiration of the term of this option as set forth in Section 3 above). To the extent that Optionee does not exercise this option within the time specified in this Section 5, this option shall terminate.

1

6. Death of Optionee. Notwithstanding the provisions of Section 4 above, in the event of the death of Optionee:

(a) if Optionee is, at the time of death, an employee of the Company, this option may be exercised, at any time within twelve (12) months following the date of death (but in no event later than the date of expiration of the term of this option as set forth in Section 3 above), by Optionee’s estate or by a person who acquired the right to exercise this option by bequest or inheritance, but only to the extent of the right to exercise that would have accrued had Optionee continued living and remained in Continuous Status as a Participant for twelve (12) months after the date of death; or

(b) if, at the time of death, this option has not yet expired but Optionee’s Continuous Status as a Participant terminated prior to the date of death, this option may be exercised, at any time within twelve (12) months following the date of death (but in no event later than the date of expiration of the term of this option as set forth in Section 3 above), by Optionee’s estate or by a person who acquired the right to exercise this option by bequest or inheritance, but only to the extent of the right to exercise that had accrued at the date of termination.

(c) To the extent that this option is not exercised by an authorized representative of Optionee within the time specified in this Section 6, this option shall terminate.

7. Value of Unvested Options. In consideration of the grant of this option, Optionee agrees that upon and following termination of Optionee’s Continuous Status as a Participant for any reason, and regardless of whether Optionee is terminated with or without cause, notice, or pre-termination procedure or whether Optionee asserts or prevails on a claim that Optionee’s employment was terminable only for cause or only with notice or pre-termination procedure, any unvested portion of this option shall be deemed to have a value of zero dollars ($0.00).

8. Exercise of Option.

(a) Optionee shall indicate his intention to exercise this option by notifying the Company’s preferred broker(s) electronically, telephonically, or in writing of his intention to do so, indicating the number of shares he intends to purchase. Payment sufficient to cover the aggregate option exercise price and any federal, state, and local taxes required to be withheld by the Company must accompany the notice of exercise, in one of the three acceptable forms listed in the first sentence of Section 8(b) below.

(b) Payment of the option exercise price may be made by cash, by check, or by instructing the broker to promptly deliver to the Company the amount of sale proceeds necessary to pay the aggregate exercise price. If Optionee is an officer of the Company within the meaning of Section 16 of the Securities Exchange Act of 1934 (the “Exchange Act”), he may in addition be allowed to pay all or part of the exercise price with shares of the Company’s common stock which, as of the exercise date, the officer has owned for six (6) months or more. Shares used by officers to pay the exercise price shall be valued at their fair market value on the exercise date.

(c) Prior to the issuance of shares upon exercise of this option, Optionee shall pay any federal, state, and local income and employment tax withholding obligations applicable to such exercise. If Optionee is an officer of the Company within the meaning of Section 16 of the Exchange Act, he may elect to pay such withholding tax obligations by having the Company withhold shares of the Company’s common stock having a value equal to the amount required to be withheld. Such an election shall be made in accordance with Section 11(d) of the Plan.

(d) This option may not be exercised for a fraction of a share.

(e) An exercise of this option shall be deemed to have occurred upon the satisfaction of the requirements of subsections (a), (b), and (c) of this Section 8. Until the issuance (as evidenced by the appropriate entry on the books of the Company or of a duly authorized transfer agent of the Company) of the stock certificate evidencing the shares as to which this option was exercised, no right to vote or receive dividends or any other rights as a stockholder shall exist with respect to such shares, notwithstanding the exercise of this option. The Company shall issue (or cause to be issued) such stock certificate promptly upon exercise of this option. No adjustment will be made for a dividend or other right for which the record date is prior to the date the stock certificate is issued, except as provided in Section 14 of the Plan.

2

9. Non-Transferability of Option. This option may not be sold, pledged, assigned, hypothecated, transferred, or disposed of in any manner other than by will or by the laws of descent or distribution and may be exercised, during the lifetime of Optionee, only by Optionee.

10. No Employment Right. Optionee acknowledges that neither the fact of this option grant nor any provision of this option Agreement or the Plan or the policies adopted pursuant to the Plan shall confer upon Optionee any right with respect to continuation of employment with the Company or to employment that is not terminable at will. Optionee further acknowledges and agrees that Optionee’s employment with the Company is not for any minimum or fixed period, is subject to the mutual consent of Optionee and the Company, and may be terminated by either Optionee or the Company at any time, for any reason or no reason, with or without cause or notice or any kind of pre- or post-termination warning, discipline or procedure.

11. No Right to Damages. Optionee acknowledges and agrees that, regardless of whether Optionee is terminated with or without cause, notice or pre-termination procedure or whether Optionee asserts or prevails on a claim that Optionee’s employment was terminable only for cause or only with notice or pre-termination procedure, Optionee has no right to, and will not bring any legal claim or action for, any damages for (a) having to exercise any vested portion of this option within three (3) months of termination or (b) cancellation of any unvested, or vested but unexercised, portion of this option.

12. Acknowledgment. By Optionee’s acceptance below, Optionee acknowledges that Optionee has received and has read, understood and accepted all the terms, conditions and restrictions of this Agreement, the Plan, and the current policies referenced in paragraph 2(b) of this Agreement. Optionee understands and agrees that this option is subject to all the terms, conditions, and restrictions stated in this Agreement and in the other documents referenced in the preceding sentence, as the latter may be amended from time to time in the Company’s sole discretion.

13. Board Approval. This option has been granted pursuant to the Plan and accordingly is subject to approval by an authorized committee of the Board of Directors. If this option has not already been approved the Company agrees to submit this grant for approval as soon as practical.

14. Governing Law. This option shall be governed by the laws of the state of Washington, USA. EXECUTED at Redmond, Washington, the day and year first above written.

MICROSOFT CORPORATION
/s/ KEN DIPIETRO
Ken DiPietro, Vice President, Human Resources

OPTIONEE’S ACCEPTANCE:

I have read and fully understood this option Agreement and, as referenced in paragraph 12 above, I accept and agree to be bound by all of the terms, conditions and restrictions contained in this option Agreement and the other documents referenced in it. I intend to express my acceptance of the option and this Agreement by typing my name in the optionee acceptance window provided in “step 2” of the grant acceptance checklist, and I further intend the typing of my name to have the same force and effect in all respects as a handwritten signature.

3

EX-10.13 11 dex1013.htm FORM OF STOCK OPTION AGREEMENT FOR NON-EMPLOYEE DIRECTORS
Form of Stock Option Agreement for Non-Employee Directors

Exhibit 10.13

MICROSOFT CORPORATION

NON-QUALIFIED STOCK OPTION FOR PURCHASE OF STOCK

(Granted Under the Microsoft Corporation 1999 Stock Option Plan For Non-Employee Directors)

Grant Number «GrantNumber»

FOR VALUABLE CONSIDERATION, Microsoft Corporation (the “company”), does on, «GrantDate» hereby grant to «FirstName» «Name» (the “optionee”), the option to purchase «Shares» shares of the Common Stock of the Company (the “Option Shares”) for a price of «OptionPrice» per share, subject to the following terms and conditions:

1. Upon acceptance of said grant, the Optionee agrees to continue to serve as director of the Company for the remainder of the term for which Optionee was elected.

2. Vesting Schedule: (a) The right to exercise this option shall vest as follows: subject to the remaining terms of this Agreement, the right to purchase one-eighth of the shares covered hereby shall vest on «VestDate», and the right to purchase additional one-eighth increments of the shares covered hereby shall vest at six-month intervals thereafter, such that this option becomes fully vested fifty-four (54) months.

3. This option shall expire ten (10) years from the date of the granting hereof, but shall be subject to earlier termination as follows:

a. In the event of the death of Optionee, the option granted herein may be exercised, to the extent exercisable on the date of death pursuant to paragraph 2 above, by the estate of the Optionee, or by any person or persons who acquired the right to exercise such option by will or by the laws of descent and distribution. The option must be exercised within the earlier of (i) one hundred eighty (180) days after the date of death of Optionee or (ii) the date on which the option expires by its terms.

b. In the event an Optionee ceases to be director of the Corporation, other than by reason of his or her death, the options granted herein may be exercised, to the extent exercisable on the date such person ceases to be a director, within the earlier of (i) one hundred eighty (180) days after the date such person ceases to be a director and (ii) the date on which the option expires by its terms.

1

4. The Change of Control provisions on Section 9 of the Microsoft Corporation 1999 Stock Plan for Non-Employee Directors (the “Plan”) shall, in appropriate circumstances, modify the application of paragraphs 2 and 3 above.

5. The Optionee shall indicate his intention to exercise the option hereby granted by giving written notice, signed by the Optionee or an authorized representative of Optionee, to the Company, stating the number of shares with respect to which the option is being exercised, accompanied by payment in full for such shares, which payment may be in whole or in part in shares of the common stock of the Company already owned by the optionee or optionee’s representative, valued at fair market value on the date of payment (as determined pursuant to Section 7(c) of the Plan).

6. This option is not assignable or transferrable by Optionee otherwise than by will or laws of descent and distribution, and said option shall be exercisable during the lifetime of Optionee only by him or her; provided that the Board may permit further transferability, on a general or specific basis, and may impose conditions and limitations on any permitted transferability.

7. Neither the optionee nor his or her successors in interest shall have any rights as a stockholder of the Company with respect to any shares granted herein until the Optionee or his or her successors become a holder of record of such shares.

8. In the event that the outstanding shares of the common stock of the Company are changed into or exchanged for a different number or kind of shares or other securities of the Company or of another corporation by reason of any reorganization, merger, consolidation, recapitalization, reclassification, stock split-up, combination of shares, or dividend payable in capital stock, appropriate adjustment shall be made in the number and kind of shares subject to any unexercised portion of the option granted herein such that the proportionate interest of Optionee shall be maintained as before the occurrence of such event. Such adjustment shall be made without change in the total price applicable to the unexercised portion of this option, but with a corresponding adjustment in the option price per share.

2

9. The Company may delay the issuance of shares covered by the exercise of this option and the delivery of a certificate for shares purchased pursuant to this option until one of the following conditions shall be satisfied:

a. The shares being purchased under this option are at the time of issue or transfer effectively registered under applicable federal securities laws now in force or hereafter amended; or

b. Counsel for the Company shall have given an opinion, which opinion shall not be unreasonably conditioned or withheld, that the shares are exempt from registration under applicable federal securities laws now in force or hereafter amended.

The company shall use its best efforts to bring about compliance with the above conditions within a reasonable time, except that the Company shall be under no obligation to cause a registration statement or a post-effective amendment to any registration statement to be prepared at its expense solely for the purpose of covering option shares granted hereunder.

10. Unless the Shares granted hereunder have been effectively registered under the Securities Act of 1933, as now in force or hereafter amended, the Company shall be under no obligation to issue or transfer any shares covered by this option unless the Optionee or Optionee’s successors in accordance with section 5 above, shall give a written representation and undertaking to the company and upon which, in the opinion of such counsel, the Company may reasonable rely that Optionee is acquiring the shares for his or her own account as an investment and not with the view to, or for sale in connection with, the distribution of such shares, and that Optionee will make no transfer of the same except in compliance with any rules and regulations in force at the time of such transfer under the Securities Act of 1933, or any other applicable law, and that if shares are issued or transferred without such registration, a legend to this effect may be placed upon the certificate representing the shares.

11. This option is granted pursuant to the Plan and the terms of the Plan are controlling.

EXECUTED at Redmond, Washington, the day and year first above written.

3

EX-21 12 dex21.htm SUBSIDIARIES OF REGISTRANT
Subsidiaries of Registrant

EXHIBIT 21

SUBSIDIARIES OF THE COMPANY

The following is a list of subsidiaries of the Company as of June 30, 2004, omitting some subsidiaries which, considered in the aggregate, would not constitute a significant subsidiary.

NAME |  | WHERE ORGANIZED
Microsoft Global Finance Limited |  | Ireland
Microsoft General Management Company |  | Nevada, USA
Microsoft Capital Group, L.P. |  | Nevada, USA
Microsoft Ireland Operations Limited |  | Ireland
Microsoft Licensing, GP |  | Nevada, USA
Microsoft T-Holdings, Inc. |  | Nevada, USA
Round Island One Limited |  | Ireland

EX-23 13 dex23.htm CONSENT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM
Consent of Independent Registered Public Accounting Firm

Exhibit 23

CONSENT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM

We consent to the incorporation by reference in Registration Statement Numbers 333-109185 (Microsoft Caribbean 1165(e) Retirement Plan & Microsoft Puerto Rico, Inc. 1165(e) Savings Plan), 33-51583 (Microsoft Corporation 1991 Stock Option Plan), 333-16665 (Microsoft Corporation 1997 Employee Stock Purchase Plan), 333-75243 (Microsoft Corporation Savings Plus 401 (k) Plan), 333-91755 (Microsoft Corporation 1999 Stock Option Plan for Non-Employee Directors), 333-52852 (Microsoft Corporation 2001 Stock Plan), 333-102240 (Microsoft Corp 2003 Employee Stock Purchase Plan), 33-36498 (Microsoft Corporation Stock Option Plan for Non-Employee Directors), 33-45617 (Microsoft Corporation Stock Option Plan for Consultants and Advisors) of Microsoft Corporation on Forms S-8 and 333-43449, 333-110107, 333-108843 of Microsoft Corporation on Forms S-3 of our report dated August 24, 2004 (which report expresses an unqualified opinion and includes an explanatory paragraph relating to the adoption of Statement of Financial Accounting Standards No. 123, Accounting for Stock-Based Compensation) appearing in this Annual Report on Form 10-K of Microsoft Corporation for the year ended June 30, 2004.

DELOITTE & TOUCHE LLP

Seattle, Washington

August 30, 2004

EX-31.1 14 dex311.htm CERTIFICATIONS OF CEO PURSUANT TO SECTION 302 OF THE SARBANES-OXLEY ACT
Certifications of CEO Pursuant to Section 302 of the Sarbanes-Oxley Act

Exhibit 31.1

CERTIFICATIONS

I, Steven A. Ballmer, certify that:

1. I have reviewed this annual report on Form 10-K of Microsoft Corporation;

2. Based on my knowledge, this report does not contain any untrue statement of a material fact or omit to state a material fact necessary to make the statements made, in light of the circumstances under which such statements were made, not misleading with respect to the period covered by this report;

3. Based on my knowledge, the financial statements, and other financial information included in this report, fairly present in all material respects the financial condition, results of operations and cash flows of the registrant as of, and for, the periods presented in this report;

4. The registrant’s other certifying officer and I are responsible for establishing and maintaining disclosure controls and procedures (as defined in Exchange Act Rules 13a-15(e) and 15d-15(e)) for the registrant and have:

a) Designed such disclosure controls and procedures, or caused such disclosure controls and procedures to be designed under our supervision, to ensure that material information relating to the registrant, including its consolidated subsidiaries, is made known to us by others within those entities, particularly during the period in which this report is being prepared;

b) Evaluated the effectiveness of the registrant’s disclosure controls and procedures and presented in this report our conclusions about the effectiveness of the disclosure controls and procedures, as of the end of the period covered by this report based on such evaluation; and

c) Disclosed in this report any change in the registrant’s internal control over financial reporting that occurred during the registrant’s most recent fiscal quarter (the registrant’s fourth fiscal quarter in the case of an annual report) that has materially affected, or is reasonably likely to materially affect, the registrant’s internal control over financial reporting; and

5. The registrant’s other certifying officer and I have disclosed, based on our most recent evaluation of internal control over financial reporting, to the registrant’s auditors and the audit committee of registrant’s board of directors (or persons performing the equivalent functions):

a) All significant deficiencies and material weaknesses in the design or operation of internal control over financial reporting which are reasonably likely to adversely affect the registrant’s ability to record, process, summarize and report financial information; and

b) Any fraud, whether or not material, that involves management or other employees who have a significant role in the registrant’s internal control over financial reporting.

September 1, 2004

/s/ Steven A. Ballmer
Steven A. Ballmer Chief Executive Officer

EX-31.2 15 dex312.htm CERTIFICATIONS OF CFO PURSUANT TO SECTION 302 OF THE SARBANES-OXLEY ACT
Certifications of CFO Pursuant to Section 302 of the Sarbanes-Oxley Act

Exhibit 31.2

CERTIFICATIONS

I, John G. Connors, certify that:

1. I have reviewed this annual report on Form 10-K of Microsoft Corporation;

2. Based on my knowledge, this report does not contain any untrue statement of a material fact or omit to state a material fact necessary to make the statements made, in light of the circumstances under which such statements were made, not misleading with respect to the period covered by this report;

3. Based on my knowledge, the financial statements, and other financial information included in this report, fairly present in all material respects the financial condition, results of operations and cash flows of the registrant as of, and for, the periods presented in this report;

4. The registrant’s other certifying officer and I are responsible for establishing and maintaining disclosure controls and procedures (as defined in Exchange Act Rules 13a-15(e) and 15d-15(e)) for the registrant and have:

a) Designed such disclosure controls and procedures, or caused such disclosure controls and procedures to be designed under our supervision, to ensure that material information relating to the registrant, including its consolidated subsidiaries, is made known to us by others within those entities, particularly during the period in which this report is being prepared;

b) Evaluated the effectiveness of the registrant’s disclosure controls and procedures and presented in this report our conclusions about the effectiveness of the disclosure controls and procedures, as of the end of the period covered by this report based on such evaluation; and

c) Disclosed in this report any change in the registrant’s internal control over financial reporting that occurred during the registrant’s most recent fiscal quarter (the registrant’s fourth fiscal quarter in the case of an annual report) that has materially affected, or is reasonably likely to materially affect, the registrant’s internal control over financial reporting; and

5. The registrant’s other certifying officer and I have disclosed, based on our most recent evaluation of internal control over financial reporting, to the registrant’s auditors and the audit committee of registrant’s board of directors (or persons performing the equivalent functions):

a) All significant deficiencies and material weaknesses in the design or operation of internal control over financial reporting which are reasonably likely to adversely affect the registrant’s ability to record, process, summarize and report financial information; and

b) Any fraud, whether or not material, that involves management or other employees who have a significant role in the registrant’s internal control over financial reporting.

September 1, 2004

/s/ John G. Connors
John G. Connors Chief Financial Officer

EX-32 16 dex32.htm CERTIFICATIONS OF CEO AND CFO PURSUANT TO SECTION 906 OF THE SARBANES-OXLEY ACT
Certifications of CEO and CFO Pursuant to Section 906 of the Sarbanes-Oxley Act

Exhibit 32

CERTIFICATIONS PURSUANT TO

SECTION 906 OF THE SARBANES-OXLEY ACT OF 2002

(18 U.S.C. SECTION 1350)

In connection with the Annual Report of Microsoft Corporation, a Washington corporation (the “Company”), on Form 10-K for the year ended June 30, 2004, as filed with the Securities and Exchange Commission (the “Report”), Steven A. Ballmer, Chief Executive Officer of the Company and John G. Connors, Chief Financial Officer of the Company, respectively, do each hereby certify, pursuant to § 906 of the Sarbanes-Oxley Act of 2002 (18 U.S.C. § 1350), that to his knowledge:

(1) The Report fully complies with the requirements of section 13(a) or 15(d) of the Securities Exchange Act of 1934; and

(2) The information contained in the Report fairly presents, in all material respects, the financial condition and result of operations of the Company.

/s/ Steven A. Ballmer
Steven A. Ballmer Chief Executive Officer September 1, 2004

/s/ John G. Connors
John G. Connors Chief Financial Officer September 1, 2004

[A signed original of this written statement required by Section 906 has been provided to Microsoft Corporation and will be retained by Microsoft Corporation and furnished to the Securities and Exchange Commission or its staff upon request.]

-----END PRIVACY-ENHANCED MESSAGE-----